@@ -81,6 +81,7 @@ var searchData=
   ['k_5fr7',['K_R7',['../kanjiCode_8h.html#a78588f651372b3694647d15276a90bdd',1,'kanjiCode.h']]],
   ['k_5fr8',['K_R8',['../kanjiCode_8h.html#a6b6724a5a4814e97ae15ecb9db45aa63',1,'kanjiCode.h']]],
   ['k_5fr9',['K_R9',['../kanjiCode_8h.html#ae1ef091a3c74b571b352322a39c4c368',1,'kanjiCode.h']]],
+  ['k_5fresign',['K_RESIGN',['../kanjiCode_8h.html#a44f55ab47deaebd9807729aaa9e9bc0f',1,'kanjiCode.h']]],
   ['k_5frook',['K_ROOK',['../kanjiCode_8h.html#a56b760bcf63fc41626644e430af31512',1,'kanjiCode.h']]],
   ['k_5frook_5fr',['K_ROOK_R',['../kanjiCode_8h.html#ad303d5c73847951130dd4429130f0b29',1,'kanjiCode.h']]],
   ['k_5fsei',['K_SEI',['../kanjiCode_8h.html#a45932aeb502fa80edcc42d6edf58e5e6',1,'kanjiCode.h']]],
@@ -149,7 +150,7 @@ var searchData=
   ['ki2moves',['ki2moves',['../classosl_1_1game__playing_1_1UsiResponse.html#a1f04f6827269872912788b7713a5be3c',1,'osl::game_playing::UsiResponse']]],
   ['kifcharacters',['KIFCharacters',['../structosl_1_1record_1_1KIFCharacters.html',1,'osl::record']]],
   ['kifu_2dto_2dmyshogi_2ecc',['kifu-to-myshogi.cc',['../kifu-to-myshogi_8cc.html',1,'']]],
-  ['killer',['Killer',['../classosl_1_1search_1_1AlphaBeta3.html#a1cd6db8daa5d6a3faa04681a697ef332af0de70ae865c05046590342560966412',1,'osl::search::AlphaBeta3::Killer()'],['../structosl_1_1search_1_1AlphaBeta2Common.html#ad23329d06ae485b6b22ec9c4c6054ef2a0aff1d776cb51e5bba5a3737c41453d9',1,'osl::search::AlphaBeta2Common::KILLER()']]],
+  ['killer',['KILLER',['../structosl_1_1search_1_1AlphaBeta2Common.html#ad23329d06ae485b6b22ec9c4c6054ef2a0aff1d776cb51e5bba5a3737c41453d9',1,'osl::search::AlphaBeta2Common::KILLER()'],['../classosl_1_1search_1_1AlphaBeta3.html#a1cd6db8daa5d6a3faa04681a697ef332af0de70ae865c05046590342560966412',1,'osl::search::AlphaBeta3::Killer()']]],
   ['killer_5fmoves',['killer_moves',['../classosl_1_1search_1_1BigramKillerMove.html#a6d5892c43456c5bd037bfe12315cfcc9',1,'osl::search::BigramKillerMove::killer_moves()'],['../classosl_1_1search_1_1KillerMoveTable.html#a2d7c5e5ac7c9243219bf1f13c9d77f61',1,'osl::search::KillerMoveTable::killer_moves()'],['../structosl_1_1search_1_1SearchState2Shared.html#ad2ed4163722cea8f9cdb6e4d008ab1a8',1,'osl::search::SearchState2Shared::killer_moves()']]],
   ['killer_5ft',['killer_t',['../structosl_1_1search_1_1AlphaBeta2Common.html#a82cabaae34a5cfd0b1e5b25a9f166eb7',1,'osl::search::AlphaBeta2Common']]],
   ['killermove',['KillerMove',['../structosl_1_1search_1_1RealizationProbability.html#a2a9770a8727567f3c14b02522c386c63a082c5d80f32d18165d4a47169766b2fe',1,'osl::search::RealizationProbability::KillerMove()'],['../structosl_1_1search_1_1FullWidthMoveProbability.html#ab54e4d7c9a032716d6d17f53e7b52bc6a557ebd4b753ec6290f29a15ca0a26783',1,'osl::search::FullWidthMoveProbability::KillerMove()']]],
@@ -185,9 +186,9 @@ var searchData=
   ['king25effectcountcombinationy',['King25EffectCountCombinationY',['../classosl_1_1eval_1_1ml_1_1King25EffectCountCombinationY.html',1,'osl::eval::ml']]],
   ['king25effectdefense',['King25EffectDefense',['../classosl_1_1eval_1_1ml_1_1King25EffectDefense.html',1,'osl::eval::ml']]],
   ['king25effecteach',['King25EffectEach',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
-  ['king25effecteach_3c_200_20_3e',['King25EffectEach< 0 >',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
-  ['king25effecteach_3c_201_20_3e',['King25EffectEach< 1 >',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
-  ['king25effecteach_3c_202_20_3e',['King25EffectEach< 2 >',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
+  ['king25effecteach_3c_200_20_3e',['King25EffectEach&lt; 0 &gt;',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
+  ['king25effecteach_3c_201_20_3e',['King25EffectEach&lt; 1 &gt;',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
+  ['king25effecteach_3c_202_20_3e',['King25EffectEach&lt; 2 &gt;',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
   ['king25effecteachboth',['King25EffectEachBoth',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBoth.html',1,'osl::eval::ml']]],
   ['king25effecteachbothending',['King25EffectEachBothEnding',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBoth.html#a3b28686e57cd92bcd05266473ef09d45',1,'osl::eval::ml::King25EffectEachBoth']]],
   ['king25effecteachbothending',['King25EffectEachBothEnding',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBothEnding.html',1,'osl::eval::ml']]],
@@ -211,8 +212,8 @@ var searchData=
   ['king25effectyattack',['King25EffectYAttack',['../classosl_1_1eval_1_1ml_1_1King25EffectYAttack.html',1,'osl::eval::ml']]],
   ['king25effectydefense',['King25EffectYDefense',['../classosl_1_1eval_1_1ml_1_1King25EffectYDefense.html',1,'osl::eval::ml']]],
   ['king25emptyabs',['King25EmptyAbs',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbs.html',1,'osl::eval::ml']]],
-  ['king25emptyabs_3c_20false_20_3e',['King25EmptyAbs< false >',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbs.html',1,'osl::eval::ml']]],
-  ['king25emptyabs_3c_20true_20_3e',['King25EmptyAbs< true >',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbs.html',1,'osl::eval::ml']]],
+  ['king25emptyabs_3c_20false_20_3e',['King25EmptyAbs&lt; false &gt;',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbs.html',1,'osl::eval::ml']]],
+  ['king25emptyabs_3c_20true_20_3e',['King25EmptyAbs&lt; true &gt;',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbs.html',1,'osl::eval::ml']]],
   ['king25emptyabsending',['King25EmptyAbsEnding',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbsEnding.html',1,'osl::eval::ml']]],
   ['king25emptyabsopening',['King25EmptyAbsOpening',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbsOpening.html',1,'osl::eval::ml']]],
   ['king25emptysquarenoeffect',['King25EmptySquareNoEffect',['../structosl_1_1eval_1_1ml_1_1King25EmptySquareNoEffect.html',1,'osl::eval::ml']]],
@@ -236,15 +237,15 @@ var searchData=
   ['king8effectall',['King8EffectAll',['../classosl_1_1eval_1_1ml_1_1King8EffectAll.html',1,'osl::eval::ml']]],
   ['king8effectbase',['King8EffectBase',['../classosl_1_1eval_1_1ml_1_1King8EffectBase.html',1,'osl::eval::ml']]],
   ['king8effectdefensesquare',['King8EffectDefenseSquare',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquare.html',1,'osl::eval::ml']]],
-  ['king8effectdefensesquare_3c_20false_20_3e',['King8EffectDefenseSquare< false >',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquare.html',1,'osl::eval::ml']]],
-  ['king8effectdefensesquare_3c_20true_20_3e',['King8EffectDefenseSquare< true >',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquare.html',1,'osl::eval::ml']]],
+  ['king8effectdefensesquare_3c_20false_20_3e',['King8EffectDefenseSquare&lt; false &gt;',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquare.html',1,'osl::eval::ml']]],
+  ['king8effectdefensesquare_3c_20true_20_3e',['King8EffectDefenseSquare&lt; true &gt;',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquare.html',1,'osl::eval::ml']]],
   ['king8effectdefensesquareboth',['King8EffectDefenseSquareBoth',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquareBoth.html',1,'osl::eval::ml']]],
   ['king8effectdefensesquareboth',['King8EffectDefenseSquareBoth',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquare.html#a505fbfc155640878720e12595b4f858c',1,'osl::eval::ml::King8EffectDefenseSquare']]],
   ['king8effectdefensesquareending',['King8EffectDefenseSquareEnding',['../structosl_1_1eval_1_1ml_1_1King8EffectDefenseSquareEnding.html',1,'osl::eval::ml']]],
   ['king8effectdefensesquareopening',['King8EffectDefenseSquareOpening',['../structosl_1_1eval_1_1ml_1_1King8EffectDefenseSquareOpening.html',1,'osl::eval::ml']]],
   ['king8effectemptysquare',['King8EffectEmptySquare',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquare.html',1,'osl::eval::ml']]],
-  ['king8effectemptysquare_3c_20false_20_3e',['King8EffectEmptySquare< false >',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquare.html',1,'osl::eval::ml']]],
-  ['king8effectemptysquare_3c_20true_20_3e',['King8EffectEmptySquare< true >',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquare.html',1,'osl::eval::ml']]],
+  ['king8effectemptysquare_3c_20false_20_3e',['King8EffectEmptySquare&lt; false &gt;',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquare.html',1,'osl::eval::ml']]],
+  ['king8effectemptysquare_3c_20true_20_3e',['King8EffectEmptySquare&lt; true &gt;',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquare.html',1,'osl::eval::ml']]],
   ['king8effectemptysquareboth',['King8EffectEmptySquareBoth',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquareBoth.html',1,'osl::eval::ml']]],
   ['king8effectemptysquareboth',['King8EffectEmptySquareBoth',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquare.html#aefd3630b7ea5ff0a479e55ae9e0ec6a1',1,'osl::eval::ml::King8EffectEmptySquare']]],
   ['king8effectemptysquareending',['King8EffectEmptySquareEnding',['../structosl_1_1eval_1_1ml_1_1King8EffectEmptySquareEnding.html',1,'osl::eval::ml']]],
@@ -281,15 +282,15 @@ var searchData=
   ['kingescapegroup',['KingEscapeGroup',['../classosl_1_1rating_1_1KingEscapeGroup.html',1,'osl::rating']]],
   ['kingescapegroup',['KingEscapeGroup',['../classosl_1_1rating_1_1KingEscapeGroup.html#ab20fe464ab96d71b17c13ddffb31e233',1,'osl::rating::KingEscapeGroup']]],
   ['kingindex',['kingIndex',['../classosl_1_1eval_1_1endgame_1_1KingPieceTable.html#aa6b8db3d022f371d2b0eb8b5255b9231',1,'osl::eval::endgame::KingPieceTable']]],
-  ['kingmobility',['KingMobility',['../classosl_1_1mobility_1_1KingMobility.html',1,'osl::mobility']]],
   ['kingmobility',['KingMobility',['../classosl_1_1eval_1_1ml_1_1KingMobility.html',1,'osl::eval::ml']]],
+  ['kingmobility',['KingMobility',['../classosl_1_1mobility_1_1KingMobility.html',1,'osl::mobility']]],
   ['kingmobility',['KingMobility',['../classosl_1_1mobility_1_1KingMobility.html#aea14679aab6ec2b6be8a8969fc58e3fa',1,'osl::mobility::KingMobility']]],
   ['kingmobility_2eh',['kingMobility.h',['../kingMobility_8h.html',1,'']]],
   ['kingmobilityabs',['kingMobilityAbs',['../classosl_1_1state_1_1NumEffectState.html#a8058d0b40f4d6e381d9c09f2404f8a4e',1,'osl::state::NumEffectState']]],
   ['kingmobilityofplayer',['kingMobilityOfPlayer',['../classosl_1_1state_1_1NumEffectState.html#a65bea914a85d99f148a9dab90e651317',1,'osl::state::NumEffectState']]],
   ['kingmobilitysum',['KingMobilitySum',['../classosl_1_1eval_1_1ml_1_1KingMobilitySum.html',1,'osl::eval::ml']]],
-  ['kingmobilitywithbishop',['KingMobilityWithBishop',['../classosl_1_1eval_1_1ml_1_1KingMobilityWithBishop.html',1,'osl::eval::ml']]],
   ['kingmobilitywithbishop',['KingMobilityWithBishop',['../classosl_1_1eval_1_1ml_1_1KingMobility.html#a2f56838bb15486e90651c424edb53aa4',1,'osl::eval::ml::KingMobility']]],
+  ['kingmobilitywithbishop',['KingMobilityWithBishop',['../classosl_1_1eval_1_1ml_1_1KingMobilityWithBishop.html',1,'osl::eval::ml']]],
   ['kingmobilitywithrook',['KingMobilityWithRook',['../classosl_1_1eval_1_1ml_1_1KingMobilityWithRook.html',1,'osl::eval::ml']]],
   ['kingmobilitywithrook',['KingMobilityWithRook',['../classosl_1_1eval_1_1ml_1_1KingMobility.html#af3c9ed0005e6444e0e44d2680821fd37',1,'osl::eval::ml::KingMobility']]],
   ['kingmovebase',['KingMoveBase',['../classosl_1_1move__probability_1_1BreakThreatmate.html#a11d13e9c16f4109ded2564591c40b799ac932adfce9292a358136aa87d3eff303',1,'osl::move_probability::BreakThreatmate']]],
@@ -327,8 +328,8 @@ var searchData=
   ['kingxblockedboth',['KingXBlockedBoth',['../classosl_1_1eval_1_1ml_1_1KingXBlocked.html#a0d4ff604a4273246c7e2ab5c56891b93',1,'osl::eval::ml::KingXBlocked::KingXBlockedBoth()'],['../classosl_1_1eval_1_1ml_1_1KingXBlockedY.html#a0d4ff604a4273246c7e2ab5c56891b93',1,'osl::eval::ml::KingXBlockedY::KingXBlockedBoth()']]],
   ['kingxblockedboth',['KingXBlockedBoth',['../classosl_1_1eval_1_1ml_1_1KingXBlockedBoth.html',1,'osl::eval::ml']]],
   ['kingxblockedy',['KingXBlockedY',['../classosl_1_1eval_1_1ml_1_1KingXBlockedY.html',1,'osl::eval::ml']]],
-  ['kingxblockedybase',['KingXBlockedYBase',['../classosl_1_1eval_1_1ml_1_1KingXBlockedYBase.html',1,'osl::eval::ml']]],
   ['kingxblockedybase',['KingXBlockedYBase',['../classosl_1_1eval_1_1ml_1_1KingXBlocked.html#a09f923f9f2add7ef70d1d96ed8be6ffb',1,'osl::eval::ml::KingXBlocked::KingXBlockedYBase()'],['../classosl_1_1eval_1_1ml_1_1KingXBlockedY.html#a09f923f9f2add7ef70d1d96ed8be6ffb',1,'osl::eval::ml::KingXBlockedY::KingXBlockedYBase()'],['../classosl_1_1eval_1_1ml_1_1KingXBothBlocked.html#a09f923f9f2add7ef70d1d96ed8be6ffb',1,'osl::eval::ml::KingXBothBlocked::KingXBlockedYBase()'],['../classosl_1_1eval_1_1ml_1_1KingXBothBlockedY.html#a09f923f9f2add7ef70d1d96ed8be6ffb',1,'osl::eval::ml::KingXBothBlockedY::KingXBlockedYBase()']]],
+  ['kingxblockedybase',['KingXBlockedYBase',['../classosl_1_1eval_1_1ml_1_1KingXBlockedYBase.html',1,'osl::eval::ml']]],
   ['kingxbothblocked',['KingXBothBlocked',['../classosl_1_1eval_1_1ml_1_1KingXBothBlocked.html',1,'osl::eval::ml']]],
   ['kingxbothblocked',['KingXBothBlocked',['../classosl_1_1eval_1_1ml_1_1KingXBothBlockedY.html#a37379553fa9850604327cf58615ab087',1,'osl::eval::ml::KingXBothBlockedY']]],
   ['kingxbothblockedy',['KingXBothBlockedY',['../classosl_1_1eval_1_1ml_1_1KingXBothBlockedY.html',1,'osl::eval::ml']]],
@@ -337,10 +338,10 @@ var searchData=
   ['kisen_2eh',['kisen.h',['../kisen_8h.html',1,'']]],
   ['kisen_5ffilename',['kisen_filename',['../classosl_1_1rating_1_1BradleyTerry.html#a1d7c7a857bff7d91a532c811ecaf08a2',1,'osl::rating::BradleyTerry::kisen_filename()'],['../probability_8cc.html#a7d206154015344334542008b65b9a110',1,'kisen_filename():&#160;probability.cc'],['../ratingstat_8cc.html#a7d206154015344334542008b65b9a110',1,'kisen_filename():&#160;ratingstat.cc']]],
   ['kisen_5fstart',['kisen_start',['../classosl_1_1rating_1_1BradleyTerry.html#adb84216c75da157172c0beae9901d122',1,'osl::rating::BradleyTerry::kisen_start()'],['../ratingstat_8cc.html#a986af9c47cde7151fd744d6b235d3d14',1,'kisen_start():&#160;ratingstat.cc']]],
-  ['kisenfile',['KisenFile',['../classosl_1_1record_1_1KisenFile.html#ad0770532a571a085a763d6552b9cb16f',1,'osl::record::KisenFile']]],
   ['kisenfile',['KisenFile',['../classosl_1_1record_1_1KisenFile.html',1,'osl::record']]],
-  ['kisenipxfile',['KisenIpxFile',['../classosl_1_1record_1_1KisenIpxFile.html#a9acd54a68941c09080fa4986c00725b5',1,'osl::record::KisenIpxFile']]],
+  ['kisenfile',['KisenFile',['../classosl_1_1record_1_1KisenFile.html#ad0770532a571a085a763d6552b9cb16f',1,'osl::record::KisenFile']]],
   ['kisenipxfile',['KisenIpxFile',['../classosl_1_1record_1_1KisenIpxFile.html',1,'osl::record']]],
+  ['kisenipxfile',['KisenIpxFile',['../classosl_1_1record_1_1KisenIpxFile.html#a9acd54a68941c09080fa4986c00725b5',1,'osl::record::KisenIpxFile']]],
   ['kisenipxwriter',['KisenIpxWriter',['../classosl_1_1record_1_1KisenIpxWriter.html#ad0c499b4ba74577ee2816b3e9db6b7e6',1,'osl::record::KisenIpxWriter']]],
   ['kisenipxwriter',['KisenIpxWriter',['../classosl_1_1record_1_1KisenIpxWriter.html',1,'osl::record']]],
   ['kisenplusfile',['KisenPlusFile',['../classosl_1_1record_1_1KisenPlusFile.html#ac7698725053b5ce6548e8c9e351146cb',1,'osl::record::KisenPlusFile']]],
@@ -366,10 +367,10 @@ var searchData=
   ['knightbonus',['knightBonus',['../classosl_1_1eval_1_1MinorPieceBonus.html#adffb6da5f54c8feaa0569c318131eeb3',1,'osl::eval::MinorPieceBonus']]],
   ['knightcapturedepth',['KnightCaptureDepth',['../structosl_1_1search_1_1QSearch2PrivateTraits.html#af9e170917970a4031f4f81ce7bd5e761ab26229305ecbe95dbf3b1eda7a3f2bda',1,'osl::search::QSearch2PrivateTraits']]],
   ['knightcheck',['KnightCheck',['../classosl_1_1eval_1_1ml_1_1KnightCheck.html',1,'osl::eval::ml']]],
-  ['knightchecky',['KnightCheckY',['../classosl_1_1eval_1_1ml_1_1KnightCheck.html#aedd90aadef0c58d28808bc752e8c8398',1,'osl::eval::ml::KnightCheck']]],
   ['knightchecky',['KnightCheckY',['../classosl_1_1eval_1_1ml_1_1KnightCheckY.html',1,'osl::eval::ml']]],
+  ['knightchecky',['KnightCheckY',['../classosl_1_1eval_1_1ml_1_1KnightCheck.html#aedd90aadef0c58d28808bc752e8c8398',1,'osl::eval::ml::KnightCheck']]],
   ['knightfork',['KnightFork',['../classosl_1_1eval_1_1ml_1_1KnightFork.html',1,'osl::eval::ml']]],
   ['knighthead',['KnightHead',['../classosl_1_1eval_1_1ml_1_1KnightHead.html',1,'osl::eval::ml']]],
-  ['knightheadopppiecepawnonstand',['KnightHeadOppPiecePawnOnStand',['../classosl_1_1eval_1_1ml_1_1KnightHead.html#a2ef528e51c8bc1684dd336af06ae8fbe',1,'osl::eval::ml::KnightHead']]],
-  ['knightheadopppiecepawnonstand',['KnightHeadOppPiecePawnOnStand',['../classosl_1_1eval_1_1ml_1_1KnightHeadOppPiecePawnOnStand.html',1,'osl::eval::ml']]]
+  ['knightheadopppiecepawnonstand',['KnightHeadOppPiecePawnOnStand',['../classosl_1_1eval_1_1ml_1_1KnightHeadOppPiecePawnOnStand.html',1,'osl::eval::ml']]],
+  ['knightheadopppiecepawnonstand',['KnightHeadOppPiecePawnOnStand',['../classosl_1_1eval_1_1ml_1_1KnightHead.html#a2ef528e51c8bc1684dd336af06ae8fbe',1,'osl::eval::ml::KnightHead']]]
 ];
