@@ -7,6 +7,8 @@ var searchData=
   ['_7ealphabeta2tree',['~AlphaBeta2Tree',['../classosl_1_1search_1_1AlphaBeta2Tree.html#a2dfe3d28aaa629e2c52784814f982e7d',1,'osl::search::AlphaBeta2Tree']]],
   ['_7ealphabeta3',['~AlphaBeta3',['../classosl_1_1search_1_1AlphaBeta3.html#a25c2b1c7a855f91f8169042b18cc925e',1,'osl::search::AlphaBeta3']]],
   ['_7ealphabeta3openmidendingevalplayer',['~AlphaBeta3OpenMidEndingEvalPlayer',['../classosl_1_1game__playing_1_1AlphaBeta3OpenMidEndingEvalPlayer.html#ab3f3b9585b154da0807a7a8c15f79677',1,'osl::game_playing::AlphaBeta3OpenMidEndingEvalPlayer']]],
+  ['_7ealphabeta4',['~AlphaBeta4',['../classosl_1_1search4_1_1AlphaBeta4.html#a3dec1f41753e0d9654e0cc6964663c67',1,'osl::search4::AlphaBeta4']]],
+  ['_7ealphabeta4player',['~AlphaBeta4Player',['../classosl_1_1game__playing_1_1AlphaBeta4Player.html#abceb8b9e632d12c604e2343ec8bbf575',1,'osl::game_playing::AlphaBeta4Player']]],
   ['_7eanalyzer',['~Analyzer',['../classosl_1_1annotate_1_1Analyzer.html#afa899ac3a6aabbe59f791f69368ad740',1,'osl::annotate::Analyzer']]],
   ['_7ebigramkillermove',['~BigramKillerMove',['../classosl_1_1search_1_1BigramKillerMove.html#a9b3ba06d372b94f9c2cf49ad05513211',1,'osl::search::BigramKillerMove']]],
   ['_7ebinaryelementreader',['~BinaryElementReader',['../classosl_1_1misc_1_1BinaryElementReader.html#aec5863f5a01eb0a43f1a2dbf3b6c5921',1,'osl::misc::BinaryElementReader']]],
