@@ -22,8 +22,8 @@ var searchData=
   ['bishophead',['BishopHead',['../classosl_1_1eval_1_1ml_1_1BishopHead.html',1,'osl::eval::ml']]],
   ['bishopheadkingrelative',['BishopHeadKingRelative',['../classosl_1_1eval_1_1ml_1_1BishopHeadKingRelative.html',1,'osl::eval::ml']]],
   ['bishopheadx',['BishopHeadX',['../classosl_1_1eval_1_1ml_1_1BishopHeadX.html',1,'osl::eval::ml']]],
-  ['bishopmobility',['BishopMobility',['../classosl_1_1eval_1_1ml_1_1BishopMobility.html',1,'osl::eval::ml']]],
   ['bishopmobility',['BishopMobility',['../structosl_1_1mobility_1_1BishopMobility.html',1,'osl::mobility']]],
+  ['bishopmobility',['BishopMobility',['../classosl_1_1eval_1_1ml_1_1BishopMobility.html',1,'osl::eval::ml']]],
   ['bishopmobilityall',['BishopMobilityAll',['../structosl_1_1eval_1_1ml_1_1BishopMobilityAll.html',1,'osl::eval::ml']]],
   ['bishopmobilityeach',['BishopMobilityEach',['../classosl_1_1eval_1_1ml_1_1BishopMobilityEach.html',1,'osl::eval::ml']]],
   ['bishoprookfork',['BishopRookFork',['../classosl_1_1eval_1_1ml_1_1BishopRookFork.html',1,'osl::eval::ml']]],
@@ -32,10 +32,10 @@ var searchData=
   ['bishopyending',['BishopYEnding',['../classosl_1_1eval_1_1ml_1_1BishopYEnding.html',1,'osl::eval::ml']]],
   ['bishopyopening',['BishopYOpening',['../classosl_1_1eval_1_1ml_1_1BishopYOpening.html',1,'osl::eval::ml']]],
   ['bitcopytraits',['BitCopyTraits',['../structosl_1_1misc_1_1detail_1_1BitCopyTraits.html',1,'osl::misc::detail']]],
-  ['bitcopytraits_3c_20move_20_3e',['BitCopyTraits< Move >',['../structosl_1_1misc_1_1detail_1_1BitCopyTraits_3_01Move_01_4.html',1,'osl::misc::detail']]],
-  ['bitcopytraits_3c_20piece_20_3e',['BitCopyTraits< Piece >',['../structosl_1_1misc_1_1detail_1_1BitCopyTraits_3_01Piece_01_4.html',1,'osl::misc::detail']]],
-  ['bitcopytraits_3c_20rating_3a_3aratedmove_20_3e',['BitCopyTraits< rating::RatedMove >',['../structosl_1_1misc_1_1detail_1_1BitCopyTraits_3_01rating_1_1RatedMove_01_4.html',1,'osl::misc::detail']]],
-  ['bitcopytraits_3c_20square_20_3e',['BitCopyTraits< Square >',['../structosl_1_1misc_1_1detail_1_1BitCopyTraits_3_01Square_01_4.html',1,'osl::misc::detail']]],
+  ['bitcopytraits_3c_20move_20_3e',['BitCopyTraits&lt; Move &gt;',['../structosl_1_1misc_1_1detail_1_1BitCopyTraits_3_01Move_01_4.html',1,'osl::misc::detail']]],
+  ['bitcopytraits_3c_20piece_20_3e',['BitCopyTraits&lt; Piece &gt;',['../structosl_1_1misc_1_1detail_1_1BitCopyTraits_3_01Piece_01_4.html',1,'osl::misc::detail']]],
+  ['bitcopytraits_3c_20rating_3a_3aratedmove_20_3e',['BitCopyTraits&lt; rating::RatedMove &gt;',['../structosl_1_1misc_1_1detail_1_1BitCopyTraits_3_01rating_1_1RatedMove_01_4.html',1,'osl::misc::detail']]],
+  ['bitcopytraits_3c_20square_20_3e',['BitCopyTraits&lt; Square &gt;',['../structosl_1_1misc_1_1detail_1_1BitCopyTraits_3_01Square_01_4.html',1,'osl::misc::detail']]],
   ['bitop',['BitOp',['../structosl_1_1misc_1_1BitOp.html',1,'osl::misc']]],
   ['bitxmask',['BitXmask',['../classosl_1_1container_1_1BitXmask.html',1,'osl::container']]],
   ['block',['Block',['../classosl_1_1rating_1_1Block.html',1,'osl::rating']]],
@@ -59,10 +59,12 @@ var searchData=
   ['bradleyterry',['BradleyTerry',['../classosl_1_1rating_1_1BradleyTerry.html',1,'osl::rating']]],
   ['breakthreatmate',['BreakThreatmate',['../classosl_1_1move__probability_1_1BreakThreatmate.html',1,'osl::move_probability']]],
   ['breakthreatmate',['BreakThreatmate',['../structosl_1_1search_1_1BreakThreatmate.html',1,'osl::search']]],
-  ['bsf_3c_20unsigned_20int_20_3e',['Bsf< unsigned int >',['../structosl_1_1misc_1_1Bsf_3_01unsigned_01int_01_4.html',1,'osl::misc']]],
-  ['bsf_3c_20unsigned_20long_20long_20_3e',['Bsf< unsigned long long >',['../structosl_1_1misc_1_1Bsf_3_01unsigned_01long_01long_01_4.html',1,'osl::misc']]],
-  ['bsf_3c_20unsigned_20short_20_3e',['Bsf< unsigned short >',['../structosl_1_1misc_1_1Bsf_3_01unsigned_01short_01_4.html',1,'osl::misc']]],
-  ['bsr_3c_20unsigned_20int_20_3e',['Bsr< unsigned int >',['../structosl_1_1misc_1_1Bsr_3_01unsigned_01int_01_4.html',1,'osl::misc']]],
-  ['bsr_3c_20unsigned_20long_20long_20_3e',['Bsr< unsigned long long >',['../structosl_1_1misc_1_1Bsr_3_01unsigned_01long_01long_01_4.html',1,'osl::misc']]],
+  ['bsf',['Bsf',['../structosl_1_1misc_1_1Bsf.html',1,'osl::misc']]],
+  ['bsf_3c_20unsigned_20int_20_3e',['Bsf&lt; unsigned int &gt;',['../structosl_1_1misc_1_1Bsf_3_01unsigned_01int_01_4.html',1,'osl::misc']]],
+  ['bsf_3c_20unsigned_20long_20long_20_3e',['Bsf&lt; unsigned long long &gt;',['../structosl_1_1misc_1_1Bsf_3_01unsigned_01long_01long_01_4.html',1,'osl::misc']]],
+  ['bsf_3c_20unsigned_20short_20_3e',['Bsf&lt; unsigned short &gt;',['../structosl_1_1misc_1_1Bsf_3_01unsigned_01short_01_4.html',1,'osl::misc']]],
+  ['bsr',['Bsr',['../structosl_1_1misc_1_1Bsr.html',1,'osl::misc']]],
+  ['bsr_3c_20unsigned_20int_20_3e',['Bsr&lt; unsigned int &gt;',['../structosl_1_1misc_1_1Bsr_3_01unsigned_01int_01_4.html',1,'osl::misc']]],
+  ['bsr_3c_20unsigned_20long_20long_20_3e',['Bsr&lt; unsigned long long &gt;',['../structosl_1_1misc_1_1Bsr_3_01unsigned_01long_01long_01_4.html',1,'osl::misc']]],
   ['byte8',['Byte8',['../unionosl_1_1effect_1_1Byte8.html',1,'osl::effect']]]
 ];
