@@ -23,18 +23,19 @@ var searchData=
   ['capturesort',['CaptureSort',['../structosl_1_1move__order_1_1CaptureSort.html',1,'osl::move_order']]],
   ['carray',['CArray',['../classosl_1_1misc_1_1CArray.html',1,'osl::misc']]],
   ['carray2d',['CArray2d',['../classosl_1_1misc_1_1CArray2d.html',1,'osl::misc']]],
-  ['carray2d_3c_20t_2c_20capacity2_2c_20capacity3_20_3e',['CArray2d< T, Capacity2, Capacity3 >',['../classosl_1_1misc_1_1CArray2d.html',1,'osl::misc']]],
+  ['carray2d_3c_20t_2c_20capacity2_2c_20capacity3_20_3e',['CArray2d&lt; T, Capacity2, Capacity3 &gt;',['../classosl_1_1misc_1_1CArray2d.html',1,'osl::misc']]],
   ['carray2dproxy',['CArray2dProxy',['../structosl_1_1misc_1_1CArray2dProxy.html',1,'osl::misc']]],
   ['carray3d',['CArray3d',['../structosl_1_1misc_1_1CArray3d.html',1,'osl::misc']]],
-  ['carray_3c_20carray2d_3c_20t_2c_20capacity2_2c_20capacity3_20_3e_2c_20capacity1_20_3e',['CArray< CArray2d< T, Capacity2, Capacity3 >, Capacity1 >',['../classosl_1_1misc_1_1CArray.html',1,'osl::misc']]],
-  ['carray_3c_20int64_5ft_2c_28sizeof_28t_5bcapacity_5d_29_2bsizeof_28int64_5ft_29_2d1_29_2fsizeof_28int64_5ft_29_3e',['CArray< int64_t,(sizeof(T[Capacity])+sizeof(int64_t)-1)/sizeof(int64_t)>',['../classosl_1_1misc_1_1CArray.html',1,'osl::misc']]],
-  ['carray_3c_20std_3a_3astring_2c_2010_20_3e',['CArray< std::string, 10 >',['../classosl_1_1misc_1_1CArray.html',1,'osl::misc']]],
-  ['carray_3c_20std_3a_3astring_2c_2032_20_3e',['CArray< std::string, 32 >',['../classosl_1_1misc_1_1CArray.html',1,'osl::misc']]],
+  ['carray_3c_20carray2d_3c_20t_2c_20capacity2_2c_20capacity3_20_3e_2c_20capacity1_20_3e',['CArray&lt; CArray2d&lt; T, Capacity2, Capacity3 &gt;, Capacity1 &gt;',['../classosl_1_1misc_1_1CArray.html',1,'osl::misc']]],
+  ['carray_3c_20int64_5ft_2c_28sizeof_28t_5bcapacity_5d_29_2bsizeof_28int64_5ft_29_2d1_29_2fsizeof_28int64_5ft_29_3e',['CArray&lt; int64_t,(sizeof(T[Capacity])+sizeof(int64_t)-1)/sizeof(int64_t)&gt;',['../classosl_1_1misc_1_1CArray.html',1,'osl::misc']]],
+  ['carray_3c_20std_3a_3astring_2c_2010_20_3e',['CArray&lt; std::string, 10 &gt;',['../classosl_1_1misc_1_1CArray.html',1,'osl::misc']]],
+  ['carray_3c_20std_3a_3astring_2c_2032_20_3e',['CArray&lt; std::string, 32 &gt;',['../classosl_1_1misc_1_1CArray.html',1,'osl::misc']]],
   ['carrayiterator',['CArrayIterator',['../structosl_1_1misc_1_1CArrayIterator.html',1,'osl::misc']]],
   ['categorymoves',['CategoryMoves',['../structosl_1_1search_1_1analyzer_1_1CategoryMoves.html',1,'osl::search::analyzer']]],
   ['categorymovevector',['CategoryMoveVector',['../classosl_1_1search_1_1analyzer_1_1CategoryMoveVector.html',1,'osl::search::analyzer']]],
   ['centering3x3',['Centering3x3',['../structosl_1_1Centering3x3.html',1,'osl']]],
   ['centering5x3',['Centering5x3',['../structosl_1_1Centering5x3.html',1,'osl']]],
+  ['cerrmonitor',['CerrMonitor',['../classosl_1_1search_1_1CerrMonitor.html',1,'osl::search']]],
   ['changeshellcolor',['ChangeShellColor',['../classosl_1_1record_1_1ChangeShellColor.html',1,'osl::record']]],
   ['characters',['Characters',['../classosl_1_1record_1_1Characters.html',1,'osl::record']]],
   ['chase',['Chase',['../classosl_1_1rating_1_1Chase.html',1,'osl::rating']]],
@@ -50,20 +51,20 @@ var searchData=
   ['checkmateanalyzer',['CheckmateAnalyzer',['../classosl_1_1annotate_1_1CheckmateAnalyzer.html',1,'osl::annotate']]],
   ['checkmateforcapture',['CheckmateForCapture',['../structosl_1_1annotate_1_1AnalysesResult_1_1CheckmateForCapture.html',1,'osl::annotate::AnalysesResult']]],
   ['checkmateforcapture',['CheckmateForCapture',['../classosl_1_1annotate_1_1CheckmateForCapture.html',1,'osl::annotate']]],
-  ['checkmateforescape',['CheckmateForEscape',['../classosl_1_1annotate_1_1CheckmateForEscape.html',1,'osl::annotate']]],
   ['checkmateforescape',['CheckmateForEscape',['../structosl_1_1annotate_1_1AnalysesResult_1_1CheckmateForEscape.html',1,'osl::annotate::AnalysesResult']]],
-  ['checkmateifcapture',['CheckmateIfCapture',['../classosl_1_1rating_1_1CheckmateIfCapture.html',1,'osl::rating']]],
-  ['checkmateifcapture',['CheckmateIfCapture',['../classosl_1_1move__probability_1_1CheckmateIfCapture.html',1,'osl::move_probability']]],
+  ['checkmateforescape',['CheckmateForEscape',['../classosl_1_1annotate_1_1CheckmateForEscape.html',1,'osl::annotate']]],
   ['checkmateifcapture',['CheckmateIfCapture',['../structosl_1_1checkmate_1_1CheckmateIfCapture.html',1,'osl::checkmate']]],
+  ['checkmateifcapture',['CheckmateIfCapture',['../classosl_1_1move__probability_1_1CheckmateIfCapture.html',1,'osl::move_probability']]],
+  ['checkmateifcapture',['CheckmateIfCapture',['../classosl_1_1rating_1_1CheckmateIfCapture.html',1,'osl::rating']]],
   ['checkmateifcapturegroup',['CheckmateIfCaptureGroup',['../classosl_1_1rating_1_1CheckmateIfCaptureGroup.html',1,'osl::rating']]],
   ['checkmatewin',['CheckmateWin',['../classosl_1_1annotate_1_1CheckmateWin.html',1,'osl::annotate']]],
   ['checkmovevector',['CheckMoveVector',['../classosl_1_1checkmate_1_1CheckMoveVector.html',1,'osl::checkmate']]],
   ['checkshadowptype',['CheckShadowPtype',['../classosl_1_1eval_1_1ml_1_1CheckShadowPtype.html',1,'osl::eval::ml']]],
   ['classifier',['Classifier',['../structosl_1_1move__classifier_1_1Classifier.html',1,'osl::move_classifier']]],
   ['classifiertraits',['ClassifierTraits',['../structosl_1_1move__classifier_1_1ClassifierTraits.html',1,'osl::move_classifier']]],
-  ['classifiertraits_3c_20kingopenmove_3c_20p_20_3e_20_3e',['ClassifierTraits< KingOpenMove< P > >',['../structosl_1_1move__classifier_1_1ClassifierTraits_3_01KingOpenMove_3_01P_01_4_01_4.html',1,'osl::move_classifier']]],
-  ['classifiertraits_3c_20opencheck_3c_20p_20_3e_20_3e',['ClassifierTraits< OpenCheck< P > >',['../structosl_1_1move__classifier_1_1ClassifierTraits_3_01OpenCheck_3_01P_01_4_01_4.html',1,'osl::move_classifier']]],
-  ['classifiertraits_3c_20safemove_3c_20p_20_3e_20_3e',['ClassifierTraits< SafeMove< P > >',['../structosl_1_1move__classifier_1_1ClassifierTraits_3_01SafeMove_3_01P_01_4_01_4.html',1,'osl::move_classifier']]],
+  ['classifiertraits_3c_20kingopenmove_3c_20p_20_3e_20_3e',['ClassifierTraits&lt; KingOpenMove&lt; P &gt; &gt;',['../structosl_1_1move__classifier_1_1ClassifierTraits_3_01KingOpenMove_3_01P_01_4_01_4.html',1,'osl::move_classifier']]],
+  ['classifiertraits_3c_20opencheck_3c_20p_20_3e_20_3e',['ClassifierTraits&lt; OpenCheck&lt; P &gt; &gt;',['../structosl_1_1move__classifier_1_1ClassifierTraits_3_01OpenCheck_3_01P_01_4_01_4.html',1,'osl::move_classifier']]],
+  ['classifiertraits_3c_20safemove_3c_20p_20_3e_20_3e',['ClassifierTraits&lt; SafeMove&lt; P &gt; &gt;',['../structosl_1_1move__classifier_1_1ClassifierTraits_3_01SafeMove_3_01P_01_4_01_4.html',1,'osl::move_classifier']]],
   ['color',['Color',['../classosl_1_1record_1_1Color.html',1,'osl::record']]],
   ['compactboard',['CompactBoard',['../classosl_1_1record_1_1CompactBoard.html',1,'osl::record']]],
   ['compacthashtable',['CompactHashTable',['../structosl_1_1search_1_1CompactHashTable.html',1,'osl::search']]],
@@ -74,8 +75,8 @@ var searchData=
   ['comparechildsize',['CompareChildSize',['../structCompareChildSize.html',1,'']]],
   ['computerplayer',['ComputerPlayer',['../classosl_1_1game__playing_1_1ComputerPlayer.html',1,'osl::game_playing']]],
   ['computerplayerselectbestmoveintime',['ComputerPlayerSelectBestMoveInTime',['../classosl_1_1game__playing_1_1ComputerPlayerSelectBestMoveInTime.html',1,'osl::game_playing']]],
-  ['concept',['Concept',['../structosl_1_1eval_1_1Concept.html',1,'osl::eval']]],
   ['concept',['Concept',['../structosl_1_1move__action_1_1Concept.html',1,'osl::move_action']]],
+  ['concept',['Concept',['../structosl_1_1eval_1_1Concept.html',1,'osl::eval']]],
   ['conditionadaptor',['ConditionAdaptor',['../structosl_1_1move__classifier_1_1ConditionAdaptor.html',1,'osl::move_classifier']]],
   ['config',['Config',['../structosl_1_1game__playing_1_1SearchPlayer_1_1Config.html',1,'osl::game_playing::SearchPlayer']]],
   ['consistencycheck',['ConsistencyCheck',['../structosl_1_1stl_1_1ConsistencyCheck.html',1,'osl::stl']]],
