@@ -1,7 +1,7 @@
 var searchData=
 [
-  ['parseerror',['ParseError',['../classosl_1_1record_1_1psn_1_1ParseError.html',1,'osl::record::psn']]],
   ['parseerror',['ParseError',['../classosl_1_1record_1_1usi_1_1ParseError.html',1,'osl::record::usi']]],
+  ['parseerror',['ParseError',['../classosl_1_1record_1_1psn_1_1ParseError.html',1,'osl::record::psn']]],
   ['passcounter',['PassCounter',['../classosl_1_1search_1_1PassCounter.html',1,'osl::search']]],
   ['pathencoding',['PathEncoding',['../classosl_1_1PathEncoding.html',1,'osl']]],
   ['pathencodinglist',['PathEncodingList',['../classosl_1_1ntesuki_1_1PathEncodingList.html',1,'osl::ntesuki']]],
@@ -49,13 +49,13 @@ var searchData=
   ['pieceonboard',['PieceOnBoard',['../structosl_1_1move__generator_1_1PieceOnBoard.html',1,'osl::move_generator']]],
   ['piecepair',['PiecePair',['../classosl_1_1eval_1_1ml_1_1PiecePair.html',1,'osl::eval::ml']]],
   ['piecepaireval',['PiecePairEval',['../classosl_1_1eval_1_1ppair_1_1PiecePairEval.html',1,'osl::eval::ppair']]],
-  ['piecepaireval_3c_20piecepairraweval_2c_20piecepairrawtable_20_3e',['PiecePairEval< PiecePairRawEval, PiecePairRawTable >',['../classosl_1_1eval_1_1ppair_1_1PiecePairEval.html',1,'osl::eval::ppair']]],
-  ['piecepaireval_3c_20piecepairwithstand_3c_20piecepairpiecetable_20_3e_2c_20piecepairpiecetable_20_3e',['PiecePairEval< PiecePairWithStand< PiecePairPieceTable >, PiecePairPieceTable >',['../classosl_1_1eval_1_1ppair_1_1PiecePairEval.html',1,'osl::eval::ppair']]],
-  ['piecepaireval_3c_20piecepairwithstand_3c_20table_20_3e_2c_20table_20_3e',['PiecePairEval< PiecePairWithStand< Table >, Table >',['../classosl_1_1eval_1_1ppair_1_1PiecePairEval.html',1,'osl::eval::ppair']]],
+  ['piecepaireval_3c_20piecepairraweval_2c_20piecepairrawtable_20_3e',['PiecePairEval&lt; PiecePairRawEval, PiecePairRawTable &gt;',['../classosl_1_1eval_1_1ppair_1_1PiecePairEval.html',1,'osl::eval::ppair']]],
+  ['piecepaireval_3c_20piecepairwithstand_3c_20piecepairpiecetable_20_3e_2c_20piecepairpiecetable_20_3e',['PiecePairEval&lt; PiecePairWithStand&lt; PiecePairPieceTable &gt;, PiecePairPieceTable &gt;',['../classosl_1_1eval_1_1ppair_1_1PiecePairEval.html',1,'osl::eval::ppair']]],
+  ['piecepaireval_3c_20piecepairwithstand_3c_20table_20_3e_2c_20table_20_3e',['PiecePairEval&lt; PiecePairWithStand&lt; Table &gt;, Table &gt;',['../classosl_1_1eval_1_1ppair_1_1PiecePairEval.html',1,'osl::eval::ppair']]],
   ['piecepairevalbase',['PiecePairEvalBase',['../classosl_1_1eval_1_1ppair_1_1PiecePairEvalBase.html',1,'osl::eval::ppair']]],
   ['piecepairevaltablebase',['PiecePairEvalTableBase',['../classosl_1_1eval_1_1ppair_1_1PiecePairEvalTableBase.html',1,'osl::eval::ppair']]],
-  ['piecepairevaltablebase_3c_20piecepairpiecetable_20_3e',['PiecePairEvalTableBase< PiecePairPieceTable >',['../classosl_1_1eval_1_1ppair_1_1PiecePairEvalTableBase.html',1,'osl::eval::ppair']]],
-  ['piecepairevaltablebase_3c_20piecepairrawtable_20_3e',['PiecePairEvalTableBase< PiecePairRawTable >',['../classosl_1_1eval_1_1ppair_1_1PiecePairEvalTableBase.html',1,'osl::eval::ppair']]],
+  ['piecepairevaltablebase_3c_20piecepairpiecetable_20_3e',['PiecePairEvalTableBase&lt; PiecePairPieceTable &gt;',['../classosl_1_1eval_1_1ppair_1_1PiecePairEvalTableBase.html',1,'osl::eval::ppair']]],
+  ['piecepairevaltablebase_3c_20piecepairrawtable_20_3e',['PiecePairEvalTableBase&lt; PiecePairRawTable &gt;',['../classosl_1_1eval_1_1ppair_1_1PiecePairEvalTableBase.html',1,'osl::eval::ppair']]],
   ['piecepairindex',['PiecePairIndex',['../structosl_1_1eval_1_1ppair_1_1PiecePairIndex.html',1,'osl::eval::ppair']]],
   ['piecepairking',['PiecePairKing',['../classosl_1_1eval_1_1ml_1_1PiecePairKing.html',1,'osl::eval::ml']]],
   ['piecepairpieceeval',['PiecePairPieceEval',['../classosl_1_1eval_1_1ppair_1_1PiecePairPieceEval.html',1,'osl::eval::ppair']]],
@@ -63,10 +63,10 @@ var searchData=
   ['piecepairraweval',['PiecePairRawEval',['../classosl_1_1eval_1_1ppair_1_1PiecePairRawEval.html',1,'osl::eval::ppair']]],
   ['piecepairrawtable',['PiecePairRawTable',['../classosl_1_1eval_1_1ppair_1_1PiecePairRawTable.html',1,'osl::eval::ppair']]],
   ['piecepairtable',['PiecePairTable',['../classosl_1_1eval_1_1ppair_1_1PiecePairTable.html',1,'osl::eval::ppair']]],
-  ['piecepairtable_3c_20signed_20char_20_3e',['PiecePairTable< signed char >',['../classosl_1_1eval_1_1ppair_1_1PiecePairTable.html',1,'osl::eval::ppair']]],
-  ['piecepairtable_3c_20signed_20short_20_3e',['PiecePairTable< signed short >',['../classosl_1_1eval_1_1ppair_1_1PiecePairTable.html',1,'osl::eval::ppair']]],
+  ['piecepairtable_3c_20signed_20char_20_3e',['PiecePairTable&lt; signed char &gt;',['../classosl_1_1eval_1_1ppair_1_1PiecePairTable.html',1,'osl::eval::ppair']]],
+  ['piecepairtable_3c_20signed_20short_20_3e',['PiecePairTable&lt; signed short &gt;',['../classosl_1_1eval_1_1ppair_1_1PiecePairTable.html',1,'osl::eval::ppair']]],
   ['piecepairwithstand',['PiecePairWithStand',['../classosl_1_1eval_1_1ppair_1_1PiecePairWithStand.html',1,'osl::eval::ppair']]],
-  ['piecepairwithstand_3c_20piecepairpiecetable_20_3e',['PiecePairWithStand< PiecePairPieceTable >',['../classosl_1_1eval_1_1ppair_1_1PiecePairWithStand.html',1,'osl::eval::ppair']]],
+  ['piecepairwithstand_3c_20piecepairpiecetable_20_3e',['PiecePairWithStand&lt; PiecePairPieceTable &gt;',['../classosl_1_1eval_1_1ppair_1_1PiecePairWithStand.html',1,'osl::eval::ppair']]],
   ['pieceptypemorethan',['PiecePtypeMoreThan',['../structosl_1_1PiecePtypeMoreThan.html',1,'osl']]],
   ['piecestand',['PieceStand',['../classosl_1_1PieceStand.html',1,'osl']]],
   ['piecestand',['PieceStand',['../classosl_1_1eval_1_1ml_1_1PieceStand.html',1,'osl::eval::ml']]],
@@ -77,8 +77,8 @@ var searchData=
   ['piecetable',['PieceTable',['../classosl_1_1PieceTable.html',1,'osl']]],
   ['piecevalues',['PieceValues',['../classosl_1_1container_1_1PieceValues.html',1,'osl::container']]],
   ['piecevector',['PieceVector',['../classosl_1_1container_1_1PieceVector.html',1,'osl::container']]],
-  ['pin',['Pin',['../classosl_1_1effect__util_1_1Pin.html',1,'osl::effect_util']]],
   ['pin',['Pin',['../classosl_1_1eval_1_1ml_1_1Pin.html',1,'osl::eval::ml']]],
+  ['pin',['Pin',['../classosl_1_1effect__util_1_1Pin.html',1,'osl::effect_util']]],
   ['pinattack',['PinAttack',['../classosl_1_1rating_1_1PinAttack.html',1,'osl::rating']]],
   ['pingroup',['PinGroup',['../structosl_1_1rating_1_1PinGroup.html',1,'osl::rating']]],
   ['pinnedgeneral',['PinnedGeneral',['../structosl_1_1move__probability_1_1PinnedGeneral.html',1,'osl::move_probability']]],
@@ -89,13 +89,14 @@ var searchData=
   ['pinptypepawnattack',['PinPtypePawnAttack',['../classosl_1_1eval_1_1ml_1_1PinPtypePawnAttack.html',1,'osl::eval::ml']]],
   ['player2type',['Player2Type',['../structosl_1_1misc_1_1Player2Type.html',1,'osl::misc']]],
   ['playermoveadaptor',['PlayerMoveAdaptor',['../structosl_1_1move__classifier_1_1PlayerMoveAdaptor.html',1,'osl::move_classifier']]],
-  ['playertraits_3c_20black_20_3e',['PlayerTraits< BLACK >',['../structosl_1_1PlayerTraits_3_01BLACK_01_4.html',1,'osl']]],
-  ['playertraits_3c_20white_20_3e',['PlayerTraits< WHITE >',['../structosl_1_1PlayerTraits_3_01WHITE_01_4.html',1,'osl']]],
+  ['playertraits',['PlayerTraits',['../structosl_1_1PlayerTraits.html',1,'osl']]],
+  ['playertraits_3c_20black_20_3e',['PlayerTraits&lt; BLACK &gt;',['../structosl_1_1PlayerTraits_3_01BLACK_01_4.html',1,'osl']]],
+  ['playertraits_3c_20white_20_3e',['PlayerTraits&lt; WHITE &gt;',['../structosl_1_1PlayerTraits_3_01WHITE_01_4.html',1,'osl']]],
   ['playmovelock',['PlayMoveLock',['../structPlayMoveLock.html',1,'']]],
   ['pointerqueue',['PointerQueue',['../classosl_1_1misc_1_1PointerQueue.html',1,'osl::misc']]],
-  ['pointerqueue_3c_20void_20_3e',['PointerQueue< void >',['../classosl_1_1misc_1_1PointerQueue.html',1,'osl::misc']]],
+  ['pointerqueue_3c_20void_20_3e',['PointerQueue&lt; void &gt;',['../classosl_1_1misc_1_1PointerQueue.html',1,'osl::misc']]],
   ['pointerset',['PointerSet',['../structosl_1_1container_1_1PointerSet.html',1,'osl::container']]],
-  ['pointerset_3c_20simplehashrecord_20_3e',['PointerSet< SimpleHashRecord >',['../structosl_1_1container_1_1PointerSet.html',1,'osl::container']]],
+  ['pointerset_3c_20simplehashrecord_20_3e',['PointerSet&lt; SimpleHashRecord &gt;',['../structosl_1_1container_1_1PointerSet.html',1,'osl::container']]],
   ['pool_5fallocator',['pool_allocator',['../structosl_1_1stl_1_1pool__allocator.html',1,'osl::stl']]],
   ['probability',['Probability',['../structosl_1_1stat_1_1Probability.html',1,'osl::stat']]],
   ['progress16',['Progress16',['../classosl_1_1progress_1_1Progress16.html',1,'osl::progress']]],
@@ -106,9 +107,9 @@ var searchData=
   ['progressdebuginfo',['ProgressDebugInfo',['../structosl_1_1eval_1_1ProgressDebugInfo.html',1,'osl::eval']]],
   ['progresseval',['ProgressEval',['../classosl_1_1eval_1_1ProgressEval.html',1,'osl::eval']]],
   ['progressevalgeneral',['ProgressEvalGeneral',['../classosl_1_1eval_1_1ProgressEvalGeneral.html',1,'osl::eval']]],
-  ['progressevalgeneral_3c_20progress_5feval_5fopening_5ft_20_3e',['ProgressEvalGeneral< progress_eval_opening_t >',['../classosl_1_1eval_1_1ProgressEvalGeneral.html',1,'osl::eval']]],
-  ['promote',['Promote',['../classosl_1_1move__generator_1_1Promote.html',1,'osl::move_generator']]],
+  ['progressevalgeneral_3c_20progress_5feval_5fopening_5ft_20_3e',['ProgressEvalGeneral&lt; progress_eval_opening_t &gt;',['../classosl_1_1eval_1_1ProgressEvalGeneral.html',1,'osl::eval']]],
   ['promote',['Promote',['../classosl_1_1effect__action_1_1Promote.html',1,'osl::effect_action']]],
+  ['promote',['Promote',['../classosl_1_1move__generator_1_1Promote.html',1,'osl::move_generator']]],
   ['promotedminorpieces',['PromotedMinorPieces',['../classosl_1_1eval_1_1ml_1_1PromotedMinorPieces.html',1,'osl::eval::ml']]],
   ['promotedminorpiecesy',['PromotedMinorPiecesY',['../classosl_1_1eval_1_1ml_1_1PromotedMinorPiecesY.html',1,'osl::eval::ml']]],
   ['promotion',['Promotion',['../structosl_1_1move__order_1_1Promotion.html',1,'osl::move_order']]],
@@ -128,62 +129,66 @@ var searchData=
   ['ptypecountxyattack',['PtypeCountXYAttack',['../classosl_1_1eval_1_1ml_1_1PtypeCountXYAttack.html',1,'osl::eval::ml']]],
   ['ptypedirectiontraits',['PtypeDirectionTraits',['../structosl_1_1PtypeDirectionTraits.html',1,'osl']]],
   ['ptypeevaltable',['PtypeEvalTable',['../classosl_1_1eval_1_1PtypeEvalTable.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20bishop_20_3e',['PtypeEvalTraits< BISHOP >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01BISHOP_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20gold_20_3e',['PtypeEvalTraits< GOLD >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01GOLD_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20king_20_3e',['PtypeEvalTraits< KING >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01KING_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20knight_20_3e',['PtypeEvalTraits< KNIGHT >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01KNIGHT_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20lance_20_3e',['PtypeEvalTraits< LANCE >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01LANCE_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20pawn_20_3e',['PtypeEvalTraits< PAWN >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PAWN_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20pbishop_20_3e',['PtypeEvalTraits< PBISHOP >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PBISHOP_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20pknight_20_3e',['PtypeEvalTraits< PKNIGHT >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PKNIGHT_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20plance_20_3e',['PtypeEvalTraits< PLANCE >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PLANCE_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20ppawn_20_3e',['PtypeEvalTraits< PPAWN >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PPAWN_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20prook_20_3e',['PtypeEvalTraits< PROOK >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PROOK_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20psilver_20_3e',['PtypeEvalTraits< PSILVER >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PSILVER_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20rook_20_3e',['PtypeEvalTraits< ROOK >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01ROOK_01_4.html',1,'osl::eval']]],
-  ['ptypeevaltraits_3c_20silver_20_3e',['PtypeEvalTraits< SILVER >',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01SILVER_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits',['PtypeEvalTraits',['../structosl_1_1eval_1_1PtypeEvalTraits.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20bishop_20_3e',['PtypeEvalTraits&lt; BISHOP &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01BISHOP_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20gold_20_3e',['PtypeEvalTraits&lt; GOLD &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01GOLD_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20king_20_3e',['PtypeEvalTraits&lt; KING &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01KING_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20knight_20_3e',['PtypeEvalTraits&lt; KNIGHT &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01KNIGHT_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20lance_20_3e',['PtypeEvalTraits&lt; LANCE &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01LANCE_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20pawn_20_3e',['PtypeEvalTraits&lt; PAWN &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PAWN_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20pbishop_20_3e',['PtypeEvalTraits&lt; PBISHOP &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PBISHOP_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20pknight_20_3e',['PtypeEvalTraits&lt; PKNIGHT &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PKNIGHT_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20plance_20_3e',['PtypeEvalTraits&lt; PLANCE &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PLANCE_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20ppawn_20_3e',['PtypeEvalTraits&lt; PPAWN &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PPAWN_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20prook_20_3e',['PtypeEvalTraits&lt; PROOK &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PROOK_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20psilver_20_3e',['PtypeEvalTraits&lt; PSILVER &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01PSILVER_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20rook_20_3e',['PtypeEvalTraits&lt; ROOK &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01ROOK_01_4.html',1,'osl::eval']]],
+  ['ptypeevaltraits_3c_20silver_20_3e',['PtypeEvalTraits&lt; SILVER &gt;',['../structosl_1_1eval_1_1PtypeEvalTraits_3_01SILVER_01_4.html',1,'osl::eval']]],
   ['ptypefuns',['PtypeFuns',['../structosl_1_1PtypeFuns.html',1,'osl']]],
-  ['ptypefunssub_3c_20t_2c_20false_20_3e',['PtypeFunsSub< T, false >',['../structosl_1_1PtypeFunsSub_3_01T_00_01false_01_4.html',1,'osl']]],
-  ['ptypefunssub_3c_20t_2c_20true_20_3e',['PtypeFunsSub< T, true >',['../structosl_1_1PtypeFunsSub_3_01T_00_01true_01_4.html',1,'osl']]],
+  ['ptypefunssub',['PtypeFunsSub',['../structosl_1_1PtypeFunsSub.html',1,'osl']]],
+  ['ptypefunssub_3c_20t_2c_20false_20_3e',['PtypeFunsSub&lt; T, false &gt;',['../structosl_1_1PtypeFunsSub_3_01T_00_01false_01_4.html',1,'osl']]],
+  ['ptypefunssub_3c_20t_2c_20true_20_3e',['PtypeFunsSub&lt; T, true &gt;',['../structosl_1_1PtypeFunsSub_3_01T_00_01true_01_4.html',1,'osl']]],
   ['ptypelist',['PtypeList',['../structosl_1_1ptl_1_1PtypeList.html',1,'osl::ptl']]],
   ['ptypeosquarelessthan',['PtypeOSquareLessThan',['../structosl_1_1PtypeOSquareLessThan.html',1,'osl']]],
   ['ptypeosquarevector',['PtypeOSquareVector',['../classosl_1_1container_1_1PtypeOSquareVector.html',1,'osl::container']]],
   ['ptypeplayertraits',['PtypePlayerTraits',['../structosl_1_1PtypePlayerTraits.html',1,'osl']]],
   ['ptypeprogress',['PtypeProgress',['../classosl_1_1progress_1_1PtypeProgress.html',1,'osl::progress']]],
   ['ptypeprogresstable',['PtypeProgressTable',['../classosl_1_1progress_1_1PtypeProgressTable.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20bishop_20_3e',['PtypeProgressTraits< BISHOP >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01BISHOP_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20gold_20_3e',['PtypeProgressTraits< GOLD >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01GOLD_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20king_20_3e',['PtypeProgressTraits< KING >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01KING_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20knight_20_3e',['PtypeProgressTraits< KNIGHT >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01KNIGHT_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20lance_20_3e',['PtypeProgressTraits< LANCE >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01LANCE_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20pawn_20_3e',['PtypeProgressTraits< PAWN >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PAWN_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20pbishop_20_3e',['PtypeProgressTraits< PBISHOP >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PBISHOP_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20pknight_20_3e',['PtypeProgressTraits< PKNIGHT >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PKNIGHT_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20plance_20_3e',['PtypeProgressTraits< PLANCE >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PLANCE_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20ppawn_20_3e',['PtypeProgressTraits< PPAWN >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PPAWN_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20prook_20_3e',['PtypeProgressTraits< PROOK >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PROOK_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20psilver_20_3e',['PtypeProgressTraits< PSILVER >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PSILVER_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20rook_20_3e',['PtypeProgressTraits< ROOK >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01ROOK_01_4.html',1,'osl::progress']]],
-  ['ptypeprogresstraits_3c_20silver_20_3e',['PtypeProgressTraits< SILVER >',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01SILVER_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits',['PtypeProgressTraits',['../structosl_1_1progress_1_1PtypeProgressTraits.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20bishop_20_3e',['PtypeProgressTraits&lt; BISHOP &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01BISHOP_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20gold_20_3e',['PtypeProgressTraits&lt; GOLD &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01GOLD_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20king_20_3e',['PtypeProgressTraits&lt; KING &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01KING_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20knight_20_3e',['PtypeProgressTraits&lt; KNIGHT &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01KNIGHT_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20lance_20_3e',['PtypeProgressTraits&lt; LANCE &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01LANCE_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20pawn_20_3e',['PtypeProgressTraits&lt; PAWN &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PAWN_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20pbishop_20_3e',['PtypeProgressTraits&lt; PBISHOP &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PBISHOP_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20pknight_20_3e',['PtypeProgressTraits&lt; PKNIGHT &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PKNIGHT_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20plance_20_3e',['PtypeProgressTraits&lt; PLANCE &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PLANCE_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20ppawn_20_3e',['PtypeProgressTraits&lt; PPAWN &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PPAWN_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20prook_20_3e',['PtypeProgressTraits&lt; PROOK &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PROOK_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20psilver_20_3e',['PtypeProgressTraits&lt; PSILVER &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01PSILVER_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20rook_20_3e',['PtypeProgressTraits&lt; ROOK &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01ROOK_01_4.html',1,'osl::progress']]],
+  ['ptypeprogresstraits_3c_20silver_20_3e',['PtypeProgressTraits&lt; SILVER &gt;',['../structosl_1_1progress_1_1PtypeProgressTraits_3_01SILVER_01_4.html',1,'osl::progress']]],
   ['ptypetable',['PtypeTable',['../classosl_1_1PtypeTable.html',1,'osl']]],
   ['ptypetobool',['PtypeToBool',['../structosl_1_1ptl_1_1CheckIsBasic_1_1PtypeToBool.html',1,'osl::ptl::CheckIsBasic']]],
   ['ptypetobool',['PtypeToBool',['../structosl_1_1ptl_1_1CheckHasMoveMask_1_1PtypeToBool.html',1,'osl::ptl::CheckHasMoveMask']]],
-  ['ptypetraits_3c_20bishop_20_3e',['PtypeTraits< BISHOP >',['../structosl_1_1PtypeTraits_3_01BISHOP_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20gold_20_3e',['PtypeTraits< GOLD >',['../structosl_1_1PtypeTraits_3_01GOLD_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20king_20_3e',['PtypeTraits< KING >',['../structosl_1_1PtypeTraits_3_01KING_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20knight_20_3e',['PtypeTraits< KNIGHT >',['../structosl_1_1PtypeTraits_3_01KNIGHT_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20lance_20_3e',['PtypeTraits< LANCE >',['../structosl_1_1PtypeTraits_3_01LANCE_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20pawn_20_3e',['PtypeTraits< PAWN >',['../structosl_1_1PtypeTraits_3_01PAWN_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20pbishop_20_3e',['PtypeTraits< PBISHOP >',['../structosl_1_1PtypeTraits_3_01PBISHOP_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20pknight_20_3e',['PtypeTraits< PKNIGHT >',['../structosl_1_1PtypeTraits_3_01PKNIGHT_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20plance_20_3e',['PtypeTraits< PLANCE >',['../structosl_1_1PtypeTraits_3_01PLANCE_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20ppawn_20_3e',['PtypeTraits< PPAWN >',['../structosl_1_1PtypeTraits_3_01PPAWN_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20prook_20_3e',['PtypeTraits< PROOK >',['../structosl_1_1PtypeTraits_3_01PROOK_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20psilver_20_3e',['PtypeTraits< PSILVER >',['../structosl_1_1PtypeTraits_3_01PSILVER_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20ptype_5fedge_20_3e',['PtypeTraits< PTYPE_EDGE >',['../structosl_1_1PtypeTraits_3_01PTYPE__EDGE_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20ptype_5fempty_20_3e',['PtypeTraits< PTYPE_EMPTY >',['../structosl_1_1PtypeTraits_3_01PTYPE__EMPTY_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20rook_20_3e',['PtypeTraits< ROOK >',['../structosl_1_1PtypeTraits_3_01ROOK_01_4.html',1,'osl']]],
-  ['ptypetraits_3c_20silver_20_3e',['PtypeTraits< SILVER >',['../structosl_1_1PtypeTraits_3_01SILVER_01_4.html',1,'osl']]],
+  ['ptypetraits',['PtypeTraits',['../structosl_1_1PtypeTraits.html',1,'osl']]],
+  ['ptypetraits_3c_20bishop_20_3e',['PtypeTraits&lt; BISHOP &gt;',['../structosl_1_1PtypeTraits_3_01BISHOP_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20gold_20_3e',['PtypeTraits&lt; GOLD &gt;',['../structosl_1_1PtypeTraits_3_01GOLD_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20king_20_3e',['PtypeTraits&lt; KING &gt;',['../structosl_1_1PtypeTraits_3_01KING_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20knight_20_3e',['PtypeTraits&lt; KNIGHT &gt;',['../structosl_1_1PtypeTraits_3_01KNIGHT_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20lance_20_3e',['PtypeTraits&lt; LANCE &gt;',['../structosl_1_1PtypeTraits_3_01LANCE_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20pawn_20_3e',['PtypeTraits&lt; PAWN &gt;',['../structosl_1_1PtypeTraits_3_01PAWN_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20pbishop_20_3e',['PtypeTraits&lt; PBISHOP &gt;',['../structosl_1_1PtypeTraits_3_01PBISHOP_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20pknight_20_3e',['PtypeTraits&lt; PKNIGHT &gt;',['../structosl_1_1PtypeTraits_3_01PKNIGHT_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20plance_20_3e',['PtypeTraits&lt; PLANCE &gt;',['../structosl_1_1PtypeTraits_3_01PLANCE_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20ppawn_20_3e',['PtypeTraits&lt; PPAWN &gt;',['../structosl_1_1PtypeTraits_3_01PPAWN_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20prook_20_3e',['PtypeTraits&lt; PROOK &gt;',['../structosl_1_1PtypeTraits_3_01PROOK_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20psilver_20_3e',['PtypeTraits&lt; PSILVER &gt;',['../structosl_1_1PtypeTraits_3_01PSILVER_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20ptype_5fedge_20_3e',['PtypeTraits&lt; PTYPE_EDGE &gt;',['../structosl_1_1PtypeTraits_3_01PTYPE__EDGE_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20ptype_5fempty_20_3e',['PtypeTraits&lt; PTYPE_EMPTY &gt;',['../structosl_1_1PtypeTraits_3_01PTYPE__EMPTY_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20rook_20_3e',['PtypeTraits&lt; ROOK &gt;',['../structosl_1_1PtypeTraits_3_01ROOK_01_4.html',1,'osl']]],
+  ['ptypetraits_3c_20silver_20_3e',['PtypeTraits&lt; SILVER &gt;',['../structosl_1_1PtypeTraits_3_01SILVER_01_4.html',1,'osl']]],
   ['ptypex',['PtypeX',['../classosl_1_1eval_1_1ml_1_1PtypeX.html',1,'osl::eval::ml']]],
   ['ptypey',['PtypeY',['../classosl_1_1eval_1_1ml_1_1PtypeY.html',1,'osl::eval::ml']]],
   ['ptypeypawny',['PtypeYPawnY',['../classosl_1_1eval_1_1ml_1_1PtypeYPawnY.html',1,'osl::eval::ml']]],
