@@ -7,10 +7,10 @@ var searchData=
   ['safemove',['SafeMove',['../structosl_1_1move__classifier_1_1SafeMove.html',1,'osl::move_classifier']]],
   ['searchallmoves',['SearchAllMoves',['../classosl_1_1game__playing_1_1SpeculativeAllMoves_1_1SearchAllMoves.html',1,'osl::game_playing::SpeculativeAllMoves']]],
   ['searchbase',['SearchBase',['../structosl_1_1search_1_1SearchBase.html',1,'osl::search']]],
-  ['searchbase_3c_20evalt_2c_20simplehashtable_2c_20countrecorder_2c_20realizationprobability_20_3e',['SearchBase< EvalT, SimpleHashTable, CountRecorder, RealizationProbability >',['../structosl_1_1search_1_1SearchBase.html',1,'osl::search']]],
+  ['searchbase_3c_20evalt_2c_20simplehashtable_2c_20countrecorder_2c_20realizationprobability_20_3e',['SearchBase&lt; EvalT, SimpleHashTable, CountRecorder, RealizationProbability &gt;',['../structosl_1_1search_1_1SearchBase.html',1,'osl::search']]],
   ['searcher',['Searcher',['../classSearcher.html',1,'']]],
-  ['searchinfo',['SearchInfo',['../structosl_1_1record_1_1SearchInfo.html',1,'osl::record']]],
   ['searchinfo',['SearchInfo',['../structosl_1_1search_1_1AlphaBeta3_1_1SearchInfo.html',1,'osl::search::AlphaBeta3']]],
+  ['searchinfo',['SearchInfo',['../structosl_1_1record_1_1SearchInfo.html',1,'osl::record']]],
   ['searchmonitor',['SearchMonitor',['../classosl_1_1search_1_1SearchMonitor.html',1,'osl::search']]],
   ['searchplayer',['SearchPlayer',['../classosl_1_1game__playing_1_1SearchPlayer.html',1,'osl::game_playing']]],
   ['searchrecorder',['SearchRecorder',['../classosl_1_1search_1_1SearchRecorder.html',1,'osl::search']]],
@@ -49,6 +49,7 @@ var searchData=
   ['simplehashtable',['SimpleHashTable',['../classosl_1_1search_1_1SimpleHashTable.html',1,'osl::search']]],
   ['simplemove',['SimpleMove',['../classosl_1_1effect__action_1_1SimpleMove.html',1,'osl::effect_action']]],
   ['simplepin',['SimplePin',['../classosl_1_1eval_1_1ml_1_1SimplePin.html',1,'osl::eval::ml']]],
+  ['simplepredictor',['SimplePredictor',['../classosl_1_1enter__king_1_1SimplePredictor.html',1,'osl::enter_king']]],
   ['simplestate',['SimpleState',['../classosl_1_1state_1_1SimpleState.html',1,'osl::state']]],
   ['simpletwinlist',['SimpleTwinList',['../structosl_1_1checkmate_1_1SimpleTwinList.html',1,'osl::checkmate']]],
   ['slist',['slist',['../structosl_1_1stl_1_1slist.html',1,'osl::stl']]],
@@ -59,8 +60,8 @@ var searchData=
   ['square',['Square',['../classosl_1_1Square.html',1,'osl']]],
   ['square8',['Square8',['../structosl_1_1container_1_1Square8.html',1,'osl::container']]],
   ['squarecompressor',['SquareCompressor',['../structosl_1_1SquareCompressor.html',1,'osl']]],
-  ['squarex',['SquareX',['../classosl_1_1move__probability_1_1SquareX.html',1,'osl::move_probability']]],
   ['squarex',['SquareX',['../classosl_1_1rating_1_1SquareX.html',1,'osl::rating']]],
+  ['squarex',['SquareX',['../classosl_1_1move__probability_1_1SquareX.html',1,'osl::move_probability']]],
   ['squarexgroup',['SquareXGroup',['../structosl_1_1rating_1_1SquareXGroup.html',1,'osl::rating']]],
   ['squarey',['SquareY',['../classosl_1_1rating_1_1SquareY.html',1,'osl::rating']]],
   ['squarey',['SquareY',['../classosl_1_1move__probability_1_1SquareY.html',1,'osl::move_probability']]],
@@ -68,12 +69,13 @@ var searchData=
   ['stack',['stack',['../structosl_1_1stl_1_1stack.html',1,'osl::stl']]],
   ['stack',['Stack',['../structosl_1_1game__playing_1_1TimeKeeper_1_1Stack.html',1,'osl::game_playing::TimeKeeper']]],
   ['standardcharacters',['StandardCharacters',['../structosl_1_1record_1_1StandardCharacters.html',1,'osl::record']]],
-  ['standardfeatureset',['StandardFeatureSet',['../classosl_1_1rating_1_1StandardFeatureSet.html',1,'osl::rating']]],
   ['standardfeatureset',['StandardFeatureSet',['../classosl_1_1move__probability_1_1StandardFeatureSet.html',1,'osl::move_probability']]],
+  ['standardfeatureset',['StandardFeatureSet',['../classosl_1_1rating_1_1StandardFeatureSet.html',1,'osl::rating']]],
   ['standelements',['StandElements',['../structosl_1_1search_1_1StandElements.html',1,'osl::search']]],
-  ['state',['State',['../structState.html',1,'']]],
+  ['standhash',['StandHash',['../structosl_1_1hash_1_1HashKey128_1_1StandHash.html',1,'osl::hash::HashKey128']]],
   ['state',['State',['../structosl_1_1game__playing_1_1GameState_1_1State.html',1,'osl::game_playing::GameState']]],
   ['state',['State',['../structosl_1_1misc_1_1BinaryReader_1_1State.html',1,'osl::misc::BinaryReader']]],
+  ['state',['State',['../structState.html',1,'']]],
   ['state',['State',['../structosl_1_1misc_1_1BinaryElementReader_1_1State.html',1,'osl::misc::BinaryElementReader']]],
   ['stateelements',['StateElements',['../structosl_1_1search_1_1StateElements.html',1,'osl::search']]],
   ['stateinfo',['StateInfo',['../structosl_1_1move__probability_1_1StateInfo.html',1,'osl::move_probability']]],
@@ -81,6 +83,7 @@ var searchData=
   ['staticinitializetracer',['StaticInitializeTracer',['../structosl_1_1misc_1_1StaticInitializeTracer.html',1,'osl::misc']]],
   ['statistics',['Statistics',['../structosl_1_1rating_1_1FeatureSet_1_1Statistics.html',1,'osl::rating::FeatureSet']]],
   ['statuslock',['StatusLock',['../structosl_1_1game__playing_1_1SpeculativeAllMoves_1_1SearchAllMoves_1_1StatusLock.html',1,'osl::game_playing::SpeculativeAllMoves::SearchAllMoves']]],
+  ['store',['Store',['../structosl_1_1search_1_1Store.html',1,'osl::search']]],
   ['store',['Store',['../structosl_1_1move__action_1_1Store.html',1,'osl::move_action']]],
   ['storepiece',['StorePiece',['../structosl_1_1effect__action_1_1StorePiece.html',1,'osl::effect_action']]],
   ['storeptypeosquare',['StorePtypeOSquare',['../structosl_1_1effect__action_1_1StorePtypeOSquare.html',1,'osl::effect_action']]],
