@@ -3,8 +3,7 @@ var searchData=
   ['v4',['V4',['../unionosl_1_1mobility_1_1V4.html',1,'osl::mobility']]],
   ['variance',['Variance',['../classosl_1_1stat_1_1Variance.html',1,'osl::stat']]],
   ['vector',['vector',['../structosl_1_1stl_1_1vector.html',1,'osl::stl']]],
-  ['vector',['vector',['../classstd_1_1vector.html',1,'']]],
-  ['vector_3c_20osl_3a_3amove_20_3e',['vector< osl::Move >',['../structosl_1_1stl_1_1vector.html',1,'osl::stl']]],
+  ['vector_3c_20osl_3a_3amove_20_3e',['vector&lt; osl::Move &gt;',['../structosl_1_1stl_1_1vector.html',1,'osl::stl']]],
   ['virtualpin',['VirtualPin',['../classosl_1_1effect__util_1_1VirtualPin.html',1,'osl::effect_util']]],
   ['vision',['Vision',['../structosl_1_1annotate_1_1AnalysesResult_1_1Vision.html',1,'osl::annotate::AnalysesResult']]],
   ['vision3',['Vision3',['../classosl_1_1annotate_1_1Vision3.html',1,'osl::annotate']]],
