@@ -1,9 +1,13 @@
 var searchData=
 [
   ['escape_2eh',['escape.h',['../feature_2escape_8h.html',1,'']]],
+  ['filepath_2ecc',['filePath.cc',['../filePath_8cc.html',1,'']]],
+  ['filepath_2eh',['filePath.h',['../filePath_8h.html',1,'']]],
+  ['find_2dalmost_2dentering_2ecc',['find-almost-entering.cc',['../find-almost-entering_8cc.html',1,'']]],
   ['find_2dlosing_2dmoves_2ecc',['find-losing-moves.cc',['../find-losing-moves_8cc.html',1,'']]],
   ['find_2dstates_2ecc',['find-states.cc',['../find-states_8cc.html',1,'']]],
   ['find_2duplevel_2dking_2ecc',['find-uplevel-king.cc',['../find-uplevel-king_8cc.html',1,'']]],
+  ['first_2dsearch_2deval_2ecc',['first-search-eval.cc',['../first-search-eval_8cc.html',1,'']]],
   ['firstmovethreatmate_2eh',['firstMoveThreatmate.h',['../firstMoveThreatmate_8h.html',1,'']]],
   ['fixed_2dcheckmate_2ecc',['fixed-checkmate.cc',['../fixed-checkmate_8cc.html',1,'']]],
   ['fixed_2dcheckmate2_2ecc',['fixed-checkmate2.cc',['../fixed-checkmate2_8cc.html',1,'']]],
