@@ -56,6 +56,8 @@ var searchData=
   ['simplehashtable_2eh',['simpleHashTable.h',['../simpleHashTable_8h.html',1,'']]],
   ['simplemove_2eh',['simpleMove.h',['../simpleMove_8h.html',1,'']]],
   ['simplemoveperf_2ecc',['simpleMovePerf.cc',['../simpleMovePerf_8cc.html',1,'']]],
+  ['simplepredictor_2ecc',['simplePredictor.cc',['../simplePredictor_8cc.html',1,'']]],
+  ['simplepredictor_2eh',['simplePredictor.h',['../simplePredictor_8h.html',1,'']]],
   ['simplestate_2ecc',['simpleState.cc',['../simpleState_8cc.html',1,'']]],
   ['simplestate_2eh',['simpleState.h',['../simpleState_8h.html',1,'']]],
   ['simplestate_2etcc',['simpleState.tcc',['../simpleState_8tcc.html',1,'']]],
