@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['checkmate_5ft',['checkmate_t',['../classosl_1_1search_1_1AlphaBeta2.html#ab399df5275be9d21b0fa5f489de954fc',1,'osl::search::AlphaBeta2::checkmate_t()'],['../classosl_1_1search_1_1AlphaBeta3.html#af6c5f506b6e28ba7c70dd87ff502a6cf',1,'osl::search::AlphaBeta3::checkmate_t()'],['../classosl_1_1search_1_1SearchState2Core.html#a6cb7b2bf743c1c7fb4d29a31d1838b03',1,'osl::search::SearchState2Core::checkmate_t()'],['../range-vs-nodes_8cc.html#a905a65f86802ae36f82d1b048200324c',1,'checkmate_t():&#160;range-vs-nodes.cc']]],
+  ['checkmate_5ft',['checkmate_t',['../classosl_1_1search_1_1AlphaBeta2.html#ab399df5275be9d21b0fa5f489de954fc',1,'osl::search::AlphaBeta2::checkmate_t()'],['../classosl_1_1search_1_1AlphaBeta3.html#af6c5f506b6e28ba7c70dd87ff502a6cf',1,'osl::search::AlphaBeta3::checkmate_t()'],['../classosl_1_1search4_1_1AlphaBeta4.html#acd8a08306d0cf437cb6b9bb6643e0d00',1,'osl::search4::AlphaBeta4::checkmate_t()'],['../classosl_1_1search_1_1SearchState2Core.html#a6cb7b2bf743c1c7fb4d29a31d1838b03',1,'osl::search::SearchState2Core::checkmate_t()'],['../range-vs-nodes_8cc.html#a905a65f86802ae36f82d1b048200324c',1,'checkmate_t():&#160;range-vs-nodes.cc']]],
   ['common_5ft',['common_t',['../classosl_1_1search_1_1AlphaBeta2Tree.html#ad54b80d3275d8ee381334db8d8a0a9b3',1,'osl::search::AlphaBeta2Tree']]],
   ['const_5fiterator',['const_iterator',['../structosl_1_1container_1_1GeneralSimpleHashTable_1_1Table.html#abda9ac262add98dc66153176e7b4145a',1,'osl::container::GeneralSimpleHashTable::Table::const_iterator()'],['../classosl_1_1misc_1_1CArray.html#a9f560fed003279236ff32643b4561209',1,'osl::misc::CArray::const_iterator()'],['../classosl_1_1misc_1_1FixedCapacityVector.html#a5bc742cdff3bc8d8d758791144c04d1b',1,'osl::misc::FixedCapacityVector::const_iterator()']]],
   ['const_5fproxy_5ft',['const_proxy_t',['../classosl_1_1misc_1_1CArray2d.html#a0148b52f0759e2542080ca4f783556d9',1,'osl::misc::CArray2d']]]
