@@ -17,6 +17,8 @@ var searchData=
   ['hash_5fhistory',['hash_history',['../classosl_1_1RepetitionCounter.html#acff71d9a165ee5301c1cae9b2a5c9df2',1,'osl::RepetitionCounter']]],
   ['hash_5fkey',['hash_key',['../structosl_1_1search_1_1AlphaBeta3_1_1SearchInfo.html#a2ffa6389907e8ad65faa99a2ace595b2',1,'osl::search::AlphaBeta3::SearchInfo::hash_key()'],['../structosl_1_1checkmate_1_1Dfpn_1_1NodeBase.html#a7322a567da2d218975f9db90c9ce4edc',1,'osl::checkmate::Dfpn::NodeBase::hash_key()']]],
   ['hashes',['hashes',['../structosl_1_1checkmate_1_1Dfpn_1_1Node.html#a1bd441f243b17ce164fb8c85cd1a4f3f',1,'osl::checkmate::Dfpn::Node']]],
+  ['hashmajorpawn',['HashMajorPawn',['../structosl_1_1hash_1_1HashKey128_1_1StandHash.html#a089942651fb3aee58094853d53e46f2c',1,'osl::hash::HashKey128::StandHash']]],
+  ['hashpiece',['HashPiece',['../structosl_1_1hash_1_1HashKey128_1_1StandHash.html#a147fdda4dfbf182cf9e1d7a157358b33',1,'osl::hash::HashKey128::StandHash']]],
   ['haslongmove',['hasLongMove',['../structosl_1_1PtypeFuns.html#af4407ddc1ce09693388464fb4da4fabf',1,'osl::PtypeFuns']]],
   ['hasmove',['hasMove',['../structosl_1_1PtypeDirectionTraits.html#a202eab073ea9de0a8f73e1499afb7bc8',1,'osl::PtypeDirectionTraits']]],
   ['haspawnmask',['hasPawnMask',['../classosl_1_1state_1_1SimpleState.html#acf43ab89bf409164f1f9355a4dd0643f',1,'osl::state::SimpleState']]],
