@@ -23,6 +23,10 @@ var searchData=
   ['width_5f',['width_',['../classosl_1_1stat_1_1Histogram.html#a5e70ed6a3069a1cd408c331ea3e8197c',1,'osl::stat::Histogram']]],
   ['window',['window',['../structosl_1_1search_1_1AlphaBeta2Tree_1_1NextQMove.html#a7d17f2dca57352552b2a81baae8f4a74',1,'osl::search::AlphaBeta2Tree::NextQMove::window()'],['../structosl_1_1search_1_1AlphaBeta2Tree_1_1NextMove.html#a991f05710a76bdba93c51c417ba9c057',1,'osl::search::AlphaBeta2Tree::NextMove::window()']]],
   ['winloss',['winloss',['../structResult.html#abc2b8eed2f8caf8421dfdc658f141151',1,'Result']]],
+  ['winning_5fthreshold_5fblack',['winning_threshold_black',['../namespaceosl_1_1enter__king.html#a16553430555153a7163b1839d63370de',1,'osl::enter_king']]],
+  ['winning_5fthreshold_5fblack_5f27',['winning_threshold_black_27',['../namespaceosl_1_1enter__king.html#a1d4729f819de4a13572c0aff7132126c',1,'osl::enter_king']]],
+  ['winning_5fthreshold_5fwhite',['winning_threshold_white',['../namespaceosl_1_1enter__king.html#a22d9014f79991ac091c59f72ae7505eb',1,'osl::enter_king']]],
+  ['winning_5fthreshold_5fwhite_5f27',['winning_threshold_white_27',['../namespaceosl_1_1enter__king.html#ae887cc1ad998d62a03c9d2adba37e8cc',1,'osl::enter_king']]],
   ['wins',['wins',['../classosl_1_1rating_1_1BradleyTerry_1_1Thread.html#a7f7048aa02a918d2941dcb3672060526',1,'osl::rating::BradleyTerry::Thread::wins()'],['../structWinLoss.html#a4b27140848b108cf25bf6196280ca2f8',1,'WinLoss::wins()']]],
   ['working_5fthreads',['working_threads',['../structosl_1_1checkmate_1_1DfpnRecordBase.html#ab7128ae47d7031e723b1bd57642c089d',1,'osl::checkmate::DfpnRecordBase']]],
   ['written',['written',['../classosl_1_1search_1_1analyzer_1_1DotWriter.html#a880b648617e75bd381e15f75f4d82aed',1,'osl::search::analyzer::DotWriter']]],
