@@ -3,7 +3,7 @@
 #ifndef OSL_CENTERING3X3_H
 #define OSL_CENTERING3X3_H
 
-#include "osl/position.h"
+#include "osl/square.h"
 #include "osl/misc/carray.h"
 
 namespace osl
@@ -15,12 +15,12 @@ namespace osl
   {
     struct Table 
     {
-      CArray<Position,Position::SIZE> centers;
+      CArray<Square,Square::SIZE> centers;
       Table();
     };
-    static const Position adjustCenterNaive(Position);
+    static const Square adjustCenterNaive(Square);
     static const Table table;
-    static const Position adjustCenter(Position src)
+    static const Square adjustCenter(Square src)
     {
       return table.centers[src.index()];
     }
