@@ -21,12 +21,12 @@ namespace osl
       static bool effectiveAttack(NumEffectState& state, Move move, int depth);
 
       /**
-       * 手番の側がPosition の駒を取っても詰みがないか．
+       * 手番の側がSquare の駒を取っても詰みがないか．
        * - target に利きがない場合はfalse
        * - 取る指手が全て取ると詰の場合は true
        * @param depth 0 なら ImmediateCheckmate のみ，2なら3手詰．
        */
-      static bool cannotCapture(NumEffectState& state, Position last_to, int depth);
+      static bool cannotCapture(NumEffectState& state, Square last_to, int depth);
 
       /** depth==0でeffectiveAttackになる可能性がなければfalse */
       static bool effectiveAttackCandidate0(const NumEffectState& state, Move move);
