@@ -25,16 +25,6 @@
 #  include <boost/thread/mutex.hpp>
 #endif
 
-#ifndef OSL_DFPN_MAX_DEPTH
-#  if (OSL_WORDSIZE == 32)
-#    define OSL_DFPN_MAX_DEPTH 256
-#  elif defined MINIMAL
-#    define OSL_DFPN_MAX_DEPTH 256
-#  else
-#    define OSL_DFPN_MAX_DEPTH 512
-#  endif
-#endif
-
 namespace osl
 {
   namespace checkmate
@@ -47,6 +37,8 @@ namespace osl
       struct List;
       boost::scoped_array<Table> table;
       size_t total_size;
+      int dfpn_max_depth;
+      size_t growth_limit, gc_threshold;
     public:
       DfpnTable(Player attack);
       DfpnTable();
@@ -54,6 +46,7 @@ namespace osl
       template <Player Attack>
       const DfpnRecord probe(const HashKey& key, PieceStand white) const;
       const DfpnRecord probe(const HashKey& key, PieceStand white) const;
+      size_t estimateNodeCount(const HashKey& key, bool dominance_max=false) const;
       template <Player Attack>
       const DfpnRecord findProofOracle(const HashKey& key, PieceStand white, Move last_move=Move()) const;
       const DfpnRecord findProofOracle(const HashKey& key, PieceStand white, Move last_move=Move()) const;
@@ -75,8 +68,15 @@ namespace osl
       size_t totalSize() { return total_size; }
       Player attack() const;
 
+      void setMaxDepth(int);
+      int maxDepth() const;
+
       void testTable();
       size_t smallTreeGC(size_t threshold=10);
+      /** set the maximum size of table (otherwise infinity).  this is one of preconditions to enable GC inside dfpn. */
+      void setGrowthLimit(size_t new_limit);
+      size_t growthLimit() const { return growth_limit; }
+      bool runGC();
     private:
 #ifdef OSL_DFPN_SMP
       typedef osl::misc::LightMutex Mutex;
@@ -101,6 +101,7 @@ namespace osl
       List *find(const HashKey& key, int subindex);
       template <Player Attack>
       const List *find(const HashKey& key, int subindex) const;
+      const List *find(const HashKey& key, int subindex) const;
     };
     /** 詰探索局面表 -- thread local */
     class DfpnPathTable;
@@ -110,7 +111,6 @@ namespace osl
     class Dfpn : boost::noncopyable
     {
     public:
-      enum { MaxDepth = OSL_DFPN_MAX_DEPTH };
       enum { DfpnMaxUniqMoves = CheckOrEscapeMaxUniqMoves };
       typedef CheckMoveVector DfpnMoveVector;
       typedef DfpnTable table_t;
@@ -129,7 +129,7 @@ namespace osl
     public:
       Dfpn();
       ~Dfpn();
-      void setTable(DfpnTable *new_table) { table = new_table; }
+      void setTable(DfpnTable *new_table);
       void setIllegal(const HashKey& key, PieceStand white);
       void setBlockingVerify(bool enable=true) { blocking_verify = enable; }
       void setParallel(int id, DfpnShared *s) 
@@ -166,8 +166,8 @@ namespace osl
       struct DepthLimitReached {};
 
       struct ProofOracle;
-      template <Player P, bool UseTable> void proofOracleAttack(const ProofOracle& oracle);
-      template <Player P, bool UseTable> void proofOracleDefense(const ProofOracle& oracle);
+      template <Player P, bool UseTable> void proofOracleAttack(const ProofOracle& oracle, int proof_limit);
+      template <Player P, bool UseTable> void proofOracleDefense(const ProofOracle& oracle, int proof_limit);
       template <Player P, bool UseTable> struct CallProofOracleAttack;      
       template <Player P, bool UseTable> struct CallProofOracleDefense;      
       /** 合駒が詰と判った直後に、同じような合駒を詰める */
@@ -204,6 +204,9 @@ namespace osl
       static void sort(const NumEffectState&, DfpnMoveVector&);
     private:
       void findDagSource();
+      void findDagSource(const HashKey& terminal_key,
+			 DfpnRecord& terminal_record,
+			 PieceStand terminal_stand, int offset=0);
     };
 
   }
