@@ -1,7 +1,7 @@
 /* immediateCheckmateTable.h
  */
-#ifndef _CHECKMATE_IMMEDIATE_CHECKMATE_TABLE_H
-#define _CHECKMATE_IMMEDIATE_CHECKMATE_TABLE_H
+#ifndef OSL_CHECKMATE_IMMEDIATE_CHECKMATE_TABLE_H
+#define OSL_CHECKMATE_IMMEDIATE_CHECKMATE_TABLE_H
 #include "osl/checkmate/king8Info.h"
 #include "osl/ptype.h"
 #include "osl/direction.h"
@@ -22,10 +22,13 @@ namespace osl
       CArray2d<unsigned short,PTYPE_SIZE,8> noEffectMasks;
     public:
       ImmediateCheckmateTable();
-
+      unsigned char dropPtypeMaskOf(unsigned int liberty_drop_mask) const
+      {
+	return dropPtypeMasks[liberty_drop_mask];
+      }
       unsigned char dropPtypeMask(King8Info canMoveMask) const
       {
-	return dropPtypeMasks[canMoveMask.libertyDropMask()];
+	return dropPtypeMaskOf(canMoveMask.libertyDropMask());
       }
       unsigned int ptypeDropMask(Ptype ptype,King8Info canMoveMask) const
       {
@@ -46,7 +49,7 @@ namespace osl
   }
 }
 
-#endif /* _CHECKMATE_IMMEDIATE_CHECKMATE_TABLE_H */
+#endif /* OSL_CHECKMATE_IMMEDIATE_CHECKMATE_TABLE_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
