@@ -15,7 +15,7 @@ namespace osl
       static const PieceStand leaf(const NumEffectState& state, 
 				   Player attacker, const PieceStand max)
       {
-	assert(state.getTurn() != attacker);
+	assert(state.turn() != attacker);
 	PieceStand result;
 	if (! effect_util::UnblockableCheck::isMember(alt(attacker), state))
 	  ProofPiecesUtil::addMonopolizedPieces(state, attacker, max, result);
