@@ -3,7 +3,7 @@
 #ifndef OSL_BITXMASK_H
 #define OSL_BITXMASK_H
 
-#include "osl/position.h"
+#include "osl/square.h"
 #include "osl/misc/carray.h"
 #include <iosfwd>
 
@@ -23,8 +23,8 @@ namespace osl
     void set(int x)   { mask |= (1 << x); }
     void clear(int x) { mask &=  ~(1 << x); }
 
-    void set(Position position)   { set(position.x()); }
-    void clear(Position position) { clear(position.x()); }
+    void set(Square position)   { set(position.x()); }
+    void clear(Square position) { clear(position.x()); }
   
     bool isSet(int x) const { return mask & (1<<x); }
 
