@@ -15,6 +15,18 @@ namespace osl
   {
     typedef MoveLogProbVectorBase base_t;
   public:
+    MoveLogProbVector() {}
+    explicit MoveLogProbVector(size_t size) : MoveLogProbVectorBase(size)
+    {
+    }
+    MoveLogProbVector(const MoveLogProbVector& src) : MoveLogProbVectorBase(src)
+    {
+    }
+    template <class RangeIterator>
+    MoveLogProbVector(const RangeIterator& first, const RangeIterator& last)
+      : MoveLogProbVectorBase(first, last)
+    {
+    }
     void push_back(Move move,int prob) {
       base_t::push_back(MoveLogProb(move,prob));
     }
