@@ -37,6 +37,10 @@ namespace osl
      */
     void dump(size_t last_n=0) const;
     void dump(std::ostream&, size_t last_n=0) const;
+    bool operator==(const MoveStack& r) const
+    {
+      return data == r.data;
+    }
   };
 } // namespace container
   using container::MoveStack;
