@@ -16,7 +16,7 @@
 #endif
 
 #ifndef OSL_NO_SSE
-#if (defined __x86_64) || (defined i386)
+#if (defined __x86_64__) || (defined __i386__)
 #  ifndef OSL_USE_SSE
 #    define OSL_USE_SSE 1
 #  endif
