@@ -1,7 +1,7 @@
 #ifndef _NOT_BY_ACTION_H
 #define _NOT_BY_ACTION_H
 #include "osl/piece.h"
-#include "osl/position.h"
+#include "osl/square.h"
 namespace osl
 {
   /**
@@ -19,13 +19,13 @@ namespace osl
     PieceFilter(Action & a,Piece p) :ac(a),piece(p){
     }
     template<Player P,Ptype Type>
-    void doActionPtype(Piece p1,Position to){
+    void doActionPtype(Piece p1,Square to){
       if(p1!=piece){
 	ac.template doActionPtype<P,Type>(p1,to);
       }
     }
     template<Player P>
-    void doAction(Piece p1,Position to){
+    void doAction(Piece p1,Square to){
       if(p1!=piece){
 	ac.template doAction<P>(p1,to);
       }
