@@ -21,21 +21,21 @@ namespace osl
       {
       }
       template<Player P,Ptype Type>
-      void doActionPtype(Piece p1,Position to){
-	Position from=p1.position();
+      void doActionPtype(Piece p1,Square to){
+	Square from=p1.square();
 	if(p1.isPromoted())
-	  ac.unknownMove(from,to,state.getPieceAt(to),promote(Type),false,P);
+	  ac.unknownMove(from,to,state.pieceAt(to),promote(Type),false,P);
 	else if(to.canPromote<P>() || from.canPromote<P>())
-	  ac.unknownMove(from,to,state.getPieceAt(to),promote(Type),true,P);
+	  ac.unknownMove(from,to,state.pieceAt(to),promote(Type),true,P);
       }
       template<Player P>
-      void doAction(Piece p1,Position to){
-	Position from=p1.position();
+      void doAction(Piece p1,Square to){
+	Square from=p1.square();
 	Ptype ptype=p1.ptype();
 	if(p1.isPromoted())
-	  ac.unknownMove(from,to,state.getPieceAt(to),ptype,false,P);
+	  ac.unknownMove(from,to,state.pieceAt(to),ptype,false,P);
 	else if(to.canPromote<P>() || from.canPromote<P>())
-	  ac.unknownMove(from,to,state.getPieceAt(to),promote(ptype),true,P);
+	  ac.unknownMove(from,to,state.pieceAt(to),promote(ptype),true,P);
       }
       bool done() const{ return false;}
     };
