@@ -18,8 +18,8 @@ namespace osl
     public:
       SimpleBetterToPromote(Action & a) :ac(a){}
       template<Player P,Ptype Type>
-      void doActionPtype(Piece p1,Position to){
-	Position from=p1.position();
+      void doActionPtype(Piece p1,Square to){
+	Square from=p1.square();
 	Ptype ptype=p1.ptype();
 	if(!isPromoted(ptype) && (to.canPromote<P>() || from.canPromote<P>()))
 	  ac.simpleMove(from,to,promote(Type),true,P);
@@ -27,8 +27,8 @@ namespace osl
 	  ac.simpleMove(from,to,ptype,false,P);
       }
       template<Player P>
-      void doAction(Piece p1,Position to){
-	Position from=p1.position();
+      void doAction(Piece p1,Square to){
+	Square from=p1.square();
 	Ptype ptype=p1.ptype();
 	if(!isPromoted(ptype) && (to.canPromote<P>() || from.canPromote<P>()))
 	  ac.simpleMove(from,to,promote(ptype),true,P);
