@@ -17,12 +17,12 @@ namespace osl
       {
       }
       template<Player P,Ptype Type>
-      void doActionPtype(Piece p, Position pos)
+      void doActionPtype(Piece p, Square pos)
       {
 	doAction<P>(p, pos);
       }
       template<Player P>
-      void doAction(Piece p, Position)
+      void doAction(Piece p, Square)
       {
 	store->push_back(p);
       }
