@@ -16,19 +16,19 @@ namespace osl
       template <int count_max>
       static int count(const PieceVector& direct_pieces, 
 		       const NumEffectState& state,
-		       Position target, Player attack)
+		       Square target, Player attack)
       {
 	int result=0;
 	BOOST_FOREACH(Piece p, direct_pieces)
 	{
-	  const Position from = p.position();
+	  const Square from = p.square();
 	  int num = p.number();
 	  const Direction long_d=Board_Table.getLongDirection<BLACK>(Offset32(target,from));
 	  if(!isLong(long_d)) continue; // unpromoted Knightを除いておくのとどちらが得か?
 	  Direction d=longToShort(long_d);
 	  for(;;){
 	    num=state.longEffectNumTable()[num][d];
-	    if(Piece::isEmptyNum(num) || state.getPieceOf(num).owner()!=attack)
+	    if(Piece::isEmptyNum(num) || state.pieceOf(num).owner()!=attack)
 	      break;
 	    if (++result >= count_max)
 	      return result;
