@@ -14,15 +14,15 @@ namespace osl
     {
     private:
       static bool hasEffectFromTo(const NumEffectState& state,
-				  PtypeO ptypeo, Position from, 
-				  Position target, Offset offset);
+				  PtypeO ptypeo, Square from, 
+				  Square target, Offset offset);
     public:
       static bool hasEffectNaive (const NumEffectState& state,
-				  PtypeO ptypeo, Position from, 
-				  Position target);
+				  PtypeO ptypeo, Square from, 
+				  Square target);
       static bool hasEffect(const NumEffectState& state,
-			    PtypeO ptypeo, Position from, 
-			    Position target)
+			    PtypeO ptypeo, Square from, 
+			    Square target)
       {
 	return hasEffectNaive(state, ptypeo, from, target);
       }
