@@ -33,6 +33,8 @@ namespace osl
 		       PtypeO ptypeo, Square from, 
 		       Square target) const
 	{
+	  assert(from.isOnBoard());
+	  assert(target.isOnBoard());
 	  const Offset32 offset32 = Offset32(target, from);
 	  const Entry& e = table[ptypeOIndex(ptypeo)][offset32.index()];
 	  if (e.has_unblockable_effect)
