@@ -17,20 +17,20 @@ namespace osl
     {
     private:
       template <int count_max>
-      static int count(const NumEffectState&, Position target, 
+      static int count(const NumEffectState&, Square target, 
 		       Player attack);
     public:
       /**
        * target に attack の影利きが一つでもあるか．
        * 相手の追加利きが先にある場合は対象としない．
        */
-      static bool hasEffect(const NumEffectState&, Position target, 
+      static bool hasEffect(const NumEffectState&, Square target, 
 			    Player attack);
       /**
        * target に attack の影利きを二つまで数える.
        * 相手の追加利きの駒以降は対象としない．
        */
-      static int count2(const NumEffectState&, Position target, 
+      static int count2(const NumEffectState&, Square target, 
 			      Player attack);
     };
   } // namespace effect_util
