@@ -20,15 +20,15 @@ namespace osl
        */
       static bool isMember(Player target, const NumEffectState& state)
       {
-	const Position king_position = state.getKingPosition(target);
+	const Square king_position = state.kingSquare(target);
 	Piece attacker_piece;
-	if (state.hasEffectBy(alt(target), king_position, attacker_piece))
+	if (state.hasEffectAt(alt(target), king_position, attacker_piece))
 	{
 	  if (attacker_piece == Piece::EMPTY())
 	    return true;	// multiple pieces
 
 	  // sigle check
-	  const Position from = attacker_piece.position();
+	  const Square from = attacker_piece.square();
 	  const EffectContent effect
 	    = Ptype_Table.getEffect(attacker_piece.ptypeO(), 
 				   from, king_position);
