@@ -12,12 +12,12 @@ namespace osl
     {
     private:
       template <Direction DIR>
-      static bool findDirection(const SimpleState& state, Position target,
+      static bool findDirection(const SimpleState& state, Square target,
 				Player defense, const PieceMask& remove)
       {
 	const Offset diff = Board_Table.getOffset(defense, DIR);
 	Piece p;
-	for (p=state.nextPiece(target, diff);;p=state.nextPiece(p.position(), diff)) {
+	for (p=state.nextPiece(target, diff);;p=state.nextPiece(p.square(), diff)) {
 	  if (! p.isPiece())
 	    return false;
 	  if (! remove.test(p.number()))
@@ -32,9 +32,9 @@ namespace osl
     public:
       /** remove が全て動くと defenseの玉に攻め方の効きが発生するか。*/
       static bool find(const NumEffectState& state, Player defense, const PieceMask& remove);
-      static bool find(const NumEffectState& state, Player defense, Position target)
+      static bool find(const NumEffectState& state, Player defense, Square target)
       {
-	return find(state, defense, state.getEffect(target));
+	return find(state, defense, state.effectSetAt(target));
       }
     };
   }
