@@ -23,26 +23,29 @@ namespace osl
 	  Table();
 	private:
 	  void adhoc_edge_king_1(const Player player,
-				 const Position king,
-				 const Position attack);
+				 const Square king,
+				 const Square attack);
 	  void adhoc_edge_king_2(const Player player,
-				 const Position king,
-				 const Position attack);
+				 const Square king,
+				 const Square attack);
 	};
-	static const Table table;
+	static Table table;
       public:
 	static int valueOf(const Piece king, const Piece attacker)
 	{
-	  return valueOf(king, attacker.ptypeO(), attacker.position());
+	  return valueOf(king, attacker.ptypeO(), attacker.square());
 	}
-	static int valueOf(Piece king, PtypeO ptypeo, Position position)
+	static int valueOf(Piece king, PtypeO ptypeo, Square position)
 	{
 	  assert(king.ptype() == KING);
 	  if (getOwner(ptypeo) == king.owner())
 	    return 0;
-	  return table.valueOf(king.position(), king.owner(), 
+	  return table.valueOf(king.square(), king.owner(), 
 			       position, getPtype(ptypeo));
 	}
+	static void saveText(const char *filename);
+	static void loadText(const char *filename) { table.loadText(filename); }
+	static void resetWeights(const int *w) { table.resetWeights(w); }
       };
     } // namespace endgame
   } // namespace endgame
