@@ -22,20 +22,23 @@ namespace osl
 	{
 	  Table();
 	};
-	static const Table table;
+	static Table table;
       public:
 	static int valueOf(const Piece king, const Piece defender)
 	{
-	  return valueOf(king, defender.ptypeO(), defender.position());
+	  return valueOf(king, defender.ptypeO(), defender.square());
 	}
-	static int valueOf(Piece king, PtypeO ptypeo, Position position)
+	static int valueOf(Piece king, PtypeO ptypeo, Square position)
 	{
 	  assert(king.ptype() == KING);
 	  if (getOwner(ptypeo) != king.owner())
 	    return 0;
-	  return table.valueOf(king.position(), king.owner(), 
+	  return table.valueOf(king.square(), king.owner(), 
 			       position, getPtype(ptypeo));
 	}
+	static void saveText(const char *filename) { table.saveText(filename); }
+	static void loadText(const char *filename) { table.loadText(filename); }
+	static void resetWeights(const int *w) { table.resetWeights(w); }
       };
     } // namespace endgame
   } // namespace endgame
