@@ -30,11 +30,12 @@ KingPieceValues<Eval>::setValues(const SimpleState& state, PieceValues& values)
 {
   values.fill(0);
   // 速度は無視
-  const Piece king_black = state.getKingPiece(BLACK);
-  const Piece king_white = state.getKingPiece(WHITE);
+  const Piece king_black = state.kingPiece(BLACK);
+  const Piece king_white = state.kingPiece(WHITE);
   
   for (int i=0; i<Piece::SIZE; i++) {
-    const Piece target = state.getPieceOf(i);
+    if(!state.usedMask().test(i)) continue;
+    const Piece target = state.pieceOf(i);
     values[i] = (Eval::valueOf(king_black, target) 
 		 + Eval::valueOf(king_white, target));
   }
