@@ -24,8 +24,8 @@ namespace osl
 	static table_t attack_table, defense_table;
 	static int index(const NumEffectState &,
 			 Player owner,
-			 const Position position,
-			 Position king)
+			 const Square position,
+			 Square king)
 	{
 	  return std::abs(position.x() - king.x()) * 17 +
 	    (owner == BLACK ? (king.y() - position.y()) :
@@ -33,16 +33,16 @@ namespace osl
 	}
 	static int index(const NumEffectState &state,
 			 Player owner,
-			 const Position position,
+			 const Square position,
 			 bool same_king)
 	{
-	  const Position king = state.getKingPosition(
+	  const Square king = state.kingSquare(
 	    same_king ? owner : alt(owner));
 	  return index(state, owner, position, king);
 	}
 	static int index(const NumEffectState &state,
 			 PtypeO ptypeo,
-			 const Position position,
+			 const Square position,
 			 bool same_king)
 	{
 	  return index(state, getOwner(ptypeo), position, same_king);
@@ -51,7 +51,7 @@ namespace osl
 			 const Piece piece,
 			 bool same_king)
 	{
-	  return index(state, piece.owner(), piece.position(), same_king);
+	  return index(state, piece.owner(), piece.square(), same_king);
 	}
 	enum { DIM = ((osl::PTYPE_MAX - osl::PTYPE_PIECE_MIN + 1) *
 		      (17 * 9)) * 2};
@@ -78,18 +78,18 @@ namespace osl
 	template <int Sign>
 	static void adjust(int attack, int defense, MultiInt& out);
       private:
-	static int index(const Player player, const Position king,
-			 const Ptype ptype, const Position pos)
+	static int index(const Player player, const Square king,
+			 const Ptype ptype, const Square pos)
 	{
 	  const int x = std::abs(pos.x() - king.x());
 	  const int y = (king.y() - pos.y()) *
 	    (player == osl::BLACK ? 1 : -1) + 8;
 	  return (ptype - osl::PTYPE_PIECE_MIN) * 17 * 9 + (x * 17 + y);
 	}
-	static int index(const Player player, const Position king,
+	static int index(const Player player, const Square king,
 			 const Piece piece)
 	{
-	  return index(player, king, piece.ptype(), piece.position());
+	  return index(player, king, piece.ptype(), piece.square());
 	}
 	static CArray<MultiInt, ONE_DIM> table;
       };
@@ -108,14 +108,14 @@ namespace osl
 	static void adjust(int black, int white, MultiInt &out);
       private:
 	template <Player KingPlayer>
-	static int index(const Piece p, const Position king)
+	static int index(const Piece p, const Square king)
 	{
-	  return index<KingPlayer>(p.ptypeO(), p.position(), king);
+	  return index<KingPlayer>(p.ptypeO(), p.square(), king);
 	}
 
 	template <Player KingPlayer>
-	static int index(const PtypeO ptypeO, const Position position,
-			 const Position king)
+	static int index(const PtypeO ptypeO, const Square position,
+			 const Square king)
 	{
 	  const int king_y = (KingPlayer == BLACK ? king.y() : 10 - king.y());
 	  const int piece_y = (KingPlayer == BLACK ? position.y() :
@@ -252,9 +252,9 @@ namespace osl
 			int white_effect, int white_piece)
 	{
 	  // ugly hack.  -1 is attack.  0 >= is defense
-	    return table[index(10 - state.getKingPosition<WHITE>().y(),
+	    return table[index(10 - state.kingSquare<WHITE>().y(),
 			       black_effect, black_piece)] -
-	      table[index(state.getKingPosition<BLACK>().y(),
+	      table[index(state.kingSquare<BLACK>().y(),
 			  white_effect, white_piece)];
 	}
       };
@@ -280,9 +280,9 @@ namespace osl
 			int black_effect, int black_piece,
 			int white_effect, int white_piece)
 	{
-	  return table[index(state.getKingPosition<BLACK>().y(),
+	  return table[index(state.kingSquare<BLACK>().y(),
 			     black_effect, black_piece)] -
-	    table[index(10 - state.getKingPosition<WHITE>().y(),
+	    table[index(10 - state.kingSquare<WHITE>().y(),
 			white_effect, white_piece)];
 	}
       };
@@ -306,13 +306,13 @@ namespace osl
 			int black_defense_effect, int black_defense_piece,
 			int white_defense_effect, int white_defense_piece)
 	{
-	  return attack_table[index(10 - state.getKingPosition<WHITE>().y(),
+	  return attack_table[index(10 - state.kingSquare<WHITE>().y(),
 				    black_attack_effect, black_attack_piece)] -
-	    attack_table[index(state.getKingPosition<BLACK>().y(),
+	    attack_table[index(state.kingSquare<BLACK>().y(),
 			       white_attack_effect, white_attack_piece)] +
-	    defense_table[index(state.getKingPosition<BLACK>().y(),
+	    defense_table[index(state.kingSquare<BLACK>().y(),
 				black_defense_effect, black_defense_piece)] -
-	    defense_table[index(10 - state.getKingPosition<WHITE>().y(),
+	    defense_table[index(10 - state.kingSquare<WHITE>().y(),
 				white_defense_effect, white_defense_piece)];
 	}
       };
@@ -365,10 +365,10 @@ namespace osl
 	  int white_attack_effect, int white_attack_piece,
 	  int black_stand_count, int white_stand_count)
 	{
-	  const int black_index = index(10 - state.getKingPosition<WHITE>().y(),
+	  const int black_index = index(10 - state.kingSquare<WHITE>().y(),
 					black_attack_effect, black_attack_piece,
 					black_stand_count);
-	  const int white_index = index(state.getKingPosition<BLACK>().y(),
+	  const int white_index = index(state.kingSquare<BLACK>().y(),
 					white_attack_effect, white_attack_piece,
 					white_stand_count);
 	  return table[black_index] - table[white_index];
@@ -425,7 +425,7 @@ namespace osl
 	  return table[black_index] - table[white_index];
 	}
       };
-      struct King25EmptyPositionNoEffect
+      struct King25EmptySquareNoEffect
       {
 	enum { DIM = 3 * 5 };
 	template <Player defense>
@@ -445,8 +445,8 @@ namespace osl
 	static void setUpBase(const Weights &weigths, CArray<int, 15>& table);
       };
 
-      class King25EmptyPositionNoEffectOpening
-	: public King25EmptyPositionNoEffect
+      class King25EmptySquareNoEffectOpening
+	: public King25EmptySquareNoEffect
       {
 	static CArray<int, 15> table;
       public:
@@ -455,8 +455,8 @@ namespace osl
 	static const CArray<int, 15>& weights() { return table; }
       };
 
-      class King25EmptyPositionNoEffectEnding
-	: public King25EmptyPositionNoEffect
+      class King25EmptySquareNoEffectEnding
+	: public King25EmptySquareNoEffect
       {
 	static CArray<int, 15> table;
       public:
@@ -473,10 +473,10 @@ namespace osl
       private:
 	static CArray<int, 1125> table;
 	template <Player player>
-	static int index(Position king,
-			 Position target);
-	static int index(Position king,
-			 Position target, Player player) {
+	static int index(Square king,
+			 Square target);
+	static int index(Square king,
+			 Square target, Player player) {
 	  if (player == BLACK)
 	    return index<BLACK>(king, target);
 	  else
@@ -520,10 +520,10 @@ namespace osl
 	static CArray<int, 5 * 3 * 8 * 3> table;
 	template <Player Defense>
 	static EffectState effectState(const NumEffectState &state,
-				       Position target);
+				       Square target);
 	template <Player Defense>
-	static int index(const NumEffectState &state, Position king,
-			 Position target);
+	static int index(const NumEffectState &state, Square king,
+			 Square target);
 	template <osl::Player Defense>
 	static int evalOne(const NumEffectState &state);
       public:
@@ -594,10 +594,10 @@ namespace osl
 	static CArray<int, 256> effect_state_table;
 	template <Player Defense>
 	static int effectStateIndex3(const NumEffectState &state,
-				     Position target);
+				     Square target);
 	template <Player Defense>
 	static void index(const NumEffectState &state, 
-			  Position target,
+			  Square target,
 			  int &index_xy,
 			  int rel_y, int king_x, int king_y, int x_diff
 	  );
@@ -654,7 +654,7 @@ namespace osl
 	  return ptypeOIndex(p1) * 32 + ptypeOIndex(p2) + 1024 * Dir;
 	}
 	template <Player King, Direction Dir>
-	static int indexY(const Position king_position,
+	static int indexY(const Square king_position,
 			  PtypeO p1, PtypeO p2)
 	{
 	  if (King == WHITE)
@@ -668,7 +668,7 @@ namespace osl
 	    + (king_y - 1) * 32 * 32 * 3;
 	}
 	template <Player King, Direction Dir>
-	static int indexX(const Position king_position,
+	static int indexX(const Square king_position,
 			  PtypeO p1, PtypeO p2)
 	{
 	  if (King == WHITE)
@@ -736,7 +736,7 @@ namespace osl
 	template <Player P>
 	static MultiInt evalOne(const NumEffectState &state);
 	template<Direction Dir>
-	static int mobilityDir(Position king,Position target)
+	static int mobilityDir(Square king,Square target)
 	{
 	  if(Dir==L) return king.x()-target.x()-1;
 	  else if(Dir==R) return target.x()-king.x()-1;
@@ -795,7 +795,7 @@ namespace osl
 	  return effect1 + 32 * (effect2 + 32 * i);
 	}
 	template <Player P>
-	static int indexX(Position king, int effect1, int effect2,
+	static int indexX(Square king, int effect1, int effect2,
 			  int i, int j)
 	{
 	  const int king_x = (king.x() >= 6 ? 10 - king.x() : king.x());
@@ -822,7 +822,7 @@ namespace osl
 				   (effect2 + 32 * i));
 	}
 	template <Player P>
-	static int indexY(Position king, int effect1, int effect2, int i)
+	static int indexY(Square king, int effect1, int effect2, int i)
 	{
 	  const int king_y = (P == BLACK ? king.y() : 10 - king.y());
 	  assert(0 <= effect1 && effect1 < 32);
@@ -867,7 +867,7 @@ namespace osl
 	  return effect1 + 32 * (effect2 + 32 * i);
 	}
 	template <Player Defense>
-	static int indexX(Position king, int effect1, int effect2, int i)
+	static int indexX(Square king, int effect1, int effect2, int i)
 	{
 	  const int king_x = (king.x() > 5 ? 10 - king.x() : king.x());
 	  if ((Defense == BLACK && king.x() > 5) ||
@@ -883,7 +883,7 @@ namespace osl
 	  return king_x - 1 + 5 * (effect1 + 32 * (effect2 + 32 * i));
 	}
 	template <Player Defense>
-	static int indexY(Position king, int effect1, int effect2, int i)
+	static int indexY(Square king, int effect1, int effect2, int i)
 	{
 	  const int king_y = (Defense == BLACK ? king.y() : 10 - king.y());
 	  assert(0 <= effect1 && effect1 < 32);
@@ -975,6 +975,49 @@ namespace osl
 	enum { ONE_DIM = 900, DIM = ONE_DIM * EvalStages };
 	static void setUp(const Weights &weights);
       };
+
+      class BishopExchangeSilverKing
+      {
+	static int indexKing(Square king) 
+	{
+	  const int y = king.y();
+	  if (y >= 3)
+	    return -1;
+	  return (y-1)*9 + king.x()-1;
+	}
+	static int indexRook(Square rook) 
+	{
+	  assert(rook.isOnBoard());
+	  const int y = rook.y();
+	  if (y >= 6)
+	    return -1;
+	  return (y-1)*9 + rook.x()-1;
+	}
+	static int indexSilver(Square silver) 
+	{
+	  return (silver.y()-1)*9 + silver.x()-1;
+	}
+      public:
+	enum { BISHOP_ONE_DIM = 18 * 81 * (45*2), DIM = BISHOP_ONE_DIM*3 };
+	static void setUp(const Weights &weights);
+	static int eval(const NumEffectState& state);
+      private:
+	template <Player KingOwner>
+	static int evalOne(const NumEffectState &state, int offset);
+	static CArray<int, DIM> table;
+      };
+
+      class EnterKingDefense
+      {
+      public:
+	enum { DIM = (8+8+8+8)*3 };
+	static void setUp(const Weights &weights);
+	static int eval(const NumEffectState &state);
+      private:
+	template <Player KingOwner>
+	static int evalOne(const NumEffectState &state);
+	static CArray<int, DIM> table;
+      };
     }
   }
 }
