@@ -650,6 +650,64 @@ namespace osl
 	  return ptype * 4 + is_rook * 2 + can_promote;
 	}
       };
+
+      class RookSilverKnight
+      {
+      public:
+	enum {
+	  ONE_DIM = 5 * 9 * 9 * 9 * 9 * 9,
+	  DIM = ONE_DIM * EvalStages
+	};
+	static void setUp(const Weights &weights);
+	static MultiInt eval(const NumEffectState &state);
+      private:
+	static CArray<MultiInt, ONE_DIM> table;	
+	static size_t index(int rook_x, int rook_y, int silver_x, int silver_y,
+			    int knight_x, int knight_y)
+	{
+	  return knight_y + 9 * (knight_x + 9 * (silver_y + 9 * (silver_x + 9 * (rook_y + 9 * rook_x))));
+	}
+      };
+
+      class BishopSilverKnight
+      {
+      public:
+	enum {
+	  ONE_DIM = 5 * 9 * 9 * 9 * 9 * 9,
+	  DIM = ONE_DIM * EvalStages
+	};
+	static void setUp(const Weights &weights);
+	static MultiInt eval(const NumEffectState &state);
+      private:
+	static CArray<MultiInt, ONE_DIM> table;	
+	static size_t index(int bishop_x, int bishop_y, int silver_x, int silver_y,
+			    int knight_x, int knight_y)
+	{
+	  return knight_y + 9 * (knight_x + 9 * (silver_y + 9 * (silver_x + 9 * (bishop_y + 9 * bishop_x))));
+	}
+      };
+
+      class AttackMajorsInBase
+      {
+      public:
+	enum {
+	  ONE_DIM = PTYPE_SIZE * PTYPE_SIZE * 2 * 2 * 2,
+	  DIM = ONE_DIM * EvalStages
+	};
+	static void setUp(const Weights &weights);
+	static MultiInt eval(const NumEffectState &state);
+      private:
+	static CArray<MultiInt, ONE_DIM> table;	
+	size_t maxActive() const { return 4; }
+	static int index(Ptype support, Ptype attack, bool has_gold, 
+			 bool rook_support, bool bishop_support)
+	{
+	  return (unpromoteSafe(support)*16 + unpromoteSafe(attack))*8+has_gold*4
+	    +rook_support*2+bishop_support;
+	}
+	template <Player Owner>
+	static void addOne(const NumEffectState &state, Piece rook, MultiInt&);
+      };
     }
   }
 }
