@@ -1723,6 +1723,20 @@ namespace osl
 	static CArray<MultiInt, ONE_DIM> table;
       };
 
+      class Promotion37
+      {
+      public:
+	enum { ONE_DIM = PTYPE_SIZE, DIM = ONE_DIM*EvalStages };
+	static void setUp(const Weights &weights);
+	static MultiInt eval(const NumEffectState &state);
+	template<Player P>
+	static MultiInt evalOne(const NumEffectState &state, int rank);
+	template<Player P>
+	static MultiInt evalWithUpdate(const NumEffectState &, Move moved,
+				       MultiInt const& last_value);
+
+	static CArray<MultiInt, ONE_DIM> table;
+      };
     }
   }
 }
