@@ -29,7 +29,7 @@ namespace osl
 	  int value = last_value;
 	  if (moved.isPass() || moved.isDrop())
 	    return last_value;
-	  if (moved.isPromote())
+	  if (moved.isPromotion())
 	  {
 	    value -= table[moved.oldPtypeO() - PTYPEO_MIN];
 	    value += table[moved.ptypeO() - PTYPEO_MIN];
