@@ -88,6 +88,21 @@ namespace osl
 	enum { ONE_DIM = 48, DIM = ONE_DIM * EvalStages };
 	static void setUp(const Weights &weights);
       };
+
+      class CheckShadowPtype 
+      {
+      public:
+	enum { 
+	  // rook v, rook h, bishop u, bishop d, lance
+	  ONE_DIM = PTYPE_SIZE * 5, 
+	  DIM = ONE_DIM * EvalStages 
+	};
+	static void setUp(const Weights &weights);
+	static MultiInt eval(const NumEffectState &state);
+	template <Player King>
+	static MultiInt evalOne(const NumEffectState &state);
+	static CArray<MultiInt, ONE_DIM> table;
+      };
     }
   }
 }
