@@ -25,6 +25,7 @@ namespace osl
 
 	/** user must initialize this before use */
 	static const PiecePairPieceTable Table;
+	static PtypeEvalTable Piece_Value;
       };
 
       /**
@@ -39,6 +40,8 @@ namespace osl
 	  : base_t(state)
 	{
 	}
+	static int adjustableDimension() { return PTYPE_SIZE; }
+	static void resetWeights(const int *w);
       };
       
     } // namespace ppair
