@@ -273,9 +273,14 @@ namespace osl
 	: ProgressEvalGeneral<progress_eval_opening_t>(state)
       {
       }
+      ProgressEval() 
+	: ProgressEvalGeneral<progress_eval_opening_t>(NumEffectState())
+      {
+      }
       static const PtypeEvalTable Piece_Value;
     };
   } // namespace eval
+  using eval::ProgressEval;
 } // namespace osl
 
 #endif /* EVAL_PROGRESSEVAL_H */
