@@ -23,7 +23,7 @@ namespace osl
 	silent = new_value;
       }
     private:
-      void readAndProcessCommand();
+      bool readAndProcessCommand();
       void processComputerMove(const search::MoveWithComment&, int seconds);
     };
   } // namespace game_playing
