@@ -15,7 +15,7 @@ namespace osl
   }
   namespace search
   {
-    class MoveWithComment;
+    struct MoveWithComment;
   }
   namespace game_playing
   {
