@@ -24,7 +24,8 @@ namespace osl
       void run();
       volatile int *stopFlag() { return &stop_by_outside; }
     protected:
-      virtual void readAndProcessCommand()=0;
+      /** @return read next command immediately */
+      virtual bool readAndProcessCommand()=0;
       virtual void processComputerMove(const search::MoveWithComment&, int seconds)=0;
     };
   } // namespace game_playing
