@@ -8,6 +8,7 @@ namespace osl
 {
   namespace game_playing
   {
+    struct GnuShogiQuit {};
     class GnuShogiClient : public CuiClient
     {
     public:
@@ -16,7 +17,7 @@ namespace osl
 		     std::istream&, std::ostream&);
       ~GnuShogiClient();
     private:
-      void readAndProcessCommand();
+      bool readAndProcessCommand();
       void processComputerMove(const search::MoveWithComment&, int seconds);
       void preComputeNextMove();
     };
