@@ -52,7 +52,7 @@ namespace osl
 	/** SearchBase::next_iteration_coefficient に設定するもの */
 	double next_iteration_coefficient;
 	/** 千日手に対するボーナス/ペナルティの歩の相対値. -2なら1歩損しても避ける */
-	int draw_coef;
+	double draw_coef;
 	bool save_pv;
 	uint64_t node_count_hard_limit;
 	/** 最善手以外も探索する幅 */
@@ -85,7 +85,7 @@ namespace osl
       void setNodeCountHardLimit(size_t node_limit);
       void setTableLimit(size_t size, int record_limit);
       void setVerbose(int verbose=1);
-      void setDrawCoef(int new_value) { config.draw_coef = new_value; }
+      void setDrawCoef(double new_value) { config.draw_coef = new_value; }
       void setNextIterationCoefficient(double new_value);
       double nextIterationCoefficient() const 
       {
