@@ -1,5 +1,5 @@
-#ifndef _HANDICAP_H
-#define _HANDICAP_H
+#ifndef OSL_HANDICAP_H
+#define OSL_HANDICAP_H
 namespace osl{
   enum Handicap{
     HIRATE,
@@ -7,4 +7,4 @@ namespace osl{
     //    KAKUOCHI,
   };
 }
-#endif // _HANDICAP_H
+#endif // OSL_HANDICAP_H
