@@ -1,10 +1,14 @@
 /* hashKey.h
  */
-#ifndef _HASH_KEY_H
-#define _HASH_KEY_H
+#ifndef OSL_HASH_KEY_H
+#define OSL_HASH_KEY_H
 
 #include "osl/config.h"
-#include "osl/hash/boardKey.h"
+#ifdef OSL_LONG_HASH_KEY
+#  include "osl/hash/boardKey.h"
+#else
+#  include "osl/hash/boardKey128.h"
+#endif
 #include "osl/piece.h"
 #include "osl/move.h"
 #include "osl/pieceStand.h"
@@ -15,20 +19,30 @@ namespace osl
 {
   namespace hash
   {
-#if OSL_WORDSIZE == 64
+#ifdef OSL_LONG_HASH_KEY
+#  if OSL_WORDSIZE == 64
     typedef HashKey64 HashKeyBase;
     typedef BoardKey64 BoardKey;
-#elif OSL_WORDSIZE == 32
+#  elif OSL_WORDSIZE == 32
     typedef HashKey32 HashKeyBase;
     typedef BoardKey32 BoardKey;
+#  endif
+#else
+    typedef HashKey128 HashKeyBase;
+    typedef BoardKey96 BoardKey;
 #endif
     class HashKey : public HashKeyBase
     {
     public:
       HashKey() :HashKeyBase(){}
       HashKey(const SimpleState&);
+#ifndef OSL_LONG_HASH_KEY
+      HashKey(uint64_t h0, uint32_t h1, uint32_t s)
+	: HashKeyBase(h0, h1, s)
+      {
+      }
+#endif
       const HashKey newHashWithMove(Move move) const;
-
       const HashKey newMakeMove(Move) const;
       const HashKey newUnmakeMove(Move) const;
 
@@ -41,16 +55,30 @@ namespace osl
 
     class HashGenTable
     {
-      CArray2d<HashKey,Square::SIZE,PTYPEO_SIZE> hashKey;
+#ifdef OSL_LONG_HASH_KEY
+      CArray2d<HashKey,Square::SIZE,PTYPEO_SIZE> key;
+#else
+      static const CArray2d<HashKey128Layout,Square::SIZE,PTYPEO_SIZE> key;
+#endif
     public:
       HashGenTable();
-      void addHashKey(HashKey& hk,Square pos,PtypeO ptypeo) const{
-	assert(pos.isValid() && isValidPtypeO(ptypeo));
-	hk+=hashKey[pos.index()][ptypeo-PTYPEO_MIN];
+#ifdef OSL_LONG_HASH_KEY
+      void addHashKey(HashKey& hk,Square sq,PtypeO ptypeo) const{
+	assert(sq.isValid() && isValidPtypeO(ptypeo));
+	hk+=key[sq.index()][ptypeo-PTYPEO_MIN];
       }
-      void subHashKey(HashKey& hk,Square pos,PtypeO ptypeo) const{
-	assert(pos.isValid() && isValidPtypeO(ptypeo));
-	hk-=hashKey[pos.index()][ptypeo-PTYPEO_MIN];
+      void subHashKey(HashKey& hk,Square sq,PtypeO ptypeo) const{
+	assert(sq.isValid() && isValidPtypeO(ptypeo));
+	hk-=key[sq.index()][ptypeo-PTYPEO_MIN];
+#else
+      static void addHashKey(HashKey& hk,Square sq,PtypeO ptypeo) {
+	assert(sq.isValid() && isValidPtypeO(ptypeo));
+	hk += HashKey128(key[sq.index()][ptypeo-PTYPEO_MIN]);
+      }
+      static void subHashKey(HashKey& hk,Square sq,PtypeO ptypeo) {
+	assert(sq.isValid() && isValidPtypeO(ptypeo));
+	hk -= HashKey128(key[sq.index()][ptypeo-PTYPEO_MIN]);
+#endif
       }
     };
     extern const HashGenTable Hash_Gen_Table;
@@ -99,7 +127,7 @@ namespace osl
 #endif
 } // namespace osl
 
-#endif /* _HASH_KEY_H */
+#endif /* OSL_HASH_KEY_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
