@@ -1,9 +1,10 @@
 /* hashRandom.h
  */
-#ifndef _HASHRANDOM_H
-#define _HASHRANDOM_H
+#ifndef OSL_HASHRANDOM_H
+#define OSL_HASHRANDOM_H
 
 #include "osl/hash/hashKey.h"
+#include "osl/misc/carray.h"
 
 namespace osl
 {
@@ -14,7 +15,7 @@ namespace osl
     public:
       static const size_t Length = 0x1000;
     private:
-      static int table[Length];
+      static CArray<int,Length> table;
     public:
       static void setUp(double sigma);
       static int value(size_t key) 
@@ -30,7 +31,7 @@ namespace osl
   using hash::HashRandom;
 }
 
-#endif /* _HASHRANDOM_H */
+#endif /* OSL_HASHRANDOM_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
