@@ -1,5 +1,5 @@
-#ifndef _MISC_UUENCODE_H
-#define _MISC_UUENCODE_H
+#ifndef OSL_MISC_UUENCODE_H
+#define OSL_MISC_UUENCODE_H
 
 #include <string>
 #include <boost/dynamic_bitset.hpp>
