@@ -18,12 +18,12 @@ namespace osl
     static int bsf(unsigned int mask)
     {
       assert(mask);
-#ifdef __x86_64
+#ifdef __x86_64__
       int ret;
       __asm__("bsfl %1,%0" : "=r"(ret) : "r"(mask));
       return ret;
 #else /* これ以下は 32bit 環境 */
-#  ifdef i386
+#  ifdef __i386__
       int ret;
       __asm__("bsfl %1,%0" : "=r"(ret) : "r"(mask));
       return ret;
@@ -45,12 +45,12 @@ namespace osl
     static unsigned short bsf(unsigned short mask)
     {
       assert(mask);
-#ifdef __x86_64
+#ifdef __x86_64__
       unsigned short ret;
       __asm__("bsfw %1,%0" : "=r"(ret) : "r"(mask));
       return ret;
 #else /* これ以下は 32bit 環境 */
-#  ifdef i386
+#  ifdef __i386__
       unsigned short ret;
       __asm__("bsfw %1,%0" : "=r"(ret) : "r"(mask));
       return ret;
@@ -67,7 +67,7 @@ namespace osl
     static int bsf(unsigned long long mask)
     {
       assert(mask);
-#ifdef __x86_64
+#ifdef __x86_64__
       long long ret;
       __asm__("bsfq %1,%0" : "=r"(ret) : "r"(mask));
       return static_cast<int>(ret);
@@ -89,12 +89,12 @@ namespace osl
     static int bsr(unsigned int mask)
     {
       assert(mask);
-#ifdef __x86_64
+#ifdef __x86_64__
       int ret;
       __asm__("bsrl %1,%0" : "=r"(ret) : "r"(mask));
       return ret;
 #else /* これ以下は 32bit 環境 */
-#  ifdef i386
+#  ifdef __i386__
       int ret;
       __asm__("bsrl %1,%0" : "=r"(ret) : "r"(mask));
       return ret;
@@ -117,7 +117,7 @@ namespace osl
     static int bsr(unsigned long long mask)
     {
       assert(mask);
-#ifdef __x86_64
+#ifdef __x86_64__
       long long ret;
       __asm__("bsrq %1,%0" : "=r"(ret) : "r"(mask));
       return static_cast<int>(ret);
