@@ -28,7 +28,11 @@ namespace osl
       return operator[](playerToIndex(p));
     }
   };
-
+  template <typename T, typename T2, size_t C>
+  inline bool operator==(const CArray2dProxy<T,C>& l, const CArray2dProxy<T2,C>& r)
+  {
+    return std::equal(l.a, l.a+C, r.a);
+  }
   /**
    * CArray の2次元版
    *
