@@ -1,5 +1,5 @@
-#ifndef _LOKI_H
-#define _LOKI_H
+#ifndef OSL_LOKI_H
+#define OSL_LOKI_H
 
 #include "osl/player.h"
 
