@@ -1,5 +1,5 @@
-#ifndef _NCORES_H
-#define _NCORES_H
+#ifndef OSL_NCORES_H
+#define OSL_NCORES_H
 namespace osl {
   namespace misc {
     /**
