@@ -1,7 +1,7 @@
 /* readme.h
  */
-#ifndef _README_H
-#define _README_H
+#ifndef OSL_MISC_README_H
+#define OSL_MISC_README_H
 
 namespace osl
 {
