@@ -1,7 +1,7 @@
 /* slowBsf.h
  */
-#ifndef _SLOWBSF_H
-#define _SLOWBSF_H
+#ifndef OSL_SLOWBSF_H
+#define OSL_SLOWBSF_H
 
 namespace osl
 {
@@ -28,7 +28,7 @@ namespace osl
 } // namespace misc
 } // namespace osl
 
-#endif /* _SLOWBSF_H */
+#endif /* OSL_SLOWBSF_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
