@@ -1,7 +1,7 @@
 /* trace.h
  */
-#ifndef _TRACE_H
-#define _TRACE_H
+#ifndef OSL_TRACE_H
+#define OSL_TRACE_H
 
 // #define OSL_STATIC_INITIALIZER_TRACE
 
@@ -22,7 +22,7 @@ namespace misc
 
 #define OSL_TRACE static osl::misc::StaticInitializeTracer tracer( __FILE__)
 
-#endif /* _TRACE_H */
+#endif /* OSL_TRACE_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
