@@ -12,17 +12,17 @@ namespace osl
      */
     class VoidAction {
     public:
-      void simpleMove(Position, Position, Ptype, bool, Player,Move){
+      void simpleMove(Square, Square, Ptype, bool, Player,Move){
       }
-      void unknownMove(Position, Position, Piece, Ptype, bool, Player,Move){
+      void unknownMove(Square, Square, Piece, Ptype, bool, Player,Move){
       }
-      void dropMove(Position, Ptype, Player,Move){
+      void dropMove(Square, Ptype, Player,Move){
       }
-      void simpleMove(Position, Position, Ptype, bool, Player){
+      void simpleMove(Square, Square, Ptype, bool, Player){
       }
-      void unknownMove(Position, Position, Piece, Ptype, bool, Player){
+      void unknownMove(Square, Square, Piece, Ptype, bool, Player){
       }
-      void dropMove(Position, Ptype, Player){
+      void dropMove(Square, Ptype, Player){
       }
     };
   } // namespace move_action
