@@ -26,8 +26,8 @@ namespace osl
       isMember(const NumEffectState& state, Move move)
       {
 	const PtypeO ptypeO = move.ptypeO();
-	Position from = move.to();
-	Position king = state.template getKingPosition <P> ();
+	Square from = move.to();
+	Square king = state.template kingSquare <P> ();
 	
 	return Neighboring25Direct::hasEffect(state, ptypeO, from, king);
       }
