@@ -3,7 +3,7 @@
 #ifndef _MOVE_CLASSIFIER_CAN_ATTACK_IN_NMOVES
 #define _MOVE_CLASSIFIER_CAN_ATTACK_IN_NMOVES
 #include "osl/piece.h"
-#include "osl/position.h"
+#include "osl/square.h"
 
 namespace osl
 {
@@ -12,8 +12,8 @@ namespace osl
     bool
     canAttackInThreeMoves (Player player,
 			   Ptype ptype,
-			   Position myPos,
-			   Position opKingPos);
+			   Square myPos,
+			   Square opKingPos);
   }//move_classifier
 }// osl
 #endif /* _MOVE_CLASSIFIER_CAN_ATTACK_IN_NMOVES */
