@@ -1,7 +1,7 @@
 /* check_.h
  */
-#ifndef _MOVE_CLASSIFIER_CHECK_H
-#define _MOVE_CLASSIFIER_CHECK_H
+#ifndef OSL_MOVE_CLASSIFIER_CHECK_H
+#define OSL_MOVE_CLASSIFIER_CHECK_H
 #include "osl/move_classifier/openCheck.h"
 #include "osl/move_classifier/directCheck.h"
 namespace osl
@@ -17,9 +17,8 @@ namespace osl
       /**
        * promote move の時 ptypeはpromote後のもの
        */
-      template<class State>
-      static bool isMember(const State& state, 
-			   Ptype ptype,Position from,Position to){
+      static bool isMember(const NumEffectState& state, 
+			   Ptype ptype,Square from,Square to){
 	if (DirectCheck<P>::isMember(state,ptype,to)) 
 	  return true;
 	if (from.isPieceStand()) 
