@@ -1,10 +1,10 @@
 /* directCheck.h
  */
-#ifndef _MOVE_CLASSIFIER_DIRECTCHECK_H
-#define _MOVE_CLASSIFIER_DIRECTCHECK_H
+#ifndef OSL_MOVE_CLASSIFIER_DIRECTCHECK_H
+#define OSL_MOVE_CLASSIFIER_DIRECTCHECK_H
 
 #include "osl/ptype.h"
-#include "osl/position.h"
+#include "osl/square.h"
 #include "osl/player.h"
 namespace osl
 {
@@ -13,25 +13,24 @@ namespace osl
     template <Player P>
     struct DirectCheck
     {
-      template<class State>
-      static bool isMember(const State& state, Ptype ptype, Position to)
+      static bool isMember(const NumEffectState& state, Ptype ptype, Square to)
       {
 	/**
 	 * 最初から王手ということはない．
 	 */
-	assert(!state.template hasEffectBy<P>(state.template getKingPosition<PlayerTraits<P>::opponent>()));
+	assert(!state.template hasEffectAt<P>(state.template kingSquare<PlayerTraits<P>::opponent>()));
 	/**
 	 * stateを動かしていないので，fromにある駒がtoからの利きを
 	 * blockすることは
 	 * あるが，blockされた利きが王手だったとすると，動かす前から王手
 	 * だったとして矛盾するのでOK
 	 */
-	return state.hasEffectFromTo(newPtypeO(P,ptype),to,
-				     state.template getKingPosition<PlayerTraits<P>::opponent>());
+	return state.hasEffectIf(newPtypeO(P,ptype),to,
+				     state.template kingSquare<PlayerTraits<P>::opponent>());
       }
 
       template<class State>
-      static bool isMember(const State& state, Ptype ptype, Position /*from*/, Position to)
+      static bool isMember(const State& state, Ptype ptype, Square /*from*/, Square to)
       {
 	return isMember(state, ptype, to);
       }
