@@ -14,11 +14,19 @@ namespace osl
     template <Player P>
     struct TrapRook
     {
-      static bool isMember(const NumEffectState& state, 
-			   Ptype ptype,Position from,Position to);
+      static bool
+#ifdef __GNUC__
+	__attribute__ ((pure))
+#endif
+      isMember(const NumEffectState& state, 
+	       Ptype ptype,Square from,Square to);
     private:
       template <Direction Dir>
-      static bool testDirection(const NumEffectState& state, Position initial);
+      static bool
+#ifdef __GNUC__
+	__attribute__ ((pure))
+#endif
+      testDirection(const NumEffectState& state, Square initial);
     };
   } // namespace move_classifier
 } // namespace osl
@@ -28,4 +36,5 @@ namespace osl
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
+// ;;; coding:utf-8
 // ;;; End:
