@@ -20,8 +20,8 @@ namespace osl
        * pawn に香車を打って追加利きをつける指手を生成.
        * 敵の利きがあるところで生成をやめる.
        */
-      static void generate(const NumEffectState&, Position pawn, MoveVector& out);
-      static void generateIfHasLance(const NumEffectState&, Position pawn, 
+      static void generate(const NumEffectState&, Square pawn, MoveVector& out);
+      static void generateIfHasLance(const NumEffectState&, Square pawn, 
 				     MoveVector& out);
     };
   } // namespace move_generator
