@@ -12,7 +12,7 @@ namespace osl
       template <class Action>
       static void generate(const NumEffectState& state, Action& action)
       {
-	PieceOnBoard<Action>::template generatePtype<P,KING>(state,state.getKingPiece<P>(),action);
+	PieceOnBoard<Action>::template generatePtype<P,KING>(state,state.kingPiece<P>(),action);
       }
       
     };
