@@ -15,7 +15,7 @@ namespace osl
     /**
      * 長い利きを止めている駒を動かして, 利きを伸ばす.
      * 
-     * ただし，駒を動かした結果, Position toに利くようなものは取り除く
+     * ただし，駒を動かした結果, Square toに利くようなものは取り除く
      */
     template<class Action>
     class Open
@@ -23,7 +23,7 @@ namespace osl
       // BOOST_CLASS_REQUIRE(Action,osl::move_action,Concept);
     public:
       template<Player P>
-      static void generate(const NumEffectState& state,Piece p,Action& action,Position to,Direction dir);
+      static void generate(const NumEffectState& state,Piece p,Action& action,Square to,Direction dir);
       
     };
 
@@ -32,7 +32,7 @@ namespace osl
       template<class Action>
       static void 
       generate(Player pl,const NumEffectState& state,Piece p,
-	       Action& action,Position to,Direction dir)
+	       Action& action,Square to,Direction dir)
       {
 	if (pl == BLACK)
 	  Open<Action>::template generate<BLACK>(state, p, action, to, dir);
