@@ -16,11 +16,11 @@ namespace osl
       template <class Action>
       static void generateDir(const NumEffectState& state, Action& action, const Direction& dir)
       {
-	Position pos = state.getKingPosition<P>()
+	Square pos = state.kingSquare<P>()
 	  + Board_Table.getOffset<P>(dir);
 	if (pos.isEdge()) return;
 
-	Piece piece = state.getPieceOnBoard(pos);
+	Piece piece = state.pieceOnBoard(pos);
 	if (piece != Piece::EMPTY() && piece.owner() == P)
 	{
 	  PieceOnBoard<Action>::template generate<P,false>(state, piece, action);
