@@ -29,9 +29,9 @@ namespace osl
 	{
 	  for (int y = start_y; y < start_y + 3; y++)
 	  {
-	    Position position(x, y);
-	    if (state.getPieceOnBoard(position).isEmpty()
-		&& !state.hasEffectBy(alt(P), position))
+	    Square position(x, y);
+	    if (state.pieceOnBoard(position).isEmpty()
+		&& !state.hasEffectAt(alt(P), position))
 	    {
 	      if (has_rook)
 	      {
