@@ -1418,7 +1418,8 @@ namespace osl
 	double sum = w[offset + index];
 	if (si.history->hasLastMove(2)) {
 	  Move my_last_move = si.history->lastMove(2);
-	  if (Neighboring8Direct::hasEffect
+	  if (my_last_move.isNormal()
+	      && Neighboring8Direct::hasEffect
 	      (*si.state, my_last_move.ptypeO(), my_last_move.to(), king))
 	    sum += w[offset + index + 1];
 	}
