@@ -30,7 +30,8 @@ namespace osl
       void addFinished();
       int dimension() const { return offsets.back(); }
     public:
-      double matchExp(const StateInfo&, Move, const double *weights) const;    
+      double matchExp(const StateInfo&, Move, const double *weights) const;
+      double matchNoExp(const StateInfo&, Move, const double *weights) const;    
       void generateLogProb(const StateInfo& state,
 			   MoveLogProbVector& out, const double *weights) const;
       double matchLight(const StateInfo&, Move, const double *weights) const;
@@ -62,6 +63,8 @@ namespace osl
       int logProbTakeBack(const StateInfo& state, Move target) const;
       int logProbSeePlus(const StateInfo& state, Move target) const;      
       double matchLight(const StateInfo&, Move) const;    
+      double matchExp(const StateInfo&, Move) const;
+      double matchNoExp(const StateInfo&, Move) const;
       bool setUp(bool verbose=false);
       bool ok() const { return initialized; }
     private:
