@@ -1,7 +1,7 @@
 /* neighboring8.h
  */
-#ifndef _NEIGHBORING8_H
-#define _NEIGHBORING8_H
+#ifndef OSL_NEIGHBORING8_H
+#define OSL_NEIGHBORING8_H
 
 #include "osl/boardTable.h"
 
@@ -9,7 +9,7 @@ namespace osl
 {
   struct Neighboring8
   {
-    static bool isNeighboring8(Position from,Position to)
+    static bool isNeighboring8(Square from,Square to)
     {
       return (from != to)
 	&& (to == from+Board_Table.getShortOffsetNotKnight(Offset32(to,from)));
@@ -18,7 +18,7 @@ namespace osl
 
 } // namespace osl
 
-#endif /* _NEIGHBORING8_H */
+#endif /* OSL_NEIGHBORING8_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
