@@ -4,6 +4,7 @@
 #define OSL_OFFSET_H
 
 #include "osl/player.h"
+#include "osl/direction.h"
 #include "osl/misc/loki.h"
 #include <iosfwd>
 
@@ -37,9 +38,12 @@ namespace osl
     Offset(int dx,int dy) : offset(makeOffset(dx,dy))
     {
     }
+    Offset(Player, Direction);
     Offset() : offset(OFFSET_ZERO)
     {
     }
+    template <Player, Direction>
+    static Offset make();	// defined in directionTraits.h
     static const Offset ZERO() { return Offset(OFFSET_ZERO); }
     int
 #ifdef __GNUC__
