@@ -15,8 +15,8 @@ namespace osl
   struct OslConfig
   {
     static const int MaxThreads=16;
-    /** compile時に指定されたディレクトリを返す. 実行時の指定は環境変数で */
-    static const std::string& home();
+    /** compile時に指定されたディレクトリを返す. 実行時の指定は環境変数が基本 */
+    static const std::string& home(const std::string& initialize_if_first_invocation="");
     static const char * home_c_str();
     static const std::string gpsusiConf();
 
@@ -93,8 +93,9 @@ namespace osl
 
     static bool healthCheck();
     static int resignThreshold();
+    static std::string configuration();
   private:
-    static const std::string makeHome();
+    static const std::string makeHome(const std::string& first_try="");
     static const std::string makeTest();
     static const std::string makeTestPublic();
     static bool isGoodDir(const std::string&);
