@@ -177,6 +177,26 @@ namespace osl
     bool isPtype() const{
       return (piece&0xf0000)==((T)<<BitOffsetPtype);
     }
+    /**
+     * あるpieceがPlayer pの持ち物でPtype ptypeであるかどうかをチェックする．
+     * TはEMPTY, EDGEではない．
+     */
+    bool isPlayerPtype(Player pl,Ptype ptype) const{
+      assert(PTYPE_PIECE_MIN<=ptype && ptype<=PTYPE_MAX);
+      return (piece&0x1f0000)==(((ptype)<<BitOffsetPtype)|(pl&0x100000));
+    }
+    /**
+     * あるpieceがPlayer pの持ち物でBASIC typeがptypeであるかどうかをチェックする．
+     * TはEMPTY, EDGEではない．
+     */
+    bool isPlayerBasicPtype(Player pl,Ptype ptype) const{
+      assert(PTYPE_PIECE_MIN<=ptype && ptype<=PTYPE_MAX);
+      assert(isBasic(ptype));
+      if(canPromote(ptype))
+	return (piece&0x170000)==(((osl::promote(ptype))<<BitOffsetPtype)|(pl&0x100000));
+      else
+	return isPlayerPtype(pl,ptype);
+    }
     bool isPiece() const {
       return (piece&0xc000)==0;
     }
