@@ -1,7 +1,7 @@
 /* pieceStandIO.h
  */
-#ifndef _PIECESTANDIO_H
-#define _PIECESTANDIO_H
+#ifndef OSL_PIECESTANDIO_H
+#define OSL_PIECESTANDIO_H
 #include <iosfwd>
 namespace osl
 {
