@@ -24,6 +24,10 @@ namespace osl{
     assert(ret==1 || ret== -1);
     return ret;
   }
+  inline int playerToSign(Player player)
+  {
+    return playerToMul(player);
+  }
   inline int playerToMask(Player player){
     return static_cast<int>(player);
   }
