@@ -17,7 +17,7 @@ namespace osl
       CheckmateIfCapture() : Feature("CC") {}
       bool match(const NumEffectState& state, Move move, const RatingEnv&) const
       {
-	return state.hasEffectBy(alt(move.player()), move.to())
+	return state.hasEffectAt(alt(move.player()), move.to())
 	  && checkmate::CheckmateIfCapture::effectiveAttackCandidate0(state, move)
 	  && checkmate::CheckmateIfCapture::effectiveAttack
 	  (const_cast<NumEffectState&>(state), move, 0); // XXX: evil cast
@@ -32,8 +32,8 @@ namespace osl
       struct Helper;
 
       static bool isCandidate(const NumEffectState& state, Move move);
-      static bool knight2Step(const NumEffectState& state, Move move, Position king);
-      static bool captureForKnightCheck(const NumEffectState& state, Move move, Position king);
+      static bool knight2Step(const NumEffectState& state, Move move, Square king);
+      static bool captureForKnightCheck(const NumEffectState& state, Move move, Square king);
     };
 
   }
