@@ -80,6 +80,7 @@ namespace osl
       void showStatistics(std::ostream&) const;
 
       static void normalize(const RatedMoveVector&, MoveLogProbVector& out);
+      static std::string defaultDirectory();
     protected:
       void add(Feature *f);
       void add(Group *g);
@@ -99,6 +100,7 @@ namespace osl
     public:
       explicit StandardFeatureSet(bool allow_load_failure=false);
       static const StandardFeatureSet& instance();
+      static bool healthCheck();
     };
 
     /** 駒得のみ*/
