@@ -4,7 +4,7 @@
 #define _RATINGENV_H
 
 #include "osl/container/moveStack.h"
-#include "osl/container/position8.h"
+#include "osl/container/square8.h"
 #include "osl/container/pieceMask.h"
 #include "osl/state/numEffectState.h"
 #include "osl/progress/progress16.h"
@@ -13,15 +13,16 @@ namespace osl
 {
   namespace rating
   {
-    struct RatingEnv
+    class RatingEnv
     {
+    public:
       MoveStack history;
-      Position8 sendoffs;
+      Square8 sendoffs;
       PieceMask my_pin, op_pin;
       int attack_count_for_turn;
       Progress16 progress;
-      mutable CArray<signed char,Position::SIZE> counteffect2_cache;
-      mutable CArray<int,Position::SIZE> pattern_cache;
+      mutable CArray<signed char,Square::SIZE> counteffect2_cache;
+      mutable CArray<int,Square::SIZE> pattern_cache;
 
       void update(const NumEffectState& new_state, Move last_move);
       void make(const NumEffectState& new_state);
