@@ -98,7 +98,7 @@ namespace osl
     class Characters
     {
     public:
-      static const osl::misc::CArray<std::string, 32> stand; 
+      static const misc::CArray<std::string, 32> stand; 
 
       virtual ~Characters();
 
@@ -144,11 +144,11 @@ namespace osl
     struct StandardCharacters : public Characters
     {
       /** 段数の文字 */
-      static const osl::misc::CArray<std::string,10> dan;
+      static const misc::CArray<std::string,10> dan;
       /** 筋の文字。駒の文字幅に合わせる必要がある。 */
-      static const osl::misc::CArray<std::string,10> suji;
+      static const misc::CArray<std::string,10> suji;
       /** 盤面上の駒の漢字文字 */
-      static const osl::misc::CArray<std::string,32> pieces;
+      static const misc::CArray<std::string,32> pieces;
 
       const std::string& getDan(const size_t index) const {return dan[index];} 
       const std::string& getSuji(const size_t index) const {return suji[index];} 
@@ -158,9 +158,9 @@ namespace osl
     /** ロシア文字（激指フォント用）*/
     struct RussianCharacters : public Characters
     {
-      static const osl::misc::CArray<std::string,10> dan;
-      static const osl::misc::CArray<std::string,10> suji;
-      static const osl::misc::CArray<std::string,32> pieces;
+      static const misc::CArray<std::string,10> dan;
+      static const misc::CArray<std::string,10> suji;
+      static const misc::CArray<std::string,32> pieces;
 
       const std::string& getDan(const size_t index) const {return dan[index];} 
       const std::string& getSuji(const size_t index) const {return suji[index];} 
@@ -170,9 +170,9 @@ namespace osl
     /** 柿木形式（KIF）。頭にv */
     struct KIFCharacters : public Characters
     {
-      static const osl::misc::CArray<std::string,10> dan;
-      static const osl::misc::CArray<std::string,10> suji;
-      static const osl::misc::CArray<std::string,32> pieces;
+      static const misc::CArray<std::string,10> dan;
+      static const misc::CArray<std::string,10> suji;
+      static const misc::CArray<std::string,32> pieces;
 
       const std::string& getDan(const size_t index) const {return dan[index];} 
       const std::string& getSuji(const size_t index) const {return suji[index];} 
@@ -205,15 +205,15 @@ namespace osl
        * @param state a state to show. 
        * @param last_move a color last_move is available unless it is null. 
        */
-      void print(const osl::state::SimpleState& state, 
-                 const osl::Move *last_move=NULL) const;
+      void print(const state::SimpleState& state, 
+                 const Move *last_move=NULL) const;
      
       void setBlackColor(const Color& c) {black_color = c;}
       void setWhiteColor(const Color& c) {white_color = c;}
       void setLastMoveColor(const Color& c) {last_move_color = c;}
     };
   } // namespace record
-} // NAMESPACE OSL
+} // namespace osl
 
 #endif /* RECORD_KANJIPRINT_H */
 // ;;; Local Variables:
