@@ -12,9 +12,13 @@ namespace osl
     namespace myshogi
     {
       std::string show(const NumEffectState& state);
+      std::string show(const NumEffectState& state,
+		       Move last_move,
+		       const NumEffectState& prev,
+		       bool add_csa_move=false);
       std::string show(Player);
       std::string show(Ptype);
-      std::string show(Position);
+      std::string show(Square);
       std::string show(Piece);
     }
   }
