@@ -18,13 +18,14 @@ namespace osl
 	typedef hash_map<HashKey,moves_t> table_t;
 	table_t table;
       public:
+	~BookInMemory();
+
 	void find(const HashKey& key, MoveVector& out) const;
 	size_t size() const { return table.size(); }
-	static const BookInMemory& instance();
+	static const BookInMemory& instance(const std::string& filename="");
       private:
-	BookInMemory();
-	~BookInMemory();
-	void readAll();
+	explicit BookInMemory(const std::string& filename);
+	void readAll(const std::string& filename);
 	int readRecursive(const HashKey& key, int index, WeightedBook& book, int, int);
       };
     }
