@@ -1,10 +1,11 @@
 /* psn.h
  */
-#ifndef _PSN_H
-#define _PSN_H
+#ifndef OSL_PSN_H
+#define OSL_PSN_H
 
 #include "osl/move.h"
 #include <string>
+#include <stdexcept>
 namespace osl
 {
   namespace state
@@ -19,6 +20,13 @@ namespace osl
      */
     namespace psn
     {
+      class ParseError : public std::invalid_argument
+      {
+      public:
+        ParseError(const std::string& msg = "")
+          : invalid_argument(msg)
+        { }
+      };
       const Move strToMove(const std::string&, const state::SimpleState&);
       const Square strToPos(const std::string&);
       Ptype charToPtype(char);
@@ -34,7 +42,7 @@ namespace osl
 } // osl
 
 
-#endif /* _PSN_H */
+#endif /* OSL_PSN_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
