@@ -108,6 +108,7 @@ namespace osl
       boost::gregorian::date start_date; // default : not_a_date_time
     public:
       Record();
+      Record(const SimpleState& initial, const vector<Move>& moves);
       void init();
       void setVersion(const std::string& str);
       const std::string getVersion() const { return version; }
@@ -138,6 +139,7 @@ namespace osl
 		    vector<SearchInfo>&) const;
       const NodeRecord* nodeOf(int index) const;
       const MoveRecord* moveOf(int index) const;
+      size_t moveRecordSize() const {return mrs.size();}
       void setResult(ResultType new_result) { result = new_result; }
       ResultType getResult() const { return result; }
       void setTounamentName(const std::string& name) { tounament_name = name; }
