@@ -19,8 +19,9 @@ namespace osl
   {
     namespace analyzer
     {
-      struct RecordSet : public container::PointerSet<SimpleHashRecord>
+      class RecordSet : public container::PointerSet<SimpleHashRecord>
       {
+      public:
 	RecordSet();
 	~RecordSet();
       };
