@@ -19,7 +19,7 @@ namespace osl
     class BigramKillerMove
     {
     private:
-      CArray2d<LRUMoves,Position::SIZE,PTYPEO_SIZE> killer_moves;
+      CArray2d<LRUMoves,Square::SIZE,PTYPEO_SIZE> killer_moves;
     public:
       BigramKillerMove();
       ~BigramKillerMove();
@@ -49,4 +49,5 @@ namespace osl
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
+// ;;; coding:utf-8
 // ;;; End:
