@@ -12,11 +12,11 @@ namespace osl
   {
     struct BreakThreatmate
     {
-      static void generateAddEffect(int limit, const NumEffectState&, Position to,
+      static void generateAddEffect(int limit, const NumEffectState&, Square to,
 				    const MoveVector& src, MoveLogProbVector& out);
-      static void generateBreakDrop(int limit, const NumEffectState&, Position to,
+      static void generateBreakDrop(int limit, const NumEffectState&, Square to,
 				    int default_prob, MoveLogProbVector& out);
-      static void generateOpenRoad(int limit, const NumEffectState&, Position target,
+      static void generateOpenRoad(int limit, const NumEffectState&, Square target,
 				   MoveLogProbVector& out);
       static void generate(int limit, const NumEffectState&, Move threatmate_move,
 			   MoveLogProbVector& out);
