@@ -13,10 +13,10 @@ namespace osl
      */
     struct FirstMoveThreatmate
     {
-      static bool isMember(Move last_move, Position king)
+      static bool isMember(Move last_move, Square king)
       {
 	const Ptype captured = last_move.capturePtype();
-	const Position to = last_move.to();
+	const Square to = last_move.to();
 	return ((captured != PTYPE_EMPTY)
 		|| (isMajor(last_move.ptype()))
 		|| (abs(to.x() - king.x()) + abs(to.y() - king.y()) < 8));
