@@ -14,8 +14,8 @@ namespace osl
   {
     class HashRejections
     {
-      class RootTable;
-      class Table;
+      struct RootTable;
+      struct Table;
       boost::shared_ptr<RootTable> root_table;
       boost::scoped_ptr<Table> table;
     public:
