@@ -26,6 +26,13 @@ namespace osl
       virtual void depthFinishedNormally(int depth);
       virtual void searchFinished();
     };
+
+    class CerrMonitor : public SearchMonitor
+    {
+    public:
+      void showPV(int depth, size_t node_count, double elapsed, int value, Move cur, const Move *first, const Move *last, 
+		  const bool *threatmate_first, const bool *threatmate_last);
+    };
   }
   using search::SearchMonitor;
 }
