@@ -55,7 +55,7 @@ namespace osl
 #endif
 	checkmate_count += count; 
       }
-      void setCheckmateCount(int count=1) { 
+      void setCheckmateCount(int count) { 
 #ifdef OSL_SMP
 	SCOPED_LOCK(lk,mutex);
 #endif
