@@ -25,7 +25,7 @@ namespace osl
       static void sortByMovingPiece(container::MoveVector& moves);
       /** 取る駒は考えない．from が一致する指手優先 */
       static void sortBySpecifiedPiece(container::MoveVector& moves, 
-				       Position from);
+				       Square from);
     };
   }
 }
