@@ -1,7 +1,7 @@
 /* sennichite.h
  */
-#ifndef _SENNICHITE_H
-#define _SENNICHITE_H
+#ifndef OSL_SENNICHITE_H
+#define OSL_SENNICHITE_H
 
 #include "osl/player.h"
 #include <iosfwd>
@@ -39,7 +39,7 @@ namespace osl
   std::ostream& operator<<(std::ostream&, const Sennichite&);
 } // namespace osl
 
-#endif /* _SENNICHITE_H */
+#endif /* OSL_SENNICHITE_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
