@@ -12,40 +12,41 @@ namespace osl
      */
     class Average
     {
-      double average;
+      double mean;
       int elements;
     public:
       // CREATORS
-      Average() : average(0), elements(0)
+      Average() : mean(0), elements(0)
       {
       }
       // MANIPULATORS
       /**
        * Add an element x
-       * @return difference between x and (old) average
+       * @return difference between x and (old) mean
        */
       double add(const double& x)
       {
 	++elements;
-	const double diff = x - average;
-	average += diff/elements;
+	const double diff = x - mean;
+	mean += diff/elements;
 	return diff;
       }
       void merge(const Average& r) 
       {
 	if (r.elements == 0)
 	  return;
-	const double sum = average*elements + r.average*r.elements;
+	const double sum = mean*elements + r.mean*r.elements;
 	elements += r.elements;
-	average = sum / elements;
+	mean = sum / elements;
       }
-      void clear()
+      void clear(double a=0.0, int e=0)
       {
-	average = 0.0;
-	elements = 0;
+	mean = a;
+	elements = e;
       }
       // ACCESSORS
-      double getAverage() const	{ return average; }
+      double getAverage() const	{ return mean; }
+      double average() const	{ return mean; }
       int numElements() const	{ return elements; }
     };
   } // namespace stat
