@@ -201,7 +201,6 @@ namespace osl
 	assert(p.owner() == P);
 	Direction d=pinnedDir<P>(p);
 	Square from=p.square();
-	assert(hasEffectIf(p.ptypeO(),from,to));
 	return primDir(d)==primDirUnsafe(Board_Table.getShort8Unsafe<P>(from,to));
       }
       bool pinnedCanMoveTo(Piece p,Square to) const
@@ -211,6 +210,25 @@ namespace osl
 	else
 	  return pinnedCanMoveTo<WHITE>(p, to);
       }
+      /**
+       * Pのpinされた駒から，そのpinの原因となっている長い利きを持つ駒を得る．
+       */
+      template<Player P>
+      Piece pinAttacker(Piece pinned) const
+      {
+	assert(pinned.owner() == P);
+	assert(pinOrOpen(P).test(pinned.number()));
+	Direction d=pinnedDir<P>(pinned);
+	int attacker_num=longEffectNumTable()[pinned.number()][(P==BLACK ? d : inverseUnsafe(d))];
+	return pieceOf(attacker_num);
+      }
+      Piece pinAttacker(Piece pinned) const
+      {
+	if (pinned.owner() == BLACK)
+	  return pinAttacker<BLACK>(pinned);
+	else
+	  return pinAttacker<WHITE>(pinned);
+      }
       // ----------------------------------------------------------------------
       // 3. あるSquareへの利き
       // ----------------------------------------------------------------------
