@@ -4,8 +4,6 @@
 #define STL_HASH_H
 #if (__GNUC__ >= 4 && __GNUC_MINOR__ >=3)
 #  include <tr1/functional>
-#elif (__GNUC__ && ! __clang__)
-#  include <ext/hash_fun.h>
 #else
 #  include <boost/functional/hash_fwd.hpp>
 #endif
@@ -22,11 +20,6 @@ namespace osl
     struct hash : public std::tr1::hash<T>
     {
     };
-#elif (defined __GNUC__ && ! defined __clang__)
-    template <class T>
-    struct hash : public __gnu_cxx::hash<T>
-    {
-    };
 #else
     template <class T>
     struct hash : public boost::hash<T>
