@@ -7,8 +7,6 @@
 #include "osl/stl/pool_allocator.h"
 #if (__GNUC__ >= 4 && __GNUC_MINOR__ >=3)
 #  include <tr1/unordered_map>
-#elif __GNUC__
-#  include <ext/hash_map>
 #else
 #  include <boost/unordered_map.hpp>
 #endif
@@ -41,19 +39,6 @@ namespace osl
     {
     }
 
-#elif defined __GNUC__
-    template<class Key, class Value, class HashFun=osl::stl::hash<Key>,
-	     class EqualKey=std::equal_to<Key>,class Alloc=pool_allocator<Value> >
-    struct hash_map
-      : public __gnu_cxx::hash_map<Key, Value, HashFun, EqualKey, Alloc>
-    {
-      typedef __gnu_cxx::hash_map<Key, Value, HashFun, EqualKey,
-				  Alloc> base_t;
-      hash_map() {}
-      hash_map(size_t s) : base_t(s)
-      {
-      }
-    };
 #else
     template<class Key, class Value, class HashFun=osl::stl::hash<Key>,
 	     class EqualKey=std::equal_to<Key>, class Alloc=pool_allocator<std::pair<const Key, Value> > >
@@ -72,11 +57,6 @@ namespace osl
     hash_map<Key,Value,HashFun,EqualKey,Alloc>::~hash_map()
     {
     }
-
-    template <class T>
-    struct hash : public boost::hash<T>
-    {
-    };
 #endif
   } // namespace stl
   using stl::hash_map;
