@@ -7,8 +7,6 @@
 #include "osl/stl/pool_allocator.h"
 #if (__GNUC__ >= 4 && __GNUC_MINOR__ >=3)
 #  include <tr1/unordered_set>
-#elif __GNUC__
-#  include <ext/hash_set>
 #else
 #  include <boost/unordered_set.hpp>
 #endif
@@ -29,19 +27,6 @@ namespace osl
       {
       }
     };
-#elif defined __GNUC__
-    template<class Value, class HashFun=osl::stl::hash<Value>,
-	     class Equal=std::equal_to<Value> >
-    struct hash_set
-      : public __gnu_cxx::hash_set<Value, HashFun, Equal, pool_allocator<Value> >
-    {
-      typedef __gnu_cxx::hash_set<Value, HashFun, Equal,
-				  pool_allocator<Value> > base_t;
-      hash_set() {}
-      hash_set(size_t s) : base_t(s)
-      {
-      }
-    };
 #else
     template<class Value, class HashFun=osl::stl::hash<Value>,
 	     class Equal=std::equal_to<Value> >
