@@ -1,12 +1,13 @@
-#ifndef _TEMPLATE_H
-#define _TEMPLATE_H
+#ifndef OSL_TEMPLATE_H
+#define OSL_TEMPLATE_H
 namespace osl
 {
 
 } // namespace osl
 
-#endif /* _TEMPLATE_H */
+#endif /* OSL_TEMPLATE_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
+// ;;; coding:utf-8
 // ;;; End:
