@@ -50,6 +50,30 @@ Analyzer::isCheckmate(NumEffectState& state, Move& best_move, bool attack, size_
 
 
 
+void osl::annotate::
+RepetitionAnalyzer::match(AnalysesResult& shared,
+			 const NumEffectState& src, const vector<Move>& moves,
+			 int last_move)
+{
+  shared.repetition.clear();
+  NumEffectState state; // assume initial position
+  HashKey key(state);
+  vector<HashKey> keys;
+  for (int i=0; i<=last_move; ++i) {
+    Move move = moves[i];
+    keys.push_back(key);
+    if (! state.isValidMove(move))
+      return;
+    key = key.newMakeMove(move);
+    state.makeMove(move);
+  }
+  if (HashKey(src) != key)
+    return;
+  for (size_t i=0; i<keys.size(); ++i) 
+    if (keys[i] == key)
+      shared.repetition.push_back(i);
+}
+
 void osl::annotate::
 CheckmateAnalyzer::match(AnalysesResult& shared,
 			 const NumEffectState& src, const vector<Move>& /*moves*/,
@@ -362,7 +386,8 @@ Vision3::match(AnalysesResult& shared,
   shared.vision.cur_eval
     = eval_t(s).value() * 200.0/eval_t::captureValue(newPtypeO(WHITE,PAWN));
   if (pv.value*eval::delta(s.turn()) 
-      < shared.vision.cur_eval*eval::delta(s.turn())+200)
+      < shared.vision.cur_eval*eval::delta(s.turn())+200
+      || abs(shared.vision.cur_eval) >= 1000)
     return;
   shared.vision.eval = pv.value;
   shared.vision.pv.push_back(pv.move);
