@@ -4,12 +4,18 @@
 #include "osl/checkmate/dualDfpn.h"
 #include "osl/game_playing/alphaBetaPlayer.h"
 #include "osl/game_playing/gameState.h"
+#include "osl/game_playing/usiState.h"
+#include "osl/game_playing/usiResponse.h"
 #include "osl/search/simpleHashTable.h"
 #include "osl/search/simpleHashRecord.h"
 #include "osl/record/csaString.h"
 #include "osl/record/csa.h"
+#include "osl/record/kanjiPrint.h"
+#include "osl/record/usi.h"
+#include <boost/make_shared.hpp>
 #include <string>
 #include <cstdio>
+#include <cstring>
 
 extern "C" 
 void osl_init()
@@ -79,6 +85,52 @@ int search(const char *state_str, int seconds, int verbose, char *move)
   return value;
 }
 
+extern "C"
+int usiMovesToKanji(const char *command, char *out, int out_size)
+{
+  assert(out_size>0);
+  osl::game_playing::UsiState usi_state;
+  osl::game_playing::UsiResponse res(usi_state, true, false);
+  std::string ret;
+
+  res.hasImmediateResponse(std::string(command), ret);
+
+  const int size = std::min(out_size, static_cast<int>(ret.size()));
+  memcpy(out, ret.c_str(), size);
+  return size;
+}
+
+extern "C"
+int usiMovesToPositionString(const char *moves_str, char *out, int out_size)
+{
+  assert(out_size>0);
+
+  osl::NumEffectState state;
+  osl::vector<osl::Move> moves;
+  std::istringstream is(moves_str);
+  std::string s;
+  while (is >> s) {
+    const osl::Move move = osl::record::usi::strToMove(s, state);
+    moves.push_back(move);
+    state.makeMove(move);
+  }
+  assert(!moves.empty());
+
+  osl::Move last_move;
+  if (! moves.empty()) {
+    last_move = moves.back();
+  }
+
+  std::ostringstream os;
+  osl::record::KanjiPrint printer(os, boost::make_shared<osl::record::KIFCharacters>());
+  printer.print(state, &last_move);
+
+  const std::string ret = os.str();
+  const int size = std::min(out_size, static_cast<int>(ret.size()));
+  memcpy(out, ret.c_str(), size);
+  return size;
+}
+
 /* ------------------------------------------------------------------------- */
 // ;;; Local Variables:
 // ;;; mode:c++
