@@ -1,17 +1,17 @@
 /* centering5x3.cc
  */
 #include "osl/centering5x3.h"
-#include "osl/position.h"
+#include "osl/square.h"
 
 osl::Centering5x3::
 Table::Table()
 {
-  centers.fill(Position::STAND());
+  centers.fill(Square::STAND());
   for (int y=1; y<=9; ++y)
   {
     for (int x=1; x<=9; ++x)
     {
-      const Position src = Position(x,y);
+      const Square src = Square(x,y);
       centers[src.index()] = adjustCenterNaive(src);
     }
   }
@@ -37,12 +37,12 @@ namespace
   }
 } // anonymous namespace
 
-const osl::Position osl::
-Centering5x3::adjustCenterNaive(Position src)
+const osl::Square osl::
+Centering5x3::adjustCenterNaive(Square src)
 {
   const int x = adjustCenterX(src.x());
   const int y = adjustCenterY(src.y());
-  return Position(x, y);
+  return Square(x, y);
 }
 
 /* ------------------------------------------------------------------------- */
