@@ -14,11 +14,13 @@
 #include "osl/centering5x3.h"
 #ifdef OSL_SMP
 #  include "osl/misc/lightMutex.h"
+#  include <boost/thread/condition.hpp>
 #endif
 #ifdef OSL_SHOW_PROOF_TREE_MIGRATION_STAT
 #  include "osl/stat/ratio.h"
 #endif
 #include "osl/misc/milliSeconds.h"
+#include "osl/oslConfig.h"
 #include <boost/foreach.hpp>
 #include <iostream>
 #include <iomanip>
@@ -53,8 +55,7 @@ struct osl::checkmate::DualDfpn::OraclePool
     }
   };
 #ifdef OSL_SMP
-  typedef osl::misc::LightMutex Mutex;
-  mutable Mutex mutex;
+  mutable boost::mutex mutex;
 #endif  
   typedef hash_map<HashKey, List> table_t;
   table_t table;
@@ -68,7 +69,7 @@ struct osl::checkmate::DualDfpn::OraclePool
     const Dfpn::ProofOracle oracle(key, PieceStand(WHITE, state));
     const std::pair<HashKey,HashKey> king = makeLargeKey(state);
 #ifdef OSL_SMP
-    SCOPED_LOCK(lk,mutex);
+    boost::mutex::scoped_lock lk(mutex);;
 #endif
     const Element e(oracle, proof_pieces, table.size(), state.inCheck());
     table[king.first].add(e);
@@ -78,7 +79,7 @@ struct osl::checkmate::DualDfpn::OraclePool
   {
     const std::pair<HashKey,HashKey> key = makeLargeKey(state);
 #ifdef OSL_SMP
-    SCOPED_LOCK(lk,mutex);
+    boost::mutex::scoped_lock lk(mutex);;
 #endif
     table_t::const_iterator p = table.find(key.first);
     if (p != table.end())
@@ -90,29 +91,29 @@ struct osl::checkmate::DualDfpn::OraclePool
   }
 
   template <Direction DIR>
-  static void addKey(HashKey& key, const SimpleState& state, Position target)
+  static void addKey(HashKey& key, const SimpleState& state, Square target)
   {
     const Offset offset = DirectionTraits<DIR>::blackOffset();
     target += offset;	// 8 近傍全て試すなら手番による符合変換は不要
-    const Piece piece = state.getPieceOnBoard(target);
+    const Piece piece = state.pieceOnBoard(target);
     hash::Hash_Gen_Table.addHashKey(key, target, piece.ptypeO());
   }
   template <Direction DIR, Direction DIR2>
-  static void addKey(HashKey& key, const SimpleState& state, Position target)
+  static void addKey(HashKey& key, const SimpleState& state, Square target)
   {
     const Offset offset = DirectionTraits<DIR>::blackOffset()
       + DirectionTraits<DIR2>::blackOffset();
     target += offset;
-    const Piece piece = state.getPieceOnBoard(target);
+    const Piece piece = state.pieceOnBoard(target);
     hash::Hash_Gen_Table.addHashKey(key, target, piece.ptypeO());
   }
   const HashKey makeKey(const SimpleState& state) const
   {
-    const Position target_king=state.getKingPosition(defender);
-    const Position center = Centering3x3::adjustCenter(target_king);
+    const Square target_king=state.kingSquare(defender);
+    const Square center = Centering3x3::adjustCenter(target_king);
     HashKey key;
     hash::Hash_Gen_Table.addHashKey(key, center, 
-				    state.getPieceOnBoard(center).ptypeO());
+				    state.pieceOnBoard(center).ptypeO());
     addKey<UL>(key, state, center); addKey<U> (key, state, center);
     addKey<UR>(key, state, center);
     addKey<L> (key, state, center); addKey<R> (key, state, center);
@@ -123,10 +124,10 @@ struct osl::checkmate::DualDfpn::OraclePool
   const std::pair<HashKey,HashKey> makeLargeKey(const SimpleState& state) const
   {
     HashKey key_small = makeKey(state), key_large;
-    const Position target_king=state.getKingPosition(defender);
-    const Position center = Centering5x3::adjustCenter(target_king);
+    const Square target_king=state.kingSquare(defender);
+    const Square center = Centering5x3::adjustCenter(target_king);
     hash::Hash_Gen_Table.addHashKey(key_large, center, 
-				    state.getPieceOnBoard(center).ptypeO());
+				    state.pieceOnBoard(center).ptypeO());
     addKey<UL>(key_large, state, center); addKey<U> (key_large, state, center);
     addKey<UR>(key_large, state, center);
     addKey<L> (key_large, state, center); addKey<R> (key_large, state, center);
@@ -146,12 +147,15 @@ struct osl::checkmate::DualDfpn::Shared
   CArray<OraclePool,2> pool;
   size_t main_node_count;
   size_t simulation_count;
+  volatile size_t last_gc, gc_threshold;
   CArray<stat::Average,max_oracle_list_size> proof_by_oracle;
   CArray<bool,2> blocking_verify;
 #ifdef OSL_SMP
-  LightMutex mutex;
+  boost::mutex mutex;
+  boost::condition condition;
   CArray<LightMutex,max_oracle_list_size> proof_by_oracle_mutex;
 #endif
+  volatile int shared_table_user, shared_table_gc_wait;
 #ifdef OSL_DFPN_SMP
   boost::scoped_ptr<DfpnParallel> parallel_search;
 #endif
@@ -159,7 +163,8 @@ struct osl::checkmate::DualDfpn::Shared
   typedef hash_map<HashKey, disproof_list_t> disproof_table_t;
   disproof_table_t disproof_table;
 
-  Shared() : main_node_count(0), simulation_count(0)
+  Shared() : main_node_count(0), simulation_count(0), last_gc(0), gc_threshold(10),
+	     shared_table_user(0), shared_table_gc_wait(0)
   {
     table[BLACK].setAttack(BLACK);
     table[WHITE].setAttack(WHITE);
@@ -189,17 +194,40 @@ struct osl::checkmate::DualDfpn::Shared
   void addMainNodeCount(int add)
   {
 #ifdef OSL_SMP
-    SCOPED_LOCK(lk,mutex);
+    boost::mutex::scoped_lock lk(mutex);;
 #endif
     main_node_count += add;
   }
   void addSimulationNodeCount(int add)
   {
 #ifdef OSL_SMP
-    SCOPED_LOCK(lk,mutex);
+    boost::mutex::scoped_lock lk(mutex);;
 #endif
     simulation_count += add;
   }
+  struct TableUseLock : boost::noncopyable
+  {
+    Shared *shared;
+    explicit TableUseLock(Shared *s) : shared(s)
+    {
+#  ifdef OSL_SMP
+      boost::mutex::scoped_lock lk(shared->mutex);
+      while (shared->shared_table_user < 0) // in gc
+	shared->condition.wait(lk);
+      shared->shared_table_user++;
+#  endif
+    }
+    ~TableUseLock()
+    {
+#  ifdef OSL_SMP
+      boost::mutex::scoped_lock lk(shared->mutex);
+      assert(shared->shared_table_user > 0);
+      shared->shared_table_user--;
+      if (shared->shared_table_user == 0 && shared->shared_table_gc_wait)
+	shared->condition.notify_all();
+#  endif
+    }
+  };
 };
 
 struct osl::checkmate::DualDfpn::Local
@@ -268,48 +296,88 @@ DualDfpn::prepareDfpnSmall(Player attack)
 }
 
 void osl::checkmate::
-DualDfpn::runGC()
+DualDfpn::runGC(bool verbose, size_t memory_use_ratio_1000)
 {
 #ifdef DFPN_SHARE_TABLE
+  const size_t unit_size = (sizeof(HashKey)+sizeof(DfpnRecord)+sizeof(char*)*2);
   size_t removed = 0;
   size_t total = shared->table[BLACK].size() + shared->table[WHITE].size();
-  if (total < local_table_growth_limit*8)
+  size_t current_use = memory_use_ratio_1000*(OslConfig::memoryUseLimit()/1000);
+  if (total < local_table_growth_limit*8
+      || total*unit_size*64 < OslConfig::memoryUseLimit()
+      || (total*unit_size*3 < current_use
+	  && total*unit_size*8 < OslConfig::memoryUseLimit()))
     return;
-# ifdef DFPN_DEBUG
   MilliSeconds start = MilliSeconds::now();
-#endif
   {
+    {
 #  ifdef OSL_SMP
-    SCOPED_LOCK(lk,shared->mutex);
+      boost::mutex::scoped_lock lk(shared->mutex);
 #  endif
-    removed += shared->table[BLACK].smallTreeGC();
-    removed += shared->table[WHITE].smallTreeGC();
+      total = shared->table[BLACK].size() + shared->table[WHITE].size();
+      if (total < local_table_growth_limit*8
+	  || (total*unit_size*3 < current_use
+	      && total*unit_size*6 < OslConfig::memoryUseLimit()))
+	return;
+      if (total < shared->last_gc + local_table_growth_limit*2)
+	return;
+      if (shared->shared_table_user > 0
+	  && memory_use_ratio_1000 < 650
+	  && total < shared->last_gc*2)
+	return;
+      if (shared->shared_table_user < 0 || shared->shared_table_gc_wait > 0)
+	return;
+#  ifdef OSL_SMP
+      while (shared->shared_table_user > 0) {
+	++shared->shared_table_gc_wait;
+	shared->condition.wait(lk);
+	--shared->shared_table_gc_wait;
+      }
+      if (shared->shared_table_user < 0)
+	return;
+#  endif
+      shared->shared_table_user--;
+    }
+    removed += shared->table[BLACK].smallTreeGC(shared->gc_threshold);
+    removed += shared->table[WHITE].smallTreeGC(shared->gc_threshold);
+    {
+#  ifdef OSL_SMP
+      boost::mutex::scoped_lock lk(shared->mutex);
+#  endif
+      if (total > shared->last_gc*2) {
+	if (100.0*removed/total < 70)
+	  shared->gc_threshold += 15;
+	else if (100.0*removed/total < 90)
+	  shared->gc_threshold += 5;
+      }
+      shared->last_gc = total - removed;
+      shared->shared_table_user++;
+      assert(shared->shared_table_user == 0);
+#  ifdef OSL_SMP
+      shared->condition.notify_all();
+#  endif
+    }
   }
-# ifdef DFPN_DEBUG
+  if (! verbose) 
+    return;
   const double elapsed = start.elapsedSeconds();
   if (removed > 10000 || elapsed > 0.1)
     std::cerr << " GC " << removed
 	      << " entries " << std::setprecision(3)
-	      << ((sizeof(HashKey)+sizeof(DfpnRecord)+sizeof(char*)*2)
-		  * removed / (1<<20)) << "MB "
+	      << (unit_size * removed / (1<<20)) << "MB "
 	      << 100.0*removed/total << "%"
 	      << " (" << elapsed << " s)\n";
-#  endif
 #endif
 }
 
 
 template <osl::Player P>
-bool
-#if (defined __GNUC__) && (! defined GPSONE) && (! defined GPSUSIONE)
-__attribute__ ((noinline))
-#endif
- osl::checkmate::
-DualDfpn::isWinningState(int node_limit, const NumEffectState& state, 
-			 const HashKey& key, const PathEncoding& path,
-			 Move& best_move, Move last_move)
+osl::ProofDisproof osl::checkmate::
+DualDfpn::findProof(int node_limit, const NumEffectState& state, 
+		    const HashKey& key, const PathEncoding& path,
+		    Move& best_move, Move last_move)
 {
-  assert(state.getTurn() == P);
+  assert(state.turn() == P);
   // oracle
   Dfpn& dfpn = prepareDfpn(P);
   const OraclePool::List l = shared->pool[P].probe(state);
@@ -336,22 +404,22 @@ DualDfpn::isWinningState(int node_limit, const NumEffectState& state,
     if (pdp.isCheckmateSuccess()) 
       assert(best_move.isNormal());
     if (pdp.isFinal())
-      return pdp.isCheckmateSuccess();
+      return pdp;
   }
   if (node_limit == 0 && num_tried) 
-    return false;			// already tested table
+    return ProofDisproof(1,1);			// already tested table
   const ProofDisproof table_pdp = dfpn.hasCheckmateMove(state, key, path, 0, best_move, last_move);
   if (table_pdp.isCheckmateSuccess())
-    return true;
+    return table_pdp;
   {
 #ifdef OSL_SMP
-    SCOPED_LOCK(lk,shared->mutex);
+    boost::mutex::scoped_lock lk(shared->mutex);
 #endif
     Shared::disproof_table_t::const_iterator p = shared->disproof_table.find(key);
     if (p != shared->disproof_table.end()) {
       BOOST_FOREACH(const PathEncoding& ppath, p->second)
 	if (ppath == path)
-	  return false;
+	  return ProofDisproof::LoopDetection();
     }
   }
 #ifdef OSL_SHOW_PROOF_TREE_MIGRATION_STAT
@@ -370,12 +438,12 @@ DualDfpn::isWinningState(int node_limit, const NumEffectState& state,
     shared->addMainNodeCount(count);
     if (pdp.isLoopDetection()) {
 #ifdef OSL_SMP
-      SCOPED_LOCK(lk,shared->mutex);
+      boost::mutex::scoped_lock lk(shared->mutex);
 #endif
       shared->disproof_table[key].push_front(path);
     }
     if (! pdp.isCheckmateSuccess())
-      return false;
+      return pdp;
     assert(best_move.isNormal());
     // fall through if checkmate success (TODO: efficient proof tree migration)
 #ifdef OSL_SHOW_PROOF_TREE_MIGRATION_STAT
@@ -383,6 +451,7 @@ DualDfpn::isWinningState(int node_limit, const NumEffectState& state,
 #endif
   }
   // main
+  Shared::TableUseLock lk(&*shared);
   PieceStand proof_pieces;
   const ProofDisproof pdp = dfpn.hasCheckmateMove(state, key, path, node_limit, best_move, proof_pieces, last_move);
   const size_t count = dfpn.nodeCount();
@@ -396,13 +465,24 @@ DualDfpn::isWinningState(int node_limit, const NumEffectState& state,
 #endif
   if (pdp.isLoopDetection()) {
 #ifdef OSL_SMP
-    SCOPED_LOCK(lk,shared->mutex);
+    boost::mutex::scoped_lock lk(shared->mutex);
 #endif
     shared->disproof_table[key].push_front(path);
   }
   if (pdp.isCheckmateSuccess())
     assert(best_move.isNormal());
-  return pdp.isCheckmateSuccess();
+  return pdp;
+}
+
+osl::checkmate::ProofDisproof osl::checkmate::
+DualDfpn::findProof(int node_limit, const NumEffectState& state, 
+		    const HashKey& key, const PathEncoding& path,
+		    Move& best_move, Move last_move)
+{
+  if (state.turn() == BLACK)
+    return findProof<BLACK>(node_limit, state, key, path, best_move, last_move);
+  else
+    return findProof<WHITE>(node_limit, state, key, path, best_move, last_move);
 }
 
 bool osl::checkmate::
@@ -410,19 +490,13 @@ DualDfpn::isWinningState(int node_limit, const NumEffectState& state,
 			   const HashKey& key, const PathEncoding& path,
 			   Move& best_move, Move last_move)
 {
-  if (state.getTurn() == BLACK)
-    return isWinningState<BLACK>(node_limit, state, key, path, best_move, last_move);
-  else
-    return isWinningState<WHITE>(node_limit, state, key, path, best_move, last_move);
+  return findProof(node_limit, state, key, path, best_move, last_move)
+    .isCheckmateSuccess();
 }
 
 #ifdef OSL_DFPN_SMP
 template <osl::Player P>
-bool
-#if (defined __GNUC__) && (! defined GPSONE) && (! defined GPSUSIONE)
-__attribute__ ((noinline))
-#endif
-osl::checkmate::
+bool osl::checkmate::
 DualDfpn::isWinningStateParallel(int node_limit, const NumEffectState& state, 
 				 const HashKey& key, const PathEncoding& path,
 				 Move& best_move, Move last_move)
@@ -432,7 +506,7 @@ DualDfpn::isWinningStateParallel(int node_limit, const NumEffectState& state,
   ProofDisproof pdp;
   {
 #ifdef OSL_SMP
-    SCOPED_LOCK(lk,shared->mutex);
+    boost::mutex::scoped_lock lk(shared->mutex);
 #endif
     if (! shared->parallel_search)
       shared->parallel_search.reset(new DfpnParallel(std::min(OslConfig::numCPUs(), 8)));
@@ -462,7 +536,7 @@ DualDfpn::isWinningStateParallel(int node_limit, const NumEffectState& state,
 				 const HashKey& key, const PathEncoding& path,
 				 Move& best_move, Move last_move)
 {
-  if (state.getTurn() == BLACK)
+  if (state.turn() == BLACK)
     return isWinningStateParallel<BLACK>(node_limit, state, key, path, best_move, last_move);
   else
     return isWinningStateParallel<WHITE>(node_limit, state, key, path, best_move, last_move);
@@ -471,15 +545,13 @@ DualDfpn::isWinningStateParallel(int node_limit, const NumEffectState& state,
 
 template <osl::Player P>
 bool
-#if (defined __GNUC__) && (! defined GPSONE) && (! defined GPSUSIONE)
-__attribute__ ((noinline))
-#endif
  osl::checkmate::
-DualDfpn::isLosingState(int node_limit, NumEffectState& state, 
+DualDfpn::isLosingState(int node_limit, const NumEffectState& state, 
 			const HashKey& key, const PathEncoding& path,
 			Move last_move)
 {
-  assert(state.getTurn() == P);
+  Shared::TableUseLock lk(&*shared);
+  assert(state.turn() == P);
   Dfpn& dfpn = prepareDfpn(alt(P));
   const ProofDisproof pdp = dfpn.hasEscapeMove(state, key, path, node_limit, last_move);
   const size_t count = dfpn.nodeCount();
@@ -489,11 +561,11 @@ DualDfpn::isLosingState(int node_limit, NumEffectState& state,
 }
 
 bool osl::checkmate::
-DualDfpn::isLosingState(int node_limit, NumEffectState& state, 
+DualDfpn::isLosingState(int node_limit, const NumEffectState& state, 
 			  const HashKey& key, const PathEncoding& path,
 			  Move last_move)
 {
-  if (state.getTurn() == BLACK)
+  if (state.turn() == BLACK)
     return isLosingState<BLACK>(node_limit, state, key, path, last_move);
   else
     return isLosingState<WHITE>(node_limit, state, key, path, last_move);
@@ -505,6 +577,7 @@ DualDfpn::writeRootHistory(const RepetitionCounter& counter,
 			   const SimpleState& state, Player attack)
 {
   // TODO: 局面表をクリアしてしまうと忘れられる => DualDfpn 内で記憶した方が良い
+  Shared::TableUseLock lk(&*shared);
   Dfpn& dfpn = prepareDfpn(attack);
   PieceStand white_stand(WHITE, state);
   for (int i=0; i<counter.checkCount(attack); ++i)
@@ -538,6 +611,7 @@ DualDfpn::setVerbose(int /*level*/)
 int osl::checkmate::
 DualDfpn::distance(Player attack, const HashKey& key)
 {
+  Shared::TableUseLock lk(&*shared);
   return prepareDfpn(attack).distance(key);
 }
 
@@ -545,7 +619,7 @@ size_t osl::checkmate::
 DualDfpn::mainNodeCount() const
 {
 #ifdef OSL_USE_RACE_DETECTOR
-  SCOPED_LOCK(lk,shared->mutex);
+  boost::mutex::scoped_lock lk(shared->mutex);
 #endif
   return shared->main_node_count;
   // return shared->table[BLACK].totalSize() + shared->table[WHITE].totalSize();
@@ -555,7 +629,7 @@ size_t osl::checkmate::
 DualDfpn::totalNodeCount() const
 {
 #ifdef OSL_USE_RACE_DETECTOR
-  SCOPED_LOCK(lk,shared->mutex);
+  boost::mutex::scoped_lock lk(shared->mutex);
 #endif
   return shared->main_node_count + shared->simulation_count;
 }
@@ -566,6 +640,29 @@ DualDfpn::table(Player attack) const
   return shared->table[attack];
 }
 
+namespace osl
+{
+  template ProofDisproof checkmate::DualDfpn::findProof<BLACK>
+  (int, const NumEffectState&, const HashKey&, const PathEncoding&,
+   Move&, Move);
+  template ProofDisproof checkmate::DualDfpn::findProof<WHITE>
+  (int, const NumEffectState&, const HashKey&, const PathEncoding&,
+   Move&, Move);
+
+
+  template bool checkmate::DualDfpn::isLosingState<BLACK>
+  (int, const NumEffectState&, const HashKey&, const PathEncoding&, Move);
+  template bool checkmate::DualDfpn::isLosingState<WHITE>
+  (int, const NumEffectState&, const HashKey&, const PathEncoding&, Move);
+
+#ifdef OSL_DFPN_SMP
+  template bool checkmate::DualDfpn::isWinningStateParallel<BLACK>
+  (int, const NumEffectState&, const HashKey&, const PathEncoding&, Move&, Move);
+  template bool checkmate::DualDfpn::isWinningStateParallel<WHITE>
+  (int, const NumEffectState&, const HashKey&, const PathEncoding&, Move&, Move);
+#endif
+}
+
 /* ------------------------------------------------------------------------- */
 // ;;; Local Variables:
 // ;;; mode:c++
