@@ -6,62 +6,64 @@
 #include "osl/boardTable.h"
 #include "osl/ptypeTable.h"
 
-namespace
+namespace osl
 {
-  using namespace osl;
-  using namespace osl::checkmate;
-  /**
-   * @return 0 は王手でない場合．それ以外は逃げ方の見積
-   */
-  const osl::checkmate::ProofNumberTable::Liberty
-  effectiveCheckShort(Ptype ptype,Direction dir,unsigned int mask)
+  namespace
   {
-    assert(isShort(dir));
-    // 王は8近傍に移動できない
-    if (ptype==KING) 
-      return ProofNumberTable::Liberty(0,false);
-    // ptypeがdir方向に利きを持たない場合も空王手の場合があるので作成
-    const bool has_effect 
-      = (Ptype_Table.getMoveMask(ptype)
-	 & (dirToMask(dir) | dirToMask(shortToLong(dir))));
-    int dx=Board_Table.getDxForBlack(dir);
-    int dy=Board_Table.getDyForBlack(dir);
-    int count = 0;
-    for (int l=0;l<8;l++) {
-      if ((mask&(1<<l))==0) 
-	continue;
-      Direction dir1=static_cast<Direction>(l);
-      int dx1=Board_Table.getDxForBlack(dir1);
-      int dy1=Board_Table.getDyForBlack(dir1);
-      Offset32 o32(dx-dx1,dy-dy1);
-      if ((dx != dx1 || dy != dy1)
-	  && !Ptype_Table.getEffect(newPtypeO(BLACK,ptype),o32).hasEffect())
-	++count;
+    using namespace osl::checkmate;
+    /**
+     * @return 0 は王手でない場合．それ以外は逃げ方の見積
+     */
+    const checkmate::ProofNumberTable::Liberty
+    effectiveCheckShort(Ptype ptype,Direction dir,unsigned int mask)
+    {
+      assert(isShort(dir));
+      // 王は8近傍に移動できない
+      if (ptype==KING) 
+	return ProofNumberTable::Liberty(0,false);
+      // ptypeがdir方向に利きを持たない場合も空王手の場合があるので作成
+      const bool has_effect 
+	= (Ptype_Table.getMoveMask(ptype)
+	   & (dirToMask(dir) | dirToMask(shortToLong(dir))));
+      int dx=Board_Table.getDxForBlack(dir);
+      int dy=Board_Table.getDyForBlack(dir);
+      int count = 0;
+      for (int l=0;l<8;l++) {
+	if ((mask&(1<<l))==0) 
+	  continue;
+	Direction dir1=static_cast<Direction>(l);
+	int dx1=Board_Table.getDxForBlack(dir1);
+	int dy1=Board_Table.getDyForBlack(dir1);
+	Offset32 o32(dx-dx1,dy-dy1);
+	if ((dx != dx1 || dy != dy1)
+	    && !Ptype_Table.getEffect(newPtypeO(BLACK,ptype),o32).hasEffect())
+	  ++count;
+      }
+      return ProofNumberTable::Liberty(std::max(count,1), has_effect);
     }
-    return ProofNumberTable::Liberty(std::max(count,1), has_effect);
-  }
-  const osl::checkmate::ProofNumberTable::Liberty
-  effectiveCheckLong(Ptype ptype,Direction dir,unsigned int mask)
-  {
-    assert(isLong(dir));
-    // ptypeがdir方向に利きを持たなくても2マス離れた空王手で8近傍に
-    // 利きが増える場合があるので作成
-    const bool has_effect 
-      = (Ptype_Table.getMoveMask(ptype) & dirToMask(dir));
-    int dx=Board_Table.getDxForBlack(dir)*2; // 1マス遠くから
-    int dy=Board_Table.getDyForBlack(dir)*2;
-    int count = 0;
-    for (int l=0;l<8;l++) {
-      if ((mask&(1<<l))==0) 
-	continue;
-      Direction dir1=static_cast<Direction>(l);
-      int dx1=Board_Table.getDxForBlack(dir1);
-      int dy1=Board_Table.getDyForBlack(dir1);
-      Offset32 o32(dx-dx1,dy-dy1);
-      if (!Ptype_Table.getEffect(newPtypeO(BLACK,ptype),o32).hasEffect())
-	++count;
+    const checkmate::ProofNumberTable::Liberty
+    effectiveCheckLong(Ptype ptype,Direction dir,unsigned int mask)
+    {
+      assert(isLong(dir));
+      // ptypeがdir方向に利きを持たなくても2マス離れた空王手で8近傍に
+      // 利きが増える場合があるので作成
+      const bool has_effect 
+	= (Ptype_Table.getMoveMask(ptype) & dirToMask(dir));
+      int dx=Board_Table.getDxForBlack(dir)*2; // 1マス遠くから
+      int dy=Board_Table.getDyForBlack(dir)*2;
+      int count = 0;
+      for (int l=0;l<8;l++) {
+	if ((mask&(1<<l))==0) 
+	  continue;
+	Direction dir1=static_cast<Direction>(l);
+	int dx1=Board_Table.getDxForBlack(dir1);
+	int dy1=Board_Table.getDyForBlack(dir1);
+	Offset32 o32(dx-dx1,dy-dy1);
+	if (!Ptype_Table.getEffect(newPtypeO(BLACK,ptype),o32).hasEffect())
+	  ++count;
+      }
+      return ProofNumberTable::Liberty(std::max(count,1), has_effect);
     }
-    return ProofNumberTable::Liberty(std::max(count,1), has_effect);
   }
 }
 
