@@ -23,7 +23,7 @@ struct osl::checkmate::ProofTreeDepthDfpn::Table
   map_t depth_table;
   index_t depth_index;
   const DfpnTable& table;
-  Table(const DfpnTable& t) : state(new NumEffectState[Dfpn::MaxDepth]), table(t)
+  Table(const DfpnTable& t) : state(new NumEffectState[t.maxDepth()]), table(t)
   {
   }
   void store(const HashKey& key, int depth, Move best_move=Move()) 
@@ -69,6 +69,7 @@ struct osl::checkmate::ProofTreeDepthDfpn::Table
     }
     return true;
   }
+  int maxDepth() const { return table.maxDepth(); }
 };
 
 osl::checkmate::
@@ -98,7 +99,7 @@ ProofTreeDepthDfpn::retrievePV
   table->state[0] = src;
   HashKey key(table->state[0]);
   pv.clear();
-  for (int i=0; i<Dfpn::MaxDepth; ++i) {
+  for (int i=0; i<table->maxDepth(); ++i) {
     Move next;
     if (is_or_node ^ (i%2))
       orNode(key, next);
@@ -117,7 +118,7 @@ ProofTreeDepthDfpn::orNode(const HashKey& key, Move& best_move, int height) cons
 {
   assert(key == HashKey(table->state[height]));  
   best_move = Move();
-  if (height >= Dfpn::MaxDepth)
+  if (height >= table->maxDepth())
     return -1;
 
   // always test ImmediateCheckmate since users do not want to see redundant solutions
@@ -177,7 +178,7 @@ int osl::checkmate::
 ProofTreeDepthDfpn::andNode(const HashKey& key, Move& best_move, int height) const
 {
   best_move = Move();
-  if (height >= Dfpn::MaxDepth)
+  if (height >= table->maxDepth())
     return -1;
   {
     int recorded;
