@@ -33,7 +33,7 @@ PieceValues::showValues(std::ostream& os, const SimpleState& state) const
   for (int y=1;y<=9;y++) {
     os << y;  
     for (int x=9;x>0;x--) {
-      const Piece piece = state.getPieceOnBoard(Position(x,y));
+      const Piece piece = state.pieceOnBoard(Square(x,y));
       os << std::setw(7);
       if (piece.isEmpty())
 	os << 0;
@@ -45,18 +45,18 @@ PieceValues::showValues(std::ostream& os, const SimpleState& state) const
   os << "black stand: ";
   for (int i=0; i<Piece::SIZE; ++i)
   {
-    const Piece piece = state.getPieceOf(i);
+    const Piece piece = state.pieceOf(i);
     if ((piece.owner() == BLACK)
-	&& (piece.position().isPieceStand()))
+	&& (piece.square().isPieceStand()))
       os << piece.ptype() << " " << (*this)[piece.number()] << " ";
   }
   os << "\n";
   os << "white stand: ";
   for (int i=0; i<Piece::SIZE; ++i)
   {
-    const Piece piece = state.getPieceOf(i);
+    const Piece piece = state.pieceOf(i);
     if ((piece.owner() == WHITE)
-	&& (piece.position().isPieceStand()))
+	&& (piece.square().isPieceStand()))
       os << piece.ptype() << " " << (*this)[piece.number()] << " ";
   }
   os << "\n";
