@@ -4,7 +4,7 @@
 
 template <int count_max>
 int osl::effect_util::
-ShadowEffect::count(const NumEffectState& state, Position target, 
+ShadowEffect::count(const NumEffectState& state, Square target, 
 		    Player attack)
 {
   PieceVector direct_pieces;
@@ -14,14 +14,14 @@ ShadowEffect::count(const NumEffectState& state, Position target,
 }
 
 bool osl::effect_util::
-ShadowEffect::hasEffect(const NumEffectState& state, Position target, 
+ShadowEffect::hasEffect(const NumEffectState& state, Square target, 
 			Player attack)
 {
   return count<1>(state, target, attack);
 }
 
 int osl::effect_util::
-ShadowEffect::count2(const NumEffectState& state, Position target, 
+ShadowEffect::count2(const NumEffectState& state, Square target, 
 		     Player attack)
 {
   return count<2>(state, target, attack);
