@@ -1,5 +1,6 @@
 #include "osl/eval/ml/majorPiece.h"
 #include "osl/mobility/rookMobility.h"
+#include <boost/foreach.hpp>
 #include <algorithm>
 using osl::MultiInt;
 
@@ -1251,6 +1252,251 @@ MajorCheckWithCapture::eval(const NumEffectState &state)
   return addOne<BLACK>(state) + addOne<WHITE>(state);
 }
 
+
+osl::misc::CArray<MultiInt, osl::eval::ml::RookSilverKnight::ONE_DIM>
+osl::eval::ml::RookSilverKnight::table;
+
+void osl::eval::ml::
+RookSilverKnight::setUp(const Weights &weights)
+{
+  for (size_t i = 0; i < ONE_DIM; ++i)
+  {
+    for (int s=0; s<NStages; ++s)
+      table[i][s] = weights.value(i + ONE_DIM*s);
+  }
+}
+
+osl::MultiInt osl::eval::ml::
+RookSilverKnight::eval(const NumEffectState &state)
+{
+  MultiInt result;
+  for (int i = PtypeTraits<ROOK>::indexMin;
+       i < PtypeTraits<ROOK>::indexLimit;
+       ++i)
+  {
+    const Piece rook = state.pieceOf(i);
+    if (!rook.isOnBoard())
+    {
+      continue;
+    }
+    for (int i = PtypeTraits<SILVER>::indexMin;
+	 i < PtypeTraits<SILVER>::indexLimit;
+	 ++i)
+    {
+      const Piece silver = state.pieceOf(i);
+      if (!silver.isOnBoard() || silver.isPromoted() ||
+          silver.owner() != rook.owner())
+      {
+        continue;
+      }
+      for (int i = PtypeTraits<KNIGHT>::indexMin;
+           i < PtypeTraits<KNIGHT>::indexLimit;
+           ++i)
+      {
+        const Piece knight = state.pieceOf(i);
+        if (!knight.isOnBoard() || knight.isPromoted() ||
+            knight.owner() != rook.owner())
+        {
+          continue;
+        }
+
+        if (rook.owner() == BLACK)
+        {
+          if (rook.square().x() > 5)
+          {
+            result += table[index(9 - rook.square().x(), rook.square().y() - 1,
+				  9 - silver.square().x(), silver.square().y() - 1,
+				  9 - knight.square().x(), knight.square().y() - 1)];
+          }
+          else
+          {
+            result += table[index(rook.square().x() - 1, rook.square().y() - 1,
+				  silver.square().x() - 1, silver.square().y() - 1,
+				  knight.square().x() - 1, knight.square().y() - 1)];
+          }
+        }
+        else
+        {
+          if (rook.square().x() >= 5)
+          {
+	    result -= table[index(9 - rook.square().x(), 9 - rook.square().y(),
+				  9 - silver.square().x(), 9 - silver.square().y(),
+				  9 - knight.square().x(), 9 - knight.square().y())];
+          }
+          else
+          {
+	    result -= table[index(rook.square().x() - 1, 9 - rook.square().y(),
+				  silver.square().x() - 1, 9 - silver.square().y(),
+				  knight.square().x() - 1, 9 - knight.square().y())];
+          }
+        }
+      }
+    }
+  }
+  return result;
+}
+
+
+osl::misc::CArray<MultiInt, osl::eval::ml::BishopSilverKnight::ONE_DIM>
+osl::eval::ml::BishopSilverKnight::table;
+
+void osl::eval::ml::
+BishopSilverKnight::setUp(const Weights &weights)
+{
+  for (size_t i = 0; i < ONE_DIM; ++i)
+  {
+    for (int s=0; s<NStages; ++s)
+      table[i][s] = weights.value(i + ONE_DIM*s);
+  }
+}
+
+osl::MultiInt osl::eval::ml::
+BishopSilverKnight::eval(const NumEffectState &state)
+{
+  MultiInt result;
+  for (int i = PtypeTraits<BISHOP>::indexMin;
+       i < PtypeTraits<BISHOP>::indexLimit;
+       ++i)
+  {
+    const Piece bishop = state.pieceOf(i);
+    if (!bishop.isOnBoard())
+    {
+      continue;
+    }
+    for (int i = PtypeTraits<SILVER>::indexMin;
+	 i < PtypeTraits<SILVER>::indexLimit;
+	 ++i)
+    {
+      const Piece silver = state.pieceOf(i);
+      if (!silver.isOnBoard() || silver.isPromoted() ||
+          silver.owner() != bishop.owner())
+      {
+        continue;
+      }
+      for (int i = PtypeTraits<KNIGHT>::indexMin;
+           i < PtypeTraits<KNIGHT>::indexLimit;
+           ++i)
+      {
+        const Piece knight = state.pieceOf(i);
+        if (!knight.isOnBoard() || knight.isPromoted() ||
+            knight.owner() != bishop.owner())
+        {
+          continue;
+        }
+
+        if (bishop.owner() == BLACK)
+        {
+          if (bishop.square().x() > 5)
+          {
+            result += table[index(9 - bishop.square().x(), bishop.square().y() - 1,
+				  9 - silver.square().x(), silver.square().y() - 1,
+				  9 - knight.square().x(), knight.square().y() - 1)];
+          }
+          else
+          {
+            result += table[index(bishop.square().x() - 1, bishop.square().y() - 1,
+				  silver.square().x() - 1, silver.square().y() - 1,
+				  knight.square().x() - 1, knight.square().y() - 1)];
+          }
+        }
+        else
+        {
+          if (bishop.square().x() >= 5)
+          {
+	    result -= table[index(9 - bishop.square().x(), 9 - bishop.square().y(),
+				  9 - silver.square().x(), 9 - silver.square().y(),
+				  9 - knight.square().x(), 9 - knight.square().y())];
+          }
+          else
+          {
+	    result -= table[index(bishop.square().x() - 1, 9 - bishop.square().y(),
+				  silver.square().x() - 1, 9 - silver.square().y(),
+				  knight.square().x() - 1, 9 - knight.square().y())];
+          }
+        }
+      }
+    }
+  }
+  return result;
+}
+
+
+osl::misc::CArray<MultiInt, osl::eval::ml::AttackMajorsInBase::ONE_DIM>
+osl::eval::ml::AttackMajorsInBase::table;
+
+void osl::eval::ml::
+AttackMajorsInBase::setUp(const Weights &weights)
+{
+  for (size_t i = 0; i < ONE_DIM; ++i) {
+    for (int s=0; s<NStages; ++s)
+      table[i][s] = weights.value(i + ONE_DIM*s);
+    if (i > 0)
+      table[i] += table[0];
+  }
+}
+
+template <osl::Player P>
+void osl::eval::ml::
+AttackMajorsInBase::addOne(const NumEffectState &state, Piece rook, MultiInt& result)
+{
+  Square sq = rook.square();
+  if (state.hasEffectAt(alt(P), sq)
+      || sq.squareForBlack(P).y() < 8)
+    return;
+  typedef std::pair<Offset,Square> pair_t;
+  const CArray<pair_t, 7> bishop_attack =
+    {{
+	pair_t(Offset::make<P,U>(), sq.neighbor<P, UL>()),
+	pair_t(Offset::make<P,U>(), sq.neighbor<P, UR>()),
+	pair_t(Offset::make<P,L>(), sq.neighbor<P, UL>()),
+	pair_t(Offset::make<P,R>(), sq.neighbor<P, UR>()),
+	pair_t(Offset::make<P,D>(), sq.neighbor<P, UL>()),
+	pair_t(Offset::make<P,D>(), sq.neighbor<P, UR>()),
+	pair_t(Offset::make<P,U>(), sq.neighbor<P, U>()),
+      }};
+  const bool has_gold = state.hasPieceOnStand(alt(P), GOLD);
+  const bool rook_support = state.hasEffectAt(P, sq);
+  BOOST_FOREACH(pair_t pair, bishop_attack) {
+    const Square attack_square = pair.second;
+    if (! state[attack_square].isEmpty()
+	|| state.countEffect(P, attack_square) > 1)
+      continue;
+    const Square bishop_square = attack_square + pair.first;
+    Piece p = state[bishop_square];
+    if (! p.isPlayerPtype(P,BISHOP)
+	|| state.hasEffectAt(alt(P), bishop_square))
+      continue;
+    int a = state.countEffect(alt(P), attack_square) + has_gold;
+    if (a <= state.countEffect(P, attack_square))
+      continue;
+    const int i = index(state.findCheapAttack(P, attack_square).ptype(),
+			state.findCheapAttack(alt(P), attack_square).ptype(),
+			has_gold, rook_support,
+			state.hasEffectNotBy(P, rook, bishop_square));
+    if (P == BLACK)
+      result += table[i];
+    else
+      result -= table[i];
+  }
+}
+
+osl::MultiInt osl::eval::ml::
+AttackMajorsInBase::eval(const NumEffectState &state)
+{
+  MultiInt result;
+  for (int i=0; i<state.nthLimit<ROOK>(); ++i) {
+    const Piece rook = state.nth<ROOK>(i);
+    if (! rook.isOnBoard() || rook.isPromoted())
+      continue;
+    Player P = rook.owner();
+    if (P == BLACK)
+      addOne<BLACK>(state, rook, result);    
+    else
+      addOne<WHITE>(state, rook, result);    
+  }
+  return result;
+}
+
 
 namespace osl
 {
