@@ -1,4 +1,5 @@
 #include "osl/eval/ml/minorPiece.h"
+#include "osl/effect_util/additionalEffect.h"
 #include <iostream>
 using osl::MultiInt;
 
@@ -2978,6 +2979,64 @@ SilverAdvance26::eval(const NumEffectState &state)
   return sum;
 }
 
+
+
+osl::CArray<osl::MultiInt, osl::PTYPE_SIZE>
+osl::eval::ml::Promotion37::table;
+void osl::eval::ml::Promotion37::setUp(const Weights &weights)
+{
+  for (size_t i = 0; i < ONE_DIM; ++i)
+  {
+    for (int s=0; s<NStages; ++s)
+      table[i][s] = weights.value(i + ONE_DIM*s);
+  }
+}
+
+template <osl::Player P>
+osl::MultiInt osl::eval::ml::
+Promotion37::evalOne(const NumEffectState &state, int rank) 
+{
+  CArray<int,PTYPE_SIZE> count = {{ 0 }};
+  for (int x=1; x<=9; ++x) {
+    const Square target(x, rank);
+    if (! state[target].isEmpty())
+      continue;
+    int a = state.countEffect(P, target);
+    const int d = state.countEffect(alt(P), target);
+    if (a > 0 && a == d)
+      a += AdditionalEffect::hasEffect(state, target, P);
+    if (a < d)
+      continue;
+    const Ptype ptype = state.findCheapAttack(P, target).ptype();
+    if (isPiece(ptype) && ! isPromoted(ptype))
+      count[ptype]++;
+  }
+  MultiInt ret;
+  for (int p=PTYPE_BASIC_MIN; p<=PTYPE_MAX; ++p) {
+    if (count[p] > 0)
+      ret += table[p]*playerToMul(P);
+    if (count[p] > 1)
+      ret += table[p-8]*(playerToMul(P)*(count[p]-1));
+  }
+  return ret;
+}
+
+osl::MultiInt osl::eval::ml::
+Promotion37::eval(const NumEffectState &state) 
+{
+  return evalOne<BLACK>(state, 3) + evalOne<WHITE>(state, 7);
+}
+
+template <osl::Player P>
+osl::MultiInt osl::eval::ml::
+Promotion37::evalWithUpdate(const NumEffectState& state, Move moved,
+			    MultiInt const& last_value)
+{
+  if (moved.isPass())
+    return last_value;
+  // todo changedEffects
+  return eval(state);
+}
 
 
 namespace osl
