@@ -23,7 +23,7 @@ PieceEval::eval(const NumEffectState &state)
   int value = 0;
   for (int i = 0; i < Piece::SIZE; ++i)
   {
-    const Piece piece = state.getPieceOf(i);
+    const Piece piece = state.pieceOf(i);
     value += table[piece.ptypeO() - PTYPEO_MIN];
   }
   return value;
