@@ -399,9 +399,9 @@ PiecePair::sanitize(Weights& values)
   values.setValue(0,0);
   for (int x=1; x<=9; ++x) {
     for (int y=1; y<=9; ++y) {
-      const Position pos1(x,y);
+      const Square pos1(x,y);
       for (size_t i=0; i<offsets.size(); ++i) {
-	const Position pos0 = pos1+offsets[i];
+	const Square pos0 = pos1+offsets[i];
 	if (! pos0.isOnBoard())
 	  continue;
 	for (int p=PTYPE_PIECE_MIN; p<=PTYPE_MAX; ++p) {
@@ -418,7 +418,7 @@ PiecePair::sanitize(Weights& values)
 }
 
 osl::eval::ml::PiecePair::index_t osl::eval::ml::
-PiecePair::index(int offset_id, Position pos0, PtypeO p0, Position pos1, PtypeO p1)
+PiecePair::index(int offset_id, Square pos0, PtypeO p0, Square pos1, PtypeO p1)
 {
   assert(pos0 != pos1);
   assert(! pos0.isPieceStand() && ! pos1.isPieceStand());
@@ -444,7 +444,7 @@ PiecePair::index(int offset_id, Piece p, Piece q)
   assert(q.isPiece());
   assert(p != q);
   assert(p.isOnBoard() && q.isOnBoard());
-  return index(offset_id, p.position(), p.ptypeO(), q.position(), q.ptypeO());
+  return index(offset_id, p.square(), p.ptypeO(), q.square(), q.ptypeO());
 }
 
 int osl::eval::ml::
@@ -452,7 +452,7 @@ PiecePair::eval(const NumEffectState& state, const Weights& values)
 {
   int ret = 0;
   for (int i=0; i<Piece::SIZE; i++) {
-    const Piece p = state.getPieceOf(i);
+    const Piece p = state.pieceOf(i);
     ret += pieceValueDouble(state, p, values);
   }
   return ret/2;
@@ -465,15 +465,15 @@ PiecePair::evalWithUpdate(const NumEffectState& state, Move moved, int last_valu
     return last_value;
   
   int ret = last_value;
-  const Position from = moved.from();
-  const Position to = moved.to();  
+  const Square from = moved.from();
+  const Square to = moved.to();  
 
   // adjust from
   if (! from.isPieceStand()) {
     for (size_t i=0; i<offsets.size(); ++i) {
-      const Position target = from + offsets[i];
-      const Piece p = state.getPieceAt(target);
-      if (! p.isPiece() || p.position() == to)
+      const Square target = from + offsets[i];
+      const Piece p = state.pieceAt(target);
+      if (! p.isPiece() || p.square() == to)
 	continue;
       assert(!target.isPieceStand());
       ret -= value(i, p, from, moved.oldPtypeO(), values);      
@@ -481,11 +481,11 @@ PiecePair::evalWithUpdate(const NumEffectState& state, Move moved, int last_valu
   }
   
   // adjust to
-  if (moved.capturePtype() == PTYPE_EMPTY) 
+  if (! moved.isCapture()) 
   {  
     for (size_t i=0; i<offsets.size(); ++i) {
-      const Position target = to + offsets[i];
-      const Piece p = state.getPieceAt(target);
+      const Square target = to + offsets[i];
+      const Piece p = state.pieceAt(target);
       if (! p.isPiece())
 	continue;
       assert(!target.isPieceStand());
@@ -496,13 +496,13 @@ PiecePair::evalWithUpdate(const NumEffectState& state, Move moved, int last_valu
 
   // adjust with capture
   for (size_t i=0; i<offsets.size(); ++i) {
-    const Position target = to + offsets[i];
-    const Piece p = state.getPieceAt(target);
+    const Square target = to + offsets[i];
+    const Piece p = state.pieceAt(target);
     if (! p.isPiece())
       continue;
     assert(!target.isPieceStand());
     ret += value(i, p, to, moved.ptypeO(), values);      
-    if (p.position() == to)
+    if (p.square() == to)
       continue;
     ret -= value(i, p, to, moved.capturePtypeO(), values);      
   }
@@ -515,7 +515,7 @@ PiecePair::evalWithUpdate(const NumEffectState& state, Move moved, int last_valu
 }
 
 int osl::eval::ml::
-PiecePair::valueCompiled(int offset_id, Position pos0, PtypeO p0, Position pos1, PtypeO p1)
+PiecePair::valueCompiled(int offset_id, Square pos0, PtypeO p0, Square pos1, PtypeO p1)
 {
   assert(pos0 != pos1);
   assert(! pos0.isPieceStand() && ! pos1.isPieceStand());
@@ -536,7 +536,7 @@ PiecePair::sum12One(const Piece *base_ptr,const int *xbase,const int *ybase)
     + *(ybase+(&y_values[0][0][1][0]-&y_values[0][0][0][0])*Direction+p1);
 }
 inline int osl::eval::ml::
-PiecePair::sum12(NumEffectState const& state,Position base,PtypeO ptypeO)
+PiecePair::sum12(NumEffectState const& state,Square base,PtypeO ptypeO)
 {
   const int *xbase= &x_values[base.x()][ptypeOIndex(ptypeO)][0][ptypeOIndex((PtypeO)0)];
   const int *ybase= &y_values[base.y()][ptypeOIndex(ptypeO)][0][ptypeOIndex((PtypeO)0)];
@@ -570,7 +570,7 @@ PiecePair::adjust12One(const Piece *base_ptr,const int *xbase1,const int *ybase1
 }
 
 inline int osl::eval::ml::
-PiecePair::adjust12(NumEffectState const& state,Position base,PtypeO pos,PtypeO neg)
+PiecePair::adjust12(NumEffectState const& state,Square base,PtypeO pos,PtypeO neg)
 {
   const int *xbase1= &x_values[base.x()][ptypeOIndex(pos)][0][ptypeOIndex((PtypeO)0)];
   const int *xbase2= &x_values[base.x()][ptypeOIndex(neg)][0][ptypeOIndex((PtypeO)0)];
@@ -596,8 +596,8 @@ int osl::eval::ml::
 PiecePair::evalWithUpdateCompiled(const NumEffectState& state, Move moved, int last_value)
 {
   int ret = last_value;
-  const Position from = moved.from();
-  const Position to = moved.to();  
+  const Square from = moved.from();
+  const Square to = moved.to();  
 
   // adjust from
   if (from.isPieceStand()) {
@@ -607,7 +607,7 @@ PiecePair::evalWithUpdateCompiled(const NumEffectState& state, Move moved, int l
   else{
     ret-=sum12(state,from,moved.oldPtypeO());
     // adjust to
-    if (moved.capturePtype() == PTYPE_EMPTY) {
+    if (! moved.isCapture()) {
       ret+=sum12(state,to,moved.ptypeO());
       const Offset diff = to-from;
       int capture_i = offset_index[diff.index()];
@@ -628,7 +628,7 @@ PiecePair::evalWithUpdateCompiled(const NumEffectState& state, Move moved, int l
       const Offset diff = to-from;
       int capture_i = offset_index[diff.index()];
       if (capture_i >= 0){
-	Position base=to;
+	Square base=to;
 	PtypeO ptypeO1=moved.ptypeO();
 	PtypeO ptypeO2=moved.capturePtypeO();
 	const int *xbase1= &x_values[base.x()][ptypeOIndex(ptypeO1)][0][ptypeOIndex((PtypeO)0)];
@@ -654,8 +654,8 @@ PiecePair::pieceValueDouble(const NumEffectState& state, Piece p, const Weights&
     return 0;
   int ret = 0;
   for (size_t i=0; i<offsets.size(); ++i) {
-    const Position target = p.position() + offsets[i];
-    const Piece q = state.getPieceAt(target);
+    const Square target = p.square() + offsets[i];
+    const Piece q = state.pieceAt(target);
     if (! q.isPiece()|| p == q)
       continue;
     assert(!target.isPieceStand()); 
