@@ -187,3 +187,69 @@ PinPtypeAll::eval(const NumEffectState &state)
 {
   return evalOne<BLACK>(state) - evalOne<WHITE>(state);
 }
+
+
+osl::misc::CArray<MultiInt, 80>
+osl::eval::ml::CheckShadowPtype::table;
+
+void osl::eval::ml::
+CheckShadowPtype::setUp(const Weights &weights)
+{
+  for (size_t i = 0; i < ONE_DIM; ++i)
+  {
+    for (int s=0; s<NStages; ++s)
+      table[i][s] = weights.value(i + ONE_DIM*s);
+  }
+}
+
+template <osl::Player Defense>
+osl::MultiInt osl::eval::ml::
+CheckShadowPtype::evalOne(const NumEffectState &state) 
+{
+  MultiInt result;
+  const Square king = state.kingSquare<Defense>();
+  PieceMask open_mask = state.checkShadow(alt(Defense));
+  while (open_mask.any())
+  {
+    const Piece piece = state.pieceOf(open_mask.takeOneBit());
+    if (king.y() == piece.square().y()) // rook h
+    {
+      result += table[piece.ptype() + PTYPE_SIZE * 1];
+    }
+    else if (king.x() == piece.square().x())
+    {
+      if (state.hasEffectByPtypeStrict<LANCE>(alt(Defense),
+						piece.square())) // lance
+      {
+	result += table[piece.ptype() + PTYPE_SIZE * 4];
+      }
+      else // rook v
+      {
+	result += table[piece.ptype() + PTYPE_SIZE * 0];
+      }
+    }
+    else // bishop
+    {
+      if ((Defense == BLACK && piece.square().y() < king.y()) ||
+	  (Defense == WHITE && piece.square().y() > king.y())) // u
+      {
+	result += table[piece.ptype() + PTYPE_SIZE * 2];
+      }
+      else
+      {
+	result += table[piece.ptype() + PTYPE_SIZE * 3];
+      }
+    }
+  }
+  return result;
+}
+
+osl::MultiInt osl::eval::ml::
+CheckShadowPtype::eval(const NumEffectState &state)
+{
+  return evalOne<BLACK>(state) - evalOne<WHITE>(state);
+}
+// ;;; Local Variables:
+// ;;; mode:c++
+// ;;; c-basic-offset:2
+// ;;; End:
