@@ -3,6 +3,7 @@
 #include "osl/eval/progressEval.h"
 #include "osl/container/pieceValues.h"
 #include "osl/state/numEffectState.h"
+#include "osl/effect_util/effectUtil.tcc"
 #include "osl/oslConfig.h"
 #include <boost/filesystem/operations.hpp>
 #include <iostream>
@@ -873,7 +874,15 @@ namespace osl
   {
     template class ProgressEvalGeneral<progress_eval_opening_t>;
   }
+#ifndef DFPNSTATONE
+  template void
+  EffectUtil::findThreat<eval::ProgressEval>(const NumEffectState& state,
+					     Square position,
+					     PtypeO ptypeo,
+					     PieceVector& out);
+#endif
 }
+
 #endif
 /* ------------------------------------------------------------------------- */
 // ;;; Local Variables:
