@@ -28,13 +28,12 @@ FindEffectMore::store(Piece p)
 template <osl::Player P>
 void osl::eval::
 See::findEffectPieces(const NumEffectState& state, Square effect_to,
-		      const PieceMask& /*my_pin*/, const PieceMask& op_pin,
 		      PtypeOSquareVector& my_pieces, 
 		      PtypeOSquareVector& op_pieces)
 {
   typedef effect_action::StorePtypeOSquare store_t;
   store_t op_pieces_store(&op_pieces, effect_to);
-  state.forEachEffect<PlayerTraits<P>::opponent,store_t>(effect_to, op_pieces_store, op_pin);
+  state.forEachEffect<PlayerTraits<P>::opponent,store_t>(effect_to, op_pieces_store);
   if (op_pieces.empty())
     return;
   op_pieces.sort();
@@ -65,7 +64,6 @@ See::findEffectPieces(const NumEffectState& state, Square effect_to,
 template <osl::Player P>
 void osl::eval::
 See::findEffectPiecesAfterMove(const NumEffectState& state, Move move,
-			       const PieceMask& /*my_pin*/, const PieceMask& op_pin,
 			       PtypeOSquareVector& my_pieces, 
 			       PtypeOSquareVector& op_pieces)
 {
@@ -74,7 +72,7 @@ See::findEffectPiecesAfterMove(const NumEffectState& state, Move move,
 
   typedef effect_action::StorePtypeOSquare store_t;
   store_t op_pieces_store(&op_pieces, to);
-  state.forEachEffect<PlayerTraits<P>::opponent,store_t>(to, op_pieces_store, op_pin);
+  state.forEachEffect<PlayerTraits<P>::opponent,store_t>(to, op_pieces_store);
   if (op_pieces.empty())
     return;
   op_pieces.sort();
@@ -111,17 +109,58 @@ See::findEffectPiecesAfterMove(const NumEffectState& state, Move move,
 
 template <osl::Player P>
 int osl::eval::
-See::computeValue(Square target, PtypeO ptypeO, 
-		  const PtypeOSquareVector& my_pieces, 
-		  const PtypeOSquareVector& op_pieces,
+See::computeValue(const NumEffectState& state, Move move,
+		  PtypeOSquareVector& my_pieces, 
+		  PtypeOSquareVector& op_pieces,
+		  const PieceMask& my_pin, const PieceMask& op_pin,
 		  const eval::PtypeEvalTable& table)
 {
+  Square target=move.to(), move_from=move.from();
+  PtypeO ptypeO=move.ptypeO();
+
   int val = 0;
   CArray<int,Piece::SIZE> vals;
   const Player Opponent = PlayerTraits<P>::opponent;
   size_t i;
-  for (i=0;i<op_pieces.size();i++)
+  int c=0;
+  bool op_deleted=false, my_deleted=false;
+  for (i=0;i<op_pieces.size();i++,c++)
   {
+    if(c>10) break; // avoid infinite loop
+      {
+	Square from=op_pieces[i].second;
+	Piece p=state.pieceAt(from);
+	int num=p.number();
+	if(num==KingTraits<Opponent>::index && my_deleted) break;
+	assert(p.owner()==Opponent);
+	if(op_pin.test(num) && !state.pinnedCanMoveTo<Opponent>(p,target) &&
+	   ptypeO!=newPtypeO(P,KING)){
+	  Piece attacker=state.pinAttacker<Opponent>(p);
+	  assert(attacker.owner()==P);
+	  Square attacker_sq=attacker.square();
+	  if(attacker_sq != move_from){
+	    size_t j=0;
+	    for(;j<my_pieces.size();j++) if(my_pieces[j].second==attacker_sq) break;
+	    if(i<=j){
+	      if(j==my_pieces.size() || op_pieces.size()<=j+1 ){
+		for(size_t k=i;k<op_pieces.size()-1;k++)
+		  op_pieces[k]=op_pieces[k+1];
+		op_pieces.pop_back();
+		op_deleted=true;
+	      }
+	      else{
+		std::pair<PtypeO,Square> v=op_pieces[i];
+		for(size_t k=i;k<=j;k++)
+		  op_pieces[k]=op_pieces[k+1];
+		op_pieces[j+1]=v;
+	      }
+	      i--;
+	      continue;
+	    }
+	  }
+	  // pin move?
+	}
+      }
     vals[i*2]=val;
     // opponent moves
     val+=table.captureValue(ptypeO);
@@ -138,9 +177,41 @@ See::computeValue(Square target, PtypeO ptypeO,
     }
     vals[i*2+1]=val;
     // my moves
+  retry:
     if (i>=my_pieces.size()){
       break;
     }
+      {
+	Square from=my_pieces[i].second;
+	Piece p=state.pieceAt(from);
+	int num=p.number();
+	assert(p.owner()==P);
+	if(num==KingTraits<P>::index && op_deleted) break;
+	if(my_pin.test(num) && !state.pinnedCanMoveTo<P>(p,target) &&
+	   ptypeO!=newPtypeO(Opponent,KING)){
+	  Piece attacker=state.pinAttacker<P>(p);
+	  assert(attacker.owner()==Opponent);
+	  Square attacker_sq=attacker.square();
+	  size_t j=0;
+	  for(;j<op_pieces.size();j++) if(op_pieces[j].second==attacker_sq) break;
+	  if(i<j){
+	    if(j==op_pieces.size() || my_pieces.size()<=j ){
+	      for(size_t k=i;k<my_pieces.size()-1;k++)
+		my_pieces[k]=my_pieces[k+1];
+	      my_pieces.pop_back();
+	      my_deleted=true;
+	    }
+	    else{
+	      std::pair<PtypeO,Square> v=my_pieces[i];
+	      for(size_t k=i;k<j;k++)
+		my_pieces[k]=my_pieces[k+1];
+	      my_pieces[j]=v;
+	    }
+	    goto retry;
+	  }
+	  // pin move?
+	}
+      }
     val+=table.captureValue(ptypeO);
     {
       ptypeO=my_pieces[i].first;
@@ -175,16 +246,16 @@ int osl::eval::See::seeInternal(const NumEffectState& state, Move move,
   int val=0; 
   if (from.isPieceStand())
   {
-    findEffectPieces<P>(state, to, my_pin, op_pin, my_pieces, op_pieces);
+    findEffectPieces<P>(state, to, my_pieces, op_pieces);
   }
   else
   {
     val = PieceEval::diffWithMove(state,move);
-    findEffectPiecesAfterMove<P>(state, move, my_pin, op_pin, my_pieces, op_pieces);
+    findEffectPiecesAfterMove<P>(state, move, my_pieces, op_pieces);
   }
   if (op_pieces.empty())
     return val;
-  return val + computeValue<P>(to, move.ptypeO(), my_pieces, op_pieces, table);
+  return val + computeValue<P>(state, move, my_pieces, op_pieces, my_pin, op_pin, table);
 }
 
 int osl::eval::See::see(const NumEffectState& state, Move move,
