@@ -4,6 +4,7 @@
 #include "osl/game_playing/searchPlayer.tcc"
 #include "osl/search/alphaBeta2.h"
 #include "osl/search/alphaBeta3.h"
+#include "osl/search/alphaBeta4.h"
 #include "osl/search/simpleHashTable.h"
 #include "osl/eval/progressEval.h"
 #include "osl/eval/pieceEval.h"
@@ -160,6 +161,53 @@ AlphaBeta3OpenMidEndingEvalPlayer::isReasonableMove(const GameState& gs,
 }
 #endif
 /* ------------------------------------------------------------------------- */
+
+osl::game_playing::
+AlphaBeta4Player::AlphaBeta4Player()
+{
+}
+
+osl::game_playing::
+AlphaBeta4Player::~AlphaBeta4Player()
+{
+}
+
+osl::game_playing::ComputerPlayer* osl::game_playing::
+AlphaBeta4Player::clone() const 
+{
+  return cloneIt(*this);
+}
+
+const osl::search::MoveWithComment osl::game_playing::
+AlphaBeta4Player::searchWithSecondsForThisMove(const GameState& gs, const search::TimeAssigned& org)
+{
+  const MilliSeconds::Interval consumed = setUpTable(gs, pawnValueOfTurn<AlphaBeta4>(gs.state().turn()));
+  const search::TimeAssigned msec(adjust(org, consumed));
+  searcher.reset();
+  try 
+  {
+    searcher.reset(new AlphaBeta4(gs.state(), *checkmate_ptr, table_ptr.get(),
+				  *recorder_ptr));
+  }
+  catch (std::bad_alloc&)
+  {
+    std::cerr << "panic. allocation of AlphaBeta4 failed\n";
+  }
+  return SearchPlayer::search<AlphaBeta4>(gs, msec);
+}
+
+bool osl::game_playing::
+AlphaBeta4Player::isReasonableMove(const GameState& gs,
+				   Move move, int pawn_sacrifice)
+{
+  setUpTable(gs, pawnValueOfTurn<AlphaBeta4>(gs.state().turn()));
+  AlphaBeta4 searcher(gs.state(), *checkmate_ptr, table_ptr.get(),
+				  *recorder_ptr);  
+  return SearchPlayer::isReasonableMoveBySearch(searcher, move, pawn_sacrifice);
+}
+
+/* ------------------------------------------------------------------------- */
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
