@@ -62,7 +62,8 @@ SearchPlayer::SearchPlayer(const SearchPlayer& copy)
     recorder_ptr(new CountRecorder()),
     searching(0), plan_stop(false),
     root_ignore_moves(0), prediction_for_speculative_search(0),
-    pv_history(new PVHistory(*copy.pv_history))
+    pv_history(new PVHistory(*copy.pv_history)),
+    almost_resign_count(0)
 {
 }
 
