@@ -1,7 +1,7 @@
 #include "osl/hash/boardKey.tcc"
 
-template struct osl::hash::GeneralBoardKey<unsigned int,4>;
-template struct osl::hash::GeneralBoardKey<unsigned long long,2>;
+template class osl::hash::GeneralBoardKey<unsigned int,4>;
+template class osl::hash::GeneralBoardKey<unsigned long long,2>;
 template struct osl::hash::GeneralHashKey<osl::hash::BoardKey32>;
 template struct osl::hash::GeneralHashKey<osl::hash::BoardKey64>;
 
