@@ -6,7 +6,11 @@
 
 namespace osl
 {
+#ifdef OSL_LONG_HASH_KEY
   BOOST_STATIC_ASSERT(sizeof(HashKey) >= sizeof(int)*5);
+#else
+  BOOST_STATIC_ASSERT(sizeof(HashKey) == sizeof(int)*4);
+#endif
 } // namespace osl
 
 #ifndef MINIMAL
@@ -36,6 +40,7 @@ void osl::hash::HashKey::dumpContentsCerr() const
   dumpContents(std::cerr);
 }
 
+#  ifdef OSL_LONG_HASH_KEY
 const osl::hash::HashKey osl::hash::HashKey::readFromDump(const std::string& str)
 {
   std::istringstream is(str);
@@ -53,6 +58,7 @@ const osl::hash::HashKey osl::hash::HashKey::readFromDump(std::istream& is)
   }
   return key;
 }
+#  endif
 #endif
 
 osl::hash::HashKey::HashKey(const SimpleState& state)
@@ -124,10 +130,20 @@ newUnmakeMove(Move move) const
   ret.changeTurn();
   return ret;
 }
-  
 
+#ifndef OSL_LONG_HASH_KEY
+namespace osl
+{
+  const CArray2d<hash::HashKey128Layout,Square::SIZE,PTYPEO_SIZE>
+  hash::HashGenTable::key = {{
+#include "hash.txt"
+    }};
+}
+#endif
+  
 osl::hash::HashGenTable::HashGenTable()
 {
+#ifdef OSL_LONG_HASH_KEY
   for(int j=0;j<PTYPEO_SIZE;j++)
   {
     const PtypeO pjo = (PtypeO)(j+PTYPEO_MIN);
@@ -140,15 +156,28 @@ osl::hash::HashGenTable::HashGenTable()
 	{
 	  PieceStand stand;
 	  stand.add(pj);
-	  hashKey[i][j].setPieceStand(stand);
+	  key[i][j].setPieceStand(stand);
 	}
       }
       else
       {
-	hashKey[i][j].setRandom();
+	key[i][j].setRandom();
       }
     }
   }
+#  ifdef OSL_DUMP_HASH_KEY
+  std::ofstream os("hash.txt");
+  for(int i=0;i<Square::SIZE;i++) {
+    os << "// " << i << "\n{\n";
+    for(int j=0;j<PTYPEO_SIZE;j++) {
+      os << "HashKey("
+	 << key[i][j].board64 << "ull, " << key[i][j].board32 << "u, "
+	 << key[i][j].piece_stand.getFlags() << "u),\n";
+    }
+    os << "},\n";
+  }
+#  endif
+#endif
 }
 
 
