@@ -1,5 +1,7 @@
 #include "osl/piece.h"
 #include "osl/move.h"
+#include "osl/state/simpleState.h"
+#include "osl/squareCompressor.h"
 #include "move-phash.c"
 #include <boost/static_assert.hpp>
 #include <iostream>
@@ -78,6 +80,38 @@ unsigned int osl::Move::hash() const
   return move_phash(intValue());
 }
 
+const osl::Move osl::Move::
+fromMove16(Move16 move16, const SimpleState& state)
+{
+  if (move16==MOVE16_NONE)
+    return Move();
+  Player turn=state.turn();
+  Square to=SquareCompressor::melt((move16>>8)&0x7f);
+  if((move16&0x80)!=0){
+    Ptype ptype=(Ptype)(move16-0x80);
+    return Move(to,ptype,turn);
+  }
+  Square from=SquareCompressor::melt(move16&0x7f);
+  Ptype ptype=state[from].ptype();
+  Ptype capture_ptype=state[to].ptype();
+  bool is_promote=(move16&0x8000)!=0;
+  if(is_promote)
+    return Move(from,to,::osl::promote(ptype),capture_ptype,true,turn);
+  else
+    return Move(from,to,ptype,capture_ptype,false,turn);
+}
+osl::Move16 osl::Move::toMove16() const
+{
+  if (isInvalid())
+    return MOVE16_NONE;
+  if (isDrop())
+    return Move16(0x80+(uint16_t)ptype()+((SquareCompressor::compress(to()))<<8));
+  if (isPromotion())
+    return Move16(SquareCompressor::compress(from())+(SquareCompressor::compress(to())<<8)+0x8000);
+  return Move16(SquareCompressor::compress(from())+(SquareCompressor::compress(to())<<8));
+}
+
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
