@@ -4,13 +4,13 @@
 bool
 osl::move_classifier::canAttackInThreeMoves (Player player,
 					     Ptype ptype,
-					     Position myPos,
-					     Position opKingPos)
+					     Square myPos,
+					     Square opKingPos)
 {
   return canAttackInThreeMovesTable
     [ptype]
-    [myPos.positionForBlack(player).index()]
-    [opKingPos.positionForBlack(player).index()];
+    [myPos.squareForBlack(player).index()]
+    [opKingPos.squareForBlack(player).index()];
 }
 // ;;; Local Variables:
 // ;;; mode:c++
