@@ -12,15 +12,15 @@ namespace osl{
   {
     typedef move_action::Store store_t;
     template void GenerateAddEffectWithEffect::generate<true>
-    (Player, const NumEffectState&, Position, store_t&);
+    (Player, const NumEffectState&, Square, store_t&);
     template void GenerateAddEffectWithEffect::generate<false>
-    (Player, const NumEffectState&, Position, store_t&);
+    (Player, const NumEffectState&, Square, store_t&);
     // for fixed depth search
-    template void AddEffectWithEffect<store_t>::generate<BLACK, true>(const NumEffectState&, Position, store_t&,bool&);
-    template void AddEffectWithEffect<store_t>::generate<WHITE, true>(const NumEffectState&, Position, store_t&,bool&);
+    template void AddEffectWithEffect<store_t>::generate<BLACK, true>(const NumEffectState&, Square, store_t&,bool&);
+    template void AddEffectWithEffect<store_t>::generate<WHITE, true>(const NumEffectState&, Square, store_t&,bool&);
     //
-    template void AddEffectWithEffect<store_t>::generate<BLACK, false>(const NumEffectState&, Position, store_t&,bool&);
-    template void AddEffectWithEffect<store_t>::generate<WHITE, false>(const NumEffectState&, Position, store_t&,bool&);
+    template void AddEffectWithEffect<store_t>::generate<BLACK, false>(const NumEffectState&, Square, store_t&,bool&);
+    template void AddEffectWithEffect<store_t>::generate<WHITE, false>(const NumEffectState&, Square, store_t&,bool&);
   } // namespace move_generator
 } // namespace osl
 // ;;; Local Variables:
