@@ -6,26 +6,26 @@
 
 template <osl::Player P>
 void osl::move_generator::AdditionalLance<P>::
-generate(const NumEffectState& state, Position pawn, MoveVector& out)
+generate(const NumEffectState& state, Square pawn, MoveVector& out)
 {
   assert((state.hasPieceOnStand<LANCE>(P)));
-  assert(state.getPieceOnBoard(pawn).ptype() == PAWN);
-  Position back_position = pawn + DirectionPlayerTraits<D,P>::offset();
-  Piece target = state.getPieceAt(back_position);
+  assert(state.pieceOnBoard(pawn).ptype() == PAWN);
+  Square back_position = pawn + DirectionPlayerTraits<D,P>::offset();
+  Piece target = state.pieceAt(back_position);
   while (target.isEmpty())
   {
-    if (state.hasEffectBy<PlayerTraits<P>::opponent>(back_position))
+    if (state.hasEffectAt<PlayerTraits<P>::opponent>(back_position))
       break;
     out.push_back(Move(back_position, LANCE, P));
 	  
     back_position = back_position + DirectionPlayerTraits<D,P>::offset();
-    target = state.getPieceAt(back_position);
+    target = state.pieceAt(back_position);
   }     
 }
 
 template <osl::Player P>
 void osl::move_generator::AdditionalLance<P>::
-generateIfHasLance(const NumEffectState& state, Position pawn, 
+generateIfHasLance(const NumEffectState& state, Square pawn, 
 		   MoveVector& out)
 {
   if (state.hasPieceOnStand<LANCE>(P))
@@ -35,8 +35,8 @@ namespace osl
 {
   namespace move_generator
   {
-    template class AdditionalLance<BLACK>;
-    template class AdditionalLance<WHITE>;
+    template struct AdditionalLance<BLACK>;
+    template struct AdditionalLance<WHITE>;
   }
 }
 
