@@ -1,8 +1,8 @@
 #include "osl/move_generator/attackToPinned.h"
 #include "osl/move_generator/attackToPinned.tcc"
 
-template void osl::move_generator::AttackToPinned<BLACK>::generate<move_action::Store>(const NumEffectState&, move_action::Store&);
-template void osl::move_generator::AttackToPinned<WHITE>::generate<move_action::Store>(const NumEffectState&, move_action::Store&);
+template void osl::move_generator::AttackToPinned<osl::BLACK>::generate<osl::move_action::Store>(const NumEffectState&, move_action::Store&);
+template void osl::move_generator::AttackToPinned<osl::WHITE>::generate<osl::move_action::Store>(const NumEffectState&, move_action::Store&);
 
 void 
 osl::move_generator::GenerateAttackToPinned::
