@@ -13,19 +13,19 @@ namespace osl
     using namespace move_action;
     // explicit template instantiation
     template void GenerateCapture::generate(Player,const NumEffectState&, 
-					    Position, Store&);
+					    Square, Store&);
     template void GenerateCapture::generate1(Player,const NumEffectState&, 
-					     Position, Store&);
+					     Square, Store&);
     template void Capture<Store>::escapeByCapture<BLACK>
-    (const NumEffectState&, Position, Piece, Store&);
+    (const NumEffectState&, Square, Piece, Store&);
     template void Capture<Store>::escapeByCapture<WHITE>
-    (const NumEffectState&, Position, Piece, Store&);
+    (const NumEffectState&, Square, Piece, Store&);
 
-    template void Capture<Store>::generate<BLACK>(NumEffectState const&, Position, Store&);
-    template void Capture<Store>::generate<WHITE>(NumEffectState const&, Position, Store&);
+    template void Capture<Store>::generate<BLACK>(NumEffectState const&, Square, Store&);
+    template void Capture<Store>::generate<WHITE>(NumEffectState const&, Square, Store&);
 
-    template void Capture<Store>::generate1<BLACK>(NumEffectState const&, Position, Store&);
-    template void Capture<Store>::generate1<WHITE>(NumEffectState const&, Position, Store&);
+    template void Capture<Store>::generate1<BLACK>(NumEffectState const&, Square, Store&);
+    template void Capture<Store>::generate1<WHITE>(NumEffectState const&, Square, Store&);
 
   } // namespace move_generator
 } // namespace osl
