@@ -9,7 +9,7 @@ namespace osl
   namespace move_generator
   {
     // explicit template instantiation
-    template struct Drop<move_action::Store>;
+    template class Drop<move_action::Store>;
     template void Drop<move_action::Store>::generate<BLACK>(const NumEffectState&,move_action::Store&);
     template void Drop<move_action::Store>::generate<WHITE>(const NumEffectState&,move_action::Store&);
   } // namespace move_generator
