@@ -21,7 +21,7 @@ namespace osl
 	Drop<SimpleState, Action>::template generateMoves <P>(state, action);
 	move_action::ToAroundKing8Filter<P, SimpleState, Action> action_filtered(state, action);
 	PieceOnBoardType<P, KING>::template
- 	  generate(state, state.getKingPiece<P>(), action_filtered);
+ 	  generate(state, state.kingPiece<P>(), action_filtered);
       }
     };
   }
