@@ -48,7 +48,7 @@ FeatureSet::addFinished()
 }
 
 double osl::move_probability::FeatureSet::
-matchExp(const StateInfo& state, Move move, const double * weights) const
+matchNoExp(const StateInfo& state, Move move, const double * weights) const
 {
   MoveInfo info(state, move);
   assert(offsets.size() == features.size()+1);
@@ -56,7 +56,13 @@ matchExp(const StateInfo& state, Move move, const double * weights) const
   for (size_t i=0; i<features.size(); ++i) {
     sum += features[i].match(state, info, offsets[i], weights);
   }
-  return exp(sum);
+  return sum;
+}
+
+double osl::move_probability::FeatureSet::
+matchExp(const StateInfo& state, Move move, const double * weights) const
+{
+  return exp(matchNoExp(state, move, weights));
 }
 
 double osl::move_probability::FeatureSet::
@@ -368,6 +374,18 @@ matchLight(const StateInfo& state, Move move) const
   return FeatureSet::matchLight(state, move, &weights[0]);
 }
 
+double osl::move_probability::StandardFeatureSet::
+matchExp(const StateInfo& state, Move move) const
+{
+  return FeatureSet::matchExp(state, move, &weights[0]);
+}
+
+double osl::move_probability::StandardFeatureSet::
+matchNoExp(const StateInfo& state, Move move) const
+{
+  return FeatureSet::matchNoExp(state, move, &weights[0]);
+}
+
 int osl::move_probability::StandardFeatureSet::
 logProbTakeBack(const StateInfo& state, Move target) const
 {
