@@ -5,8 +5,10 @@
 #include "osl/misc/ncores.h"
 #include "osl/eval/ml/openMidEndingEval.h"
 #include "osl/progress/ml/newProgress.h"
+#include "osl/container/tripleInt.h"
 #include <boost/filesystem/operations.hpp>
 #include <boost/static_assert.hpp>
+#include <boost/lexical_cast.hpp>
 #include <map>
 #include <limits>
 #include <iostream>
@@ -209,9 +211,12 @@ void osl::OslConfig::trySetDir(std::string& dir, const std::string& candidate)
     std::cerr << "skipping " << candidate << std::endl;
 }
 
-const std::string osl::OslConfig::makeHome()
+const std::string osl::OslConfig::makeHome(const std::string& first_try)
 {
   std::string result;
+  if (first_try != "")
+    trySetDir(result, first_try);
+
   if (const char *env = getenv("GPSSHOGI_HOME"))
     trySetDir(result, env);
   
@@ -232,9 +237,9 @@ const std::string osl::OslConfig::makeHome()
   return result;
 }
 
-const std::string& osl::OslConfig::home()
+const std::string& osl::OslConfig::home(const std::string& init)
 {
-  static const std::string home_directory = makeHome();
+  static const std::string home_directory = makeHome(init);
   return home_directory;
 }
 
@@ -476,6 +481,22 @@ void osl::OslConfig::setDfpnMaxDepth(int new_depth)
   dfpn_max_depth = new_depth;
 }
 
+std::string osl::OslConfig::configuration()
+{
+  return
+    "wordsize " +boost::lexical_cast<std::string>(OSL_WORDSIZE)+""
+# ifdef __GNUC__
+  " gcc " __VERSION__
+# endif
+#ifndef OSL_USE_SSE 
+    " nosse"
+#endif
+# ifndef NDEBUG
+    " (debug)"
+# endif  
+    ;
+}
+
 /* ------------------------------------------------------------------------- */
 // ;;; Local Variables:
 // ;;; mode:c++
