@@ -9,7 +9,7 @@ PathEncodingTable()
 {
   for (size_t i=0; i<MaxEncodingLength; ++i)
   {
-    for (size_t j=0; j<Position::SIZE; ++j)
+    for (size_t j=0; j<Square::SIZE; ++j)
     {
       for (int k=0; k<PTYPE_SIZE; ++k)
       {
@@ -29,7 +29,7 @@ osl::PathEncodingTable::
 {
 }
 
-#ifndef MINIMAL
+#if (!defined MINIMAL ) || (defined DFPNSTATONE)
 std::ostream& osl::operator<<(std::ostream& os, const osl::PathEncoding& path)
 {
   os << std::hex << path.getPath() << std::dec << " " << path.getDepth();
