@@ -14,7 +14,7 @@ std::ostream& osl::operator<<(std::ostream& os,const Piece piece)
   if (piece.isPiece())
     os << "Piece(" << piece.owner() << "," << piece.ptype() 
 	       << ",num=" << piece.number() 
-	       << "," << piece.position() << ')';
+	       << "," << piece.square() << ')';
   else if (piece == Piece::EMPTY())
     os << "PIECE_EMPTY";
   else if (piece == Piece::EDGE())
@@ -24,7 +24,7 @@ std::ostream& osl::operator<<(std::ostream& os,const Piece piece)
   return os;
 }
 
-const osl::Piece osl::Piece::makeKing(Player owner, Position position)
+const osl::Piece osl::Piece::makeKing(Player owner, Square position)
 {
   const int number = ((owner == BLACK)
 		      ? (int)KingTraits<BLACK>::index
