@@ -5,10 +5,10 @@
 
 int osl::progress::
 Effect5x3d::makeProgress(Player defense, const NumEffectState& state,
-			 Position king)
+			 Square king)
 {
   
-  const Position center = Centering5x3::adjustCenter(king);
+  const Square center = Centering5x3::adjustCenter(king);
 
   const int min_x = center.x() - 2;
   const int min_y = center.y() - 1;
@@ -20,7 +20,7 @@ Effect5x3d::makeProgress(Player defense, const NumEffectState& state,
     {
       for (int dy=0; dy<3; ++dy)
 	{
-	  const Position target(min_x+dx,min_y+dy);
+	  const Square target(min_x+dx,min_y+dy);
 	  sum_effect += state.countEffect(defense, target) *
 	    Effect5x3_Table.getDefenseEffect(defense,king,dx,dy);
 	}
@@ -32,13 +32,13 @@ Effect5x3d::makeProgress(Player defense, const NumEffectState& state,
 void osl::progress::
 Effect5x3d::update(const NumEffectState& new_state, Move /*last_move*/)
 {
-  const Position kb = new_state.getKingPosition<BLACK>(), kw = new_state.getKingPosition<WHITE>();
+  const Square kb = new_state.kingSquare<BLACK>(), kw = new_state.kingSquare<WHITE>();
   BoardMask mb = new_state.changedEffects(BLACK), mw = new_state.changedEffects(WHITE);
 
   if (mb.anyInRange(Board_Mask_Table5x3_Center.mask(kb)))
-    progresses[BLACK]=makeProgress(BLACK,new_state,new_state.getKingPosition<BLACK>());
+    progresses[BLACK]=makeProgress(BLACK,new_state,new_state.kingSquare<BLACK>());
   if (mw.anyInRange(Board_Mask_Table5x3_Center.mask(kw)))
-    progresses[WHITE]=makeProgress(WHITE,new_state,new_state.getKingPosition<WHITE>());
+    progresses[WHITE]=makeProgress(WHITE,new_state,new_state.kingSquare<WHITE>());
 }
 
 /* ------------------------------------------------------------------------- */
