@@ -275,7 +275,8 @@ bool osl::progress::ml::NewProgress::setUp(const char *filename)
   initialized_flag = is;
   if (!initialized_flag)
   {
-    std::cerr << "Failed to load NewProgress data " << read_count << std::endl;
+    std::cerr << "Failed to load NewProgress data " << read_count
+	      << " from file " << filename << std::endl;
   }
   return initialized_flag;
 }
