@@ -688,6 +688,12 @@ FeatureSet::showStatistics(std::ostream& os) const
   }
 }
 #endif
+
+std::string osl::rating::FeatureSet::defaultDirectory()
+{
+  return OslConfig::home()+"/data/rating";
+}
+
 /* ------------------------------------------------------------------------- */
 
 osl::rating::
@@ -767,13 +773,14 @@ StandardFeatureSet::StandardFeatureSet(bool allow_load_failure)
   add(new EscapePinGroup());
 
   addFinished();
-  bool success = tryLoad(OslConfig::home()+"/data/rating");
+  bool success = tryLoad(defaultDirectory());
   if (! allow_load_failure && ! success) {
-    std::cerr << "error: unable to load rating from " << OslConfig::home()+"/data/rating";
-    throw std::runtime_error("load failed " + OslConfig::home()+"/data/rating");
+    std::cerr << "error: unable to load rating from " << defaultDirectory();
+    throw std::runtime_error("load failed " + OslConfig::home()+defaultDirectory());
   }
 }
 
+
 const osl::rating::StandardFeatureSet& osl::rating::
 StandardFeatureSet::instance()
 {
@@ -781,6 +788,24 @@ StandardFeatureSet::instance()
   return common_instance;
 }
 
+bool osl::rating::StandardFeatureSet::healthCheck()
+{
+  std::cerr << "loading " << defaultDirectory() << ' ';
+  try {
+    instance();
+    std::cerr << "success\n";
+  }
+  catch (std::exception& e)
+  {
+    std::cerr << e.what() << "\n";
+    return false;
+  }
+  catch (...) {
+    std::cerr << "unknown exception\n";
+    return false;
+  }
+  return true;
+}
 
 osl::rating::
 CaptureSet::CaptureSet(bool allow_load_failure)
@@ -789,10 +814,10 @@ CaptureSet::CaptureSet(bool allow_load_failure)
   add(new ShadowEffectGroup());
 
   addFinished();
-  bool success = tryLoad(OslConfig::home()+"/data/rating");
+  bool success = tryLoad(defaultDirectory());
   if (! allow_load_failure && ! success) {
-    std::cerr << "error: unable to load rating from " << OslConfig::home()+"/data/rating";
-    throw std::runtime_error("load failed " + OslConfig::home()+"/data/rating");
+    std::cerr << "error: unable to load rating from " << defaultDirectory();
+    throw std::runtime_error("load failed " + defaultDirectory());
   }
 }
 
