@@ -2,7 +2,7 @@
  */
 #include "osl/rating/ratingEnv.h"
 #include "osl/rating/feature/king8.h"
-#include "osl/effect_util/sendOffPosition.h"
+#include "osl/effect_util/sendOffSquare.h"
 #include "osl/effect_util/pin.h"
 #include "osl/progress/effect5x3.h"
 
@@ -18,8 +18,8 @@ RatingEnv::make(const NumEffectState& state,
 		const PieceMask& my_pin, const PieceMask& op_pin, Progress16 progress)
 {
   sendoffs.clear();
-  const Position king_position = state.getKingPosition(alt(state.getTurn()));
-  effect_util::SendOffPosition::find(state.getTurn(), state, king_position, 
+  const Square king_position = state.kingSquare(alt(state.turn()));
+  effect_util::SendOffSquare::find(state.turn(), state, king_position, 
 				     sendoffs);
   this->my_pin = my_pin;
   this->op_pin = op_pin;
@@ -34,8 +34,8 @@ RatingEnv::make(const NumEffectState& state)
 {
   progress::Effect5x3 progress(state);
   make(state, 
-       state.pin(state.getTurn()),
-       state.pin(alt(state.getTurn())),
+       state.pin(state.turn()),
+       state.pin(alt(state.turn())),
        progress.progress16());
 }
 
