@@ -41,11 +41,15 @@ namespace osl
 	    const Move move = ((s == "%PASS" || /* gekisashi */ s == "<PASS>")
 			       ? Move::PASS(state.turn())
 			       : csa::strToMove(s, state));
-	    if (move.isPass() || (move.isNormal() && state.isValidMove(move,false)))
+	    if (move.isPass()
+		|| (move.isNormal() && state.isValidMove(move,false)))
 	    {
-	      info.moves.push_back(move);
 	      state.makeMove(move);
-	      continue;
+	      if (! state.inCheck(alt(state.turn()))) {
+		info.moves.push_back(move);
+		continue;
+	      }
+	      // fall through
 	    }
 	  }
 	  catch(CsaIOError& e)
