@@ -4,7 +4,7 @@
 #include "osl/record/kanjiMove.h"
 #include "osl/record/kanjiCode.h"
 #include "osl/misc/sjis2euc.h"
-#include "osl/misc/iconvConvert.h"
+#include "osl/misc/eucToLang.h"
 #include "osl/state/simpleState.h"
 #include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string/replace.hpp>
@@ -148,7 +148,7 @@ namespace osl
       if (m.isNormal()) {
 	if (! state->isValidMove(m)) {
 	  std::ostringstream ss;
-	  ss << *state << IconvConvert::eucToLang(s) << "\n" << m;
+	  ss << *state << misc::eucToLang(s) << "\n" << m;
 	  std::cerr << ss.str();
 	  throw KakinokiIOError(ss.str());
 	}	
