@@ -4,7 +4,7 @@
 #include "osl/container/moveVector.h"
 #include "osl/move_generator/legalMoves.h"
 #include "osl/stl/copy_if.h"
-#include "osl/misc/iconvConvert.h"
+#include "osl/misc/eucToLang.h"
 #include <boost/foreach.hpp>
 #include <boost/mem_fn.hpp>
 #include <boost/lambda/lambda.hpp>
@@ -362,7 +362,7 @@ KanjiMove::selectCandidates(found_moves_t& found,
 
   assert(found.size() == 1);
   if (!str.empty())
-    std::cerr << "WARNING: A single candidate is selected, but the input string still has some characters: " << IconvConvert::eucToLang(str) << std::endl;
+    std::cerr << "WARNING: A single candidate is selected, but the input string still has some characters: " << misc::eucToLang(str) << std::endl;
 }
 
 const osl::Move osl::record::
@@ -371,7 +371,12 @@ KanjiMove::strToMove(const std::string& orig,
                      const osl::Move& last_move) const
 {
   std::string str(orig);
-  assert(orig.size() >= 4*2 || (str.substr(2,2) == K_ONAZI && orig.size() >= 3*2));
+  if (str.find(K_RESIGN) != str.npos)
+    return Move();
+  assert(str.size() >= 4*2
+	 || (str.size() >= 3*2
+	     && (str.substr(2,2) == K_ONAZI
+		 || (isdigit(str[2]) && isdigit(str[3])))));
   const Player player = str.substr(0,2) == K_BLACK_SIGN ? BLACK : WHITE;
   assert(player == state.turn());
   str.erase(0,2);
