@@ -5,11 +5,12 @@
 #include "osl/state/numEffectState.h"
 #include "osl/oslConfig.h"
 #include <boost/foreach.hpp>
+#include <boost/scoped_ptr.hpp>
 
 osl::record::opening::
-BookInMemory::BookInMemory()
+BookInMemory::BookInMemory(const std::string& filename)
 {
-  readAll();
+  readAll(filename);
 }
 
 osl::record::opening::
@@ -21,18 +22,17 @@ int osl::record::opening::
 BookInMemory::readRecursive(const HashKey& key, int index, WeightedBook& book, int depth, int /*parent_visit*/)
 {
   const int depth_threshold = 60, visit_threshold = 4, scale = 16;
-  if (depth > depth_threshold || table.find(key) != table.end())
-    return 0;
   const int visit = book.getBlackWinCount(index)+book.getWhiteWinCount(index);
-  if (visit < visit_threshold)
-    return 0;
+  if (depth > depth_threshold || table.find(key) != table.end()
+      || visit < visit_threshold)
+    return visit;
   const vector<record::opening::WMove>& moves = book.getMoves(index);
   FixedCapacityVector<std::pair<int, Move>, 40> children;
   BOOST_FOREACH(WMove move, moves)
   {
     const HashKey child = key.newMakeMove(move.getMove());
     const int cv = readRecursive(child, move.getStateIndex(), book, depth+1, visit);
-    if (cv < visit_threshold || cv*scale < visit)
+    if (cv < visit_threshold || cv*scale < visit || move.getWeight() == 0)
       continue;
     children.push_back(std::make_pair(cv, move.getMove()));
     if (children.size() == children.capacity())
@@ -53,9 +53,9 @@ BookInMemory::readRecursive(const HashKey& key, int index, WeightedBook& book, i
 }
 
 void osl::record::opening::
-BookInMemory::readAll()
+BookInMemory::readAll(const std::string& filename)
 {
-  WeightedBook book(OslConfig::openingBook());
+  WeightedBook book(OslConfig::openingBook(filename));
   int index = book.getStartState();
   const NumEffectState state;
   readRecursive(HashKey(state), index, book, 0, 0);
@@ -74,10 +74,13 @@ BookInMemory::find(const HashKey& key, MoveVector& out) const
 
 const osl::record::opening::BookInMemory&
 osl::record::opening::
-BookInMemory::instance()
+BookInMemory::instance(const std::string& filename)
 {
-  static BookInMemory book;
-  return book;
+  static std::map<std::string,boost::shared_ptr<BookInMemory> > table;
+  boost::shared_ptr<BookInMemory> &book = table[filename];
+  if (! book)
+    book.reset(new BookInMemory(filename));
+  return *book;
 }
 
 // ;;; Local Variables:
