@@ -29,7 +29,7 @@
 #include "osl/effect_util/additionalEffect.h"
 #include "osl/misc/nonBlockDelete.h"
 #include "osl/misc/ctime.h"
-#include "osl/misc/iconvConvert.h"
+#include "osl/misc/eucToLang.h"
 #include "osl/stat/ratio.h"
 #include "osl/enter_king/enterKing.h"
 #include <boost/foreach.hpp>
@@ -1452,7 +1452,7 @@ showPV(std::ostream& os, int result, Move m, char stable_char) const
 	  record->threatmate().isThreatmate(state.turn()))
 	str += "(" K_TSUMERO ")";
     }
-    std::string converted = IconvConvert::eucToLang(str);
+    std::string converted = misc::eucToLang(str);
     if (! converted.empty())
       os << converted << std::endl;
   }
