@@ -25,7 +25,6 @@
 #include "osl/move_order/moveSorter.h"
 #include "osl/move_order/captureSort.h"
 #include "osl/move_order/cheapPtype.h"
-#include "osl/apply_move/applyMoveWithPath.h"
 #include "osl/record/csa.h"
 #include "osl/stl/hash_map.h"
 #include "osl/stat/average.h"
@@ -269,14 +268,14 @@ searchRoot(int limit)
 {
   depth = 0;
   SearchInfo& root = tree[0];
-  root.moved = Move::PASS(alt(state.getTurn()));
+  root.moved = Move::PASS(alt(state.turn()));
   root.hash_key = HashKey(state);
   root.height = limit;
-  root.path = PathEncoding(state.getTurn(), 0);
+  root.path = PathEncoding(state.turn(), 0);
   root.eval = eval_t(state);
   root.moves.clear();
   recorder.resetNodeCount();
-  root_player = state.getTurn();
+  root_player = state.turn();
   repetition_counter.clear();
   repetition_counter.push(root.hash_key, state);
 #if 1
@@ -294,7 +293,7 @@ searchRoot(int limit)
 #endif
   
   Move best_move;
-  const Player turn = state.getTurn();
+  const Player turn = state.turn();
   int best_value = minusInfty(turn);
   root.alpha = best_value + eval::delta(turn);
   root.beta = -minusInfty(turn) - eval::delta(turn);
@@ -326,7 +325,7 @@ searchRoot(int limit)
 	  if (decorate_csa_in_pv) {
 	    if (i && root.pv[i-1].move.to() == root.pv[i].move.to()) std::cerr << '!';
 	    else if (root.pv[i].move.capturePtype()) std::cerr << 'x' << record::csa::show(root.pv[i].move.capturePtype());
-	    if (root.pv[i].move.isPromote()) std::cerr << '*';
+	    if (root.pv[i].move.isPromotion()) std::cerr << '*';
 	    if (root.pv[i].in_check) std::cerr << '#';
 	    if (show_height_in_pv) std::cerr << "(" << root.pv[i].height/10 << ")";
 	  }
@@ -354,7 +353,7 @@ struct osl::search::AlphaBeta3::CallSearch
 {
   AlphaBeta3 *search;
   explicit CallSearch(AlphaBeta3 *s) : search(s) {}
-  void operator()(Position) const { search->template presearch<P>(); }
+  void operator()(Square) const { search->template presearch<P>(); }
 };
 
 template <osl::Player P>
@@ -362,7 +361,7 @@ struct osl::search::AlphaBeta3::CallQuiesce
 {
   AlphaBeta3 *search;
   explicit CallQuiesce(AlphaBeta3 *s) : search(s) {}
-  void operator()(Position) const { search->template quiesce<PlayerTraits<P>::opponent>(); }
+  void operator()(Square) const { search->template quiesce<PlayerTraits<P>::opponent>(); }
 };
 
 template <osl::Player P>
@@ -395,7 +394,9 @@ makeMoveAndSearch(Move move, int consume)
   // repetition_counter.push(node.hash_key, state);
   
   CallSearch<P> f(this);
-  ApplyMoveWithPath<P>::doUndoMoveOrPass(state, node.path, move, f);
+  node.path.pushMove(move);
+  state.makeUnmakeMove(Player2Type<P>(), move, f);
+  node.path.popMove(move);
 
   // repetition_counter.pop();
   --depth;
@@ -409,8 +410,7 @@ reductionOk() const
 {
   const SearchInfo& node = tree[depth];
   const Move m = node.moved;
-  if (m.capturePtype() != PTYPE_EMPTY
-      || m.isPromote())
+  if (m.isCaptureOrPromotion())
     return false;
   if (node.in_check || (depth > 0 && tree[depth-1].in_check))
     return false;
@@ -422,13 +422,13 @@ void osl::search::AlphaBeta3::
 presearch()
 {
   SearchInfo& node = tree[depth];
-  assert(state.getTurn() == alt(P));
+  assert(state.turn() == alt(P));
   const Player turn = alt(P);
-  if (state.hasEffectBy(turn, state.getKingPosition(alt(turn)))) {
+  if (state.hasEffectAt(turn, state.kingSquare(alt(turn)))) {
     node.search_value = winByFoul(turn);
     return;
   }
-  node.in_check = state.hasEffectBy(alt(turn), state.getKingPosition(turn));
+  node.in_check = state.hasEffectAt(alt(turn), state.kingSquare(turn));
   node.eval.update(state, node.moved);
 
   // heuristic extension
@@ -448,7 +448,7 @@ presearch()
   } 
   else if (depth > 1 && node.moved.to() == tree[depth-1].moved.to() && ! node.moved.isPass()) {
     const int ext = (node.alpha != node.beta
-		     || tree[depth-1].moved.capturePtype() != PTYPE_EMPTY)
+		     || tree[depth-1].moved.isCapture())
       ? 50 : 25;
     node.extended += ext;
     node.height += ext;
@@ -544,7 +544,7 @@ search()
   add_node_count(depth);
 
   SearchInfo& node = tree[depth];
-  assert(state.getTurn() == P);
+  assert(state.turn() == P);
   recorder.addNodeCount();  
 
   if (node.height < 0) {
@@ -677,7 +677,7 @@ osl::Move osl::search::AlphaBeta3::nextMove()
     node.moves.clear();
     if (node.in_check) {
       move_generator::GenerateEscape<P>::
-	generate(state,state.getKingPiece<P>(),node.moves);
+	generate(state,state.kingPiece<P>(),node.moves);
       node.move_type = KingEscape; // fall through
     } // fall through
   case KingEscape:
@@ -777,10 +777,10 @@ generateCapture(const NumEffectState& state, SearchInfo& node)
     all.clear();
     move_action::Store store(all);
     for (int j=Ptype_Table.getIndexMin(ptype); j<Ptype_Table.getIndexLimit(ptype); ++j) {
-      const Piece p = state.getPieceOf(j);
+      const Piece p = state.pieceOf(j);
       if (! p.isOnBoardByOwner<PlayerTraits<P>::opponent>())
 	continue;
-      move_generator::GenerateCapture::generate(P,state, p.position(), store);
+      move_generator::GenerateCapture::generate(P,state, p.square(), store);
     }
     BOOST_FOREACH(Move move, all) {
       if (See::see(state, move) > 0) {
@@ -805,10 +805,10 @@ generateCapture(const NumEffectState& state, SearchInfo& node)
   {
     move_action::Store store(all);
     for (int j=Ptype_Table.getIndexMin(PAWN); j<Ptype_Table.getIndexLimit(PAWN); ++j) {
-      const Piece p = state.getPieceOf(j);
+      const Piece p = state.pieceOf(j);
       if (! p.isOnBoardByOwner<PlayerTraits<P>::opponent>())
 	continue;
-      move_generator::GenerateCapture::generate(P,state, p.position(), store);
+      move_generator::GenerateCapture::generate(P,state, p.square(), store);
     }
   }
   BOOST_FOREACH(Move move, all) {
@@ -823,7 +823,7 @@ bool osl::search::AlphaBeta3::
 seePlusLight(const NumEffectState& state, Move m)
 {
   assert(P == m.player());
-  assert(P == state.getTurn());
+  assert(P == state.turn());
   assert(! m.isDrop());
   if (state.countEffect(P, m.to()) > state.countEffect(P, m.to()))
     return true;
@@ -841,18 +841,18 @@ generateCaptureAll(const NumEffectState& state, SearchInfo& node)
     for (size_t i=0; i+1<PieceStand::order.size(); ++i) {
       const Ptype ptype = PieceStand::order[i];
       for (int j=Ptype_Table.getIndexMin(ptype); j<Ptype_Table.getIndexLimit(ptype); ++j) {
-	const Piece p = state.getPieceOf(j);
+	const Piece p = state.pieceOf(j);
 	if (! p.isOnBoardByOwner<PlayerTraits<P>::opponent>())
 	  continue;
-	move_generator::GenerateCapture::generate(P,state, p.position(), store);
+	move_generator::GenerateCapture::generate(P,state, p.square(), store);
       }
     }
     move_generator::Promote<P>::generateMoves(state, store);
     for (int j=PtypeTraits<PAWN>::indexMin; j<PtypeTraits<PAWN>::indexLimit; ++j) {
-      const Piece p = state.getPieceOf(j);
+      const Piece p = state.pieceOf(j);
       if (! p.isOnBoardByOwner<PlayerTraits<P>::opponent>())
 	continue;
-      move_generator::GenerateCapture::generate(P,state, p.position(), store);
+      move_generator::GenerateCapture::generate(P,state, p.square(), store);
     }
   }
   BOOST_FOREACH(Move move, all)
@@ -866,8 +866,8 @@ void osl::search::AlphaBeta3::
 quiesceRoot()
 {
   SearchInfo& node = tree[depth];
-  assert(! state.hasEffectBy(P, state.getKingPosition(alt(P))));
-  assert(node.in_check == state.hasEffectBy(alt(P), state.getKingPosition(P)));
+  assert(! state.hasEffectAt(P, state.kingSquare(alt(P))));
+  assert(node.in_check == state.hasEffectAt(alt(P), state.kingSquare(P)));
 
   node.search_value = evalValue();
   const int static_value = node.search_value;
@@ -875,7 +875,7 @@ quiesceRoot()
   if (node.in_check) {
     node.moves.clear();
     move_generator::GenerateEscape<P>::
-      generate(state,state.getKingPiece<P>(),node.moves);
+      generate(state,state.kingPiece<P>(),node.moves);
     best_value = threatmatePenalty(P)+depth*EvalTraits<P>::delta*2;
     
     BOOST_FOREACH(Move move, node.moves) {
@@ -904,11 +904,11 @@ quiesceRoot()
     if (EvalTraits<P>::betterThan(node.alpha, expected))
       break;
     for (int j=Ptype_Table.getIndexMin(ptype); j<Ptype_Table.getIndexLimit(ptype); ++j) {
-      const Piece p = state.getPieceOf(j);
+      const Piece p = state.pieceOf(j);
       if (! p.isOnBoardByOwner<PlayerTraits<P>::opponent>())
 	continue;
       node.moves.clear();
-      move_generator::GenerateCapture::generate(P,state, p.position(), node.moves);
+      move_generator::GenerateCapture::generate(P,state, p.square(), node.moves);
       BOOST_FOREACH(Move move, node.moves) {
 	if (See::see(state, move) < 0)
 	  continue;
@@ -943,7 +943,9 @@ makeMoveAndQuiesce(Move move)
   tree[depth].pv.clear();
 
   CallQuiesce<P> f(this);
-  ApplyMoveWithPath<P>::doUndoMoveOrPass(state, tree[depth].path, move, f);
+  tree[depth].path.pushMove(move);
+  state.makeUnmakeMove(move, f);
+  tree[depth].path.popMove(move);
 
   --depth;
 
@@ -956,15 +958,15 @@ quiesce()
 {
   add_node_count(depth);
 
-  assert(state.getTurn() == P);
+  assert(state.turn() == P);
   recorder.addQuiescenceCount();
   SearchInfo& node = tree[depth];
-  if (state.hasEffectBy(P, state.getKingPosition(alt(P)))) {
+  if (state.hasEffectAt(P, state.kingSquare(alt(P)))) {
     node.search_value = winByFoul(P);
     return;
   }
   node.eval.update(state, node.moved);
-  node.in_check = state.hasEffectBy(alt(P), state.getKingPosition(P));
+  node.in_check = state.hasEffectAt(alt(P), state.kingSquare(P));
 
   const int static_value = evalValue();
   int best_value = static_value;
@@ -972,7 +974,7 @@ quiesce()
   if (node.in_check) {
     node.moves.clear();
     move_generator::GenerateEscape<P>::
-      generate(state,state.getKingPiece<P>(),node.moves);
+      generate(state,state.kingPiece<P>(),node.moves);
 
     best_value = threatmatePenalty(P)+depth*EvalTraits<P>::delta*2;
     
@@ -1003,11 +1005,11 @@ quiesce()
     if (EvalTraits<P>::betterThan(node.alpha, expected))
       break;
     for (int j=Ptype_Table.getIndexMin(ptype); j<Ptype_Table.getIndexLimit(ptype); ++j) {
-      const Piece p = state.getPieceOf(j);
+      const Piece p = state.pieceOf(j);
       if (! p.isOnBoardByOwner<PlayerTraits<P>::opponent>())
 	continue;
       node.moves.clear();
-      move_generator::GenerateCapture::generate(P,state, p.position(), node.moves);
+      move_generator::GenerateCapture::generate(P,state, p.square(), node.moves);
 
       for (size_t k=0; k<std::min((size_t)1, node.moves.size()); ++k) {
 	const Move move = node.moves[k];
