@@ -218,7 +218,7 @@ validCaptureMove(osl::state::NumEffectState const& state,
  * opMinus 1 - op drop move
  */
 template<osl::Player P>
-bool osl::search::StateElements::canReject(osl::state::NumEffectState const& state,bool notRejectSennichite,bool notRootMove,Move lastMove,Move actualMove) const
+bool osl::search::StateElements::canReject(osl::state::NumEffectState const& state,bool mayRejectSennichite,bool isRootMove,Move lastMove,Move actualMove) const
 {
   const Player altP=PlayerTraits<P>::opponent;
   switch(myOnboardPlus.size()){
@@ -228,7 +228,7 @@ bool osl::search::StateElements::canReject(osl::state::NumEffectState const& sta
       if(opOnboardMinus.size()==1 && myOnboardMinus.size()==0){
 	// op simple move
 	if(validSimpleMove<altP>(state,opOnboardPlus[0],opOnboardMinus[0],lastMove)){
-	  if(notRejectSennichite && stand.isZero()){
+	  if(!mayRejectSennichite && stand.isZero()){
 	    return false;
 	  }
 	  return stand.geZero();
@@ -243,7 +243,7 @@ bool osl::search::StateElements::canReject(osl::state::NumEffectState const& sta
 	  Ptype ptype=getPtype(opOnboardMinus[0].ptypeO());
 	  if(!isPromoted(ptype)){
 	    localStand.sub(ptype);
-	    if(notRejectSennichite && localStand.isZero()){
+	    if(!mayRejectSennichite && localStand.isZero()){
 	      return false;
 	    }
 	    return localStand.geZero();
@@ -252,7 +252,8 @@ bool osl::search::StateElements::canReject(osl::state::NumEffectState const& sta
       }
       else{ // pass moves (including piece loosing cases)
 	if(opOnboardMinus.size()==0 && myOnboardMinus.size()==0){
-	  return stand.gegtZero(!notRootMove);
+	  if(isRootMove) return stand.gtZero();
+	  else return stand.geZero(); 
 	}
       }
       return false;
@@ -273,7 +274,7 @@ bool osl::search::StateElements::canReject(osl::state::NumEffectState const& sta
 	    localStand.add(capturePtype);
 	    if(localStand.isZero()){
 	      assert(actualMove.player()==P);
-	      if(notRejectSennichite &&
+	      if(!mayRejectSennichite &&
 		 actualMove.ptypeO()==myOnboardPlus[0].ptypeO() &&
 		 actualMove.from()==myOnboardMinus[0].pos() &&
 		 actualMove.to()==myOnboardPlus[0].pos()) return false;
@@ -288,7 +289,7 @@ bool osl::search::StateElements::canReject(osl::state::NumEffectState const& sta
 	  if(validSimpleMove<P>(state,myOnboardMinus[0],myOnboardPlus[0],lastMove)){
 	    if(stand.isZero()){
 	      assert(actualMove.player()==P);
-	      if(notRejectSennichite &&
+	      if(!mayRejectSennichite &&
 		 actualMove.ptypeO()==myOnboardPlus[0].ptypeO() &&
 		 actualMove.from()==myOnboardMinus[0].pos() &&
 		 actualMove.to()==myOnboardPlus[0].pos()) return false;
@@ -308,7 +309,7 @@ bool osl::search::StateElements::canReject(osl::state::NumEffectState const& sta
 	    Ptype capturePtype=unpromote(getPtype(myOnboardPlus[0].ptypeO()));
 	    // 次のmoveを実行すると相手に取っては増える．
 	    localStand.add(capturePtype);
-	    if(notRejectSennichite && localStand.isZero()){
+	    if(!mayRejectSennichite && localStand.isZero()){
 	      return false;
 	    }
 	    return localStand.geZero();
@@ -322,7 +323,7 @@ bool osl::search::StateElements::canReject(osl::state::NumEffectState const& sta
 	  StandElements localStand(stand);
 	  localStand.sub(getPtype(myOnboardPlus[0].ptypeO()));
 	  if(localStand.isZero()){
-	    if(notRejectSennichite &&
+	    if(!mayRejectSennichite &&
 	       actualMove.ptypeO()==myOnboardPlus[0].ptypeO() &&
 	       actualMove.isDrop() &&
 	       actualMove.to()==myOnboardPlus[0].pos()) return false;
@@ -396,23 +397,24 @@ ProbeCounter probeCounter;
 
 template<osl::Player P>
 bool osl::search::MoveStackRejections::
-probe(osl::state::NumEffectState const& state,osl::container::MoveStack const& history,int curDepth,osl::Move const& m,int alpha,int checkCountOfAltP)
+probe(osl::state::NumEffectState const& state,osl::container::MoveStack const& history,int ply,osl::Move const& m,int alpha,int checkCountOfAltP)
 {
   StateElements elements;
   elements.addMyMove(m);
   assert(m.player()==P);
   bool existNormal=false;
-  for(int i=1;i<curDepth;i+=2){
+  for(int i=1;i<ply;i+=2){
     Move m1=history.lastMove(i);
     if(m1.isNormal()){
       assert(m1.player()==alt(P));
       elements.addOpMove(m1);
       existNormal=true;
     }
+    else if(m1.isInvalid()) return false;
     if(elements.isLoop()){
-      bool notRejectSennichite=osl::eval::betterThan(P,0,alpha) || (i<=checkCountOfAltP*2-1) || (i==curDepth-1);
+      bool mayRejectSennichite=osl::eval::notLessThan(P,alpha,0) && (i>checkCountOfAltP*2-1);
       if(elements.stand.isZero()){
-	if(!notRejectSennichite) return true;
+	if(mayRejectSennichite) return true;
       }
       else if(elements.stand.geZero()) return true;
     }
@@ -422,16 +424,17 @@ probe(osl::state::NumEffectState const& state,osl::container::MoveStack const& h
       elements.addMyMove(m2);
       existNormal=true;
     }
+    else if(m2.isInvalid()) return false;
 #ifdef SHOW_PROBE_COUNTER
     probeCounter.incCheck(i);
 #endif
     // i==1 -- checkCount=1
     // i==3 -- checkCount=2
-    bool notRejectSennichite=osl::eval::betterThan(P,0,alpha) || (i<=checkCountOfAltP*2-1);
-    bool notRootMove=(i != curDepth-1);
+    bool mayRejectSennichite=osl::eval::notLessThan(P,alpha,0) && (i>checkCountOfAltP*2-1);
+    bool isRootMove=(i == ply-1);
     if(
        existNormal && 
-       elements.canReject<P>(state,notRejectSennichite,notRootMove,m,m2)
+       elements.canReject<P>(state,mayRejectSennichite,isRootMove,m,m2)
        ){
 #ifdef SHOW_PROBE_COUNTER
       probeCounter.incHit(i);
@@ -446,9 +449,9 @@ namespace osl
   namespace search
   {
     template bool MoveStackRejections::probe<BLACK>(
-						    osl::state::NumEffectState const& state,osl::container::MoveStack const& history,int curDepth,osl::Move const& m,int alpha, int checkCountOfAltP);
+						    osl::state::NumEffectState const& state,osl::container::MoveStack const& history,int ply,osl::Move const& m,int alpha, int checkCountOfAltP);
     template bool MoveStackRejections::probe<WHITE>(
-						    osl::state::NumEffectState const& state,osl::container::MoveStack const& history,int curDepth,osl::Move const& m,int alpha,int checkCountOfAltP);
+						    osl::state::NumEffectState const& state,osl::container::MoveStack const& history,int ply,osl::Move const& m,int alpha,int checkCountOfAltP);
   }
 }
 
