@@ -1,7 +1,9 @@
 /* searchMonitor.cc
  */
 #include "osl/search/searchMonitor.h"
-
+#include "osl/record/csa.h"
+#include <iostream>
+#include <iomanip>
 osl::search::SearchMonitor::
 ~SearchMonitor()
 {
@@ -52,6 +54,23 @@ void osl::search::SearchMonitor::searchFinished()
 {
 }
 
+//
+void osl::search::CerrMonitor::
+showPV(int depth, size_t /*node_count*/, double elapsed, int value, Move cur,
+       const Move *first, const Move *last, 
+       const bool */*threatmate_first*/, const bool */*threatmate_last*/)
+{
+  std::cerr << " " << record::csa::show(cur) << " "
+	    << std::setw(6) << value
+	    << " " << std::setw(2) << last -first
+	    << "/" << std::setw(2) << depth << " ";
+  for (int i=0; i<last-first; ++i) {
+    std::cerr << record::csa::show(first[i]);
+  }
+  std::cerr << " " << elapsed << 's' << std::endl;
+}
+
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
