@@ -12,8 +12,8 @@ SimpleHashRecord::dump(std::ostream& os) const
 {
   os << "SimpleHashRecord " << this 
      << " node_count " << nodeCount() << "\n";
-  os << "best move " << record::csa::show(best_move.getMove())
-	    << " " << best_move.getLogProb()
+  os << "best move " << record::csa::show(best_move.move())
+	    << " " << best_move.logProb()
      << "\t";
   os << "limit: l " << lower_limit << " u " << upper_limit << "\n";
   os << "in_check " << inCheck() << "\n";
