@@ -17,16 +17,16 @@ namespace osl
   {
     struct OrderSpecifiedPiece
     {
-      Position from;
-      explicit OrderSpecifiedPiece(Position f) : from(f)
+      Square from;
+      explicit OrderSpecifiedPiece(Square f) : from(f)
       {
       }
       bool operator()(Move l, Move r) const
       {
-	const Position from_l = l.from();
+	const Square from_l = l.from();
 	if (from_l == from)
 	  return true;
-	const Position from_r = r.from();
+	const Square from_r = r.from();
 	if (from_r == from)
 	  return false;
 
@@ -37,7 +37,7 @@ namespace osl
 } // namespace osl
 
 void osl::search::SortCaptureMoves::
-sortBySpecifiedPiece(MoveVector& moves, Position from)
+sortBySpecifiedPiece(MoveVector& moves, Square from)
 {
   std::sort(moves.begin(), moves.end(), OrderSpecifiedPiece(from));
 }
