@@ -20,7 +20,7 @@ UsiReporter::showPV(std::ostream& os, int depth, size_t node_count, double elaps
   if (OslConfig::usiModeInSilent() && ! ignore_silent)
     return;
   int seldepth = last-first;
-  if (last - first && *first != cur)
+  if (last == first || *first != cur)
     ++seldepth;
   if (ignore_silent)
     std::cerr << "info depth " << depth << " seldepth " << seldepth
@@ -110,7 +110,8 @@ UsiReporter::hashInfo(std::ostream& os, double ratio)
 
 osl::search::
 UsiMonitor::UsiMonitor(bool ex, std::ostream& o, double s)
-  : silent_period(s), extended(ex), os(o), udp_socket(0), udp_endpoint(0)
+  : silent_period(s), extended(ex), os(o), udp_socket(0), udp_endpoint(0),
+    client_id("")
 {
 }
 
@@ -120,12 +121,15 @@ UsiMonitor::~UsiMonitor()
 }
 
 void osl::search::
-UsiMonitor::showDeferred()
+UsiMonitor::showDeferred(bool forced)
 {
-  if (depth0.elapsedSeconds() < silent_period || deferred.empty())
+  if ((!forced && depth0.elapsedSeconds() < silent_period)
+      || deferred.empty())
     return;
   os << deferred << std::flush;
   if (udp_socket) {
+    if (client_id != "")
+      deferred = client_id + " " + deferred;
     boost::system::error_code ignored_error;
     udp_socket->send_to(boost::asio::buffer(deferred.c_str(), deferred.length()),
                         *udp_endpoint,
@@ -165,15 +169,23 @@ UsiMonitor::showPV(int depth, size_t node_count, double elapsed, int value, Move
     std::string msg = ss.str();
     os << msg << std::flush;
     if (udp_socket) {
+      if (client_id != "")
+	msg = client_id + " " + msg;
       boost::system::error_code ignored_error;
       udp_socket->send_to(boost::asio::buffer(msg.c_str(), msg.length()),
                           *udp_endpoint, 0,
 			  ignored_error);
     }
-    deferred.clear();
+    deferred.clear();		// msg sent was newer than deferred
   }
 }
 
+void osl::search::UsiMonitor::
+showFailLow(int depth, size_t node_count, double elapsed, int value, Move cur)
+{
+  showPV(depth, node_count, elapsed, value, cur, 0, 0, 0, 0);
+}
+
 void osl::search::
 UsiMonitor::rootMove(Move cur)
 {
@@ -199,6 +211,8 @@ UsiMonitor::timeInfo(size_t node_count, double elapsed)
     std::string msg = ss.str();
     os << msg << std::flush;
     if (udp_socket) {
+      if (client_id != "")
+	msg = client_id + " " + msg;
       boost::system::error_code ignored_error;
       udp_socket->send_to(boost::asio::buffer(msg.c_str(), msg.length()),
                           *udp_endpoint, 0,
@@ -237,13 +251,21 @@ UsiMonitor::rootLossByCheckmate()
 }
 
 void osl::search::
-UsiMonitor::setUdpLogging(boost::asio::ip::udp::socket *s,
+UsiMonitor::setUdpLogging(std::string& udp_client_id,
+			  boost::asio::ip::udp::socket *s,
 			  boost::asio::ip::udp::endpoint *e)
 {
+  client_id = udp_client_id;
   udp_socket = s;
   udp_endpoint = e;
 }
 
+void osl::search::
+UsiMonitor::searchFinished()
+{
+  showDeferred(true);
+}
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
