@@ -1,6 +1,7 @@
 /* square.cc
  */
 #include "osl/square.h"
+#include "osl/boardTable.h"
 #include <boost/static_assert.hpp>
 #include <iostream>
 
@@ -25,6 +26,19 @@ Square::squareForBlackSlow(Player player) const
   return Square(reverseX(x()),reverseY(y()));
 }
 
+
+const osl::Square osl::
+Square::neighbor(Player P, Direction D) const
+{
+  return Board_Table.nextSquare(P, *this, D);
+}
+
+const osl::Square osl::
+Square::back(Player P, Direction D) const
+{
+  return Board_Table.nextSquare(alt(P), *this, D);
+}
+
 std::ostream& osl::operator<<(std::ostream& os, Square square)
 {
   if (square.isPieceStand())
