@@ -723,9 +723,6 @@ bool osl::state::NumEffectState::isConsistent(bool showError) const
 
 bool osl::state::NumEffectState::isConsistent(const NumEffectState& prev, Move moved, bool show_error) const
 {
-#ifdef MINIMAL
-  show_error=false;
-#endif
   // test changedEffects
   const CArray<BoardMask,2> changed_squares
     = {{ changedEffects(BLACK), changedEffects(WHITE) }};
@@ -928,7 +925,7 @@ void osl::state::NumEffectState::copyFrom(const NumEffectState& src)
   (*this).used_mask=src.used_mask;
 #endif
   (*this).stand_mask=src.stand_mask;
-#if defined(i386) || defined(__x86_64)
+#if defined(__i386__) || defined(__x86_64__)
   {  
     v2di b16=*((v2di*)&src.board[16]);
     v2di b20=*((v2di*)&src.board[20]);
