@@ -286,6 +286,34 @@ bool osl::SimpleState::isConsistent(bool show_error) const
       return false;
     }
   }
+  // illegal position for piece
+  for (int i=0; i<nthLimit<PAWN>(); ++i) {
+    const Piece pawn = nth<PAWN>(i);
+    if (! pawn.isPromoted() && pawn.isOnBoard()
+	&& pawn.square().squareForBlack(pawn.owner()).y() == 1) {
+      if (show_error)
+	std::cerr << "pawn " << pawn << std::endl;
+      return false;
+    } 
+  }
+  for (int i=0; i<nthLimit<LANCE>(); ++i) {
+    const Piece lance = nth<LANCE>(i);
+    if (! lance.isPromoted() && lance.isOnBoard()
+	&& lance.square().squareForBlack(lance.owner()).y() == 1) {
+      if (show_error)
+	std::cerr << "lance " << lance << std::endl;
+      return false;
+    } 
+  }
+  for (int i=0; i<nthLimit<KNIGHT>(); ++i) {
+    const Piece knight = nth<KNIGHT>(i);
+    if (! knight.isPromoted() && knight.isOnBoard()
+	&& knight.square().squareForBlack(knight.owner()).y() == 1) {
+      if (show_error)
+	std::cerr << "knight " << knight << std::endl;
+      return false;
+    } 
+  }
   return true;
 }
 
@@ -415,7 +443,7 @@ bool osl::SimpleState::isValidMove(Move move,bool show_error) const
     }
     return false;
   }
-  if (! isValidMoveByRule(move, show_error))
+  if (! isValidMoveByRule(move, show_error) || ! move.isValid())
     return false;
   return isAlmostValidMove(move, show_error);
 }
