@@ -4,8 +4,8 @@
 
 bool osl::threatmate::KfendPredictor::predict(const NumEffectState& state, 
 					      const Move move){
-  const Player turn = alt(state.getTurn());
-  const Position opKingPosition = state.getKingPosition(alt(turn));
+  const Player turn = alt(state.turn());
+  const Square opKingSquare = state.kingSquare(alt(turn));
 
   // Capture Piece
   if (move.capturePtype())
@@ -13,7 +13,7 @@ bool osl::threatmate::KfendPredictor::predict(const NumEffectState& state,
 
   // Add Effect for King's Neighboring8
   if ( Neighboring8Direct::hasEffect(state, newPtypeO(turn, move.ptype()),
-				     move.to(), opKingPosition) )
+				     move.to(), opKingSquare) )
     return true;
   return false;
 }
