@@ -1,6 +1,6 @@
 /* printPiece.cc
  */
-#include "osl/position.h"
+#include "osl/square.h"
 #include <iostream>
 
 using namespace osl;
@@ -9,7 +9,7 @@ int main()
   unsigned long position;
   while (std::cin >> position)
   {
-    Position p = Position::makeDirect(position);
+    Square p = Square::makeDirect(position);
     std::cout << p.x() << " " << p.y() << " " << std::boolalpha << p.isOnBoard() << std::endl;
   }
 }
