@@ -35,8 +35,8 @@ void usage(const char *prog)
 bool verbose = false;
 
 void adjust(PiecePairRawTable& table, 
-	    Position pos1, PtypeO ptypeo1,
-	    Position pos2, PtypeO ptypeo2,
+	    Square pos1, PtypeO ptypeo1,
+	    Square pos2, PtypeO ptypeo2,
 	    int value)
 {
   assert(pos1.isOnBoard());
@@ -59,8 +59,8 @@ void adjust(PiecePairRawTable& table,
 }
 
 void adjustKingBonus(PiecePairRawTable& table, 
-		     Position pos1, PtypeO ptypeo1, // king
-		     Position pos2, PtypeO ptypeo2, // attacker
+		     Square pos1, PtypeO ptypeo1, // king
+		     Square pos2, PtypeO ptypeo2, // attacker
 		     int bonus)
 {
   assert(getPtype(ptypeo1) == KING);
@@ -73,7 +73,7 @@ void adjustKingBonus(PiecePairRawTable& table,
 
 /** king: white, attacker: black*/
 void adjustDual(PiecePairRawTable& table, 
-		Position king, Position attacker, Ptype attackerType,
+		Square king, Square attacker, Ptype attackerType,
 		int blackAttackBonus, int whiteAttackBonus)
 {
   adjustKingBonus(table, king.rotate180(), newPtypeO(BLACK, KING),
@@ -85,8 +85,8 @@ void adjustDual(PiecePairRawTable& table,
 }
 
 void adjustDual(PiecePairRawTable& table, 
-		Position black, Ptype black_ptype,
-		Position white, Ptype white_ptype,
+		Square black, Ptype black_ptype,
+		Square white, Ptype white_ptype,
 		int value)
 {
   adjust(table, black, newPtypeO(BLACK, black_ptype),
@@ -96,8 +96,8 @@ void adjustDual(PiecePairRawTable& table,
 }
 
 void addValue(Player player, PiecePairRawTable& table,
-	      Position pos1, Ptype ptype1,
-	      Position pos2, Ptype ptype2,
+	      Square pos1, Ptype ptype1,
+	      Square pos2, Ptype ptype2,
 	      int bonus)
 {
   const PtypeO ptypeo1 = newPtypeO(player, ptype1);
@@ -106,8 +106,8 @@ void addValue(Player player, PiecePairRawTable& table,
 }
 
 void addPenalty(Player player, PiecePairRawTable& table,
-		Position pos1, Ptype ptype1,
-		Position pos2, Ptype ptype2,
+		Square pos1, Ptype ptype1,
+		Square pos2, Ptype ptype2,
 		int bonus)
 {
   assert(eval::betterThan(player, 0, bonus));
@@ -115,8 +115,8 @@ void addPenalty(Player player, PiecePairRawTable& table,
 }
 
 void addBonus(Player player, PiecePairRawTable& table,
-	      Position pos1, Ptype ptype1,
-	      Position pos2, Ptype ptype2,
+	      Square pos1, Ptype ptype1,
+	      Square pos2, Ptype ptype2,
 	      int bonus)
 {
   assert(eval::betterThan(player, bonus, 0));
@@ -124,8 +124,8 @@ void addBonus(Player player, PiecePairRawTable& table,
 }
 
 void addPenaltyDual(PiecePairRawTable& table, 
-		    Position pos1, Ptype ptype1,
-		    Position pos2, Ptype ptype2,
+		    Square pos1, Ptype ptype1,
+		    Square pos2, Ptype ptype2,
 		    int black_bonus)
 {
   assert(black_bonus < 0);
@@ -134,7 +134,7 @@ void addPenaltyDual(PiecePairRawTable& table,
 }
 
 void addSelfPenaltyDual(PiecePairRawTable& table, 
-			Position pos, Ptype ptype,
+			Square pos, Ptype ptype,
 			int black_bonus)
 {
   addPenaltyDual(table, pos, ptype, pos, ptype, black_bonus);
@@ -174,13 +174,13 @@ int main(int argc, char **argv)
   table->loadFromBinaryFile(read_pairfilename);
 
   // 通常の5x5の範囲
-  CArray2d<bool,Position::SIZE,Position::SIZE> adjusted;
+  CArray2d<bool,Square::SIZE,Square::SIZE> adjusted;
   adjusted.fill(false);
   for (int king_x=1; king_x<=9; ++king_x)
   {
     for (int king_y=1; king_y<=9; ++king_y)
     {
-      const Position king(king_x,king_y);
+      const Square king(king_x,king_y);
       for (int attacker_x = ((king_x==9) ? king_x-3 : king_x-2); 
 	   attacker_x <= ((king_x==1) ? king_x+3 : king_x+2); ++attacker_x)
       {
@@ -191,7 +191,7 @@ int main(int argc, char **argv)
 	{
 	  if ((attacker_y < 1) || (attacker_y > 9))
 	    continue;
-	  const Position attacker(attacker_x,attacker_y);
+	  const Square attacker(attacker_x,attacker_y);
 	  if (king == attacker)
 	    continue;
 	  adjusted[king.index()][attacker.index()] = true;
@@ -247,7 +247,7 @@ int main(int argc, char **argv)
 	{
 	  if ((attacker_y < 1) || (attacker_y > 9))
 	    continue;
-	  const Position attacker(attacker_x,attacker_y);
+	  const Square attacker(attacker_x,attacker_y);
 	  if (king == attacker)
 	    continue;
 
@@ -286,14 +286,14 @@ int main(int argc, char **argv)
   {
     for (int king_y=1; king_y<=3; ++king_y)
     {
-      const Position king(king_x,king_y);
+      const Square king(king_x,king_y);
       for (int rook_x=1; rook_x<=9; ++rook_x)
       {
 	for (int rook_y=king_y-1; rook_y<=king_y+1; ++rook_y)
 	{
 	  if ((rook_y < 1) || (rook_y > 9))
 	    continue;
-	  const Position rook(rook_x, rook_y);
+	  const Square rook(rook_x, rook_y);
 	  if (king == rook)
 	    continue;
 	  if (! adjusted[king.index()][rook.index()])
@@ -312,7 +312,7 @@ int main(int argc, char **argv)
 	{
 	  if ((attacker_y < 1) || (attacker_y > 9))
 	    continue;
-	  const Position attacker(attacker_x,attacker_y);
+	  const Square attacker(attacker_x,attacker_y);
 	  if (king == attacker)
 	    continue;
 	  if (adjusted[king.index()][attacker.index()])
@@ -331,7 +331,7 @@ int main(int argc, char **argv)
   {
     for (int king_y=1; king_y<=3; ++king_y)
     {
-      const Position king(king_x,king_y);
+      const Square king(king_x,king_y);
       for (int attacker_x = ((king_x==9) ? king_x-5 : king_x-4); 
 	   attacker_x <= ((king_x==1) ? king_x+5 : king_x+4); ++attacker_x)
       {
@@ -341,7 +341,7 @@ int main(int argc, char **argv)
 	{
 	  if ((attacker_y < 1) || (attacker_y > 9))
 	    continue;
-	  const Position attacker(attacker_x,attacker_y);
+	  const Square attacker(attacker_x,attacker_y);
 	  if (king == attacker)
 	    continue;
 	  if (adjusted[king.index()][attacker.index()])
@@ -358,7 +358,7 @@ int main(int argc, char **argv)
   {
     for (int attacker_y=1; attacker_y<=9; ++attacker_y)
     {
-      const Position attacker(attacker_x,attacker_y);
+      const Square attacker(attacker_x,attacker_y);
       // 端の駒は色々減点
       if ((attacker_x == 1) || (attacker_x == 9))
       {
@@ -373,56 +373,56 @@ int main(int argc, char **argv)
     }
   }
   // 捌きにくい銀
-  addPenalty(BLACK, *table, Position(2,6), SILVER, Position(3,7), KNIGHT, -80);
-  addPenalty(WHITE, *table, Position(8,4), SILVER, Position(7,3), KNIGHT, +80);
+  addPenalty(BLACK, *table, Square(2,6), SILVER, Square(3,7), KNIGHT, -80);
+  addPenalty(WHITE, *table, Square(8,4), SILVER, Square(7,3), KNIGHT, +80);
 
-  addPenalty(BLACK, *table, Position(2,6), SILVER, Position(1,5), PAWN, -80);
-  addPenalty(WHITE, *table, Position(8,4), SILVER, Position(9,5), PAWN, +80);
+  addPenalty(BLACK, *table, Square(2,6), SILVER, Square(1,5), PAWN, -80);
+  addPenalty(WHITE, *table, Square(8,4), SILVER, Square(9,5), PAWN, +80);
 
-  addPenalty(BLACK, *table, Position(9,7), SILVER, Position(8,8), BISHOP, -80);
-  addPenalty(BLACK, *table, Position(1,7), SILVER, Position(2,8), BISHOP, -80);
-  addPenalty(WHITE, *table, Position(9,3), SILVER, Position(8,2), BISHOP, +80);
-  addPenalty(WHITE, *table, Position(1,3), SILVER, Position(2,2), BISHOP, +80);
+  addPenalty(BLACK, *table, Square(9,7), SILVER, Square(8,8), BISHOP, -80);
+  addPenalty(BLACK, *table, Square(1,7), SILVER, Square(2,8), BISHOP, -80);
+  addPenalty(WHITE, *table, Square(9,3), SILVER, Square(8,2), BISHOP, +80);
+  addPenalty(WHITE, *table, Square(1,3), SILVER, Square(2,2), BISHOP, +80);
   
   // 穴熊関係
-  addPenalty(BLACK, *table, Position(9,9), KING, Position(7,7), KNIGHT, -120);
-  addPenalty(BLACK, *table, Position(9,9), KING, Position(9,7), KNIGHT, -120);
-  addPenalty(BLACK, *table, Position(1,9), KING, Position(3,7), KNIGHT, -120);
-  addPenalty(BLACK, *table, Position(1,9), KING, Position(1,7), KNIGHT, -120);
-  addPenalty(WHITE, *table, Position(9,1), KING, Position(7,3), KNIGHT, +120);
-  addPenalty(WHITE, *table, Position(9,1), KING, Position(9,3), KNIGHT, +120);
-  addPenalty(WHITE, *table, Position(1,1), KING, Position(3,3), KNIGHT, +120);
-  addPenalty(WHITE, *table, Position(1,1), KING, Position(1,3), KNIGHT, +120);
+  addPenalty(BLACK, *table, Square(9,9), KING, Square(7,7), KNIGHT, -120);
+  addPenalty(BLACK, *table, Square(9,9), KING, Square(9,7), KNIGHT, -120);
+  addPenalty(BLACK, *table, Square(1,9), KING, Square(3,7), KNIGHT, -120);
+  addPenalty(BLACK, *table, Square(1,9), KING, Square(1,7), KNIGHT, -120);
+  addPenalty(WHITE, *table, Square(9,1), KING, Square(7,3), KNIGHT, +120);
+  addPenalty(WHITE, *table, Square(9,1), KING, Square(9,3), KNIGHT, +120);
+  addPenalty(WHITE, *table, Square(1,1), KING, Square(3,3), KNIGHT, +120);
+  addPenalty(WHITE, *table, Square(1,1), KING, Square(1,3), KNIGHT, +120);
 
   // 玉の点数を引いておき，桂香があれば復活させる
-  addPenalty(BLACK, *table, Position(9,9), KING, Position(9,9), KING, -120);
-  addBonus(BLACK, *table, Position(9,9), KING, Position(9,8), LANCE, 40);
-  addBonus(BLACK, *table, Position(9,9), KING, Position(8,9), KNIGHT, 80);
+  addPenalty(BLACK, *table, Square(9,9), KING, Square(9,9), KING, -120);
+  addBonus(BLACK, *table, Square(9,9), KING, Square(9,8), LANCE, 40);
+  addBonus(BLACK, *table, Square(9,9), KING, Square(8,9), KNIGHT, 80);
 
-  addPenalty(BLACK, *table, Position(1,9), KING, Position(1,9), KING, -120);
-  addBonus(BLACK, *table, Position(1,9), KING, Position(1,8), LANCE, 40);
-  addBonus(BLACK, *table, Position(1,9), KING, Position(2,9), KNIGHT, 80);
+  addPenalty(BLACK, *table, Square(1,9), KING, Square(1,9), KING, -120);
+  addBonus(BLACK, *table, Square(1,9), KING, Square(1,8), LANCE, 40);
+  addBonus(BLACK, *table, Square(1,9), KING, Square(2,9), KNIGHT, 80);
 
-  addPenalty(WHITE, *table, Position(9,1), KING, Position(9,1), KING, +120);
-  addBonus(WHITE, *table, Position(9,1), KING, Position(9,2), LANCE, -40);
-  addBonus(WHITE, *table, Position(9,1), KING, Position(8,1), KNIGHT, -80);
+  addPenalty(WHITE, *table, Square(9,1), KING, Square(9,1), KING, +120);
+  addBonus(WHITE, *table, Square(9,1), KING, Square(9,2), LANCE, -40);
+  addBonus(WHITE, *table, Square(9,1), KING, Square(8,1), KNIGHT, -80);
 
-  addPenalty(WHITE, *table, Position(1,1), KING, Position(1,1), KING, +120);
-  addBonus(WHITE, *table, Position(1,1), KING, Position(1,2), LANCE, -40);
-  addBonus(WHITE, *table, Position(1,1), KING, Position(2,1), KNIGHT, -80);
+  addPenalty(WHITE, *table, Square(1,1), KING, Square(1,1), KING, +120);
+  addBonus(WHITE, *table, Square(1,1), KING, Square(1,2), LANCE, -40);
+  addBonus(WHITE, *table, Square(1,1), KING, Square(2,1), KNIGHT, -80);
 
   // 5段目の桂馬 (取られそう)
   for (int x=2; x<=8; ++x)	// 1,9はペナルティ済
   {
     // 
-    const Position attacker(x,5);
+    const Square attacker(x,5);
     addSelfPenaltyDual(*table, attacker, KNIGHT, -100);
 
     // 相手の歩が遠ければ大丈夫かも．
-    adjust(*table, Position(x,1), newPtypeO(WHITE,PAWN), attacker, newPtypeO(BLACK,KNIGHT), 100);
-    adjust(*table, Position(x,2), newPtypeO(WHITE,PAWN), attacker, newPtypeO(BLACK,KNIGHT), 100);
-    adjust(*table, Position(x,9), newPtypeO(BLACK,PAWN), attacker, newPtypeO(WHITE,KNIGHT), -100);
-    adjust(*table, Position(x,8), newPtypeO(BLACK,PAWN), attacker, newPtypeO(WHITE,KNIGHT), -100);
+    adjust(*table, Square(x,1), newPtypeO(WHITE,PAWN), attacker, newPtypeO(BLACK,KNIGHT), 100);
+    adjust(*table, Square(x,2), newPtypeO(WHITE,PAWN), attacker, newPtypeO(BLACK,KNIGHT), 100);
+    adjust(*table, Square(x,9), newPtypeO(BLACK,PAWN), attacker, newPtypeO(WHITE,KNIGHT), -100);
+    adjust(*table, Square(x,8), newPtypeO(BLACK,PAWN), attacker, newPtypeO(WHITE,KNIGHT), -100);
   }
 
   // 敵の大駒の成駒と自陣の生の駒
@@ -432,10 +432,10 @@ int main(int argc, char **argv)
     {
       for (int promoted_y=1; promoted_y<=3; ++promoted_y)
       {
-	const Position promoted(promoted_x, promoted_y);
+	const Square promoted(promoted_x, promoted_y);
 	for (int y=1; y<=3; ++y)
 	{
-	  const Position unpromoted(x, y);
+	  const Square unpromoted(x, y);
 	  if (promoted == unpromoted)
 	    continue;
 	  adjust(*table, promoted, newPtypeO(BLACK,PROOK), 
@@ -450,10 +450,10 @@ int main(int argc, char **argv)
       }
       for (int promoted_y=7; promoted_y<=9; ++promoted_y)
       {
-	const Position promoted(promoted_x, promoted_y);
+	const Square promoted(promoted_x, promoted_y);
 	for (int y=7; y<=9; ++y)
 	{
-	  const Position unpromoted(x, y);
+	  const Square unpromoted(x, y);
 	  if (promoted == unpromoted)
 	    continue;
 	  adjust(*table, promoted, newPtypeO(WHITE,PROOK), 
@@ -472,8 +472,8 @@ int main(int argc, char **argv)
   for (int x=1; x<=9; ++x)
   {
     // 
-    const Position black_position(x,4);
-    const Position white_position(x,6);
+    const Square black_position(x,4);
+    const Square white_position(x,6);
     addBonus(BLACK, *table, black_position, PAWN, black_position, PAWN, 100);
     addBonus(WHITE, *table, white_position, PAWN, white_position, PAWN,-100);
   }
@@ -481,80 +481,80 @@ int main(int argc, char **argv)
   for (int x=1; x<=9; ++x)
   {
     // 危ない飛車
-    addPenalty(BLACK, *table, Position(x,6), ROOK, Position(x,7), PAWN, -95);
-    addPenalty(WHITE, *table, Position(x,4), ROOK, Position(x,3), PAWN, +95);
+    addPenalty(BLACK, *table, Square(x,6), ROOK, Square(x,7), PAWN, -95);
+    addPenalty(WHITE, *table, Square(x,4), ROOK, Square(x,3), PAWN, +95);
     // 捌きにくい銀
     if (x == 1 || x == 3 || x == 7 || x == 9) 
     {
-      addPenalty(BLACK, *table, Position(x,6), SILVER, Position(x,7), PAWN, -80);
-      addPenalty(WHITE, *table, Position(x,4), SILVER, Position(x,3), PAWN, +80);
+      addPenalty(BLACK, *table, Square(x,6), SILVER, Square(x,7), PAWN, -80);
+      addPenalty(WHITE, *table, Square(x,4), SILVER, Square(x,3), PAWN, +80);
     }
     // 捻り飛車失敗?
     for (int i=x-1; i<=x+1; ++i)
     {
       if (i<1 || i > 9)
 	continue;
-      addPenalty(BLACK, *table, Position(x,6), ROOK, Position(i,8), KING, -100);
-      addPenalty(BLACK, *table, Position(x,6), ROOK, Position(i,9), KING,  -90);
-      addPenalty(WHITE, *table, Position(x,4), ROOK, Position(i,2), KING, +100);
-      addPenalty(WHITE, *table, Position(x,4), ROOK, Position(i,1), KING,  +90);
+      addPenalty(BLACK, *table, Square(x,6), ROOK, Square(i,8), KING, -100);
+      addPenalty(BLACK, *table, Square(x,6), ROOK, Square(i,9), KING,  -90);
+      addPenalty(WHITE, *table, Square(x,4), ROOK, Square(i,2), KING, +100);
+      addPenalty(WHITE, *table, Square(x,4), ROOK, Square(i,1), KING,  +90);
     }
     // 玉飛接近
     for (int y=7; y<=9; ++y)
     {
       const int wy = 10-y;
-      addPenalty(BLACK, *table, Position(x,y), KING, Position(x,y-1), ROOK, -70);
-      addPenalty(BLACK, *table, Position(x,y-1), KING, Position(x,y), ROOK, -70);
-      addPenalty(WHITE, *table, Position(x,wy), KING, Position(x,wy+1), ROOK, +70);
-      addPenalty(WHITE, *table, Position(x,wy+1), KING, Position(x,wy), ROOK, +70);
+      addPenalty(BLACK, *table, Square(x,y), KING, Square(x,y-1), ROOK, -70);
+      addPenalty(BLACK, *table, Square(x,y-1), KING, Square(x,y), ROOK, -70);
+      addPenalty(WHITE, *table, Square(x,wy), KING, Square(x,wy+1), ROOK, +70);
+      addPenalty(WHITE, *table, Square(x,wy+1), KING, Square(x,wy), ROOK, +70);
       if (x > 1)
       {
-	addPenalty(BLACK, *table, Position(x,y), KING, Position(x-1,y), ROOK, -70);
-	addPenalty(WHITE, *table, Position(x,wy), KING, Position(x-1,wy), ROOK, +70);
+	addPenalty(BLACK, *table, Square(x,y), KING, Square(x-1,y), ROOK, -70);
+	addPenalty(WHITE, *table, Square(x,wy), KING, Square(x-1,wy), ROOK, +70);
       }
       if (x > 2) 
       {
-	addPenalty(BLACK, *table, Position(x,y), KING, Position(x-2,y), ROOK, -50);
-	addPenalty(WHITE, *table, Position(x,wy), KING, Position(x-2,wy), ROOK, +50);
+	addPenalty(BLACK, *table, Square(x,y), KING, Square(x-2,y), ROOK, -50);
+	addPenalty(WHITE, *table, Square(x,wy), KING, Square(x-2,wy), ROOK, +50);
       }
       if (x < 9)
       {
-	addPenalty(BLACK, *table, Position(x,y), KING, Position(x+1,y), ROOK, -70);
-	addPenalty(WHITE, *table, Position(x,wy), KING, Position(x+1,wy), ROOK, +70);
+	addPenalty(BLACK, *table, Square(x,y), KING, Square(x+1,y), ROOK, -70);
+	addPenalty(WHITE, *table, Square(x,wy), KING, Square(x+1,wy), ROOK, +70);
       }
       if (x < 8)
       {
-	addPenalty(BLACK, *table, Position(x,y), KING, Position(x+2,y), ROOK, -50);
-	addPenalty(WHITE, *table, Position(x,wy), KING, Position(x+2,wy), ROOK, +50);
+	addPenalty(BLACK, *table, Square(x,y), KING, Square(x+2,y), ROOK, -50);
+	addPenalty(WHITE, *table, Square(x,wy), KING, Square(x+2,wy), ROOK, +50);
       }
     } // for y
   } // for x
 
   // 桂馬と飛車
-  addPenalty(BLACK, *table, Position(1,7), ROOK, Position(2,9), KNIGHT, -70);
-  addPenalty(BLACK, *table, Position(3,7), ROOK, Position(2,9), KNIGHT, -70);
-  addPenalty(BLACK, *table, Position(7,7), ROOK, Position(8,9), KNIGHT, -70);
-  addPenalty(BLACK, *table, Position(9,7), ROOK, Position(8,9), KNIGHT, -70);
-  addPenalty(WHITE, *table, Position(1,3), ROOK, Position(2,1), KNIGHT, +70);
-  addPenalty(WHITE, *table, Position(3,3), ROOK, Position(2,1), KNIGHT, +70);
-  addPenalty(WHITE, *table, Position(7,3), ROOK, Position(8,1), KNIGHT, +70);
-  addPenalty(WHITE, *table, Position(9,3), ROOK, Position(8,1), KNIGHT, +70);
+  addPenalty(BLACK, *table, Square(1,7), ROOK, Square(2,9), KNIGHT, -70);
+  addPenalty(BLACK, *table, Square(3,7), ROOK, Square(2,9), KNIGHT, -70);
+  addPenalty(BLACK, *table, Square(7,7), ROOK, Square(8,9), KNIGHT, -70);
+  addPenalty(BLACK, *table, Square(9,7), ROOK, Square(8,9), KNIGHT, -70);
+  addPenalty(WHITE, *table, Square(1,3), ROOK, Square(2,1), KNIGHT, +70);
+  addPenalty(WHITE, *table, Square(3,3), ROOK, Square(2,1), KNIGHT, +70);
+  addPenalty(WHITE, *table, Square(7,3), ROOK, Square(8,1), KNIGHT, +70);
+  addPenalty(WHITE, *table, Square(9,3), ROOK, Square(8,1), KNIGHT, +70);
   // 角道を防ぐ金
   for (int x=1; x<=9; ++x)
   {
     for (int y=8; y<=9; ++y) 
     {
-      const Position bishop(x, y);
+      const Square bishop(x, y);
       if (x < 9)
       {
-	const Position ul(x+1, y-1);
+	const Square ul(x+1, y-1);
 	addPenalty(BLACK, *table, bishop, BISHOP, ul, GOLD, -65);
 	addPenalty(WHITE, *table, bishop.rotate180(), BISHOP, 
 		   ul.rotate180(), GOLD, 65);
       }
       if (x > 1) 
       {
-	const Position ur(x-1, y-1);
+	const Square ur(x-1, y-1);
 	addPenalty(BLACK, *table, bishop, BISHOP, ur, GOLD, -65);
 	addPenalty(WHITE, *table, bishop.rotate180(), BISHOP, 
 		   ur.rotate180(), GOLD, 65);
@@ -574,25 +574,25 @@ int main(int argc, char **argv)
 	continue;
       for (int y1=1; y1<=3; ++y1) 
       {
-	const Position p1(x1,y1);
+	const Square p1(x1,y1);
 	for (int y2=y1; y2<=3; ++y2) 
 	{
 	  if (x1 == x2 && y1 == y2)
 	    continue;
-	  const Position p2(x2,y2);
+	  const Square p2(x2,y2);
 	  const int py = (3-std::min(y1, y2))*10; // 3段目のほうがマシに
 	  const int center = std::min(abs(5-x1), abs(5-x2)); // 端を減点
 	  const int p = 0-py-center*15; // y=1:0,-80
 	  if (p == 0)
 	    continue;
-	  for (int t1=0; t1<types.size(); ++t1)
+	  for (int t1=0; t1<(int)types.size(); ++t1)
 	  {
 	    assert(isPiece(types[t1]));
 	    if (y1 < 3 && types[t1] == KNIGHT)
 	      continue;
 	    if (y1 == 1 && (types[t1] == LANCE || types[t1] == PAWN))
 	      continue;
-	    for (int t2=0; t2<types.size(); ++t2)
+	    for (int t2=0; t2<(int)types.size(); ++t2)
 	    {
 	      if (y2 < 3 && types[t2] == KNIGHT)
 		continue;
@@ -613,12 +613,12 @@ int main(int argc, char **argv)
   {
     for (int y=5; y<=7; ++y)
     {
-      const Position pawn(x,y);
+      const Square pawn(x,y);
       for (int ry=6; ry<=9; ++ry)
       {
 	if (y == ry)
 	  continue;
-	const Position rook(x,ry);
+	const Square rook(x,ry);
 	const int p = -y*10-25;
 	addPenalty(BLACK, *table, rook, ROOK, pawn, PAWN, p);
 	addPenalty(WHITE, *table, rook.rotate180(), ROOK, 
@@ -632,10 +632,10 @@ int main(int argc, char **argv)
   {
     for (int y=3; y<=7; ++y)
     {
-      const Position pawn(x,y);
+      const Square pawn(x,y);
       for (int ry=1; ry<y; ++ry)
       {
-	const Position rook(x,ry);
+	const Square rook(x,ry);
 	adjustDual(*table, pawn, PAWN, rook, ROOK, 90);
 	adjustDual(*table, pawn, PAWN, rook, LANCE, 90);
       }
@@ -647,8 +647,8 @@ int main(int argc, char **argv)
   {
     for (int y=8; y<=9; ++y)
     {
-      const Position pawn(x,y);
-      const Position pawn_white = pawn.rotate180();
+      const Square pawn(x,y);
+      const Square pawn_white = pawn.rotate180();
 #if 0
       addPenalty(BLACK, *table, pawn, PAWN, pawn, PAWN, -60);
       addPenalty(WHITE, *table, pawn_white, PAWN, pawn_white, PAWN, 60);
@@ -658,8 +658,8 @@ int main(int argc, char **argv)
       {
 	for (int ky=7; ky<=9; ++ky)
 	{
-	  const Position king(kx,ky);
-	  const Position king_white = king.rotate180();
+	  const Square king(kx,ky);
+	  const Square king_white = king.rotate180();
 	  if (king == pawn)
 	    continue;
 	  const int penalty = -(8-abs(kx-x))*10;	// 0-80
@@ -670,8 +670,8 @@ int main(int argc, char **argv)
 
 	  // 敵玉の居る筋に対するペナルティ
 	  adjust(*table, pawn, newPtypeO(BLACK,PAWN), 
-		 Position(kx,10-ky), newPtypeO(WHITE,KING), penalty);
-	  adjust(*table, Position(x,10-y), newPtypeO(WHITE,PAWN), 
+		 Square(kx,10-ky), newPtypeO(WHITE,KING), penalty);
+	  adjust(*table, Square(x,10-y), newPtypeO(WHITE,PAWN), 
 		 king, newPtypeO(BLACK,KING), -penalty);
 	}
       }
