@@ -21,6 +21,16 @@ void to_binary()
   osl::misc::BinaryWriter::write(std::cout, data);
 }
 
+template <class T>
+void write_line(T value) 
+{
+  std::cout << value << std::endl;
+}
+void write_line(double value) 
+{
+  printf("%.8f\n", value);
+}
+
 template <class T>
 void to_text()
 {
@@ -28,10 +38,7 @@ void to_text()
   osl::misc::BinaryReader<T> reader(std::cin);
   while (reader.read(data)) {
     BOOST_FOREACH(T value, data) {
-      if (boost::is_same<double,T>::value)
-	printf("%.8f\n", value);
-      else
-	std::cout << value << std::endl;
+      write_line(value);
     }
     if (data.size() < reader.blockSize())
       break;
