@@ -2,6 +2,7 @@
 #include "osl/record/opening/openingBook.h"
 #include "osl/record/psn.h"
 #include "osl/state/numEffectState.h"
+#include "osl/oslConfig.h"
 
 #include <iostream>
 
@@ -49,7 +50,7 @@ void printNextMoves(WinCountBook& book, WinCountTracer& tracer,
 
 int main(int argc, char **argv)
 {
-  std::string bookFilename = "../data/joseki.dat";
+  std::string bookFilename = OslConfig::openingBook();
   WinCountBook book(bookFilename.c_str());
   WinCountTracer tracer(book);
   NumEffectState state;
