@@ -53,10 +53,10 @@ vector<double> rating_to_probability(const RatedMoveVector& moves)
 {
   double sum = 0;
   for (size_t i=0; i<moves.size(); ++i)
-    sum += exp10(moves[i].rating()/400.0);
+    sum += pow(10, moves[i].rating()/400.0);
   vector<double> result(moves.size());
   for (size_t i=0; i<moves.size(); ++i) 
-    result[i] = exp10(moves[i].rating()/400.0) / sum;
+    result[i] = pow(10, moves[i].rating()/400.0) / sum;
   return result;
 }
 
