@@ -6,7 +6,6 @@
 #include "osl/record/csaRecord.h"
 #include "osl/record/csaIOError.h"
 #include "osl/record/kisen.h"
-#include "osl/apply_move/applyMove.h"
 #include "osl/misc/perfmon.h"
 #include "osl/stat/histogram.h"
 #include "osl/stat/variance.h"
@@ -106,7 +105,7 @@ namespace osl
     assert(numerator.length() == denominator.length());
     assert(numerator.start() == denominator.start());
     stat::Histogram logprob(numerator.width(), numerator.length(), numerator.start());
-    for (int i=0; i<numerator.length(); ++i) {
+    for (size_t i=0; i<numerator.length(); ++i) {
       const double n = numerator.frequency(i);
       const double d = denominator.frequency(i);
       const double prob = n / d;
@@ -122,7 +121,7 @@ namespace osl
     assert(denom1.width() == denom2.width() && denom1.length() == denom2.length() && denom1.start() == denom2.start());
     stat::Histogram l1(numerator.width(), numerator.length(), numerator.start()), 
       l2(numerator.width(), numerator.length(), numerator.start());
-    for (int i=0; i<numerator.length(); ++i) {
+    for (size_t i=0; i<numerator.length(); ++i) {
       const double n = numerator.frequency(i);
       const double d1 = denom1.frequency(i);
       const double d2 = denom2.frequency(i);
@@ -300,7 +299,7 @@ namespace osl
 	return;
       generated_all.add(moves[i].rating());
       const RatedMove *found = moves.find(selected);
-      if (found && (found - &*moves.begin()) <= i) {
+      if (found && (found - &*moves.begin()) <= (int)i) {
 	if (moves[i].move() == selected)
 	  this->selected.add(moves[i].rating());
 	generated.add(moves[i].rating());
@@ -358,8 +357,8 @@ namespace osl
     void show(std::ostream& os)
     {
       os << "depth\n";
-      for (size_t i=0; i<sc_length_2d; ++i) {
-	for (size_t j=0; j<sc_length_2d; ++j) {
+      for (int i=0; i<sc_length_2d; ++i) {
+	for (int j=0; j<sc_length_2d; ++j) {
 	  double s = selected.frequency(i*sc_length_2d+j);
 	  double g = generated.frequency(i*sc_length_2d+j);
 	  // os << std::setw(5) << (g > 20 ? s/g : 0.0);
@@ -368,8 +367,8 @@ namespace osl
 	os << "\n";
       }
       os << "width\n";
-      for (size_t i=0; i<sc_length_2d; ++i) {
-	for (size_t j=0; j<sc_length_2d; ++j) {
+      for (int i=0; i<sc_length_2d; ++i) {
+	for (int j=0; j<sc_length_2d; ++j) {
 	  double s = selected.frequency(i*sc_length_2d+j);
 	  double a = all_generated.frequency(i*sc_length_2d+j);
 	  // os << std::setw(5) << (a > 20 ? s/a : 0.0);
@@ -378,8 +377,8 @@ namespace osl
 	os << "\n";
       }
       os << "order\n";
-      for (size_t i=0; i<sc_length_2d; ++i) {
-	for (size_t j=0; j<sc_length_2d; ++j) {
+      for (int i=0; i<sc_length_2d; ++i) {
+	for (int j=0; j<sc_length_2d; ++j) {
 	  // os << std::setw(5) << std::setprecision(3) << variance[i*sc_length_2d+j].getAverage();
 	  os << std::setw(5) << static_cast<int>(variance[i*sc_length_2d+j].getAverage());
 	}
@@ -571,7 +570,7 @@ void test_position(const FeatureSet& f, Move next_move, Move last_move, const Ra
   }
   if (! nocapture_added
       && moves[0].move().capturePtype() == PTYPE_EMPTY
-      && ! moves[0].move().isPromote()) {
+      && ! moves[0].move().isPromotion()) {
     nocapture_added = true;
     max_nocapture.add(highest);
   }
@@ -629,7 +628,7 @@ void test_position(const FeatureSet& f, Move next_move, Move last_move, const Ra
     if (moves[i].move().to() == last_move.to())
       continue;
     if (! (moves[i].move().capturePtype() != PTYPE_EMPTY
-	   || moves[i].move().isPromote())
+	   || moves[i].move().isPromotion())
 	|| PieceEval::computeDiffAfterMoveForRP(state, moves[i].move()) <= 0)
       continue;
     if (i<order) {
@@ -656,7 +655,7 @@ void test_position(const FeatureSet& f, Move next_move, Move last_move, const Ra
       max_notakeback.add(moves[i].rating());
     }
     if (! nocapture_added && moves[i].move().capturePtype() == PTYPE_EMPTY
-	&& ! moves[i].move().isPromote()) {
+	&& ! moves[i].move().isPromotion()) {
       nocapture_added = true;
       max_nocapture.add(moves[i].rating());
     }
@@ -684,7 +683,7 @@ void test_record(const FeatureSet& f,
   env.make(state);
   eval::ProgressEval eval(state);
   for (size_t i=0; i<moves.size(); ++i) {
-    if (state.inCheck(alt(state.getTurn())))
+    if (state.inCheck(alt(state.turn())))
       break;			// illegal
 
     const Move move = moves[i];
@@ -693,7 +692,7 @@ void test_record(const FeatureSet& f,
       test_position(f, moves[i], (i>0 ? moves[i-1] : Move::PASS(alt(moves[i].player()))),
 		    env, state, eval);
     }
-    ApplyMoveOfTurn::doMove(state, move);
+    state.makeMove(move);
     eval.update(state, move);
     env.update(state, move);
   }
