@@ -82,7 +82,7 @@ void run(const std::string& filename)
   }
   else {
     std::cout << "# " 
-	      << IconvConvert::convert("EUC-JP", "SHIFT_JIS", record::K_KIFU)
+	      << IconvConvert::convert("EUC-JP", "SHIFT_JIS", K_KIFU)
 	      << "\r\n";
   }
   try {
@@ -106,10 +106,10 @@ void run(const std::string& filename)
 	 << record::StandardCharacters::dan[to.y()];
       ss << record::ki2::show(moves[i].oldPtype());
       if (moves[i].isPromotion())
-	ss << record::K_NARU;
+	ss << K_NARU;
       const Square from = moves[i].from();
       if (from.isPieceStand())
-	ss << record::K_UTSU;
+	ss << K_UTSU;
       else
 	ss << "(" << from.x() << from.y() << ")";
       ss << "   ";
