@@ -1,24 +1,35 @@
 /* kakinoki-to-csa.cc
  */
 #include "osl/record/kakinoki.h"
+#include "osl/record/ki2.h"
 #include "osl/record/csa.h"
 #include "osl/record/record.h"
+#include <boost/algorithm/string/predicate.hpp>
 #include <iostream>
 #include <sstream>
 
 using namespace osl;
 void convert(const char *filename)
 {
-  KakinokiFile file(filename);
   vector<Move> moves;
   vector<int> time;
   vector<std::string> comment;
   vector<record::SearchInfo> move_comment;
-  Record record = file.getRecord();
+  Record record;
+  NumEffectState state;
+  if (boost::algorithm::iends_with(filename, ".ki2")) {
+    Ki2File file(filename);
+    record = file.getRecord();
+    state = file.getInitialState();
+  }
+  else {
+    KakinokiFile file(filename);
+    record = file.getRecord();
+    state = file.getInitialState();
+  }
   std::cout << "N+" << record.getPlayer(BLACK) << std::endl;
   std::cout << "N-" << record.getPlayer(WHITE) << std::endl;
   record.getMoves(moves, time, comment, move_comment);
-  NumEffectState state(file.getInitialState());
   std::cout << state;
   for (size_t i=0; i<moves.size(); ++i) 
   {
