@@ -1,7 +1,7 @@
 /* show-ipx.cc
  */
 #include "osl/record/kisen.h"
-#include "osl/misc/iconvConvert.h"
+#include "osl/misc/eucToLang.h"
 #include <iostream>
 using namespace osl;
 
@@ -14,11 +14,11 @@ int main(int argc, char **argv)
 	std::cout << "N/A\t";
       else
 	std::cout << ipx.getStartDate(j).year() << "\t";
-      std::cout << IconvConvert::eucToLang(ipx.getPlayer(j, BLACK)) << "\t" 
-		<< IconvConvert::eucToLang(ipx.getTitle(j, BLACK)) << "\t"
+      std::cout << misc::eucToLang(ipx.getPlayer(j, BLACK)) << "\t" 
+		<< misc::eucToLang(ipx.getTitle(j, BLACK)) << "\t"
 		<< ipx.getRating(j, BLACK) << "\t";
-      std::cout << IconvConvert::eucToLang(ipx.getPlayer(j, WHITE)) << "\t" 
-		<< IconvConvert::eucToLang(ipx.getTitle(j, WHITE)) << "\t"
+      std::cout << misc::eucToLang(ipx.getPlayer(j, WHITE)) << "\t" 
+		<< misc::eucToLang(ipx.getTitle(j, WHITE)) << "\t"
 		<< ipx.getRating(j, WHITE) << "\n";
     }
   }
