@@ -6,11 +6,11 @@
 #include <iostream>
 #include <cstdio>
 using namespace osl;
-Position target(5,8);
+Square target(5,8);
 
 int main(int argc, char **argv)
 {
-  const char *program_name = argv[0];
+  // const char *program_name = argv[0];
   bool error_flag = false;
   bool verbose = false;
   
