@@ -6,7 +6,6 @@
 #include "osl/state/numEffectState.h"
 #include "osl/move_generator/allMoves.h"
 #include "osl/effect_util/effectUtil.h"
-#include "osl/apply_move/applyMove.h"
 #include "osl/record/csaRecord.h"
 #include "osl/container/moveVector.h"
 
@@ -19,15 +18,15 @@ using namespace osl;
 
 int main(int argc, char **argv)
 {
-  const char *program_name = argv[0];
+  // const char *program_name = argv[0];
   bool error_flag = false;
   bool verbose = false;
-  const char *kisenFilename = 0;
+  // const char *kisenFilename = 0;
   
-  extern char *optarg;
+  // extern char *optarg;
   extern int optind;
   char c;
-  size_t num_records = 1;
+  // size_t num_records = 1;
   while ((c = getopt(argc, argv, "vh")) != EOF) {
     switch(c)
     {
@@ -44,7 +43,7 @@ int main(int argc, char **argv)
 
   try {
     nice(20);
-    size_t record_processed = 0;
+    // size_t record_processed = 0;
       
     for (int i=0; i<argc; ++i) {
       CsaFile file(argv [i]);
@@ -52,7 +51,7 @@ int main(int argc, char **argv)
       NumEffectState state(record.getInitialState());
 
       MoveVector moves;
-      GenerateAllMoves::generate(state.getTurn(), state, moves);
+      GenerateAllMoves::generate(state.turn(), state, moves);
       search::SortCaptureMoves::sortByTakeBack(state, moves);
       std::cout << state << moves << "\n";
     }
