@@ -25,13 +25,13 @@ CPPUNIT_TEST_SUITE_REGISTRATION(Centering3x3Test);
 
 void Centering3x3Test::test11()
 {
-  CPPUNIT_ASSERT_EQUAL(Position(2,2), 
-		       Centering3x3::adjustCenter(Position(1,1)));
+  CPPUNIT_ASSERT_EQUAL(Square(2,2), 
+		       Centering3x3::adjustCenter(Square(1,1)));
 }
 void Centering3x3Test::test22()
 {
-  CPPUNIT_ASSERT_EQUAL(Position(2,2), 
-		       Centering3x3::adjustCenter(Position(2,2)));
+  CPPUNIT_ASSERT_EQUAL(Square(2,2), 
+		       Centering3x3::adjustCenter(Square(2,2)));
 }
 
 
@@ -41,7 +41,7 @@ void Centering3x3Test::testXY()
   {
     for (int x=0; x<=10; ++x)
     {
-      const Position target = Position(x,y);
+      const Square target = Square(x,y);
       if (target.isOnBoard())
       {
 	CPPUNIT_ASSERT_EQUAL(Centering3x3::adjustCenterNaive(target),
