@@ -7,12 +7,12 @@
 
 #include <cppunit/TestCase.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <boost/progress.hpp>
 #include <iostream>
 #include <fstream>
 
 using namespace osl;
 using namespace osl::checkmate;
-extern bool isShortTest;
 
 class CheckmateFixedDepthSearcherTest : public CppUnit::TestFixture 
 {
@@ -27,6 +27,7 @@ class CheckmateFixedDepthSearcherTest : public CppUnit::TestFixture
   CPPUNIT_TEST(testCheckFiles);
   CPPUNIT_TEST(testNoCheckFiles);
   CPPUNIT_TEST(testNoCheckmate);
+  CPPUNIT_TEST(testNoPromote);
   CPPUNIT_TEST_SUITE_END();
 public:
   void testZero();
@@ -38,6 +39,7 @@ public:
   void testCheckFiles();
   void testNoCheckFiles();
   void testNoCheckmate();
+  void testNoPromote();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(CheckmateFixedDepthSearcherTest);
@@ -78,7 +80,7 @@ void CheckmateFixedDepthSearcherTest::testZero()
 			   "P-00AL\n"
 			   "-\n").getInitialState());
     FixedDepthSearcher searcher(state);
-    Move lastMove=Move(Position(2,4),Position(2,3),PPAWN,
+    Move lastMove=Move(Square(2,4),Square(2,3),PPAWN,
 		       PTYPE_EMPTY,false,BLACK);
     ProofDisproof pdp=searcher.hasEscapeMove<BLACK>(lastMove,0);
     CPPUNIT_ASSERT(!pdp.isCheckmateSuccess() && !pdp.isCheckmateFail());
@@ -98,7 +100,7 @@ void CheckmateFixedDepthSearcherTest::testZero()
 			   "P-00AL\n"
 			   "-\n").getInitialState());
     FixedDepthSearcher searcher(state);
-    Move lastMove=Move(Position(1,2),PAWN,BLACK);
+    Move lastMove=Move(Square(1,2),PAWN,BLACK);
     ProofDisproof pdp=searcher.hasEscapeMove<BLACK>(lastMove,0);
     CPPUNIT_ASSERT_EQUAL(ProofDisproof::PawnCheckmate(),pdp);
   }
@@ -140,7 +142,7 @@ void CheckmateFixedDepthSearcherTest::testOne()
 			   "P-00AL\n"
 			   "-\n").getInitialState());
     FixedDepthSearcher searcher(state);
-    Move lastMove=Move(Position(2,4),Position(3,3),PPAWN,
+    Move lastMove=Move(Square(2,4),Square(3,3),PPAWN,
 		       PTYPE_EMPTY,false,BLACK);
     ProofDisproof pdp=searcher.hasEscapeMove<BLACK>(lastMove,1);
     CPPUNIT_ASSERT(!pdp.isCheckmateSuccess() && !pdp.isCheckmateFail());
@@ -205,8 +207,8 @@ void CheckmateFixedDepthSearcherTest::testThree()
     Move best_move;
     ProofDisproof pdp=searcher.hasCheckmateMove<BLACK>(3, best_move);
     CPPUNIT_ASSERT_EQUAL(ProofDisproof::Checkmate(), pdp);
-    CPPUNIT_ASSERT(best_move == Move(Position(9,4),Position(9,3),PPAWN,PTYPE_EMPTY,true,BLACK) ||
-		   best_move == Move(Position(7,1),Position(8,2),PSILVER,KNIGHT,true,BLACK));
+    CPPUNIT_ASSERT(best_move == Move(Square(9,4),Square(9,3),PPAWN,PTYPE_EMPTY,true,BLACK) ||
+		   best_move == Move(Square(7,1),Square(8,2),PSILVER,KNIGHT,true,BLACK));
   }
   {
     NumEffectState state(CsaString(
@@ -226,7 +228,7 @@ void CheckmateFixedDepthSearcherTest::testThree()
     Move best_move;
     ProofDisproof pdp=searcher.hasCheckmateMove<BLACK>(3, best_move);
     CPPUNIT_ASSERT_EQUAL(ProofDisproof::Checkmate(), pdp);
-    CPPUNIT_ASSERT_EQUAL(Move(Position(3,3),GOLD,BLACK), best_move);
+    CPPUNIT_ASSERT_EQUAL(Move(Square(3,3),GOLD,BLACK), best_move);
   }  
 }
 
@@ -251,7 +253,7 @@ void CheckmateFixedDepthSearcherTest::testProofPieces()
     PieceStand pieces;
     ProofDisproof pdp=searcher.hasCheckmateMove<BLACK>(3, best_move, pieces);
     CPPUNIT_ASSERT_EQUAL(ProofDisproof::Checkmate(), pdp);
-    CPPUNIT_ASSERT_EQUAL(Move(Position(3,3),GOLD,BLACK), best_move);
+    CPPUNIT_ASSERT_EQUAL(Move(Square(3,3),GOLD,BLACK), best_move);
     CPPUNIT_ASSERT_EQUAL(PieceStand(0,0,0,0,2,0,0,0), pieces);
   }  
   {
@@ -273,7 +275,7 @@ void CheckmateFixedDepthSearcherTest::testProofPieces()
     PieceStand pieces;
     ProofDisproof pdp=searcher.hasCheckmateMove<BLACK>(2, best_move, pieces);
     CPPUNIT_ASSERT_EQUAL(ProofDisproof::Checkmate(), pdp);
-    CPPUNIT_ASSERT_EQUAL(Move(Position(4,4),Position(4,1),PROOK,PTYPE_EMPTY,
+    CPPUNIT_ASSERT_EQUAL(Move(Square(4,4),Square(4,1),PROOK,PTYPE_EMPTY,
 			      false,BLACK), 
 			 best_move);
     CPPUNIT_ASSERT_EQUAL(PieceStand(0,4,4,4,0,2,0,0), pieces);
@@ -297,7 +299,7 @@ void CheckmateFixedDepthSearcherTest::testProofPieces()
     PieceStand pieces;
     ProofDisproof pdp=searcher.hasCheckmateMove<BLACK>(3, best_move, pieces);
     CPPUNIT_ASSERT_EQUAL(ProofDisproof::Checkmate(), pdp);
-    CPPUNIT_ASSERT_EQUAL(Move(Position(3,3),GOLD,BLACK), best_move);
+    CPPUNIT_ASSERT_EQUAL(Move(Square(3,3),GOLD,BLACK), best_move);
     CPPUNIT_ASSERT_EQUAL(PieceStand(0,0,1,0,2,0,0,0), pieces);
   }  
 }
@@ -320,7 +322,7 @@ void CheckmateFixedDepthSearcherTest::testSuicide()
 			   "P-00AL\n"
 			   "-\n").getInitialState());
     FixedDepthSearcher searcher(state);
-    Move lastMove=Move(Position(2,1),GOLD,BLACK);
+    Move lastMove=Move(Square(2,1),GOLD,BLACK);
     ProofDisproof pdp=searcher.hasEscapeMove<BLACK>(lastMove,/*0*/1);
     CPPUNIT_ASSERT_EQUAL(ProofDisproof::NoEscape(),pdp);
   }
@@ -340,7 +342,7 @@ void CheckmateFixedDepthSearcherTest::testSuicide()
 			   "P-00AL\n"
 			   "-\n").getInitialState());
     FixedDepthSearcher searcher(state);
-    Move lastMove=Move(Position(3,1),ROOK,BLACK);
+    Move lastMove=Move(Square(3,1),ROOK,BLACK);
     ProofDisproof pdp=searcher.hasEscapeMove<BLACK>(lastMove,0);
     CPPUNIT_ASSERT_EQUAL(ProofDisproof::NoEscape(),pdp);
   }
@@ -419,7 +421,7 @@ int checkCount;
 int checkCounts[20];
 static void testCheckFile(std::string filename)
 {
-  filename = OslConfig::testFile(filename);
+  filename = OslConfig::testPublicFile(filename);
   
   checkCount++;
   Record rec=CsaFile(filename).getRecord();
@@ -431,7 +433,7 @@ static void testCheckFile(std::string filename)
   Move best_move;
   ProofDisproof pdp;
   for(int i=0;i<=8;i++){
-    if(state.getTurn()==BLACK)
+    if(state.turn()==BLACK)
       pdp=searcher.hasCheckmateMove<BLACK>(i, best_move);
     else
       pdp=searcher.hasCheckmateMove<WHITE>(i, best_move);
@@ -445,21 +447,22 @@ static void testCheckFile(std::string filename)
 }
 void CheckmateFixedDepthSearcherTest::testCheckFiles()
 {
-  std::ifstream ifs(OslConfig::testFile("kisenCheckProblems/FILES"));
+  std::ifstream ifs(OslConfig::testPublicFile("short-checkmate-problems/FILES"));
   CPPUNIT_ASSERT(ifs);
   int i=0;
   int count=500;
-  if (isShortTest)
+  if (OslConfig::inUnitTestShort())
     count=2;
   std::string filename;
-  while((ifs >> filename) && (++i<count)) {
-    if(filename == "") 
-      break;
-    if (! isShortTest)
-      std::cerr << "testCheckFile: " << filename << " ";
-    testCheckFile("kisenCheckProblems/" + filename);
+  boost::scoped_ptr<boost::progress_display> progress;
+  if (OslConfig::inUnitTestLong())
+    progress.reset(new boost::progress_display(count, std::cerr));
+  while((ifs >> filename) && filename != "" && (++i<count)) {
+    if (progress)
+      ++(*progress);
+    testCheckFile("short-checkmate-problems/" + filename);
   }
-  if(!isShortTest){
+  if(OslConfig::verbose()){
     std::cerr << std::endl << "checkCount=" << checkCount << std::endl;
     for(i=0;i<=8;i++){
       std::cerr  << "checkCounts[" << i << "]=" << checkCounts[i] << std::endl;
@@ -471,7 +474,7 @@ int noCheckCount;
 int noCheckCounts[20];
 static void testNoCheckFile(std::string filename)
 {
-  filename = OslConfig::testFile(filename);
+  filename = OslConfig::testPublicFile(filename);
 
   noCheckCount++;
   Record rec=CsaFile(filename).getRecord();
@@ -483,7 +486,7 @@ static void testNoCheckFile(std::string filename)
   Move best_move;
   ProofDisproof pdp;
   for(int i=0;i<=8;i++){
-    if(state.getTurn()==BLACK)
+    if(state.turn()==BLACK)
       pdp=searcher.hasCheckmateMove<BLACK>(i, best_move);
     else
       pdp=searcher.hasCheckmateMove<WHITE>(i, best_move);
@@ -497,21 +500,22 @@ static void testNoCheckFile(std::string filename)
 }
 void CheckmateFixedDepthSearcherTest::testNoCheckFiles()
 {
-  std::ifstream ifs(OslConfig::testFile("kisenNoCheckProblems/FILES"));
+  std::ifstream ifs(OslConfig::testPublicFile("nocheckmate-problems/FILES"));
   CPPUNIT_ASSERT(ifs);
   int i=0;
   int count=500;
-  if (isShortTest)
+  if (OslConfig::inUnitTestShort())
     count=2;
   std::string filename;
-  while((ifs >> filename) && (++i<count)) {
-    if(filename == "") 
-      break;
-    if (! isShortTest)
-      std::cerr << "testNoCheckFile: " << filename << " ";
-    testNoCheckFile("kisenNoCheckProblems/" + filename);
+  boost::scoped_ptr<boost::progress_display> progress;
+  if (OslConfig::inUnitTestLong())
+    progress.reset(new boost::progress_display(count, std::cerr));
+  while((ifs >> filename) && filename != "" && (++i<count)) {
+    if (progress)
+      ++(*progress);
+    testNoCheckFile("nocheckmate-problems/" + filename);
   }
-  if(!isShortTest){
+  if(OslConfig::verbose()){
     std::cerr << std::endl << "noCheckCount=" << noCheckCount << std::endl;
     for(i=0;i<=8;i++){
       std::cerr  << "noCheckCounts[" << i << "]=" << noCheckCounts[i] << std::endl;
@@ -589,6 +593,32 @@ void CheckmateFixedDepthSearcherTest::testNoCheckmate()
   }
 }
 
+void CheckmateFixedDepthSearcherTest::testNoPromote()
+{
+  {
+    NumEffectState state(CsaString(
+			   "P1 *  *  *  *  *  *  * +GI * \n"
+			   "P2 *  *  *  *  *  *  * -KE-KY\n"
+			   "P3 *  *  *  *  * +UM+KI-OU-FU\n"
+			   "P4 *  *  *  *  *  *  *  * -KE\n"
+			   "P5 *  *  *  *  *  *  *  * +GI\n"
+			   "P6 *  *  *  *  *  *  *  *  * \n"
+			   "P7 *  *  *  *  *  *  *  *  * \n"
+			   "P8 *  *  *  *  *  *  *  *  * \n"
+			   "P9 *  * +OU+TO *  * -HI *  * \n"
+			   "P+00FU\n"
+			   "P-00AL\n"
+			   "-\n").getInitialState());
+    FixedDepthSearcher searcher(state);
+    const Move m33ki(Square(4,4), Square(3,3), GOLD, PTYPE_EMPTY, false, BLACK);
+    ProofDisproof pdp=searcher.hasEscapeMove<BLACK>(m33ki, 3);
+    CPPUNIT_ASSERT(!pdp.isCheckmateSuccess());
+    // 33同飛車不成なら不詰、成ると詰み
+  }
+}
+
+
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
