@@ -6,14 +6,13 @@
 #include "osl/container/moveVector.h"
 #include "osl/move_generator/allMoves.h"
 #include "osl/move_action/store.h"
-#include "osl/apply_move/applyMove.h"
 #include "osl/record/csaRecord.h"
 #include "osl/record/csaString.h"
 #include "osl/oslConfig.h"
 
 #include <cppunit/TestCase.h>
 #include <cppunit/extensions/HelperMacros.h>
-
+#include <boost/progress.hpp>
 #include <iostream>
 #include <fstream>
 
@@ -22,7 +21,6 @@ class ImmediateCheckmateTest : public CppUnit::TestFixture
 {
   CPPUNIT_TEST_SUITE(ImmediateCheckmateTest);
   CPPUNIT_TEST(testOne);
-  CPPUNIT_TEST(testKing8Info);
   CPPUNIT_TEST(testMoveShort);
   CPPUNIT_TEST(testChallenge);
   CPPUNIT_TEST(testCheckmate);
@@ -33,7 +31,6 @@ class ImmediateCheckmateTest : public CppUnit::TestFixture
 public:
   void setUp();
   void testOne();
-  void testKing8Info();
   void testCheckmate();
   void testPawnDropFoul();
   void testDropShort();
@@ -49,146 +46,12 @@ using namespace osl::checkmate;
 using namespace osl::state;
 using namespace osl::move_generator;
 using namespace osl::move_action;
-extern bool isShortTest;
 
 typedef AllMoves<Store> DoAll;
 
 void ImmediateCheckmateTest::testOne()
 {
 }
-void ImmediateCheckmateTest::testKing8Info()
-{
-  {
-    SimpleState sstate=CsaString(
-      "P1-KY-KE+GI+KA *  * +RY * -KY\n"
-      "P2 *  * -OU * -KI * +NK *  * \n"
-      "P3-FU * -GI-FU-FU-FU *  * -FU\n"
-      "P4 *  * -FU *  *  *  *  *  * \n"
-      "P5 *  *  *  * +KA *  *  *  * \n"
-      "P6 *  *  *  *  *  *  *  *  * \n"
-      "P7+FU * +FU+FU+FU+FU+FU * +FU\n"
-      "P8 *  * -NK * +OU *  *  *  * \n"
-      "P9+KY+KE * -HI * +KI+GI * +KY\n"
-      "P+00FU00FU00FU\n"
-      "P-00KI00KI00GI00FU00FU\n"
-      "-\n"
-      ).getInitialState();
-    NumEffectState state(sstate);
-    // +0027KE or +5528UM
-    King8Info king8=King8Info::make(BLACK,state);
-    CPPUNIT_ASSERT_EQUAL((1u<<D),king8.liberty());
-    CPPUNIT_ASSERT_EQUAL(1u,king8.libertyCount());
-  }
-  {
-    SimpleState sstate=CsaString(
-      "P1-KY * -GI-KI * +HI * -KE-KY\n"
-      "P2 *  *  *  * -OU * +NK *  * \n"
-      "P3-FU * -FU-FU-FU-FU-FU * -FU\n"
-      "P4 *  *  *  *  *  *  *  *  * \n"
-      "P5 *  *  *  * -KA *  *  *  * \n"
-      "P6 *  *  *  *  *  * +FU *  * \n"
-      "P7+FU *  * +FU+FU+FU+GI * +FU\n"
-      "P8 *  * -NK * +KI * +OU *  * \n"
-      "P9+KY * -RY *  * -KA-GI+KE+KY\n"
-      "P+00KI00KI00GI00FU00FU\n"
-      "P-00FU00FU00FU\n"
-      "+\n"
-      ).getInitialState();
-    NumEffectState state(sstate);
-    // +0027KE or +5528UM
-    King8Info king8=King8Info::make(WHITE,state);
-    CPPUNIT_ASSERT_EQUAL((1u<<D),king8.liberty());
-    CPPUNIT_ASSERT_EQUAL(1u,king8.libertyCount());
-  }
-  {
-    SimpleState sstate=CsaString(
-      "P1 *  *  * -KI *  *  *  * -KY\n"
-      "P2 * +KI-GI *  *  *  *  *  * \n"
-      "P3+GI-FU-FU *  *  *  *  * -FU\n"
-      "P4-FU * -KE *  * -FU-FU-FU * \n"
-      "P5 *  * +KA *  *  *  *  *  * \n"
-      "P6 *  *  *  * -FU *  * +HI * \n"
-      "P7 * +FU+KE+FU * +KA-OU * +FU\n"
-      "P8 *  * +OU+GI *  *  *  *  * \n"
-      "P9 *  * +KI * -NG+KY *  * +KY\n"
-      "P+00KE00FU\n"
-      "P-00HI00KI00KE00KY00FU00FU00FU00FU00FU00FU\n"
-      "+\n"
-      ).getInitialState();
-    NumEffectState state(sstate);
-    // +0027KE or +5528UM
-    King8Info king8=King8Info::make(BLACK,state);
-    CPPUNIT_ASSERT_EQUAL((1u<<DL),king8.liberty());
-    CPPUNIT_ASSERT_EQUAL((1u<<DR)|(1u<<D)|(1u<<L)|(1u<<UL)|(1u<<U)|(1u<<UR),
-			  king8.dropCandidate());
-    CPPUNIT_ASSERT_EQUAL(255u,king8.libertyCandidate());
-    CPPUNIT_ASSERT_EQUAL((1u<<DR)|(1u<<D)|(1u<<L)|(1u<<UL)|(1u<<U)|(1u<<UR),
-			 king8.moveCandidate2());
-    CPPUNIT_ASSERT_EQUAL((1u<<DR)|(1u<<D)|(1u<<L)|(1u<<UL)|(1u<<U)|(1u<<UR),
-			 king8.spaces());
-    CPPUNIT_ASSERT_EQUAL((1u<<DR)|(1u<<D)|(1u<<L)|(1u<<UL)|(1u<<U)|(1u<<UR),
-			 king8.moves());
-    CPPUNIT_ASSERT_EQUAL(1u,king8.libertyCount());
-  }
-  {
-    SimpleState sstate=CsaString(
-      "P1+NY+TO *  *  *  * -OU-KE-KY\n"
-      "P2 *  *  *  *  * -GI-KI *  *\n"
-      "P3 * +RY *  * +UM * -KI-FU-FU\n"
-      "P4 *  * +FU-FU *  *  *  *  *\n"
-      "P5 *  * -KE * +FU *  * +FU *\n"
-      "P6+KE *  * +FU+GI-FU *  * +FU\n"
-      "P7 *  * -UM *  *  *  *  *  *\n"
-      "P8 *  *  *  *  *  *  *  *  * \n"
-      "P9 * +OU * -GI *  *  *  * -NG\n"
-      "P+00HI00KI00KE00KY00FU00FU00FU00FU00FU00FU\n"
-      "P-00KI00KY00FU00FU\n"
-      "P-00AL\n"
-      "+\n"
-      ).getInitialState();
-    NumEffectState state(sstate);
-    King8Info king8=King8Info::make(BLACK,state);
-    CPPUNIT_ASSERT_EQUAL((1u<<UL)|(1u<<R),
-			 king8.liberty());
-    CPPUNIT_ASSERT_EQUAL(0x00u,king8.dropCandidate());
-    CPPUNIT_ASSERT_EQUAL((1u<<UL)|(1u<<R),
-			 king8.libertyCandidate());
-    CPPUNIT_ASSERT_EQUAL(0x00u,king8.moveCandidate2());
-    CPPUNIT_ASSERT_EQUAL((1u<<UL)|(1u<<R),king8.spaces());
-    CPPUNIT_ASSERT_EQUAL((1u<<UR),king8.moves());
-    CPPUNIT_ASSERT_EQUAL((1u<<U),king8.libertyCount());
-  }
-  {
-    SimpleState sstate=CsaString(
-      "P1 *  *  * -KI *  *  *  * -KY\n"
-      "P2 * +KI-GI *  *  *  *  *  * \n"
-      "P3+GI-FU-FU *  *  *  *  * -FU\n"
-      "P4-FU * -KE *  * -FU-FU-FU * \n"
-      "P5 *  *  *  *  *  *  *  *  * \n"
-      "P6 *  *  *  * -FU *  * +HI * \n"
-      "P7 * +FU+KE+FU * +KA-OU * +FU\n"
-      "P8 *  * +OU+GI * +KA *  *  * \n"
-      "P9 *  * +KI * -NG+KY *  * +KY\n"
-      "P+00KE00FU\n"
-      "P-00HI00KI00KE00KY00FU00FU00FU00FU00FU00FU\n"
-      "-\n"
-      ).getInitialState();
-    NumEffectState state(sstate);
-    // +0027KE or +5528UM
-    King8Info king8=King8Info::make(BLACK,state);
-    CPPUNIT_ASSERT_EQUAL((1u<<R),king8.liberty());
-    CPPUNIT_ASSERT_EQUAL((1u<<DR)|(1u<<D)|(1u<<L)|(1u<<UL)|(1u<<U),
-			 king8.dropCandidate());
-    CPPUNIT_ASSERT_EQUAL(255u,king8.libertyCandidate());
-    CPPUNIT_ASSERT_EQUAL((1u<<DR)|(1u<<D)|(1u<<L)|(1u<<UL)|(1u<<U),
-			 king8.moveCandidate2());
-    CPPUNIT_ASSERT_EQUAL((1u<<DR)|(1u<<D)|(1u<<L)|(1u<<UL)|(1u<<U),
-			 king8.spaces());
-    CPPUNIT_ASSERT_EQUAL((1u<<DR)|(1u<<D)|(1u<<L)|(1u<<UL)|(1u<<U),
-			 king8.moves());
-    CPPUNIT_ASSERT_EQUAL((1u<<UL),king8.libertyCount());
-  }
-}
 void ImmediateCheckmateTest::testPawnDropFoul()
 {
   {
@@ -258,8 +121,8 @@ void ImmediateCheckmateTest::testMoveShort()
     // +0027KE or +5528UM
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<WHITE>(state,bestMove));
-    CPPUNIT_ASSERT(Move(Position(2,7),KNIGHT,WHITE) ==  bestMove ||
-		   Move(Position(5,5),Position(2,8),PBISHOP,ROOK,true,WHITE) ==  bestMove);
+    CPPUNIT_ASSERT(Move(Square(2,7),KNIGHT,WHITE) ==  bestMove ||
+		   Move(Square(5,5),Square(2,8),PBISHOP,ROOK,true,WHITE) ==  bestMove);
   }
   {
     SimpleState sstate=CsaString(
@@ -281,7 +144,7 @@ void ImmediateCheckmateTest::testMoveShort()
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<WHITE>(state,bestMove));
 
-    CPPUNIT_ASSERT_EQUAL(Move(Position(2,5),Position(6,5),PROOK,PTYPE_EMPTY,false,WHITE),bestMove);
+    CPPUNIT_ASSERT_EQUAL(Move(Square(2,5),Square(6,5),PROOK,PTYPE_EMPTY,false,WHITE),bestMove);
   }
   {
     SimpleState sstate=CsaString(
@@ -302,7 +165,7 @@ void ImmediateCheckmateTest::testMoveShort()
     Move bestMove;
     // +0052KIは普通のpinned
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
-    CPPUNIT_ASSERT(bestMove == Move(Position(5,2),GOLD,BLACK));
+    CPPUNIT_ASSERT(bestMove == Move(Square(5,2),GOLD,BLACK));
   }
   {
     SimpleState sstate=CsaString(
@@ -363,7 +226,7 @@ void ImmediateCheckmateTest::testMoveShort()
     Move bestMove;
     // +4434KI
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
-    CPPUNIT_ASSERT(bestMove == Move(Position(4,4),Position(3,4),GOLD,PAWN,false,BLACK));
+    CPPUNIT_ASSERT(bestMove == Move(Square(4,4),Square(3,4),GOLD,PAWN,false,BLACK));
   }
   {
     SimpleState sstate=CsaString(
@@ -384,7 +247,48 @@ void ImmediateCheckmateTest::testMoveShort()
     Move bestMove;
     // +6553KE
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
-    CPPUNIT_ASSERT(bestMove == Move(Position(6,5),Position(5,3),KNIGHT,GOLD,false,BLACK));
+    CPPUNIT_ASSERT(bestMove == Move(Square(6,5),Square(5,3),KNIGHT,GOLD,false,BLACK));
+  }
+  {
+    SimpleState sstate=CsaString(
+				 "P1-KY *  *  *  * -OU-GI * -KY\n"
+				 "P2 *  *  * +NK *  *  *  *  * \n"
+				 "P3 *  *  *  * -KI-KI+NK-FU * \n"
+				 "P4-FU * -FU *  *  *  * -KI-FU\n"
+				 "P5 *  *  * +KE-FU+FU-FU *  * \n"
+				 "P6+FU-HI+FU *  *  *  * +FU+FU\n"
+				 "P7 *  *  * -KA * -FU *  *  * \n"
+				 "P8 *  *  *  *  *  * +GI+OU * \n"
+				 "P9+KY *  *  *  * +KI *  * +KY\n"
+				 "P+00KA00GI00FU\n"
+				 "P-00HI00GI00KE00FU00FU00FU00FU00FU\n"
+				 "+\n"
+				 ).getInitialState(); 
+    NumEffectState state(sstate);
+    Move bestMove;
+    // +6553KE is captured by 4353KI
+    CPPUNIT_ASSERT(!ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
+  }
+  {
+    SimpleState sstate=CsaString(
+				 "P1-KY *  *  *  * -OU-GI * -KY\n"
+				 "P2 *  *  * +NK *  *  *  *  * \n"
+				 "P3 *  *  *  * -KI-KI+NK-FU * \n"
+				 "P4-FU * -FU *  * +HI * -KI-FU\n"
+				 "P5 *  *  * +KE-FU+FU-FU *  * \n"
+				 "P6+FU-HI+FU *  *  *  * +FU+FU\n"
+				 "P7 *  *  * -KA * -FU *  *  * \n"
+				 "P8 *  *  *  *  *  * +GI+OU * \n"
+				 "P9+KY *  *  *  * +KI *  * +KY\n"
+				 "P+00KA00GI00FU\n"
+				 "P-00GI00KE00FU00FU00FU00FU00FU\n"
+				 "+\n"
+				 ).getInitialState(); 
+    NumEffectState state(sstate);
+    Move bestMove;
+    // +6553KE is valid because 43KI is pinned
+    CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
+    CPPUNIT_ASSERT(bestMove == Move(Square(6,5),Square(5,3),KNIGHT,GOLD,false,BLACK));
   }
   {
     SimpleState sstate=CsaString(
@@ -466,7 +370,7 @@ void ImmediateCheckmateTest::testMoveShort()
     // 
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<WHITE>(state,bestMove));
     // open moveでも詰みだが，見つけられるのは寄る手
-    CPPUNIT_ASSERT(bestMove == Move(Position(3,9),Position(2,9),GOLD,PTYPE_EMPTY,false,WHITE));
+    CPPUNIT_ASSERT(bestMove == Move(Square(3,9),Square(2,9),GOLD,PTYPE_EMPTY,false,WHITE));
   }
   {
     SimpleState sstate=CsaString(
@@ -487,7 +391,7 @@ void ImmediateCheckmateTest::testMoveShort()
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
     // +7766OU などという王手をしてはいけない
-    CPPUNIT_ASSERT(bestMove != Move(Position(7,7),Position(6,6),KING,PAWN,false,BLACK));
+    CPPUNIT_ASSERT(bestMove != Move(Square(7,7),Square(6,6),KING,PAWN,false,BLACK));
   }
   {
     SimpleState sstate=CsaString(
@@ -594,7 +498,7 @@ void ImmediateCheckmateTest::testMoveShort()
     // 
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
-    CPPUNIT_ASSERT(bestMove == Move(Position(9,4),Position(9,3),PPAWN,KNIGHT,true,BLACK));
+    CPPUNIT_ASSERT(bestMove == Move(Square(9,4),Square(9,3),PPAWN,KNIGHT,true,BLACK));
   }
   {
     SimpleState sstate=CsaString(
@@ -615,7 +519,7 @@ void ImmediateCheckmateTest::testMoveShort()
     // 
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<WHITE>(state,bestMove));
-    CPPUNIT_ASSERT_EQUAL(Move(Position(1,9),Position(2,8),PBISHOP,PTYPE_EMPTY,false,WHITE),bestMove);
+    CPPUNIT_ASSERT_EQUAL(Move(Square(1,9),Square(2,8),PBISHOP,PTYPE_EMPTY,false,WHITE),bestMove);
   }
   {
     SimpleState sstate=CsaString(
@@ -636,8 +540,8 @@ void ImmediateCheckmateTest::testMoveShort()
     // 
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<WHITE>(state,bestMove));
-    CPPUNIT_ASSERT(bestMove == Move(Position(7,6),Position(7,7),PPAWN,PTYPE_EMPTY,true,WHITE) ||
-		   bestMove == Move(Position(9,5),Position(7,7),PBISHOP,PTYPE_EMPTY,true,WHITE));
+    CPPUNIT_ASSERT(bestMove == Move(Square(7,6),Square(7,7),PPAWN,PTYPE_EMPTY,true,WHITE) ||
+		   bestMove == Move(Square(9,5),Square(7,7),PBISHOP,PTYPE_EMPTY,true,WHITE));
   }
   {
     SimpleState sstate=CsaString(
@@ -756,22 +660,22 @@ int answerMoveCount;
 
 static bool noEscape(const NumEffectState &state)
 {
-  Player pl=state.getTurn();
+  Player pl=state.turn();
   // 自殺手
-  if(state.hasEffectBy(pl,state.getKingPosition(alt(pl)))) return false;
+  if(state.hasEffectAt(pl,state.kingSquare(alt(pl)))) return false;
   // not 王手
-  if(!state.hasEffectBy(alt(pl),state.getKingPosition(pl))) return false;
+  if(!state.hasEffectAt(alt(pl),state.kingSquare(pl))) return false;
   MoveVector moves;
   {
     Store action(moves);
-    DoAll::generate(state.getTurn(),state,action);
+    DoAll::generate(state.turn(),state,action);
   }
   for(size_t i=0;i<moves.size();i++){
     NumEffectState next_state = state;
-    ApplyMoveOfTurn::doMove(next_state, moves[i]);
-    Player pl=next_state.getTurn();
+    next_state.makeMove(moves[i]);
+    Player pl=next_state.turn();
     // 王手をのがれた
-    if(!next_state.hasEffectBy(pl,next_state.getKingPosition(alt(pl)))) return false;
+    if(!next_state.hasEffectAt(pl,next_state.kingSquare(alt(pl)))) return false;
   }
   return true;
 }
@@ -782,7 +686,7 @@ static bool isImmediateCheck(const NumEffectState& state_org,Move const& move)
   if(onlyDrop && move.from().isOnBoard()) return false;
   if(!move.from().isOnBoard() && move.ptype()==PAWN) return false;
   NumEffectState state = state_org;
-  ApplyMoveOfTurn::doMove(state, move);
+  state.makeMove(move);
   if(noEscape(state))
     return true;
   return false;
@@ -794,7 +698,7 @@ static bool hasImmediateCheck(NumEffectState& state,Move& bestMove)
   MoveVector moves;
   {
     Store action(moves);
-    DoAll::generate(state.getTurn(),state,action);
+    DoAll::generate(state.turn(),state,action);
   }
   for(size_t i=0;i<moves.size();i++){
     if(isImmediateCheck<onlyDrop>(state,moves[i])) {
@@ -828,7 +732,7 @@ void ImmediateCheckmateTest::testDropShort()
     // 
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
-    CPPUNIT_ASSERT(bestMove==Move(Position(2,9),KNIGHT,BLACK));
+    CPPUNIT_ASSERT(bestMove==Move(Square(2,9),KNIGHT,BLACK));
   }
   {
     NumEffectState state(CsaString(
@@ -847,9 +751,9 @@ void ImmediateCheckmateTest::testDropShort()
 			 ).getInitialState());
     // 
     Move bestMove;
-    CPPUNIT_ASSERT(isImmediateCheck<true>(state,Move(Position(8,5),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(isImmediateCheck<true>(state,Move(Square(8,5),KNIGHT,BLACK)));
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
-    CPPUNIT_ASSERT(bestMove==Move(Position(8,5),KNIGHT,BLACK));
+    CPPUNIT_ASSERT(bestMove==Move(Square(8,5),KNIGHT,BLACK));
   }
   {
     NumEffectState state(CsaString(
@@ -868,9 +772,9 @@ void ImmediateCheckmateTest::testDropShort()
 			 ).getInitialState());
     // 
     Move bestMove;
-    CPPUNIT_ASSERT(isImmediateCheck<true>(state,Move(Position(8,5),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(isImmediateCheck<true>(state,Move(Square(8,5),KNIGHT,BLACK)));
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
-    CPPUNIT_ASSERT(bestMove==Move(Position(8,5),KNIGHT,BLACK));
+    CPPUNIT_ASSERT(bestMove==Move(Square(8,5),KNIGHT,BLACK));
   }
   {
     NumEffectState state(CsaString(
@@ -889,7 +793,7 @@ void ImmediateCheckmateTest::testDropShort()
 			 ).getInitialState());
     // 
     Move bestMove;
-    CPPUNIT_ASSERT(isImmediateCheck<true>(state,Move(Position(3,6),GOLD,WHITE)));
+    CPPUNIT_ASSERT(isImmediateCheck<true>(state,Move(Square(3,6),GOLD,WHITE)));
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<WHITE>(state,bestMove));
   }
   {
@@ -933,7 +837,7 @@ void ImmediateCheckmateTest::testDropShort()
     // 22KI
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
-    CPPUNIT_ASSERT_EQUAL(Move(Position(2,2),GOLD,BLACK),bestMove);
+    CPPUNIT_ASSERT_EQUAL(Move(Square(2,2),GOLD,BLACK),bestMove);
   }
   {
     SimpleState sstate=CsaString(
@@ -953,7 +857,7 @@ void ImmediateCheckmateTest::testDropShort()
     // -0049KI!!
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<WHITE>(state,bestMove));
-    CPPUNIT_ASSERT_EQUAL(Move(Position(4,9),GOLD,WHITE),bestMove);
+    CPPUNIT_ASSERT_EQUAL(Move(Square(4,9),GOLD,WHITE),bestMove);
   }
   {
     SimpleState sstate=CsaString(
@@ -993,7 +897,7 @@ void ImmediateCheckmateTest::testDropShort()
     // 31HI
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
-    CPPUNIT_ASSERT_EQUAL(Move(Position(3,1),ROOK,BLACK),bestMove);
+    CPPUNIT_ASSERT_EQUAL(Move(Square(3,1),ROOK,BLACK),bestMove);
   }
   {
     SimpleState sstate=CsaString(
@@ -1014,7 +918,7 @@ void ImmediateCheckmateTest::testDropShort()
     // 68KA
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<WHITE>(state,bestMove));
-    CPPUNIT_ASSERT_EQUAL(Move(Position(6,8),BISHOP,WHITE),bestMove);
+    CPPUNIT_ASSERT_EQUAL(Move(Square(6,8),BISHOP,WHITE),bestMove);
   }
   {
     SimpleState sstate=CsaString(
@@ -1035,7 +939,7 @@ void ImmediateCheckmateTest::testDropShort()
     // 82HI
     Move bestMove;
     CPPUNIT_ASSERT(ImmediateCheckmate::hasCheckmateMove<BLACK>(state,bestMove));
-    CPPUNIT_ASSERT_EQUAL(Move(Position(8,2),ROOK,BLACK),bestMove);
+    CPPUNIT_ASSERT_EQUAL(Move(Square(8,2),ROOK,BLACK),bestMove);
   }
   {
     SimpleState sstate=CsaString(
@@ -1282,7 +1186,7 @@ void ImmediateCheckmateTest::testCheckmate()
     const bool is_checkmate
       = ImmediateCheckmate::hasCheckmateMove<BLACK>(state, check_move);
     // +6574TOは -5372OUで後1000手くらい詰まない
-    CPPUNIT_ASSERT(check_move != Move(Position(6,5),Position(7,4),PPAWN,PTYPE_EMPTY,false,BLACK));
+    CPPUNIT_ASSERT(check_move != Move(Square(6,5),Square(7,4),PPAWN,PTYPE_EMPTY,false,BLACK));
     CPPUNIT_ASSERT(! is_checkmate);
   }
 }
@@ -1293,15 +1197,15 @@ static void level1(const NumEffectState &state_org)
   MoveVector moves;
   {
     Store action(moves);
-    DoAll::generate(state_org.getTurn(),state_org,action);
+    DoAll::generate(state_org.turn(),state_org,action);
   }
   for(size_t i=0;i<moves.size();i++){
     NumEffectState state = state_org;
-    ApplyMoveOfTurn::doMove(state, moves[i]);
-    Player pl=state.getTurn();
+    state.makeMove(moves[i]);
+    Player pl=state.turn();
     state1Count++;
-    if(!state.hasEffectBy(pl,state.getKingPosition(alt(pl))) &&
-       !state.hasEffectBy(alt(pl),state.getKingPosition(pl))
+    if(!state.hasEffectAt(pl,state.kingSquare(alt(pl))) &&
+       !state.hasEffectAt(alt(pl),state.kingSquare(pl))
        ){
       stateCount++;
       Move bestMove1;
@@ -1325,8 +1229,8 @@ static void level1(const NumEffectState &state_org)
 	if(hasImmediateCheck<true>(state,bestMove1)){
 	  immediateDrop++;
 	  Move bestMove;
-	  if(!ImmediateCheckmate::hasCheckmateMove(state.getTurn(),state,bestMove)){
-	    if(!isShortTest)
+	  if(!ImmediateCheckmate::hasCheckmateMove(state.turn(),state,bestMove)){
+	    if(OslConfig::verbose())
 	      std::cerr << std::endl << bestMove1 << std::endl << 
 		state << std::endl;
 	  }
@@ -1339,8 +1243,8 @@ static void level1(const NumEffectState &state_org)
 	}
 	else{
 	  Move bestMove;
-	  if(!ImmediateCheckmate::hasCheckmateMove(state.getTurn(),state,bestMove)){
-	    if(!isShortTest)
+	  if(!ImmediateCheckmate::hasCheckmateMove(state.turn(),state,bestMove)){
+	    if(OslConfig::verbose())
 	      std::cerr << std::endl << bestMove1 << std::endl << 
 		state << std::endl;
 	  }
@@ -1354,10 +1258,10 @@ static void level1(const NumEffectState &state_org)
       }
       else{
 	Move bestMove;
-	CPPUNIT_ASSERT(!ImmediateCheckmate::hasCheckmateMove(state.getTurn(),state,bestMove) ||
+	CPPUNIT_ASSERT(!ImmediateCheckmate::hasCheckmateMove(state.turn(),state,bestMove) ||
 		       (std::cerr << std::endl << bestMove << std::endl << state << std::endl,0)
 		       );
-	CPPUNIT_ASSERT(!ImmediateCheckmate::hasCheckmateMove(state.getTurn(),state,bestMove) ||
+	CPPUNIT_ASSERT(!ImmediateCheckmate::hasCheckmateMove(state.turn(),state,bestMove) ||
 		       (std::cerr << std::endl << bestMove << std::endl << state << std::endl,0)
 		       );
       }
@@ -1366,7 +1270,7 @@ static void level1(const NumEffectState &state_org)
 }
 static void testFile(std::string filename)
 {
-  filename = OslConfig::testFile(filename);
+  filename = OslConfig::testPublicFile(filename);
   
   Record rec=CsaFile(filename).getRecord();
   vector<osl::Move> dummy=rec.getMoves();
@@ -1377,34 +1281,35 @@ static void testFile(std::string filename)
   MoveVector moves;
   {
     Store action(moves);
-    DoAll::generate(state.getTurn(),state,action);
+    DoAll::generate(state.turn(),state,action);
   }
   for(size_t i=0;i<moves.size();i++){
     NumEffectState new_state = state;
-    ApplyMoveOfTurn::doMove(new_state, moves[i]);
-    Player pl=new_state.getTurn();
-    if(!new_state.hasEffectBy(pl,new_state.getKingPosition(alt(pl)))){
+    new_state.makeMove(moves[i]);
+    Player pl=new_state.turn();
+    if(!new_state.hasEffectAt(pl,new_state.kingSquare(alt(pl)))){
       level1(new_state);
     }
   }
 }
 void ImmediateCheckmateTest::testFiles()
 {
-  std::ifstream ifs(OslConfig::testFile("kisenCheckProblems/FILES"));
+  std::ifstream ifs(OslConfig::testPublicFile("short-checkmate-problems/FILES"));
   CPPUNIT_ASSERT(ifs);
   int i=0;
   int count=10;
-  if (isShortTest)
+  if (OslConfig::inUnitTestShort())
     count=2;
   std::string filename;
-  while((ifs >> filename) && (++i<count)) {
-    if(filename == "") 
-      break;
-    if (! isShortTest)
-      std::cerr << "testFilesCheck: " << filename << " ";
-    testFile("kisenCheckProblems/" + filename);
+  boost::scoped_ptr<boost::progress_display> progress;
+  if (OslConfig::inUnitTestLong())
+    progress.reset(new boost::progress_display(count, std::cerr));
+  while((ifs >> filename) && filename != "" && (++i<count)) {
+    if (progress)
+      ++(*progress);
+    testFile("short-checkmate-problems/" + filename);
   }
-  if(!isShortTest)
+  if(OslConfig::verbose())
     std::cerr << std::endl << "stateCount=" << stateCount <<
       ",state0Count=" << state0Count <<
       ",state1Count=" << state1Count <<
