@@ -20,8 +20,8 @@ CPPUNIT_TEST_SUITE_REGISTRATION(PawnCheckmateMovesTest);
 
 void PawnCheckmateMovesTest::testPair()
 {
-  const Position from = Position(2,4);
-  const Position to = Position(2,3);
+  const Square from = Square(2,4);
+  const Square to = Square(2,3);
   
   const Move p = Move(from, to, PPAWN, PTYPE_EMPTY, true, BLACK);
   const Move np = Move(from, to, PAWN, PTYPE_EMPTY, false, BLACK);
