@@ -16,7 +16,7 @@ class bitXmaskTest : public CppUnit::TestFixture
 CPPUNIT_TEST_SUITE_REGISTRATION(bitXmaskTest);
 
 void bitXmaskTest::testShow(){
-  Position p0=Position(8,3);
+  Square p0=Square(8,3);
   BitXmask xMask;
   xMask.clearAll();
   xMask.set(p0.x());
