@@ -1,4 +1,5 @@
 #include "osl/effect/moveSignature.h"
+#include "osl/oslConfig.h"
 #include <iomanip>
 #include <iostream>
 #include <cppunit/TestCase.h>
@@ -6,7 +7,6 @@
 
 using namespace osl;
 using namespace osl::effect;
-extern bool isShortTest;
 
 class moveSignatureTest : public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE( moveSignatureTest );
@@ -24,7 +24,7 @@ moveSignatureTest::moveSignatureTest(){
 }
 
 void moveSignatureTest::testShow(){
-  if(isShortTest) return;
+  if(! OslConfig::verbose()) return;
   for(int i=PTYPEO_MIN;i<=PTYPEO_MAX;i++){
     PtypeO ptypeO=static_cast<PtypeO>(i);
     std::cout << ptypeO << "," << Move_Signature_Table.getSignature(ptypeO) << std::endl;
