@@ -35,14 +35,14 @@ void ShadowEffectTest::testHasEffect()
 			   "+\n"
 			   ).getInitialState());
     CPPUNIT_ASSERT_EQUAL(false, ShadowEffect::hasEffect
-			 (state, Position(8,8), BLACK));
+			 (state, Square(8,8), BLACK));
     CPPUNIT_ASSERT_EQUAL(true, ShadowEffect::hasEffect
-			 (state, Position(8,8), WHITE));
+			 (state, Square(8,8), WHITE));
 
     CPPUNIT_ASSERT_EQUAL(true, ShadowEffect::hasEffect
-			 (state, Position(2,2), BLACK));
+			 (state, Square(2,2), BLACK));
     CPPUNIT_ASSERT_EQUAL(false, ShadowEffect::hasEffect
-			 (state, Position(2,2), WHITE));
+			 (state, Square(2,2), WHITE));
   }
 }
 // ;;; Local Variables:
