@@ -21,6 +21,7 @@ class OpenMidEndingEvalTest : public CppUnit::TestFixture
   CPPUNIT_TEST(testIcc);
   CPPUNIT_TEST(testKing25EmptySquareNoEffect);
   CPPUNIT_TEST(testCaptureValue);
+  CPPUNIT_TEST(testArray);
   CPPUNIT_TEST_SUITE_END();
 public:
   void testInit();
@@ -30,6 +31,7 @@ public:
   void testBasic();
   void testKing25EmptySquareNoEffect();
   void testCaptureValue();
+  void testArray();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(OpenMidEndingEvalTest);
@@ -231,6 +233,11 @@ void OpenMidEndingEvalTest::testCaptureValue()
   }
 }
 
+void OpenMidEndingEvalTest::testArray()
+{
+  OpenMidEndingEval evals[3];
+  (void)evals[0];
+}
 
 /* ------------------------------------------------------------------------- */
 // ;;; Local Variables:
