@@ -22,6 +22,7 @@ class PieceEvalTest : public CppUnit::TestFixture
   CPPUNIT_TEST(testConsistentUpdate);
   CPPUNIT_TEST(testConsistentExpect);
   CPPUNIT_TEST(testSoma);
+  CPPUNIT_TEST(testArray);
   CPPUNIT_TEST_SUITE_END();
 public:
   void testBug();
@@ -32,6 +33,7 @@ public:
   void testComputeDiffAfterTakeBack();
   void testConsistentUpdate();
   void testConsistentExpect();
+  void testArray();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(PieceEvalTest);
@@ -245,6 +247,12 @@ void PieceEvalTest::testConsistentExpect()
   consistencyTestExpect<PieceEval>();
 }
 
+void PieceEvalTest::testArray()
+{
+  PieceEval evals[3];
+  (void)evals[0];
+}
+
 /* ------------------------------------------------------------------------- */
 // ;;; Local Variables:
 // ;;; mode:c++
