@@ -20,6 +20,7 @@ class ProgressEvalTest : public CppUnit::TestFixture
   CPPUNIT_TEST(testPinBonus);
   CPPUNIT_TEST(testSeeScale);
   CPPUNIT_TEST(testSymmetry);
+  CPPUNIT_TEST(testArray);
   CPPUNIT_TEST_SUITE_END();
 public:
   void testLoad();
@@ -30,6 +31,7 @@ public:
   void testPinBonus();
   void testSeeScale();
   void testSymmetry();
+  void testArray();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(ProgressEvalTest);
@@ -207,6 +209,13 @@ void ProgressEvalTest::testSymmetry()
     }
   }
 }
+
+void ProgressEvalTest::testArray()
+{
+  ProgressEval evals[3];
+  (void)evals[0];
+}
+
 /* ------------------------------------------------------------------------- */
 // ;;; Local Variables:
 // ;;; mode:c++
