@@ -20,8 +20,8 @@ public:
   void testUndo() 
   {
     vector<Move> moves;
-    const Move m76fu(Position(7,7),Position(7,6),PAWN,PTYPE_EMPTY,false,BLACK);
-    const Move m34fu(Position(3,3),Position(3,4),PAWN,PTYPE_EMPTY,false,WHITE);
+    const Move m76fu(Square(7,7),Square(7,6),PAWN,PTYPE_EMPTY,false,BLACK);
+    const Move m34fu(Square(3,3),Square(3,4),PAWN,PTYPE_EMPTY,false,WHITE);
     moves.push_back(m76fu);
     moves.push_back(m34fu);
     
