@@ -22,6 +22,7 @@ class GameStateTest : public CppUnit::TestFixture
   CPPUNIT_TEST(testRootHistoryFiles);
   CPPUNIT_TEST(testRootHistoryImmediateUse);
   CPPUNIT_TEST(testGenerateNotLosingMoves);
+  CPPUNIT_TEST(testGenerateMoves);
   CPPUNIT_TEST_SUITE_END();
 public:
   void testRepetition();
@@ -30,6 +31,7 @@ public:
   void testRootHistoryImmediateUse();
   void testRootHistoryRecord(const SimpleState& state, const vector<osl::Move>&);
   void testGenerateNotLosingMoves();
+  void testGenerateMoves();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(GameStateTest);
@@ -178,6 +180,62 @@ void GameStateTest::testGenerateNotLosingMoves()
   }  
 }
 
+void GameStateTest::testGenerateMoves()
+{
+  {
+    CsaString csa("P1-KY-KE-OU-KI *  *  *  * -KY\n"
+		  "P2 *  * -GI *  *  *  * -KI * \n"
+		  "P3-FU * -FU-FU-FU-FU *  *  * \n"
+		  "P4 *  *  *  *  *  * -HI-GI-FU\n"
+		  "P5 *  * +FU *  * +KE *  *  * \n"
+		  "P6 *  * +KE *  * +FU-FU *  * \n"
+		  "P7+FU+FU * +FU+FU *  * +HI+FU\n"
+		  "P8 * +GI+KI+OU *  *  *  *  * \n"
+		  "P9+KY+KE *  *  * +KI *  * +KY\n"
+		  "P+00KA00FU00FU00FU\n"
+		  "P-00KA00GI00FU\n"
+		  "+\n"
+		  "+0035FU\n"
+		  "-3494HI\n");
+    GameState state(csa.getInitialState());
+    const vector<Move> moves = csa.getRecord().getMoves();
+    BOOST_FOREACH(Move move, moves)
+      state.pushMove(move);
+    MoveVector normal, win, draw, loss;
+    state.generateMoves(normal, win, draw, loss);
+    CPPUNIT_ASSERT(loss.isMember(Move(Square(3,5),Square(3,4),PAWN,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(loss.size() == 1);
+  }
+  {
+    CsaString csa("P1-KY *  * -KI *  *  * -KE-KY\n"
+		  "P2 * -OU-GI * -KI-HI *  *  * \n"
+		  "P3 * -FU-KE * -FU * -KA-FU * \n"
+		  "P4-FU * -FU-FU-GI * -FU * -FU\n"
+		  "P5 *  *  *  *  * -FU * +FU * \n"
+		  "P6+FU+FU+FU+FU+FU * +FU *  * \n"
+		  "P7 * +GI+KA+KI+GI+FU *  * +FU\n"
+		  "P8 * +OU+KI *  *  *  * +HI * \n"
+		  "P9+KY+KE *  *  *  *  * +KE+KY\n"
+		  "+\n"
+		  "+2838HI\n"
+		  "-3344KA\n"
+		  "+3828HI\n");
+    GameState state(csa.getInitialState());
+    const vector<Move> moves = csa.getRecord().getMoves();
+    BOOST_FOREACH(Move move, moves)
+      state.pushMove(move);
+    const Move m33ka(Square(4,4),Square(3,3),BISHOP,PTYPE_EMPTY,false,WHITE);
+
+    MoveVector normal, win, draw, loss;
+    state.generateMoves(normal, win, draw, loss);
+
+    CPPUNIT_ASSERT(! loss.isMember(m33ka));
+    CPPUNIT_ASSERT(draw.isMember(m33ka));
+    CPPUNIT_ASSERT(loss.empty());
+    CPPUNIT_ASSERT_EQUAL((size_t)1u, draw.size());
+  }
+}
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
