@@ -46,8 +46,10 @@ void HashKeyTest::testDump()
   
   std::ostringstream ss;
   key.dumpContents(ss);
+#ifdef OSL_LONG_HASH_KEY
   HashKey key2 = HashKey::readFromDump(ss.str());
   CPPUNIT_ASSERT_EQUAL(key, key2);
+#endif
 }
 
 void HashKeyTest::testFiles(){
