@@ -103,49 +103,49 @@ public:
   void testIgnoreUnpromote()
   {
     // pawn
-    CPPUNIT_ASSERT(Move(Square(4,4),Square(4,3),PAWN,PTYPE_EMPTY,false,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,4),Square(4,3),PPAWN,PTYPE_EMPTY,true,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,3),PAWN,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,5),Square(4,4),PAWN,PTYPE_EMPTY,false,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(Move(Square(4,6),Square(4,7),PAWN,PTYPE_EMPTY,false,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(4,6),Square(4,7),PPAWN,PTYPE_EMPTY,true,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(4,7),PAWN,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(4,5),Square(4,6),PAWN,PTYPE_EMPTY,false,WHITE).ignoreUnpromote(WHITE));
+    CPPUNIT_ASSERT(Move(Square(4,4),Square(4,3),PAWN,PTYPE_EMPTY,false,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,4),Square(4,3),PPAWN,PTYPE_EMPTY,true,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,3),PAWN,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,5),Square(4,4),PAWN,PTYPE_EMPTY,false,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(Move(Square(4,6),Square(4,7),PAWN,PTYPE_EMPTY,false,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,6),Square(4,7),PPAWN,PTYPE_EMPTY,true,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,7),PAWN,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,5),Square(4,6),PAWN,PTYPE_EMPTY,false,WHITE).ignoreUnpromote());
     // lance
-    CPPUNIT_ASSERT(!Move(Square(4,4),Square(4,3),LANCE,PTYPE_EMPTY,false,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(Move(Square(4,4),Square(4,2),LANCE,PTYPE_EMPTY,false,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,4),Square(4,3),PLANCE,PTYPE_EMPTY,true,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,3),LANCE,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,5),Square(4,4),LANCE,PTYPE_EMPTY,false,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,6),Square(4,7),LANCE,PTYPE_EMPTY,false,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(Move(Square(4,6),Square(4,8),LANCE,PTYPE_EMPTY,false,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(4,6),Square(4,7),PLANCE,PTYPE_EMPTY,true,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(4,7),LANCE,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(4,5),Square(4,6),LANCE,PTYPE_EMPTY,false,WHITE).ignoreUnpromote(WHITE));
+    CPPUNIT_ASSERT(!Move(Square(4,4),Square(4,3),LANCE,PTYPE_EMPTY,false,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(Move(Square(4,4),Square(4,2),LANCE,PTYPE_EMPTY,false,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,4),Square(4,3),PLANCE,PTYPE_EMPTY,true,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,3),LANCE,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,5),Square(4,4),LANCE,PTYPE_EMPTY,false,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,6),Square(4,7),LANCE,PTYPE_EMPTY,false,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(Move(Square(4,6),Square(4,8),LANCE,PTYPE_EMPTY,false,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,6),Square(4,7),PLANCE,PTYPE_EMPTY,true,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,7),LANCE,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,5),Square(4,6),LANCE,PTYPE_EMPTY,false,WHITE).ignoreUnpromote());
     // bishop
-    CPPUNIT_ASSERT(Move(Square(4,4),Square(2,2),BISHOP,PTYPE_EMPTY,false,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(Move(Square(4,2),Square(8,6),BISHOP,PTYPE_EMPTY,false,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,4),Square(2,2),PBISHOP,PTYPE_EMPTY,true,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,2),Square(8,6),PBISHOP,PTYPE_EMPTY,true,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,3),BISHOP,BLACK).ignoreUnpromote(BLACK));
+    CPPUNIT_ASSERT(Move(Square(4,4),Square(2,2),BISHOP,PTYPE_EMPTY,false,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(Move(Square(4,2),Square(8,6),BISHOP,PTYPE_EMPTY,false,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,4),Square(2,2),PBISHOP,PTYPE_EMPTY,true,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,2),Square(8,6),PBISHOP,PTYPE_EMPTY,true,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,3),BISHOP,BLACK).ignoreUnpromote());
 
-    CPPUNIT_ASSERT(Move(Square(6,6),Square(8,8),BISHOP,PTYPE_EMPTY,false,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(Move(Square(6,8),Square(2,4),BISHOP,PTYPE_EMPTY,false,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(6,6),Square(8,8),PBISHOP,PTYPE_EMPTY,true,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(6,8),Square(2,4),PBISHOP,PTYPE_EMPTY,true,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(6,7),BISHOP,WHITE).ignoreUnpromote(WHITE));
+    CPPUNIT_ASSERT(Move(Square(6,6),Square(8,8),BISHOP,PTYPE_EMPTY,false,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(Move(Square(6,8),Square(2,4),BISHOP,PTYPE_EMPTY,false,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(6,6),Square(8,8),PBISHOP,PTYPE_EMPTY,true,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(6,8),Square(2,4),PBISHOP,PTYPE_EMPTY,true,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(6,7),BISHOP,WHITE).ignoreUnpromote());
     // ROOK
-    CPPUNIT_ASSERT(Move(Square(4,4),Square(4,2),ROOK,PTYPE_EMPTY,false,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(Move(Square(4,2),Square(4,6),ROOK,PTYPE_EMPTY,false,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,4),Square(4,2),PROOK,PTYPE_EMPTY,true,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,2),Square(4,6),PROOK,PTYPE_EMPTY,true,BLACK).ignoreUnpromote(BLACK));
-    CPPUNIT_ASSERT(!Move(Square(4,3),ROOK,BLACK).ignoreUnpromote(BLACK));
+    CPPUNIT_ASSERT(Move(Square(4,4),Square(4,2),ROOK,PTYPE_EMPTY,false,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(Move(Square(4,2),Square(4,6),ROOK,PTYPE_EMPTY,false,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,4),Square(4,2),PROOK,PTYPE_EMPTY,true,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,2),Square(4,6),PROOK,PTYPE_EMPTY,true,BLACK).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(4,3),ROOK,BLACK).ignoreUnpromote());
 
-    CPPUNIT_ASSERT(Move(Square(6,6),Square(6,8),ROOK,PTYPE_EMPTY,false,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(Move(Square(6,8),Square(6,4),ROOK,PTYPE_EMPTY,false,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(6,6),Square(6,8),PROOK,PTYPE_EMPTY,true,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(6,8),Square(6,4),PROOK,PTYPE_EMPTY,true,WHITE).ignoreUnpromote(WHITE));
-    CPPUNIT_ASSERT(!Move(Square(6,7),ROOK,WHITE).ignoreUnpromote(WHITE));
+    CPPUNIT_ASSERT(Move(Square(6,6),Square(6,8),ROOK,PTYPE_EMPTY,false,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(Move(Square(6,8),Square(6,4),ROOK,PTYPE_EMPTY,false,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(6,6),Square(6,8),PROOK,PTYPE_EMPTY,true,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(6,8),Square(6,4),PROOK,PTYPE_EMPTY,true,WHITE).ignoreUnpromote());
+    CPPUNIT_ASSERT(!Move(Square(6,7),ROOK,WHITE).ignoreUnpromote());
   }
   void testHasIgnoredUnpromote()
   {
