@@ -1723,7 +1723,7 @@ static void testMoveFile(const std::string& fileName){
 		it!=effectMoves.end();){
 	      Move m= *it; ++it;
 	      CPPUNIT_ASSERT(Classifier::isSafeMove(state,m));
-	      CPPUNIT_ASSERT(!m.ignoreUnpromote(m.player())||
+	      CPPUNIT_ASSERT(!m.ignoreUnpromote()||
 			     (std::cerr << "\n" << state << "\n" << m << std::endl,0)
 		);
 	      CPPUNIT_ASSERT((std::find(it,effectMoves.end(),m)
@@ -1744,7 +1744,7 @@ static void testMoveFile(const std::string& fileName){
 	  size_t count1=0;
 	  for(size_t j=0;j<effectMoves.size();j++){
 	    CPPUNIT_ASSERT(Classifier::isSafeMove(state,effectMoves[j]));
-	    CPPUNIT_ASSERT(!effectMoves[j].ignoreUnpromote(effectMoves[j].player()));
+	    CPPUNIT_ASSERT(!effectMoves[j].ignoreUnpromote());
 	    CPPUNIT_ASSERT((state.isValidMove(effectMoves[j],true)  
 			    && isAddEffectWithEffectMove(state,pos,effectMoves[j]))
 			   || (std::cerr << effectMoves[j] << ",isValid=" << state.isValidMove(effectMoves[j],true)  << std::endl << state << std::endl << "pos=" << pos << std::endl,0)
