@@ -130,7 +130,7 @@ static void myStateTest(State& state0){
     const Move move=moves[i];
     CPPUNIT_ASSERT(state0.isValidMove(move));
     CPPUNIT_ASSERT(Classifier::isSafeMove(state0,move));
-    CPPUNIT_ASSERT(!move.ignoreUnpromote(move.player()));
+    CPPUNIT_ASSERT(!move.ignoreUnpromote());
   }
   Move tmpMove=moves[0];
   state0.makeMove(tmpMove);
@@ -175,8 +175,10 @@ static void testMoveFile(const std::string& fileName){
 	);
     }
     const Move move=moves[i];
-    if(move.ignoreUnpromote(move.player()))
+    if(move.ignoreUnpromote()) {
+      CPPUNIT_ASSERT(! curMoves.isMember(move.promote()));      
       CPPUNIT_ASSERT(curMoves.isMember(move.promote()));
+    }
     else
       CPPUNIT_ASSERT(curMoves.isMember(move));
     state.makeMove(move);
