@@ -126,7 +126,7 @@ static void testFile(const std::string& fileName)
 			     captureMoves[j].to()==pos ) ||
 			    (std::cerr << eState << captureMoves[j] << std::endl,0)
 	      );
-	    CPPUNIT_ASSERT( !captureMoves[j].ignoreUnpromote(eState.turn()));
+	    CPPUNIT_ASSERT( !captureMoves[j].ignoreUnpromote());
 	    CPPUNIT_ASSERT( Classifier::isSafeMove(eState,captureMoves[j]));
 	  }
 	  for(size_t j=0;j<allMoves.size();j++)
