@@ -434,7 +434,7 @@ static void testMoveFile(const std::string& filename){
 	  if(p.ptype()==KING){
 	    BOOST_FOREACH (Move move, escapeMoves) { 
 	      assert(state.isConsistent(true));
-	      CPPUNIT_ASSERT(! move.ignoreUnpromote(state.turn()));
+	      CPPUNIT_ASSERT(! move.ignoreUnpromote());
 	      
 	      NumEffectState next_state = state;
 	      next_state.makeMove(move);
@@ -443,7 +443,7 @@ static void testMoveFile(const std::string& filename){
 		);
 	    }
 	    BOOST_FOREACH (Move move, escape_cheap) { 
-	      CPPUNIT_ASSERT(! move.ignoreUnpromote(state.turn()));	      
+	      CPPUNIT_ASSERT(! move.ignoreUnpromote());	      
 	      NumEffectState next_state = state;
 	      next_state.makeMove(move);
 	      CPPUNIT_ASSERT(! next_state.inCheck(pl));
