@@ -28,9 +28,9 @@ public:
 			   "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
 			   "+\n").getInitialState());
 
-    const Move m1 = Move(Position(2,6), Position(2,3), PROOK, 
+    const Move m1 = Move(Square(2,6), Square(2,3), PROOK, 
 			    PAWN, true, BLACK);
-    const Move m2 = Move(Position(5,6), Position(5,3), PROOK, 
+    const Move m2 = Move(Square(5,6), Square(5,3), PROOK, 
 			    PAWN, true, BLACK);
     MoveVector moves;
     moves.push_back(m1);
