@@ -15,8 +15,8 @@ class MoveOrderCheapPtypeTest : public CppUnit::TestFixture
 public:
   void testSort() 
   { 
-    const Position from = Position(2,3);
-    const Position to   = Position(2,2);
+    const Square from = Square(2,3);
+    const Square to   = Square(2,2);
     
     const Move m1 = Move(from, to, ROOK, PTYPE_EMPTY, false, BLACK);
     const Move m2 = Move(from, to, SILVER, PTYPE_EMPTY, false, BLACK);
