@@ -34,7 +34,6 @@ public:
 
 using namespace osl;
 using namespace osl::ntesuki;
-extern bool isShortTest;
 
 typedef  NtesukiMoveGenerator movegen_t;
 
@@ -51,12 +50,12 @@ static void compare_simulation(SimpleState& sstate_orig,
     gam(new movegen_t());
 
   NtesukiSearcher searcher(state_orig, gam.get(),
-			   100000, &stop_flag, !isShortTest, ntesuki_correct + 1);
+			   100000, &stop_flag, OslConfig::verbose(), ntesuki_correct + 1);
   NtesukiTable& table = searcher.getTable();
 
   int ntesuki_num = 0;
   TRY_DFPN;
-  ntesuki_num = searcher.searchSlow(state_orig.getTurn());
+  ntesuki_num = searcher.searchSlow(state_orig.turn());
   CATCH_DFPN;
   CPPUNIT_ASSERT_EQUAL(ntesuki_correct,ntesuki_num);
 
@@ -67,7 +66,7 @@ static void compare_simulation(SimpleState& sstate_orig,
 
   NtesukiSimulationSearcher simulator(state, gam.get(), path,
 				      table, osl::ntesuki::NtesukiRecord::no_is,
-				      !isShortTest);
+				      OslConfig::verbose());
   NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					 PieceStand(WHITE, state), 0);
   NtesukiRecord::state = &state;
@@ -204,10 +203,10 @@ test1Tesuki0()
 
   NumEffectState state_orig(sstate_orig);
   NtesukiSearcher searcher(state_orig, gam.get(),
-			   10000000, &stop_flag, !isShortTest);
+			   10000000, &stop_flag, OslConfig::verbose());
   NtesukiTable& table = searcher.getTable();
 
-  const int ntesuki_num = searcher.searchSlow(state_orig.getTurn(), 20000000);
+  const int ntesuki_num = searcher.searchSlow(state_orig.turn(), 20000000);
   CPPUNIT_ASSERT_EQUAL(1, ntesuki_num);
   const NtesukiRecord* record_orig = table.allocateRoot(HashKey(state_orig),
 						      PieceStand(WHITE, state_orig), 0);
@@ -230,7 +229,7 @@ test1Tesuki0()
     NumEffectState state(sstate);
 
     NtesukiSimulationSearcher simulator(state, gam.get(), path,
-					table, osl::ntesuki::NtesukiRecord::no_is, !isShortTest);
+					table, osl::ntesuki::NtesukiRecord::no_is, OslConfig::verbose());
     NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					     PieceStand(WHITE, state), 0);
   
@@ -256,7 +255,7 @@ test1Tesuki0()
     NumEffectState state(sstate);
 
     NtesukiSimulationSearcher simulator(state, gam.get(), path,
-					table, osl::ntesuki::NtesukiRecord::no_is, !isShortTest);
+					table, osl::ntesuki::NtesukiRecord::no_is, OslConfig::verbose());
   
     NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					     PieceStand(WHITE, state), 0);
@@ -292,10 +291,10 @@ test1Tesuki1()
     "+\n").getInitialState();
   NumEffectState state_orig(sstate_orig);
   NtesukiSearcher searcher(state_orig, gam.get(),
-			   10000000, &stop_flag, !isShortTest);
+			   10000000, &stop_flag, OslConfig::verbose());
   NtesukiTable& table = searcher.getTable();
 
-  const int ntesuki_num = searcher.searchSlow(state_orig.getTurn(), 20000000);
+  const int ntesuki_num = searcher.searchSlow(state_orig.turn(), 20000000);
   CPPUNIT_ASSERT_EQUAL(1, ntesuki_num);
   const NtesukiRecord* record_orig = table.allocateRoot(HashKey(state_orig),
 						      PieceStand(WHITE, state_orig), 0);
@@ -317,7 +316,7 @@ test1Tesuki1()
     NumEffectState state(sstate);
 
     NtesukiSimulationSearcher simulator(state, gam.get(), path,
-					table, osl::ntesuki::NtesukiRecord::no_is, !isShortTest);
+					table, osl::ntesuki::NtesukiRecord::no_is, OslConfig::verbose());
     NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					     PieceStand(WHITE, state), 0);
     bool result = simulator.startFromAttackProof<BLACK>(record, record_orig,
@@ -342,7 +341,7 @@ test1Tesuki1()
     NumEffectState state(sstate);
 
     NtesukiSimulationSearcher simulator(state, gam.get(), path,
-					table, osl::ntesuki::NtesukiRecord::no_is, !isShortTest);
+					table, osl::ntesuki::NtesukiRecord::no_is, OslConfig::verbose());
     NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					     PieceStand(WHITE, state), 0);  
     bool result = simulator.startFromAttackProof<BLACK>(record, record_orig,
@@ -367,7 +366,7 @@ test1Tesuki1()
     NumEffectState state(sstate);
     
     NtesukiSimulationSearcher simulator(state, gam.get(), path,
-					table, osl::ntesuki::NtesukiRecord::no_is, !isShortTest);
+					table, osl::ntesuki::NtesukiRecord::no_is, OslConfig::verbose());
     NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					     PieceStand(WHITE, state), 0);    
     bool result = simulator.startFromAttackProof<BLACK>(record, record_orig,
@@ -392,7 +391,7 @@ test1Tesuki1()
     NumEffectState state(sstate);
     
     NtesukiSimulationSearcher simulator(state, gam.get(), path,
-					table, osl::ntesuki::NtesukiRecord::no_is, !isShortTest);
+					table, osl::ntesuki::NtesukiRecord::no_is, OslConfig::verbose());
     NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					     PieceStand(WHITE, state), 0);    
     bool result = simulator.startFromAttackProof<BLACK>(record, record_orig,
@@ -420,15 +419,15 @@ test0Tesuki0Fail()
     "+\n").getInitialState();
   NumEffectState state_orig(sstate_orig);
   NtesukiSearcher searcher(state_orig, gam.get(),
-			   100000, &stop_flag, !isShortTest, 1);
+			   100000, &stop_flag, OslConfig::verbose(), 1);
   NtesukiTable& table = searcher.getTable();
 
-  const int ntesuki_num = searcher.searchSlow(state_orig.getTurn());
+  const int ntesuki_num = searcher.searchSlow(state_orig.turn());
   CPPUNIT_ASSERT_EQUAL(-1, ntesuki_num);
   const NtesukiRecord* record_orig = table.allocateRoot(HashKey(state_orig),
 						      PieceStand(WHITE, state_orig), 0);
     
-  PathEncoding path(state_orig.getTurn());
+  PathEncoding path(state_orig.turn());
     
   {
     SimpleState sstate = CsaString(
@@ -446,7 +445,7 @@ test0Tesuki0Fail()
     NumEffectState state(sstate);
 
     NtesukiSimulationSearcher simulator(state, gam.get(), path,
-					table, osl::ntesuki::NtesukiRecord::no_is, !isShortTest);
+					table, osl::ntesuki::NtesukiRecord::no_is, OslConfig::verbose());
     NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					     PieceStand(WHITE, state), 0);  
     bool result = simulator.startFromAttackDisproof<BLACK>(record, record_orig,
@@ -471,7 +470,7 @@ test0Tesuki0Fail()
     NumEffectState state(sstate);
 
     NtesukiSimulationSearcher simulator(state, gam.get(), path,
-					table, osl::ntesuki::NtesukiRecord::no_is, !isShortTest);
+					table, osl::ntesuki::NtesukiRecord::no_is, OslConfig::verbose());
     NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					     PieceStand(WHITE, state), 0);  
     bool result = simulator.startFromAttackDisproof<BLACK>(record, record_orig,
@@ -500,15 +499,15 @@ test1Tesuki0Fail()
     "+\n").getInitialState();
   NumEffectState state_orig(sstate_orig);
   NtesukiSearcher searcher(state_orig, gam.get(),
-			   100000, &stop_flag, !isShortTest);
+			   100000, &stop_flag, OslConfig::verbose());
   NtesukiTable& table = searcher.getTable();
 
-  const int ntesuki_num = searcher.searchSlow(state_orig.getTurn());
+  const int ntesuki_num = searcher.searchSlow(state_orig.turn());
   CPPUNIT_ASSERT_EQUAL(-1, ntesuki_num);
   const NtesukiRecord* record_orig = table.allocateRoot(HashKey(state_orig),
 						      PieceStand(WHITE, state_orig), 0);
     
-  PathEncoding path(state_orig.getTurn());
+  PathEncoding path(state_orig.turn());
     
   {
     SimpleState sstate = CsaString(
@@ -526,7 +525,7 @@ test1Tesuki0Fail()
     NumEffectState state(sstate);
 
     NtesukiSimulationSearcher simulator(state, gam.get(), path,
-					table, osl::ntesuki::NtesukiRecord::no_is, !isShortTest);
+					table, osl::ntesuki::NtesukiRecord::no_is, OslConfig::verbose());
     NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					     PieceStand(WHITE, state), 0);  
     bool result = simulator.startFromAttackDisproof<BLACK>(record, record_orig,
@@ -551,7 +550,7 @@ test1Tesuki0Fail()
     NumEffectState state(sstate);
 
     NtesukiSimulationSearcher simulator(state, gam.get(), path,
-					table, osl::ntesuki::NtesukiRecord::no_is, !isShortTest);
+					table, osl::ntesuki::NtesukiRecord::no_is, OslConfig::verbose());
   
     NtesukiRecord* record = table.allocateRoot(HashKey(state),
 					     PieceStand(WHITE, state), 0);
