@@ -53,7 +53,6 @@ CPPUNIT_TEST_SUITE_REGISTRATION(ProofDisproofPieces);
 
 using namespace osl;
 using namespace osl::ntesuki;
-extern bool isShortTest;
 const size_t TABLE_LIMIT = 1000000;
 const size_t READ_LIMIT = 2000000;
 
@@ -79,9 +78,9 @@ void ProofDisproofPieces::test_proof0tesuki0()
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
   NumEffectState nState(state);
-  NtesukiSearcher searcher(nState, gam.get(),  TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(),  TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(0, ntesuki_num);
 
   HashKey key (state);
@@ -112,9 +111,9 @@ void ProofDisproofPieces::test_proof1tesuki0()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose());
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(1, ntesuki_num);
 
   HashKey key (state);
@@ -144,9 +143,9 @@ void ProofDisproofPieces::test_proof1tesuki1()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose());
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(1, ntesuki_num);
 
   HashKey key (state);
@@ -177,13 +176,13 @@ void ProofDisproofPieces::test_proof1tesuki2()
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
   NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT,
-			   &stop_flag, !isShortTest, 2,
+			   &stop_flag, OslConfig::verbose(), 2,
 			   osl::ntesuki::NtesukiRecord::pn_iw,
 			   osl::ntesuki::NtesukiRecord::no_ps,
 			   osl::ntesuki::NtesukiRecord::no_is,
 			   2);
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(1, ntesuki_num);
 
   HashKey key (state);
@@ -238,7 +237,7 @@ void ProofDisproofPieces::test_proof0tesuki1()
     boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
       gam(new movegen_t());
     NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT,
-			     &stop_flag, !isShortTest, 1);
+			     &stop_flag, OslConfig::verbose(), 1);
     
     const int ntesuki_num = searcher.searchSlow(osl::WHITE, READ_LIMIT);
     CPPUNIT_ASSERT_EQUAL(0, ntesuki_num);
@@ -278,7 +277,7 @@ void ProofDisproofPieces::test_proof0tesuki2()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
   const int ntesuki_num = searcher.searchSlow(BLACK, READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(0, ntesuki_num);
@@ -307,7 +306,7 @@ void ProofDisproofPieces::test_proof0tesuki2()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
   const int ntesuki_num = searcher.searchSlow(BLACK, READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(0, ntesuki_num);
@@ -337,7 +336,7 @@ void ProofDisproofPieces::test_proof0tesuki2()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
   const int ntesuki_num = searcher.searchSlow(BLACK, READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(0, ntesuki_num);
@@ -367,7 +366,7 @@ void ProofDisproofPieces::test_proof0tesuki2()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
   const int ntesuki_num = searcher.searchSlow(BLACK, READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(0, ntesuki_num);
@@ -398,9 +397,9 @@ void ProofDisproofPieces::test_proof0tesuki2()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(0, ntesuki_num);
 
   HashKey key (state);
@@ -431,9 +430,9 @@ void ProofDisproofPieces::test_proof0tesuki2()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(0, ntesuki_num);
 
   HashKey key (state);
@@ -481,13 +480,13 @@ void ProofDisproofPieces::test_proof1tesuki3()
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
   NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag,
-			   !isShortTest, 2,
+			   OslConfig::verbose(), 2,
 			   osl::ntesuki::NtesukiRecord::pn_iw,
 			   osl::ntesuki::NtesukiRecord::no_ps,
 			   osl::ntesuki::NtesukiRecord::no_is,
 			   2);
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(1, ntesuki_num);
 
   HashKey key (state);
@@ -522,13 +521,13 @@ void ProofDisproofPieces::test_proof1tesuki3()
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
   NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag,
-			   !isShortTest,2,
+			   OslConfig::verbose(),2,
 			   osl::ntesuki::NtesukiRecord::pn_iw,
 			   osl::ntesuki::NtesukiRecord::no_ps,
 			   osl::ntesuki::NtesukiRecord::no_is,
 			   2);
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(1, ntesuki_num);
 
   HashKey key (state);
@@ -562,13 +561,13 @@ void ProofDisproofPieces::test_proof1tesuki3()
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
   NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag,
-			   !isShortTest,2,
+			   OslConfig::verbose(),2,
 			   osl::ntesuki::NtesukiRecord::pn_iw,
 			   osl::ntesuki::NtesukiRecord::no_ps,
 			   osl::ntesuki::NtesukiRecord::no_is,
 			   2);
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(1, ntesuki_num);
 
   HashKey key (state);
@@ -606,10 +605,10 @@ void ProofDisproofPieces::test_proofKatagyoku0()
     gam(new movegen_t());
   NumEffectState nState(state);
   NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT,
-			   &stop_flag, !isShortTest);
+			   &stop_flag, OslConfig::verbose());
 
   const int ntesuki_num =
-    searcher.searchSlow(nState.getTurn());
+    searcher.searchSlow(nState.turn());
 
   CPPUNIT_ASSERT_EQUAL(1, ntesuki_num);
   HashKey key (state);
@@ -639,9 +638,9 @@ void ProofDisproofPieces::test_disproof0tesuki0()
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
   NumEffectState nState(state);
-  NtesukiSearcher searcher(nState, gam.get(),  TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(),  TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(-1, ntesuki_num);
 
   HashKey key (state);
@@ -671,9 +670,9 @@ void ProofDisproofPieces::test_disproof0tesuki1()
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
   NumEffectState nState(state);
-  NtesukiSearcher searcher(nState, gam.get(),  TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(),  TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(-1, ntesuki_num);
 
   HashKey key (state);
@@ -709,9 +708,9 @@ void ProofDisproofPieces::test_disproof1tesuki0()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose());
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(-1, ntesuki_num);
 
   HashKey key (state);
@@ -747,7 +746,7 @@ void ProofDisproofPieces::test_disproof1tesuki1()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose());
 
   const int ntesuki_num = searcher.searchSlow(BLACK, READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(-1, ntesuki_num);
@@ -786,9 +785,9 @@ void ProofDisproofPieces::test_disproof1tesuki1_1()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose());
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(-1, ntesuki_num);
 
   HashKey key (state);
@@ -825,9 +824,9 @@ void ProofDisproofPieces::test_disproof1tesuki1_2()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose());
 
-  const int ntesuki_num = searcher.searchSlow(nState.getTurn(), READ_LIMIT);
+  const int ntesuki_num = searcher.searchSlow(nState.turn(), READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(-1, ntesuki_num);
 
   HashKey key (state);
@@ -869,7 +868,7 @@ void ProofDisproofPieces::test_pdp_pieces0()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
   const int ntesuki_num = searcher.searchSlow(WHITE, READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(0, ntesuki_num);
@@ -901,7 +900,7 @@ void ProofDisproofPieces::test_pdp_pieces0()
   NumEffectState nState(state);
   boost::scoped_ptr<osl::ntesuki::NtesukiMoveGenerator>
     gam(new movegen_t());
-  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, !isShortTest, 1);
+  NtesukiSearcher searcher(nState, gam.get(), TABLE_LIMIT, &stop_flag, OslConfig::verbose(), 1);
 
   const int ntesuki_num = searcher.searchSlow(WHITE, READ_LIMIT);
   CPPUNIT_ASSERT_EQUAL(-1, ntesuki_num);
