@@ -24,6 +24,7 @@ class PieceTest : public CppUnit::TestFixture
   CPPUNIT_TEST(testPromote);
   CPPUNIT_TEST(testCanMoveOn);
   CPPUNIT_TEST(testPieceMask);
+  CPPUNIT_TEST(testIsPlayerPtype);
   CPPUNIT_TEST_SUITE_END();
  public:
   void testSize();
@@ -37,6 +38,7 @@ class PieceTest : public CppUnit::TestFixture
   void testPromote();
   void testCanMoveOn();
   void testPieceMask();
+  void testIsPlayerPtype();
 };
 
 using namespace osl;
@@ -257,6 +259,69 @@ void PieceTest::testPieceMask(){
   for(int i=30;i<40;i++)
     CPPUNIT_ASSERT(pm.test(i));
 }
+void PieceTest::testIsPlayerPtype(){
+  for(int pi=0;pi<2;pi++){
+    for(int ptypei=PTYPE_PIECE_MIN;ptypei<=PTYPE_MAX;ptypei++){
+      Ptype ptype=(Ptype)ptypei;
+      Player pl=indexToPlayer(pi);
+      CPPUNIT_ASSERT(!Piece::EMPTY().isPlayerPtype(pl,ptype));
+      CPPUNIT_ASSERT(!Piece::EDGE().isPlayerPtype(pl,ptype));
+      if(isBasic(ptype)){
+	CPPUNIT_ASSERT(!Piece::EMPTY().isPlayerBasicPtype(pl,ptype));
+	CPPUNIT_ASSERT(!Piece::EDGE().isPlayerBasicPtype(pl,ptype));
+      }
+      for(int num=0;num<40;num++){
+	{
+	  Piece p(pl,(Ptype)ptype,num,Square::STAND());
+	  for(int pi1=0;pi1<2;pi1++){
+	    Player pl1=indexToPlayer(pi1);
+	    for(int ptypei1=PTYPE_PIECE_MIN;ptypei1<=PTYPE_MAX;ptypei1++){
+	      Ptype ptype1=(Ptype)ptypei1;
+	      if(pl==pl1 && ptype==ptype1){
+		CPPUNIT_ASSERT(p.isPlayerPtype(pl1,ptype1));
+	      }
+	      else{
+		CPPUNIT_ASSERT(!p.isPlayerPtype(pl1,ptype1));
+	      }
+	      if(isBasic(ptype1)){
+		if(pl==pl1 && unpromote(ptype)==ptype1){
+		  CPPUNIT_ASSERT(p.isPlayerBasicPtype(pl1,ptype1));
+		}
+		else{
+		  CPPUNIT_ASSERT(!p.isPlayerBasicPtype(pl1,ptype1));
+		}
+	      }
+	    }
+	  }
+	  for(int x=1;x<=9;x++)
+	    for(int y=1;y<=9;y++){
+	      Piece p(pl,(Ptype)ptype,num,Square(x,y));
+	      for(int pi1=0;pi1<2;pi1++){
+		Player pl1=indexToPlayer(pi1);
+		for(int ptypei1=PTYPE_PIECE_MIN;ptypei1<=PTYPE_MAX;ptypei1++){
+		  Ptype ptype1=(Ptype)ptypei1;
+		  if(pl==pl1 && ptype==ptype1){
+		    CPPUNIT_ASSERT(p.isPlayerPtype(pl1,ptype1));
+		  }
+		  else{
+		    CPPUNIT_ASSERT(!p.isPlayerPtype(pl1,ptype1));
+		  }
+		  if(isBasic(ptype1)){
+		    if(pl==pl1 && unpromote(ptype)==ptype1){
+		      CPPUNIT_ASSERT(p.isPlayerBasicPtype(pl1,ptype1));
+		    }
+		    else{
+		      CPPUNIT_ASSERT(!p.isPlayerBasicPtype(pl1,ptype1));
+		    }
+		  }
+		}
+	      }
+	    }
+	}
+      }
+    }
+  }
+}
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
