@@ -1,9 +1,9 @@
 #include "osl/player.h"
+#include "osl/oslConfig.h"
 #include <iostream>
 #include <cppunit/TestCase.h>
 #include <cppunit/extensions/HelperMacros.h>
 using namespace osl;
-extern bool isShortTest;
 
 class playerTest : public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE( playerTest );
@@ -24,7 +24,7 @@ void playerTest::testAlt(){
 }
 
 void playerTest::testShow(){
-  if (! isShortTest)
+  if (OslConfig::verbose())
   {
     std::cout << BLACK << std::endl;
     std::cout << WHITE << std::endl;
