@@ -2,7 +2,6 @@
  */
 
 #include "osl/progress/ptypeProgress.h"
-#include "osl/apply_move/applyMove.h"
 #include "osl/state/numEffectState.h"
 #include "osl/record/csaRecord.h"
 #include "osl/oslConfig.h"
@@ -28,18 +27,15 @@ using namespace osl::progress;
 
 void PtypeProgressTest::testConsistent()
 {
-  extern bool isShortTest;
   std::ifstream ifs(OslConfig::testCsaFile("FILES"));
   CPPUNIT_ASSERT(ifs);
   int max=100;
-  if (isShortTest)
+  if (OslConfig::inUnitTestShort())
       max=10;
   std::string filename;
   int i=0;
   while((ifs >> filename) && (++i<max)) 
   {
-    if (! isShortTest)
-      std::cerr << filename << " ";
     std::string full_filename = OslConfig::testCsaFile(filename);
 
     Record rec=CsaFile(full_filename).getRecord();
@@ -48,7 +44,7 @@ void PtypeProgressTest::testConsistent()
     PtypeProgress incremental(state);
     for (size_t i=0; i<moves.size(); ++i)
     {
-      ApplyMoveOfTurn::doMove(state, moves[i]);
+      state.makeMove(moves[i]);
       incremental.update(state, moves[i]);
       const PtypeProgress batch(state);
       CPPUNIT_ASSERT_EQUAL(incremental, batch);
