@@ -35,9 +35,9 @@ void PatternLongTest::testNextPieceOrEnd()
 			 "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
 			 "+\n").getInitialState());
   const Piece piece 
-    = PatternLong::nextPieceOrEnd(state, Position(6,6), 
-				  Board_Table.getShortOffset(Offset32(Position(6,6), Position(2,2)))).first;
-  CPPUNIT_ASSERT_EQUAL(state.getPieceOnBoard(Position(8,8)), piece);
+    = PatternLong::nextPieceOrEnd(state, Square(6,6), 
+				  Board_Table.getShortOffset(Offset32(Square(6,6), Square(2,2)))).first;
+  CPPUNIT_ASSERT_EQUAL(state.pieceOnBoard(Square(8,8)), piece);
 }
 // ;;; Local Variables:
 // ;;; mode:c++
