@@ -20,8 +20,8 @@ using namespace osl::rating;
 
 void RatedMoveVectorTest::testSort()
 {
-  RatedMove a(Move(Position(5,5),GOLD,BLACK), 200, 200);
-  RatedMove b(Move(Position(5,5),SILVER,BLACK), 100, 100);
+  RatedMove a(Move(Square(5,5),GOLD,BLACK), 200, 200);
+  RatedMove b(Move(Square(5,5),SILVER,BLACK), 100, 100);
   {
     RatedMoveVector v;
     v.push_back(a);
