@@ -20,13 +20,13 @@ using namespace osl::record;
 
 void KanjiMoveTest::testMove()
 {
-  const static std::string str_b26fu     = K_BLACK_SIGN + K_R2 + K_K6 + K_PAWN;
-  const static std::string str_w84fu     = K_WHITE_SIGN + K_R8 + K_K4 + K_PAWN;
-  const static std::string str_b25fu     = K_BLACK_SIGN + K_R2 + K_K5 + K_PAWN;
-  const static std::string str_w85fu     = K_WHITE_SIGN + K_R8 + K_K5 + K_PAWN;
-  const static std::string str_b24fu     = K_BLACK_SIGN + K_R2 + K_K4 + K_PAWN;
-  const static std::string str_wdofu     = K_WHITE_SIGN + K_ONAZI + K_SPACE + K_PAWN;
-  const static std::string str_b58kimigi = K_BLACK_SIGN + K_R5 + K_K8 + K_GOLD + K_MIGI;
+  const static std::string str_b26fu     = K_BLACK_SIGN K_R2 K_K6 K_PAWN;
+  const static std::string str_w84fu     = K_WHITE_SIGN K_R8 K_K4 K_PAWN;
+  const static std::string str_b25fu     = K_BLACK_SIGN K_R2 K_K5 K_PAWN;
+  const static std::string str_w85fu     = K_WHITE_SIGN K_R8 K_K5 K_PAWN;
+  const static std::string str_b24fu     = K_BLACK_SIGN K_R2 K_K4 K_PAWN;
+  const static std::string str_wdofu     = K_WHITE_SIGN K_ONAZI K_SPACE K_PAWN;
+  const static std::string str_b58kimigi = K_BLACK_SIGN K_R5 K_K8 K_GOLD K_MIGI;
   
   KanjiMove kmove;
   NumEffectState state((SimpleState(HIRATE)));
