@@ -32,7 +32,7 @@ void Ki2Test::testShow()
     const NumEffectState state;
     const Move move(Square(7,7), Square(7,6), PAWN, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K6+K_PAWN, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R7 K_K6 K_PAWN), 
 			 record::ki2::show(move, state));
   }
   {
@@ -52,41 +52,41 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m82y(Square(7,2), Square(8,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_GOLD+K_UE, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K2 K_GOLD K_UE), 
 			 record::ki2::show(m82u, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_GOLD+K_YORU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K2 K_GOLD K_YORU), 
 			 record::ki2::show(m82y, state));
     const Move m52h(Square(5,1), Square(5,2), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
     const Move m52u(Square(6,3), Square(5,2), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_PPAWN+K_HIKU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K2 K_PPAWN K_HIKU), 
 			 record::ki2::show(m52h, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_PPAWN+K_UE, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K2 K_PPAWN K_UE), 
 			 record::ki2::show(m52u, state));
     const Move m53y(Square(6,3), Square(5,3), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
     const Move m53u(Square(5,4), Square(5,3), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K3+K_PPAWN+K_YORU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K3 K_PPAWN K_YORU), 
 			 record::ki2::show(m53y, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K3+K_PPAWN+K_UE, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K3 K_PPAWN K_UE), 
 			 record::ki2::show(m53u, state));
     const Move m76h(Square(6,5), Square(7,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
     const Move m76u(Square(7,7), Square(7,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K6+K_SILVER+K_HIKU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R7 K_K6 K_SILVER K_HIKU), 
 			 record::ki2::show(m76h, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K6+K_SILVER+K_UE, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R7 K_K6 K_SILVER K_UE), 
 			 record::ki2::show(m76u, state));
     const Move m56h(Square(6,5), Square(5,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
     const Move m56u(Square(4,7), Square(5,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K6+K_SILVER+K_HIKU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K6 K_SILVER K_HIKU), 
 			 record::ki2::show(m56h, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K6+K_SILVER+K_UE, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K6 K_SILVER K_UE), 
 			 record::ki2::show(m56u, state));
   }
   {
@@ -106,41 +106,41 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m81r(Square(7,2), Square(8,1), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K1+K_GOLD+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K1 K_GOLD K_HIDARI), 
 			 record::ki2::show(m81l, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K1+K_GOLD+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K1 K_GOLD K_MIGI), 
 			 record::ki2::show(m81r, state));
     const Move m82l(Square(9,2), Square(8,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
     const Move m82r(Square(7,2), Square(8,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_GOLD+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K2 K_GOLD K_HIDARI), 
 			 record::ki2::show(m82l, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_GOLD+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K2 K_GOLD K_MIGI), 
 			 record::ki2::show(m82r, state));
     const Move m56l(Square(6,5), Square(5,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
     const Move m56r(Square(4,5), Square(5,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K6+K_SILVER+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K6 K_SILVER K_HIDARI), 
 			 record::ki2::show(m56l, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K6+K_SILVER+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K6 K_SILVER K_MIGI), 
 			 record::ki2::show(m56r, state));
     const Move m78l(Square(8,9), Square(7,8), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
     const Move m78s(Square(7,9), Square(7,8), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K8+K_GOLD+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R7 K_K8 K_GOLD K_HIDARI), 
 			 record::ki2::show(m78l, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K8+K_GOLD+K_SUGU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R7 K_K8 K_GOLD K_SUGU), 
 			 record::ki2::show(m78s, state));
     const Move m38s(Square(3,9), Square(3,8), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
     const Move m38r(Square(2,9), Square(3,8), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R3+K_K8+K_SILVER+K_SUGU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R3 K_K8 K_SILVER K_SUGU), 
 			 record::ki2::show(m38s, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R3+K_K8+K_SILVER+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R3 K_K8 K_SILVER K_MIGI), 
 			 record::ki2::show(m38r, state));
   }
   {
@@ -162,11 +162,11 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m52r(Square(4,3), Square(5,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_GOLD+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K2 K_GOLD K_HIDARI), 
 			 record::ki2::show(m52l, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_GOLD+K_SUGU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K2 K_GOLD K_SUGU), 
 			 record::ki2::show(m52s, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_GOLD+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K2 K_GOLD K_MIGI), 
 			 record::ki2::show(m52r, state));
     const Move m88r(Square(7,9), Square(8,8), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
@@ -178,15 +178,15 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m88lu(Square(9,9), Square(8,8), PPAWN, 
 		     PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K8+K_PPAWN+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K8 K_PPAWN K_MIGI), 
 			 record::ki2::show(m88r, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K8+K_PPAWN+K_SUGU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K8 K_PPAWN K_SUGU), 
 			 record::ki2::show(m88s, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K8+K_PPAWN+K_YORU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K8 K_PPAWN K_YORU), 
 			 record::ki2::show(m88y, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K8+K_PPAWN+K_HIKU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K8 K_PPAWN K_HIKU), 
 			 record::ki2::show(m88h, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K8+K_PPAWN+K_HIDARI+K_UE, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K8 K_PPAWN K_HIDARI K_UE), 
 			 record::ki2::show(m88lu, state));
     const Move m28s(Square(2,9), Square(2,8), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
@@ -196,13 +196,13 @@ void Ki2Test::testShow()
 		     PTYPE_EMPTY, false, BLACK);
     const Move m28lh(Square(3,7), Square(2,8), SILVER, 
 		     PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R2+K_K8+K_SILVER+K_SUGU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R2 K_K8 K_SILVER K_SUGU), 
 			 record::ki2::show(m28s, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R2+K_K8+K_SILVER+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R2 K_K8 K_SILVER K_MIGI), 
 			 record::ki2::show(m28r, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R2+K_K8+K_SILVER+K_HIDARI+K_UE, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R2 K_K8 K_SILVER K_HIDARI K_UE), 
 			 record::ki2::show(m28lu, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R2+K_K8+K_SILVER+K_HIDARI+K_HIKU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R2 K_K8 K_SILVER K_HIDARI K_HIKU), 
 			 record::ki2::show(m28lh, state));
   }
   {
@@ -222,9 +222,9 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m82u(Square(8,4), Square(8,2), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_PROOK+K_HIKU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K2 K_PROOK K_HIKU), 
 			 record::ki2::show(m82h, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_PROOK+K_UE, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K2 K_PROOK K_UE), 
 			 record::ki2::show(m82u, state));
   }
   {
@@ -244,9 +244,9 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m43h(Square(5,2), Square(4,3), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R4+K_K3+K_PROOK+K_YORU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R4 K_K3 K_PROOK K_YORU), 
 			 record::ki2::show(m43y, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R4+K_K3+K_PROOK+K_HIKU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R4 K_K3 K_PROOK K_HIKU), 
 			 record::ki2::show(m43h, state));
   }
   {
@@ -266,9 +266,9 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m43l(Square(5,3), Square(4,3), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R4+K_K3+K_PROOK+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R4 K_K3 K_PROOK K_MIGI), 
 			 record::ki2::show(m43r, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R4+K_K3+K_PROOK+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R4 K_K3 K_PROOK K_HIDARI), 
 			 record::ki2::show(m43l, state));
   }
   {
@@ -288,9 +288,9 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m88r(Square(8,9), Square(8,8), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K8+K_PROOK+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K8 K_PROOK K_HIDARI), 
 			 record::ki2::show(m88l, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K8+K_PROOK+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K8 K_PROOK K_MIGI), 
 			 record::ki2::show(m88r, state));
   }
   {
@@ -310,17 +310,17 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m17r(Square(1,9), Square(1,7), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R1+K_K7+K_PROOK+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R1 K_K7 K_PROOK K_HIDARI), 
 			 record::ki2::show(m17l, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R1+K_K7+K_PROOK+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R1 K_K7 K_PROOK K_MIGI), 
 			 record::ki2::show(m17r, state));
     const Move m82l(Square(9,1), Square(8,2), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
     const Move m82r(Square(8,1), Square(8,2), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_PBISHOP+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K2 K_PBISHOP K_HIDARI), 
 			 record::ki2::show(m82l, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_PBISHOP+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K2 K_PBISHOP K_MIGI), 
 			 record::ki2::show(m82r, state));
   }
   {
@@ -340,9 +340,9 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m85h(Square(6,3), Square(8,5), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K5+K_PBISHOP+K_YORU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K5 K_PBISHOP K_YORU), 
 			 record::ki2::show(m85y, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K5+K_PBISHOP+K_HIKU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R8 K_K5 K_PBISHOP K_HIKU), 
 			 record::ki2::show(m85h, state));
   }
   {
@@ -362,9 +362,9 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m12u(Square(3,4), Square(1,2), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R1+K_K2+K_PBISHOP+K_HIKU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R1 K_K2 K_PBISHOP K_HIKU), 
 			 record::ki2::show(m12h, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R1+K_K2+K_PBISHOP+K_UE, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R1 K_K2 K_PBISHOP K_UE), 
 			 record::ki2::show(m12u, state));
   }
   {
@@ -384,9 +384,9 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m77r(Square(5,9), Square(7,7), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K7+K_PBISHOP+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R7 K_K7 K_PBISHOP K_HIDARI), 
 			 record::ki2::show(m77l, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K7+K_PBISHOP+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R7 K_K7 K_PBISHOP K_MIGI), 
 			 record::ki2::show(m77r, state));
   }
   {
@@ -406,9 +406,9 @@ void Ki2Test::testShow()
 		    PTYPE_EMPTY, false, BLACK);
     const Move m29r(Square(1,8), Square(2,9), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R2+K_K9+K_PBISHOP+K_HIDARI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R2 K_K9 K_PBISHOP K_HIDARI), 
 			 record::ki2::show(m29l, state));
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R2+K_K9+K_PBISHOP+K_MIGI, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R2 K_K9 K_PBISHOP K_MIGI), 
 			 record::ki2::show(m29r, state));
   }
   {
@@ -425,7 +425,7 @@ void Ki2Test::testShow()
 			   "P+00AL\n"
 			   "-\n").getInitialState());
     const Move m33ke(Square(3,3), KNIGHT, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R3+K_K3+K_KNIGHT, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R3 K_K3 K_KNIGHT), 
 			 record::ki2::show(m33ke, state));
   }
   {
@@ -444,7 +444,7 @@ void Ki2Test::testShow()
 			   "-\n").getInitialState());
     const Move m57kn(Square(4,5), Square(5,7), 
 		     PKNIGHT, PTYPE_EMPTY, true, WHITE);
-    CPPUNIT_ASSERT_EQUAL(K_WHITE_SIGN+K_R5+K_K7+K_KNIGHT+K_HIDARI+K_NARU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_WHITE_SIGN K_R5 K_K7 K_KNIGHT K_HIDARI K_NARU), 
 			 record::ki2::show(m57kn, state));
   }
   {
@@ -463,7 +463,7 @@ void Ki2Test::testShow()
 			   "+\n").getInitialState());
     const Move m52funari(Square(5,3), Square(5,2), 
 		     PPAWN, PTYPE_EMPTY, true, BLACK);
-    CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_PAWN+K_NARU, 
+    CPPUNIT_ASSERT_EQUAL(std::string(K_BLACK_SIGN K_R5 K_K2 K_PAWN K_NARU), 
 			 record::ki2::show(m52funari, state));
   }
 }
