@@ -10,6 +10,18 @@
 #include <cppunit/extensions/HelperMacros.h>
 #include <boost/foreach.hpp>
 
+#ifdef __APPLE__
+// avoid problems observed in imac with g++ 4.6.2 + cppunit 1.12.1
+#  undef CPPUNIT_ASSERT_EQUAL
+#  define CPPUNIT_ASSERT_EQUAL(a,b) assert((a)==(b))
+#  undef CPPUNIT_ASSERT
+#  define CPPUNIT_ASSERT(x) assert(x)
+#  undef CPPUNIT_ASSERT_NO_THROW
+#  define CPPUNIT_ASSERT_NO_THROW(x) do {try { (x); } catch (...){assert(0);}}while(0)
+#  undef CPPUNIT_ASSERT_THROW
+#  define CPPUNIT_ASSERT_THROW(x,e) do {try { (x); assert(0);} catch (e&){} catch(...){assert(0);}}while(0)
+#endif
+
 class UsiTest : public CppUnit::TestFixture 
 {
   CPPUNIT_TEST_SUITE(UsiTest);
@@ -51,6 +63,10 @@ void UsiTest::testMove()
 
   const Move m76fu2 = usi::strToMove(usi76fu, state);
   CPPUNIT_ASSERT_EQUAL(m76fu, m76fu2);
+
+  const std::string usi_win = "win";
+  const Move win = usi::strToMove(usi_win, state);
+  CPPUNIT_ASSERT_EQUAL(win, Move::DeclareWin());
 }
 
 void UsiTest::testParseBoard()
