@@ -3,9 +3,8 @@
 #ifndef _RECURSIVEDOUNDOMOVE_H
 #define _RECURSIVEDOUNDOMOVE_H
 
-#include "osl/position.h"
+#include "osl/square.h"
 #include "osl/move.h"
-#include "osl/apply_move/applyMove.h"
 #include <cppunit/extensions/HelperMacros.h>
 #include <cstddef>
 #include <iostream>
@@ -24,11 +23,11 @@ namespace osl
     {
       *depth+=1;
     }
-    void operator()(Position lastTo);
+    void operator()(Square lastTo);
   };
 
   template <Player P,class State>
-  void RecursiveDoUndoMove<P,State>::operator()(Position lastTo)
+  void RecursiveDoUndoMove<P,State>::operator()(Square lastTo)
   {
     CPPUNIT_ASSERT_EQUAL(cur->to(), lastTo);
     CPPUNIT_ASSERT(state.isConsistent(true) ||
@@ -40,8 +39,7 @@ namespace osl
     CPPUNIT_ASSERT(state.isValidMove(*cur));
     typedef RecursiveDoUndoMove<PlayerTraits<P>::opponent,State> next_t;
     next_t nextCall(state, cur,last, depth);
-    ApplyMove<PlayerTraits<P>::opponent>::doUndoMove
-      (state, *cur,nextCall);
+    state.makeUnmakeMove(*cur,nextCall);
     CPPUNIT_ASSERT(state.isConsistent(true));
     CPPUNIT_ASSERT_EQUAL(state, backupState);
   }
