@@ -26,12 +26,12 @@ void osl::search::LRUMovesTest::testSetMove()
   CPPUNIT_ASSERT_EQUAL(Move::INVALID(), moves[0]);
   CPPUNIT_ASSERT_EQUAL(Move::INVALID(), moves[1]);
 
-  const Move m24ki(Position(2,4), GOLD, BLACK);
+  const Move m24ki(Square(2,4), GOLD, BLACK);
   moves.setMove(m24ki);
   CPPUNIT_ASSERT_EQUAL(m24ki, moves[0]);
   CPPUNIT_ASSERT_EQUAL(Move::INVALID(), moves[1]);
 
-  const Move m24fu(Position(2,4), PAWN, BLACK);
+  const Move m24fu(Square(2,4), PAWN, BLACK);
   moves.setMove(m24fu);
   CPPUNIT_ASSERT_EQUAL(m24fu, moves[0]);
   CPPUNIT_ASSERT_EQUAL(m24ki, moves[1]);
