@@ -109,7 +109,7 @@ void QuiescenceGeneratorTest::testEscapeFromLastMove()
 			   "P-00GI00FU00FU\n"
 			   "-\n").getInitialState());
     MoveVector moves;
-    Move last_move(Position(8,7),PAWN,BLACK);
+    Move last_move(Square(8,7),PAWN,BLACK);
     QuiescenceGenerator<WHITE>::escapeFromLastMove<PieceEval>(state, last_move, moves);
     // 角逃げろ
     CPPUNIT_ASSERT_EQUAL((size_t)6, moves.size());     
@@ -129,7 +129,7 @@ void QuiescenceGeneratorTest::testEscapeFromLastMove()
 			   "P-00KI00FU00FU\n"
 			   "-\n").getInitialState());
     MoveVector moves;
-    Move last_move(Position(8,6),LANCE,BLACK);
+    Move last_move(Square(8,6),LANCE,BLACK);
     QuiescenceGenerator<WHITE>::escapeFromLastMove<PieceEval>(state, last_move, moves);
     // 飛車逃げろ
     CPPUNIT_ASSERT_EQUAL((size_t)2, moves.size()); // 95,55
@@ -149,9 +149,9 @@ void QuiescenceGeneratorTest::testEscapeFromLastMove()
            "P-00FU00FU00FU00FU\n"
 	   "+\n").getInitialState());
     MoveVector moves;
-    const Move last_move(Position(5,4),ROOK,WHITE);
+    const Move last_move(Square(5,4),ROOK,WHITE);
     QuiescenceGenerator<BLACK>::escapeFromLastMove<PieceEval>(state, last_move, moves);
-    const Move m56fu(Position(5,6),PAWN,BLACK);
+    const Move m56fu(Square(5,6),PAWN,BLACK);
     CPPUNIT_ASSERT(moves.isMember(m56fu)); 
   }
   {
@@ -168,9 +168,9 @@ void QuiescenceGeneratorTest::testEscapeFromLastMove()
 			   "P-00KA00FU00FU00FU\n"
 			   "-\n").getInitialState());
     MoveVector moves;
-    const Move last_move(Position(2,2),BISHOP,BLACK);
+    const Move last_move(Square(2,2),BISHOP,BLACK);
     QuiescenceGenerator<WHITE>::escapeFromLastMove<PieceEval>(state, last_move, moves);
-    const Move m33ka(Position(3,3),BISHOP,WHITE);
+    const Move m33ka(Square(3,3),BISHOP,WHITE);
     CPPUNIT_ASSERT(moves.isMember(m33ka)); 
   }
 }
@@ -257,10 +257,10 @@ void QuiescenceGeneratorTest::testCheckPin()
 			   "P-00KI00KE00FU\n"
 			   "-\n").getInitialState());
     MoveVector moves;
-    const PieceMask pins = effect_util::Pin::make(state,Position(8,8),BLACK);
+    const PieceMask pins = effect_util::Pin::make(state,Square(8,8),BLACK);
     QuiescenceGenerator<WHITE>::check(state, pins, moves);
     // △7七金で負け
-    const Move m77ki(Position(7,7),GOLD,WHITE);
+    const Move m77ki(Square(7,7),GOLD,WHITE);
     CPPUNIT_ASSERT(moves.isMember(m77ki)); 
   }
 }
@@ -283,7 +283,7 @@ void QuiescenceGeneratorTest::testCheck()
 			   "-\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<WHITE>::check(state, PieceMask(), moves);
-    const Move m86ki(Position(8,6), GOLD, WHITE);
+    const Move m86ki(Square(8,6), GOLD, WHITE);
     CPPUNIT_ASSERT(moves.isMember(m86ki));
   }
   {
@@ -358,7 +358,7 @@ void QuiescenceGeneratorTest::testCheck()
 			   "P-00AL\n"
 			   "-\n").getInitialState());
     MoveVector moves;
-    const PieceMask pins = effect_util::Pin::make(state, Position(8,2), WHITE);
+    const PieceMask pins = effect_util::Pin::make(state, Square(8,2), WHITE);
     QuiescenceGenerator<BLACK>::check(state, pins, moves, false); // 71GI
     CPPUNIT_ASSERT_EQUAL((size_t)1, moves.size());
   }
@@ -452,7 +452,7 @@ void QuiescenceGeneratorTest::testEscape()
 	   "+\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<BLACK>::escapeAll(state, moves);
-    const Move m56fu(Position(5,6),PAWN,BLACK);
+    const Move m56fu(Square(5,6),PAWN,BLACK);
     CPPUNIT_ASSERT(moves.isMember(m56fu)); 
   }
 }
@@ -522,12 +522,12 @@ void QuiescenceGeneratorTest::testAttackMajorPiece()
     MoveVector moves;
     QuiescenceGenerator<WHITE>::attackMajorPiece(state, PieceMask(), moves);
     CPPUNIT_ASSERT_EQUAL((size_t)6, moves.size());
-// Drop(-,PAWN,Position(36)) これを作るかどうかは微妙
-// Drop(-,PAWN,Position(37))
-// Drop(-,SILVER,Position(27))
-// Drop(-,SILVER,Position(49))
-// Drop(-,SILVER,Position(44))
-// Drop(-,SILVER,Position(26))
+// Drop(-,PAWN,Square(36)) これを作るかどうかは微妙
+// Drop(-,PAWN,Square(37))
+// Drop(-,SILVER,Square(27))
+// Drop(-,SILVER,Square(49))
+// Drop(-,SILVER,Square(44))
+// Drop(-,SILVER,Square(26))
   }
   {
     NumEffectState state(CsaString(
@@ -545,7 +545,7 @@ void QuiescenceGeneratorTest::testAttackMajorPiece()
 			   "-\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<WHITE>::attackMajorPiece(state, PieceMask(), moves);
-    const Move m62gi(Position(6,2), SILVER, WHITE);
+    const Move m62gi(Square(6,2), SILVER, WHITE);
     CPPUNIT_ASSERT(moves.isMember(m62gi));
   }
   {
@@ -584,7 +584,7 @@ void QuiescenceGeneratorTest::testAttackMajorPiece()
     // 仕留められる
     MoveVector moves;
     QuiescenceGenerator<BLACK>::attackMajorPiece(state, PieceMask(), moves);
-    const Move m22ki(Position(2,2), GOLD, BLACK);
+    const Move m22ki(Square(2,2), GOLD, BLACK);
     CPPUNIT_ASSERT(moves.isMember(m22ki));
   }
   {
@@ -602,7 +602,7 @@ void QuiescenceGeneratorTest::testAttackMajorPiece()
 			   "+\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<BLACK>::attackMajorPiece(state, PieceMask(), moves);
-    const Move m65gi(Position(6,6), Position(6,5), SILVER, PTYPE_EMPTY, false, BLACK);
+    const Move m65gi(Square(6,6), Square(6,5), SILVER, PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT(moves.isMember(m65gi));
   }
   {
@@ -621,7 +621,7 @@ void QuiescenceGeneratorTest::testAttackMajorPiece()
 			   "+\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<BLACK>::attackMajorPiece(state, PieceMask(), moves);
-    const Move m42um(Position(8,6), Position(4,2), PBISHOP, PTYPE_EMPTY, true, BLACK);
+    const Move m42um(Square(8,6), Square(4,2), PBISHOP, PTYPE_EMPTY, true, BLACK);
     CPPUNIT_ASSERT(moves.isMember(m42um));
   }
   {
@@ -640,8 +640,8 @@ void QuiescenceGeneratorTest::testAttackMajorPiece()
 			   "+\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<BLACK>::attackMajorPiece(state, PieceMask(), moves);
-    const Move m52gi(Position(5,2), SILVER, BLACK);
-    const Move m82um(Position(7,1), Position(8,2), PBISHOP, PTYPE_EMPTY, false, BLACK);
+    const Move m52gi(Square(5,2), SILVER, BLACK);
+    const Move m82um(Square(7,1), Square(8,2), PBISHOP, PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT(! moves.isMember(m82um));
     CPPUNIT_ASSERT(moves.isMember(m52gi));
   }
@@ -661,7 +661,7 @@ void QuiescenceGeneratorTest::testAttackMajorPiece()
 			   "+\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<BLACK>::attackMajorPiece(state, PieceMask(), moves);
-    const Move m84fu(Position(8,5), Position(8,4), PAWN, PTYPE_EMPTY, false, BLACK);
+    const Move m84fu(Square(8,5), Square(8,4), PAWN, PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT(moves.isMember(m84fu));
   }
 }
@@ -702,9 +702,9 @@ void QuiescenceGeneratorTest::testAttackGoldWithPawn()
 			   "+\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<BLACK>::attackGoldWithPawn(state, PieceMask(), moves);
-    const Move m53ky(Position(5,3), LANCE, BLACK);
-    const Move m53gi(Position(5,3), SILVER, BLACK);
-    const Move m44ke(Position(4,4), KNIGHT, BLACK);
+    const Move m53ky(Square(5,3), LANCE, BLACK);
+    const Move m53gi(Square(5,3), SILVER, BLACK);
+    const Move m44ke(Square(4,4), KNIGHT, BLACK);
     CPPUNIT_ASSERT(moves.isMember(m53ky));
     CPPUNIT_ASSERT(moves.isMember(m53gi));
     CPPUNIT_ASSERT(moves.isMember(m44ke));
@@ -724,8 +724,8 @@ void QuiescenceGeneratorTest::testAttackGoldWithPawn()
 			   "-\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<WHITE>::attackGoldWithPawn(state, PieceMask(), moves);
-    const Move m47ke(Position(4,7), KNIGHT, WHITE);
-    const Move m27ke(Position(1,5), Position(2,7), KNIGHT, PTYPE_EMPTY, false, WHITE);
+    const Move m47ke(Square(4,7), KNIGHT, WHITE);
+    const Move m27ke(Square(1,5), Square(2,7), KNIGHT, PTYPE_EMPTY, false, WHITE);
     CPPUNIT_ASSERT(moves.isMember(m47ke));
     CPPUNIT_ASSERT(moves.isMember(m27ke));
   }
@@ -745,7 +745,7 @@ void QuiescenceGeneratorTest::testAttackGoldWithPawn()
 			   "+\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<BLACK>::attackGoldWithPawn(state, PieceMask(), moves);
-    const Move m64ky(Position(6,4), LANCE, BLACK);
+    const Move m64ky(Square(6,4), LANCE, BLACK);
     CPPUNIT_ASSERT(moves.isMember(m64ky));
   }
   {
@@ -764,7 +764,7 @@ void QuiescenceGeneratorTest::testAttackGoldWithPawn()
 			   "-\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<WHITE>::attackGoldWithPawn(state, PieceMask(), moves);
-    const Move m45ke(Position(4,5), KNIGHT, WHITE);
+    const Move m45ke(Square(4,5), KNIGHT, WHITE);
     
     CPPUNIT_ASSERT(moves.isMember(m45ke));
   }
@@ -788,13 +788,13 @@ void QuiescenceGeneratorTest::testAttackSilverWithPawn()
 			   "+\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<BLACK>::attackSilverWithPawn(state, PieceMask(), moves);
-    const Move m53ky(Position(5,3), LANCE, BLACK);
-    const Move m44ke(Position(4,4), KNIGHT, BLACK);
+    const Move m53ky(Square(5,3), LANCE, BLACK);
+    const Move m44ke(Square(4,4), KNIGHT, BLACK);
     CPPUNIT_ASSERT(moves.isMember(m53ky));
     CPPUNIT_ASSERT(moves.isMember(m44ke));
 
-    const Move m23ky(Position(2,3), LANCE, BLACK);
-    const Move m34ke(Position(3,4), KNIGHT, BLACK);
+    const Move m23ky(Square(2,3), LANCE, BLACK);
+    const Move m34ke(Square(3,4), KNIGHT, BLACK);
     CPPUNIT_ASSERT(! moves.isMember(m23ky));
     CPPUNIT_ASSERT(! moves.isMember(m34ke));
   }
@@ -814,7 +814,7 @@ void QuiescenceGeneratorTest::testAttackSilverWithPawn()
 			   "+\n").getInitialState());
     MoveVector moves;
     QuiescenceGenerator<BLACK>::attackSilverWithPawn(state, PieceMask(), moves);
-    const Move m82to(Position(9,3), Position(8,2), PPAWN, PTYPE_EMPTY, false, BLACK);
+    const Move m82to(Square(9,3), Square(8,2), PPAWN, PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT(moves.isMember(m82to));
   }
 }
@@ -860,7 +860,7 @@ void QuiescenceGeneratorTest::testUtilizePromoted()
 			   "P-00KA\n"
 			   "+\n").getInitialState());
     MoveVector moves;
-    const Piece target = state.getPieceOnBoard(Position(7,3));
+    const Piece target = state.pieceOnBoard(Square(7,3));
     QuiescenceGenerator<BLACK>::utilizePromoted(state, target, moves);
     CPPUNIT_ASSERT_EQUAL((size_t)5, moves.size());
   }
@@ -879,7 +879,7 @@ void QuiescenceGeneratorTest::testUtilizePromoted()
 			   "P-00KA\n"
 			   "+\n").getInitialState());
     MoveVector moves;
-    const Piece target = state.getPieceOnBoard(Position(7,3));
+    const Piece target = state.pieceOnBoard(Square(7,3));
     QuiescenceGenerator<BLACK>::utilizePromoted(state, target, moves);
     CPPUNIT_ASSERT_EQUAL((size_t)1, moves.size());
   }
@@ -898,7 +898,7 @@ void QuiescenceGeneratorTest::testUtilizePromoted()
 			   "P-00KA\n"
 			   "+\n").getInitialState());
     MoveVector moves;
-    const Piece target = state.getPieceOnBoard(Position(7,3));
+    const Piece target = state.pieceOnBoard(Square(7,3));
     QuiescenceGenerator<BLACK>::utilizePromoted(state, target, moves);
     CPPUNIT_ASSERT_EQUAL((size_t)2, moves.size());
   }
@@ -921,7 +921,7 @@ void QuiescenceGeneratorTest::testEscapeByMoveOnly()
 			   "P-00KA00FU\n"
 			   "-\n").getInitialState());
     MoveVector moves;
-    const Piece target = state.getPieceOnBoard(Position(8,6));
+    const Piece target = state.pieceOnBoard(Square(8,6));
     const bool has_safe_move
       = QuiescenceGenerator<WHITE>::escapeByMoveOnly(state, target, moves);
     // 後ろに下がっても取られる
@@ -942,7 +942,7 @@ void QuiescenceGeneratorTest::testEscapeByMoveOnly()
 			   "P-00KA00FU\n"
 			   "-\n").getInitialState());
     MoveVector moves;
-    const Piece target = state.getPieceOnBoard(Position(8,6));
+    const Piece target = state.pieceOnBoard(Square(8,6));
     const bool has_safe_move
       = QuiescenceGenerator<WHITE>::escapeByMoveOnly(state, target, moves);
     // 後ろに下がれる
@@ -963,7 +963,7 @@ void QuiescenceGeneratorTest::testEscapeByMoveOnly()
 			   "P-00KA\n"
 			   "-\n").getInitialState());
     MoveVector moves;
-    const Piece target = state.getPieceOnBoard(Position(8,3));
+    const Piece target = state.pieceOnBoard(Square(8,3));
     const bool has_safe_move
       = QuiescenceGenerator<WHITE>::escapeByMoveOnly(state, target, moves);
     // 後ろに下がっても追撃される
@@ -984,7 +984,7 @@ void QuiescenceGeneratorTest::testEscapeByMoveOnly()
 			   "P-00KA\n"
 			   "-\n").getInitialState());
     MoveVector moves;
-    const Piece target = state.getPieceOnBoard(Position(8,3));
+    const Piece target = state.pieceOnBoard(Square(8,3));
     const bool has_safe_move
       = QuiescenceGenerator<WHITE>::escapeByMoveOnly(state, target, moves);
     // 横に二歩逃げられる
@@ -1009,7 +1009,7 @@ void QuiescenceGeneratorTest::testBreakThreatmate()
 			   "P-00GI00GI00KY00FU00FU00FU00FU00FU\n"
 			   "-\n").getInitialState());
     MoveVector moves;
-    const Move m33ke(Position(3,3), KNIGHT, BLACK);
+    const Move m33ke(Square(3,3), KNIGHT, BLACK);
     QuiescenceGenerator<WHITE>::breakThreatmate(state, m33ke, PieceMask(),
 						moves);
     CPPUNIT_ASSERT(! moves.empty());
@@ -1029,10 +1029,10 @@ void QuiescenceGeneratorTest::testBreakThreatmate()
 			   "P-00KE00FU00FU\n"
 			   "+\n").getInitialState());
     MoveVector moves;
-    const Move m88ki(Position(7,8), Position(8,8), GOLD, PTYPE_EMPTY, false, WHITE);
+    const Move m88ki(Square(7,8), Square(8,8), GOLD, PTYPE_EMPTY, false, WHITE);
     QuiescenceGenerator<BLACK>::breakThreatmate(state, m88ki, PieceMask(),
 						moves);
-    const Move m96fu(Position(9,7), Position(9,6), PAWN, PTYPE_EMPTY, false, BLACK);
+    const Move m96fu(Square(9,7), Square(9,6), PAWN, PTYPE_EMPTY, false, BLACK);
     
     CPPUNIT_ASSERT(moves.isMember(m96fu));
   }
