@@ -15,6 +15,7 @@
 
 #include <cppunit/TestCase.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <boost/progress.hpp>
 
 #include <fstream>
 #include <iostream>
@@ -72,7 +73,6 @@ using namespace osl;
 using namespace osl::search;
 using namespace osl::game_playing;
 using namespace osl::eval;
-extern bool isShortTest;
 
 const int Gold = PtypeEvalTraits<GOLD>::val;
 const int Silver = PtypeEvalTraits<SILVER>::val;
@@ -124,7 +124,7 @@ void QuiescenceSearchTest::test050313()
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
     const int result = searcher.search(WHITE, ev, 
-				       Move(Position(8,1),ROOK,BLACK));
+				       Move(Square(8,1),ROOK,BLACK));
     CPPUNIT_ASSERT(result < 1000000);
   }
   {
@@ -146,7 +146,7 @@ void QuiescenceSearchTest::test050313()
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
     const int result = searcher.search(WHITE, ev, 
-				       Move(Position(8,6),GOLD,BLACK));
+				       Move(Square(8,6),GOLD,BLACK));
     CPPUNIT_ASSERT(result < -5000000);
     CPPUNIT_ASSERT(searcher.nodeCount() < 5000); // 1手詰なんだけど...
   }
@@ -169,7 +169,7 @@ void QuiescenceSearchTest::test050313()
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
     const int result = searcher.search(BLACK, ev, 
-				       Move(Position(8,8),SILVER,WHITE));
+				       Move(Square(8,8),SILVER,WHITE));
     CPPUNIT_ASSERT(result < 0);
   }
 }
@@ -195,7 +195,7 @@ void QuiescenceSearchTest::testLose2()
   SimpleHashTable table(1000,-6);
   qsearch_t searcher(sstate, table);
   PieceEval ev(state);
-  const int result = searcher.search<BLACK>(ev, Move(Position(9,7),PAWN,WHITE));
+  const int result = searcher.search<BLACK>(ev, Move(Square(9,7),PAWN,WHITE));
   CPPUNIT_ASSERT(result < -100000);
 }
 
@@ -217,7 +217,7 @@ void QuiescenceSearchTest::testLose()
   SimpleHashTable table(0);
   qsearch_t searcher(sstate, table);
   PieceEval ev(state);
-  const int val1 = searcher.search(BLACK, ev, Move(Position(5,7),PAWN,WHITE));
+  const int val1 = searcher.search(BLACK, ev, Move(Square(5,7),PAWN,WHITE));
   // TODO: まだ必死は認識できない
   // CPPUNIT_ASSERT_EQUAL(FixedEval::winValue(WHITE), val1);
   // std::cerr << val1 << "\n";
@@ -241,7 +241,7 @@ void QuiescenceSearchTest::testForcedEscape()
   SimpleHashTable table(0);
   qsearch_t searcher(sstate, table);
   PieceEval ev(state);
-  const int val1 = searcher.search(BLACK, ev, Move(Position(5,7),PAWN,WHITE));
+  const int val1 = searcher.search(BLACK, ev, Move(Square(5,7),PAWN,WHITE));
   CPPUNIT_ASSERT(val1 <= -PtypeEvalTraits<KNIGHT>::val*2);
 }
 
@@ -265,7 +265,7 @@ void QuiescenceSearchTest::testKnightAttack()
     SimpleHashTable table(0);
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
-    const int val1 = searcher.search(BLACK, ev, Move(Position(3,4),KNIGHT,WHITE));
+    const int val1 = searcher.search(BLACK, ev, Move(Square(3,4),KNIGHT,WHITE));
     CPPUNIT_ASSERT(val1 > 0);
   }
   {
@@ -285,7 +285,7 @@ void QuiescenceSearchTest::testKnightAttack()
     SimpleHashTable table(0);
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
-    const int val1 = searcher.search(BLACK, ev, Move(Position(1,6),PAWN,WHITE));
+    const int val1 = searcher.search(BLACK, ev, Move(Square(1,6),PAWN,WHITE));
     CPPUNIT_ASSERT(val1 < 0);
   }
 #endif
@@ -310,7 +310,7 @@ void QuiescenceSearchTest::testNoCapture()
     SimpleHashTable table(0);
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
-    const int val1 = searcher.search(BLACK, ev, Move(Position(8,2),ROOK,WHITE));
+    const int val1 = searcher.search(BLACK, ev, Move(Square(8,2),ROOK,WHITE));
     CPPUNIT_ASSERT_EQUAL(0, val1);
   }
   {
@@ -329,7 +329,7 @@ void QuiescenceSearchTest::testNoCapture()
     SimpleHashTable table(0);
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
-    const int val1 = searcher.search(WHITE, ev, Move(Position(5,6),PAWN,BLACK));
+    const int val1 = searcher.search(WHITE, ev, Move(Square(5,6),PAWN,BLACK));
     CPPUNIT_ASSERT_EQUAL(0, val1);
   }
 }
@@ -353,7 +353,7 @@ void QuiescenceSearchTest::testCaptureBlack()
     SearchState2Core sstate(state1, checkmate_searcher);
     qsearch_t searcher1(sstate, table);
     PieceEval ev(state1);
-    const int val1 = searcher1.search(BLACK, ev, Move(Position(8,6),ROOK,WHITE));
+    const int val1 = searcher1.search(BLACK, ev, Move(Square(8,6),ROOK,WHITE));
     CPPUNIT_ASSERT_EQUAL(PtypeEvalTraits<ROOK>::val*2, val1);
   }
   {    
@@ -373,7 +373,7 @@ void QuiescenceSearchTest::testCaptureBlack()
     qsearch_t searcher2(sstate, table);
     PieceEval ev2(state2);
     const int val2 = searcher2.search(BLACK, ev2, 
-				      Move(Position(8,6),ROOK,WHITE));
+				      Move(Square(8,6),ROOK,WHITE));
     CPPUNIT_ASSERT_EQUAL(PtypeEvalTraits<BISHOP>::val*2, val2); //  + 脅威
   }
 }
@@ -397,7 +397,7 @@ void QuiescenceSearchTest::testCaptureWhite()
     SearchState2Core sstate(state1, checkmate_searcher);
     qsearch_t searcher1(sstate, table);
     PieceEval ev(state1);
-    const int val1 = searcher1.search(WHITE, ev, Move(Position(8,7),PAWN,BLACK));
+    const int val1 = searcher1.search(WHITE, ev, Move(Square(8,7),PAWN,BLACK));
     CPPUNIT_ASSERT_EQUAL(-PtypeEvalTraits<PROOK>::val
 			 -PtypeEvalTraits<PAWN>::val*2
 			 +PtypeEvalTraits<ROOK>::val,
@@ -419,7 +419,7 @@ void QuiescenceSearchTest::testCaptureWhite()
     SearchState2Core sstate(state2, checkmate_searcher);
     qsearch_t searcher2(sstate, table);
     PieceEval ev2(state2);
-    const int val2 = searcher2.search(WHITE, ev2, Move(Position(7,8),SILVER,BLACK));
+    const int val2 = searcher2.search(WHITE, ev2, Move(Square(7,8),SILVER,BLACK));
     CPPUNIT_ASSERT_EQUAL(0, val2); // 0 + 脅威
   }
 }
@@ -445,7 +445,7 @@ void QuiescenceSearchTest::testCaptureCheck()
     SearchState2Core sstate(state0, checkmate_searcher);
     qsearch_t searcher0(sstate, table);
     PieceEval ev0(state0);
-    const int val0 = searcher0.search(WHITE, ev0, Move(Position(3,2),SILVER,BLACK));
+    const int val0 = searcher0.search(WHITE, ev0, Move(Square(3,2),SILVER,BLACK));
     CPPUNIT_ASSERT_EQUAL(-Pawn*2+Psilver-Silver, val0);
   }
   {
@@ -466,7 +466,7 @@ void QuiescenceSearchTest::testCaptureCheck()
     CPPUNIT_ASSERT_EQUAL(0, PieceEval(state1).value());
     qsearch_t searcher1(sstate, table);
     PieceEval ev(state1);
-    const int val1 = searcher1.search(WHITE, ev, Move(Position(3,2),GOLD,BLACK));
+    const int val1 = searcher1.search(WHITE, ev, Move(Square(3,2),GOLD,BLACK));
     CPPUNIT_ASSERT_EQUAL(-PtypeEvalTraits<PAWN>::val*2, val1);
   }
   {
@@ -488,9 +488,9 @@ void QuiescenceSearchTest::testCaptureCheck()
     SearchState2Core sstate(state2, checkmate_searcher);
     qsearch_t searcher2(sstate, table);
     PieceEval ev(state2);
-    if (! isShortTest)
+    if (OslConfig::verbose())
       std::cerr << ev.value() << "\n";
-    const Move last_move = Move(Position(3,9),SILVER,WHITE);
+    const Move last_move = Move(Square(3,9),SILVER,WHITE);
     const int val2 = searcher2.search(BLACK, ev, last_move);
     const int val2n = searcher2.search<BLACK>(-899, -895, ev, last_move);
     CPPUNIT_ASSERT_EQUAL(val2, val2n);
@@ -513,10 +513,10 @@ void QuiescenceSearchTest::testCaptureCheck()
     SearchState2Core sstate(state3, checkmate_searcher);
     qsearch_t searcher3(sstate, table);
     PieceEval ev(state3);
-    if (! isShortTest)
+    if (OslConfig::verbose())
       std::cerr << ev.value() << "\n";
     // +2818OU -4938NG PASS
-    const Move last_move = Move(Position(3,9),BISHOP,WHITE);
+    const Move last_move = Move(Square(3,9),BISHOP,WHITE);
     const int val3  = searcher3.search(BLACK, ev, last_move);
     const int val3n = searcher3.search<BLACK>(val3-1, val3+1, 
 					      ev, last_move);
@@ -545,7 +545,7 @@ void QuiescenceSearchTest::testCaptureCheckMate()
     SearchState2Core sstate(state, checkmate_searcher);
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
-    const int val1 = searcher.search(BLACK, ev, Move(Position(2,3),PAWN,WHITE));
+    const int val1 = searcher.search(BLACK, ev, Move(Square(2,3),PAWN,WHITE));
     CPPUNIT_ASSERT_EQUAL(FixedEval::winByCheckmate(BLACK), val1);
   }
   {
@@ -564,7 +564,7 @@ void QuiescenceSearchTest::testCaptureCheckMate()
     SearchState2Core sstate(state, checkmate_searcher);
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
-    const int val1 = searcher.search(WHITE, ev, Move(Position(7,6),PAWN,BLACK));
+    const int val1 = searcher.search(WHITE, ev, Move(Square(7,6),PAWN,BLACK));
     CPPUNIT_ASSERT_EQUAL(Pawn*2, val1);
   }
   {
@@ -583,7 +583,7 @@ void QuiescenceSearchTest::testCaptureCheckMate()
     SearchState2Core sstate(state, checkmate_searcher);
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
-    const int val1 = searcher.search(WHITE, ev, Move(Position(7,6),PAWN,BLACK));
+    const int val1 = searcher.search(WHITE, ev, Move(Square(7,6),PAWN,BLACK));
     CPPUNIT_ASSERT_EQUAL(-PtypeEvalTraits<ROOK>::val*2, val1);
   }
   {
@@ -603,7 +603,7 @@ void QuiescenceSearchTest::testCaptureCheckMate()
     SearchState2Core sstate(state, checkmate_searcher);
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
-    const int val1 = searcher.search(WHITE, ev, Move(Position(8,2),GOLD,BLACK));
+    const int val1 = searcher.search(WHITE, ev, Move(Square(8,2),GOLD,BLACK));
     CPPUNIT_ASSERT_EQUAL(Pawn*2, val1);
   }
   {
@@ -627,7 +627,7 @@ void QuiescenceSearchTest::testCaptureCheckMate()
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
     const int val1 = searcher.search(WHITE, ev, 
-				     Move(Position(5,1),Position(4,1),
+				     Move(Square(5,1),Square(4,1),
 					     PKNIGHT,PTYPE_EMPTY,false,BLACK));
     CPPUNIT_ASSERT(eval::isConsistentValueForNormalState<PieceEval>(val1));
     CPPUNIT_ASSERT(! FixedEval::isWinValue(BLACK, val1));
@@ -648,7 +648,7 @@ void QuiescenceSearchTest::testIsEvalValueConsistent(std::string const& fileName
 
   PieceEval ev(sstate);
   GameState state(sstate);
-  SimpleHashTable table(400000,-8,!isShortTest);
+  SimpleHashTable table(400000,-8,OslConfig::verbose());
   SimpleHashTable null_table(400000,100,false);
   const int black_win = search::FixedEval::winByLoop(BLACK);
   const int white_win = search::FixedEval::winByLoop(WHITE);
@@ -672,12 +672,12 @@ void QuiescenceSearchTest::testIsEvalValueConsistent(std::string const& fileName
       qsearch_t qs_null(sstate0, null_table);
       qsearch_t qs(sstate1, table);
       const Move last_move = moves[i-1];
-      const int val_null = qs_null.search(state0.getTurn(), ev, last_move, 6);
-      const int val = qs.searchIteratively(state1.getTurn(), ev, last_move, 6);
+      const int val_null = qs_null.search(state0.turn(), ev, last_move, 6);
+      const int val = qs.searchIteratively(state1.turn(), ev, last_move, 6);
       node_count += qs.nodeCount() + qs_null.nodeCount();
-      if (abs(val_null - val) > 1000)
+      if (abs(val_null - val) > 10000)
       {
-	if (! isShortTest)
+	if (OslConfig::verbose())
 	  std::cerr << fileName << " " << i << "\n" << state0
 		    << "\n" << ev.value() << " " << val_null << " " << val << "\n";
 	++error_count;
@@ -685,7 +685,7 @@ void QuiescenceSearchTest::testIsEvalValueConsistent(std::string const& fileName
     
       CPPUNIT_ASSERT(isConsistentValue(val));
       
-      if (isShortTest)		// 最近はかなり異なる
+      if (OslConfig::inUnitTestShort())		// 最近はかなり異なる
 	CPPUNIT_ASSERT(error_count < 50);
       // CPPUNIT_ASSERT_EQUAL(val_null, val);
       CPPUNIT_ASSERT(state0.isConsistent(true));
@@ -696,7 +696,7 @@ void QuiescenceSearchTest::testIsEvalValueConsistent(std::string const& fileName
     state.pushMove(move);
     ev.update(state.state(), move);
   }
-  if (! isShortTest)
+  if (OslConfig::verbose())
   {
     std::cerr << node_count << " " << (MilliSeconds::now() - started).toSeconds() << "\n";
   }
@@ -706,8 +706,14 @@ void QuiescenceSearchTest::testEquality()
 {
   std::ifstream ifs(OslConfig::testCsaFile("FILES"));
   CPPUNIT_ASSERT(ifs);
+  const int count = (OslConfig::inUnitTestShort() ? 10: 100);
+  boost::scoped_ptr<boost::progress_display> progress;
+  if (OslConfig::inUnitTestLong() && !OslConfig::verbose())
+    progress.reset(new boost::progress_display(count, std::cerr));
   std::string file_name;
-  for (int i=0; i<(isShortTest ? 10: 100) && (ifs >> file_name); i++){
+  for (int i=0; i<count && (ifs >> file_name); i++){
+    if (progress)
+      ++(*progress);
     if (file_name == "") 
       break;
     testIsEvalValueConsistent(OslConfig::testCsaFile(file_name));
@@ -736,7 +742,7 @@ void QuiescenceSearchTest::testTakeBack()
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
     const int value = searcher.takeBackValue<WHITE>
-      (1001, -1001, ev, Move(Position(2,6),PAWN,BLACK));
+      (1001, -1001, ev, Move(Square(2,6),PAWN,BLACK));
     CPPUNIT_ASSERT_EQUAL(0, value);
   }
   {
@@ -756,7 +762,7 @@ void QuiescenceSearchTest::testTakeBack()
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
     const int value = searcher.takeBackValue<WHITE>
-      (1001, -1001, ev, Move(Position(2,4),PAWN,BLACK));
+      (1001, -1001, ev, Move(Square(2,4),PAWN,BLACK));
     CPPUNIT_ASSERT_EQUAL(0, value);
   }
   {
@@ -776,7 +782,7 @@ void QuiescenceSearchTest::testTakeBack()
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
     const int value = searcher.takeBackValue<WHITE>
-      (1001, -1001, ev, Move(Position(2,4),PAWN,BLACK));
+      (1001, -1001, ev, Move(Square(2,4),PAWN,BLACK));
     CPPUNIT_ASSERT_EQUAL(-Pawn*2, value);
   }
   {
@@ -796,7 +802,7 @@ void QuiescenceSearchTest::testTakeBack()
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
     const int value = searcher.takeBackValue<BLACK>
-      (-1001, 1001, ev, Move(Position(4,7),KNIGHT,WHITE));
+      (-1001, 1001, ev, Move(Square(4,7),KNIGHT,WHITE));
     CPPUNIT_ASSERT_EQUAL(0, value);
   }
   {				// 詰
@@ -819,7 +825,7 @@ void QuiescenceSearchTest::testTakeBack()
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
     const int value = searcher.takeBackValue<BLACK>
-      (-10001,+10001,ev,Move(Position(3,8),Position(3,7),PSILVER,GOLD,false,WHITE));
+      (-10001,+10001,ev,Move(Square(3,8),Square(3,7),PSILVER,GOLD,false,WHITE));
     CPPUNIT_ASSERT_EQUAL(FixedEval::winByCheckmate(WHITE), value);
   }
 }
@@ -973,7 +979,7 @@ bool QuiescenceSearchTest::betterThan(const char *l, const char *r)
   osl::search::SearchState2::checkmate_t checkmate_searcher;
   state_t state_l(CsaString(l).getInitialState());
   state_t state_r(CsaString(r).getInitialState());
-  assert(state_l.getTurn() == state_r.getTurn());
+  assert(state_l.turn() == state_r.turn());
   SimpleHashTable table(1000);
   int value_l, value_r;
   {
@@ -997,7 +1003,7 @@ bool QuiescenceSearchTest::betterThan(const char *l, const char *r)
     PieceEval ev(state_r);
     value_r = searcher.staticValueWithThreat(ev);
   }
-  return eval::betterThan(state_l.getTurn(), value_l, value_r);
+  return eval::betterThan(state_l.turn(), value_l, value_r);
 }
 
 void QuiescenceSearchTest::testCompare()
@@ -1138,7 +1144,7 @@ void QuiescenceSearchTest::testFocalPawn()
     SimpleHashTable table(10000,-6);
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
-    const Move m24fu(Position(2,5),Position(2,4),PAWN,PTYPE_EMPTY,false,BLACK);
+    const Move m24fu(Square(2,5),Square(2,4),PAWN,PTYPE_EMPTY,false,BLACK);
     const int val = searcher.search(WHITE, ev, m24fu);
     CPPUNIT_ASSERT(val > 0);	// 先手有利!
   }
@@ -1160,7 +1166,7 @@ void QuiescenceSearchTest::testFocalPawn()
     SimpleHashTable table(10000,-6);
     qsearch_t searcher(sstate, table);
     PieceEval ev(state);
-    const Move m24fu(Position(2,5),Position(2,4),PAWN,PTYPE_EMPTY,false,BLACK);
+    const Move m24fu(Square(2,5),Square(2,4),PAWN,PTYPE_EMPTY,false,BLACK);
     const int val = searcher.search(WHITE, ev, m24fu);
     CPPUNIT_ASSERT(val > 0);	// 先手有利!
   }
