@@ -19,18 +19,17 @@ using namespace osl;
 
 void SearchRecorderTest::testWrite()
 {
-  extern bool isShortTest;
-  const bool verbose = ! isShortTest;
+  const bool verbose = OslConfig::verbose();
 
   SearchRecorder recorder("SearchRecorderTest.log");
-  MoveLogProb m(Move(Position(6,5),Position(2,1),PBISHOP,KNIGHT,true,BLACK),
+  MoveLogProb m(Move(Square(6,5),Square(2,1),PBISHOP,KNIGHT,true,BLACK),
 		7777777);
   recorder.tryMove(m, 111, 11111);
   recorder.recordValue(m, 222, true, 22222);
   recorder.recordTopLevelLowFail(m, 333);
   recorder.recordTopLevelHighFail(m, 444);
   recorder.startSearch(555);
-  recorder.finishSearch(m.getMove(), 1.0, verbose);
+  recorder.finishSearch(m.move(), 1.0, verbose);
 }
 
 // ;;; Local Variables:
