@@ -13,8 +13,8 @@ class ShouldPromoteCutTest : public CppUnit::TestFixture
   CPPUNIT_TEST_SUITE_END();
 public:
   void testPlayer() {
-    const Position p39(3,9);
-    const Position p66(6,6);
+    const Square p39(3,9);
+    const Square p66(6,6);
 
     // WHITE
     const Move w3966ump(p39,p66,PBISHOP,PTYPE_EMPTY,true,WHITE);
