@@ -51,6 +51,7 @@ class EffectTest : public CppUnit::TestFixture
   CPPUNIT_TEST(testCountEffect2);
   CPPUNIT_TEST(testCountEffect);
   CPPUNIT_TEST(testCountEffectPin);
+  CPPUNIT_TEST(testPinAttacker);
   CPPUNIT_TEST(testKingCanBeCaptured);
 
   CPPUNIT_TEST(testCsaFiles);
@@ -97,6 +98,7 @@ public:
   void testCountEffect2();
   void testCountEffect();
   void testCountEffectPin();
+  void testPinAttacker();
   void testKingCanBeCaptured();
   void testCsaFiles();
 
@@ -775,6 +777,34 @@ void EffectTest::testCountEffectPin()
   CPPUNIT_ASSERT_EQUAL(1, ne_state.countEffect(BLACK, Square(7,7), pin));
 }
 
+void EffectTest::testPinAttacker()
+{
+  NumEffectState state=CsaString(
+    "P1-KY * -KI * -KE *  *  * +RY\n"
+    "P2 * -OU * -GI+GI *  *  *  * \n"
+    "P3 * -GI * -KI *  *  *  *  * \n"
+    "P4-FU+KE-FU-FU-FU *  *  * -FU\n"
+    "P5 * -FU *  *  * +FU *  *  * \n"
+    "P6+FU * +FU+FU+FU+KA *  * +FU\n"
+    "P7 * +FU *  *  * +GI *  *  * \n"
+    "P8 * +OU+KI-RY *  * +FU *  * \n"
+    "P9+KY *  *  *  *  *  *  * +KY\n"
+    "P+00KA00KE00KY00FU00FU00FU\n"
+    "P-00KI00KE00FU\n"
+    "-\n").getInitialState();
+  state_t ne_state(state);
+  {
+    Piece p=ne_state.pieceAt(Square(6,4));
+    Piece attacker=ne_state.pinAttacker(p);
+    CPPUNIT_ASSERT_EQUAL(Square(4,6),attacker.square());
+  }
+  {
+    Piece p=ne_state.pieceAt(Square(7,8));
+    Piece attacker=ne_state.pinAttacker(p);
+    CPPUNIT_ASSERT_EQUAL(Square(6,8),attacker.square());
+  }
+}
+
 void EffectTest::testKingCanBeCaptured()
 {
   NumEffectState state=CsaString(
