@@ -10,11 +10,11 @@
 // No need to include header files of every test classes.
 // Instead, place CPPUNIT_TEST_SUITE_REGISTRATION(fooTest); in each fooTest.cc
 
-bool isShortTest=true;
 int main(int /* argc */, char ** /* argv */)
 {
   nice(20);
-  osl::OslConfig::setVerbose(true);
+  osl::OslConfig::setInUnitTest(1);
+  osl::OslConfig::setVerbose(false);
   osl::OslConfig::showOslHome();
   
   CppUnit::TextUi::TestRunner runner;
