@@ -7,18 +7,17 @@
 #include <iostream>
 #include <unistd.h>
 
-bool isShortTest=false;
 int main(int argc, char **argv)
 {
   // extern char *optarg;
   extern int optind;
-  bool error_flag = false;
+  bool error_flag = false, is_short_test = false;
   char c;
   while ((c = getopt(argc, argv, "s")) != EOF)
   {
     switch (c)
     {
-    case 's':	isShortTest = true;
+    case 's':	is_short_test = true;
       break;
     default:	error_flag = true;
     }
@@ -31,6 +30,7 @@ int main(int argc, char **argv)
     return 1;
   } 
 
+  osl::OslConfig::setInUnitTest(is_short_test ? 1 : 2);
   osl::OslConfig::setVerbose(true);
   osl::OslConfig::showOslHome();
   
